// Generated by dts-bundle-generator v9.5.1

export declare const $Port: {
	readonly type: "object";
	readonly description: "An open port on a container";
	readonly required: readonly [
		"PrivatePort",
		"Type"
	];
	readonly properties: {
		readonly IP: {
			readonly type: "string";
			readonly format: "ip-address";
			readonly description: "Host IP address that the container's port is mapped to";
		};
		readonly PrivatePort: {
			readonly type: "integer";
			readonly format: "uint16";
			readonly "x-nullable": false;
			readonly description: "Port on the container";
		};
		readonly PublicPort: {
			readonly type: "integer";
			readonly format: "uint16";
			readonly description: "Port exposed on the host";
		};
		readonly Type: {
			readonly type: "string";
			readonly "x-nullable": false;
			readonly enum: readonly [
				"tcp",
				"udp",
				"sctp"
			];
		};
	};
	readonly example: {
		readonly PrivatePort: 8080;
		readonly PublicPort: 80;
		readonly Type: "tcp";
	};
};
export declare const $MountPoint: {
	readonly type: "object";
	readonly description: "MountPoint represents a mount point configuration inside the container.\nThis is used for reporting the mountpoints in use by a container.\n";
	readonly properties: {
		readonly Type: {
			readonly description: "The mount type:\n\n- `bind` a mount of a file or directory from the host into the container.\n- `volume` a docker volume with the given `Name`.\n- `tmpfs` a `tmpfs`.\n- `npipe` a named pipe from the host into the container.\n- `cluster` a Swarm cluster volume\n";
			readonly type: "string";
			readonly enum: readonly [
				"bind",
				"volume",
				"tmpfs",
				"npipe",
				"cluster"
			];
			readonly example: "volume";
		};
		readonly Name: {
			readonly description: "Name is the name reference to the underlying data defined by `Source`\ne.g., the volume name.\n";
			readonly type: "string";
			readonly example: "myvolume";
		};
		readonly Source: {
			readonly description: "Source location of the mount.\n\nFor volumes, this contains the storage location of the volume (within\n`/var/lib/docker/volumes/`). For bind-mounts, and `npipe`, this contains\nthe source (host) part of the bind-mount. For `tmpfs` mount points, this\nfield is empty.\n";
			readonly type: "string";
			readonly example: "/var/lib/docker/volumes/myvolume/_data";
		};
		readonly Destination: {
			readonly description: "Destination is the path relative to the container root (`/`) where\nthe `Source` is mounted inside the container.\n";
			readonly type: "string";
			readonly example: "/usr/share/nginx/html/";
		};
		readonly Driver: {
			readonly description: "Driver is the volume driver used to create the volume (if it is a volume).\n";
			readonly type: "string";
			readonly example: "local";
		};
		readonly Mode: {
			readonly description: "Mode is a comma separated list of options supplied by the user when\ncreating the bind/volume mount.\n\nThe default is platform-specific (`\"z\"` on Linux, empty on Windows).\n";
			readonly type: "string";
			readonly example: "z";
		};
		readonly RW: {
			readonly description: "Whether the mount is mounted writable (read-write).\n";
			readonly type: "boolean";
			readonly example: true;
		};
		readonly Propagation: {
			readonly description: "Propagation describes how mounts are propagated from the host into the\nmount point, and vice-versa. Refer to the [Linux kernel documentation](https://www.kernel.org/doc/Documentation/filesystems/sharedsubtree.txt)\nfor details. This field is not used on Windows.\n";
			readonly type: "string";
			readonly example: "";
		};
	};
};
export declare const $DeviceMapping: {
	readonly type: "object";
	readonly description: "A device mapping between the host and container";
	readonly properties: {
		readonly PathOnHost: {
			readonly type: "string";
		};
		readonly PathInContainer: {
			readonly type: "string";
		};
		readonly CgroupPermissions: {
			readonly type: "string";
		};
	};
	readonly example: {
		readonly PathOnHost: "/dev/deviceName";
		readonly PathInContainer: "/dev/deviceName";
		readonly CgroupPermissions: "mrw";
	};
};
export declare const $DeviceRequest: {
	readonly type: "object";
	readonly description: "A request for devices to be sent to device drivers";
	readonly properties: {
		readonly Driver: {
			readonly type: "string";
			readonly example: "nvidia";
		};
		readonly Count: {
			readonly type: "integer";
			readonly example: -1;
		};
		readonly DeviceIDs: {
			readonly type: "array";
			readonly items: {
				readonly type: "string";
			};
			readonly example: readonly [
				"0",
				"1",
				"GPU-fef8089b-4820-abfc-e83e-94318197576e"
			];
		};
		readonly Capabilities: {
			readonly description: "A list of capabilities; an OR list of AND lists of capabilities.\n";
			readonly type: "array";
			readonly items: {
				readonly type: "array";
				readonly items: {
					readonly type: "string";
				};
			};
			readonly example: readonly [
				readonly [
					"gpu",
					"nvidia",
					"compute"
				]
			];
		};
		readonly Options: {
			readonly description: "Driver-specific options, specified as a key/value pairs. These options\nare passed directly to the driver.\n";
			readonly type: "object";
			readonly additionalProperties: {
				readonly type: "string";
			};
		};
	};
};
export declare const $ThrottleDevice: {
	readonly type: "object";
	readonly properties: {
		readonly Path: {
			readonly description: "Device path";
			readonly type: "string";
		};
		readonly Rate: {
			readonly description: "Rate";
			readonly type: "integer";
			readonly format: "int64";
			readonly minimum: 0;
		};
	};
};
export declare const $Mount: {
	readonly type: "object";
	readonly properties: {
		readonly Target: {
			readonly description: "Container path.";
			readonly type: "string";
		};
		readonly Source: {
			readonly description: "Mount source (e.g. a volume name, a host path).";
			readonly type: "string";
		};
		readonly Type: {
			readonly description: "The mount type. Available types:\n\n- `bind` Mounts a file or directory from the host into the container. Must exist prior to creating the container.\n- `volume` Creates a volume with the given name and options (or uses a pre-existing volume with the same name and options). These are **not** removed when the container is removed.\n- `tmpfs` Create a tmpfs with the given options. The mount source cannot be specified for tmpfs.\n- `npipe` Mounts a named pipe from the host into the container. Must exist prior to creating the container.\n- `cluster` a Swarm cluster volume\n";
			readonly type: "string";
			readonly enum: readonly [
				"bind",
				"volume",
				"tmpfs",
				"npipe",
				"cluster"
			];
		};
		readonly ReadOnly: {
			readonly description: "Whether the mount should be read-only.";
			readonly type: "boolean";
		};
		readonly Consistency: {
			readonly description: "The consistency requirement for the mount: `default`, `consistent`, `cached`, or `delegated`.";
			readonly type: "string";
		};
		readonly BindOptions: {
			readonly description: "Optional configuration for the `bind` type.";
			readonly type: "object";
			readonly properties: {
				readonly Propagation: {
					readonly description: "A propagation mode with the value `[r]private`, `[r]shared`, or `[r]slave`.";
					readonly type: "string";
					readonly enum: readonly [
						"private",
						"rprivate",
						"shared",
						"rshared",
						"slave",
						"rslave"
					];
				};
				readonly NonRecursive: {
					readonly description: "Disable recursive bind mount.";
					readonly type: "boolean";
					readonly default: false;
				};
				readonly CreateMountpoint: {
					readonly description: "Create mount point on host if missing";
					readonly type: "boolean";
					readonly default: false;
				};
				readonly ReadOnlyNonRecursive: {
					readonly description: "Make the mount non-recursively read-only, but still leave the mount recursive\n(unless NonRecursive is set to `true` in conjunction).\n\nAddded in v1.44, before that version all read-only mounts were\nnon-recursive by default. To match the previous behaviour this\nwill default to `true` for clients on versions prior to v1.44.\n";
					readonly type: "boolean";
					readonly default: false;
				};
				readonly ReadOnlyForceRecursive: {
					readonly description: "Raise an error if the mount cannot be made recursively read-only.";
					readonly type: "boolean";
					readonly default: false;
				};
			};
		};
		readonly VolumeOptions: {
			readonly description: "Optional configuration for the `volume` type.";
			readonly type: "object";
			readonly properties: {
				readonly NoCopy: {
					readonly description: "Populate volume with data from the target.";
					readonly type: "boolean";
					readonly default: false;
				};
				readonly Labels: {
					readonly description: "User-defined key/value metadata.";
					readonly type: "object";
					readonly additionalProperties: {
						readonly type: "string";
					};
				};
				readonly DriverConfig: {
					readonly description: "Map of driver specific options";
					readonly type: "object";
					readonly properties: {
						readonly Name: {
							readonly description: "Name of the driver to use to create the volume.";
							readonly type: "string";
						};
						readonly Options: {
							readonly description: "key/value map of driver specific options.";
							readonly type: "object";
							readonly additionalProperties: {
								readonly type: "string";
							};
						};
					};
				};
				readonly Subpath: {
					readonly description: "Source path inside the volume. Must be relative without any back traversals.";
					readonly type: "string";
					readonly example: "dir-inside-volume/subdirectory";
				};
			};
		};
		readonly TmpfsOptions: {
			readonly description: "Optional configuration for the `tmpfs` type.";
			readonly type: "object";
			readonly properties: {
				readonly SizeBytes: {
					readonly description: "The size for the tmpfs mount in bytes.";
					readonly type: "integer";
					readonly format: "int64";
				};
				readonly Mode: {
					readonly description: "The permission mode for the tmpfs mount in an integer.";
					readonly type: "integer";
				};
			};
		};
	};
};
export declare const $RestartPolicy: {
	readonly description: "The behavior to apply when the container exits. The default is not to\nrestart.\n\nAn ever increasing delay (double the previous delay, starting at 100ms) is\nadded before each restart to prevent flooding the server.\n";
	readonly type: "object";
	readonly properties: {
		readonly Name: {
			readonly type: "string";
			readonly description: "- Empty string means not to restart\n- `no` Do not automatically restart\n- `always` Always restart\n- `unless-stopped` Restart always except when the user has manually stopped the container\n- `on-failure` Restart only when the container exit code is non-zero\n";
			readonly enum: readonly [
				"",
				"no",
				"always",
				"unless-stopped",
				"on-failure"
			];
		};
		readonly MaximumRetryCount: {
			readonly type: "integer";
			readonly description: "If `on-failure` is used, the number of times to retry before giving up.\n";
		};
	};
};
export declare const $Resources: {
	readonly description: "A container's resources (cgroups config, ulimits, etc)";
	readonly type: "object";
	readonly properties: {
		readonly CpuShares: {
			readonly description: "An integer value representing this container's relative CPU weight\nversus other containers.\n";
			readonly type: "integer";
		};
		readonly Memory: {
			readonly description: "Memory limit in bytes.";
			readonly type: "integer";
			readonly format: "int64";
			readonly default: 0;
		};
		readonly CgroupParent: {
			readonly description: "Path to `cgroups` under which the container's `cgroup` is created. If\nthe path is not absolute, the path is considered to be relative to the\n`cgroups` path of the init process. Cgroups are created if they do not\nalready exist.\n";
			readonly type: "string";
		};
		readonly BlkioWeight: {
			readonly description: "Block IO weight (relative weight).";
			readonly type: "integer";
			readonly minimum: 0;
			readonly maximum: 1000;
		};
		readonly BlkioWeightDevice: {
			readonly description: "Block IO weight (relative device weight) in the form:\n\n```\n[{\"Path\": \"device_path\", \"Weight\": weight}]\n```\n";
			readonly type: "array";
			readonly items: {
				readonly type: "object";
				readonly properties: {
					readonly Path: {
						readonly type: "string";
					};
					readonly Weight: {
						readonly type: "integer";
						readonly minimum: 0;
					};
				};
			};
		};
		readonly BlkioDeviceReadBps: {
			readonly description: "Limit read rate (bytes per second) from a device, in the form:\n\n```\n[{\"Path\": \"device_path\", \"Rate\": rate}]\n```\n";
			readonly type: "array";
			readonly items: {
				readonly $ref: "#/definitions/ThrottleDevice";
			};
		};
		readonly BlkioDeviceWriteBps: {
			readonly description: "Limit write rate (bytes per second) to a device, in the form:\n\n```\n[{\"Path\": \"device_path\", \"Rate\": rate}]\n```\n";
			readonly type: "array";
			readonly items: {
				readonly $ref: "#/definitions/ThrottleDevice";
			};
		};
		readonly BlkioDeviceReadIOps: {
			readonly description: "Limit read rate (IO per second) from a device, in the form:\n\n```\n[{\"Path\": \"device_path\", \"Rate\": rate}]\n```\n";
			readonly type: "array";
			readonly items: {
				readonly $ref: "#/definitions/ThrottleDevice";
			};
		};
		readonly BlkioDeviceWriteIOps: {
			readonly description: "Limit write rate (IO per second) to a device, in the form:\n\n```\n[{\"Path\": \"device_path\", \"Rate\": rate}]\n```\n";
			readonly type: "array";
			readonly items: {
				readonly $ref: "#/definitions/ThrottleDevice";
			};
		};
		readonly CpuPeriod: {
			readonly description: "The length of a CPU period in microseconds.";
			readonly type: "integer";
			readonly format: "int64";
		};
		readonly CpuQuota: {
			readonly description: "Microseconds of CPU time that the container can get in a CPU period.\n";
			readonly type: "integer";
			readonly format: "int64";
		};
		readonly CpuRealtimePeriod: {
			readonly description: "The length of a CPU real-time period in microseconds. Set to 0 to\nallocate no time allocated to real-time tasks.\n";
			readonly type: "integer";
			readonly format: "int64";
		};
		readonly CpuRealtimeRuntime: {
			readonly description: "The length of a CPU real-time runtime in microseconds. Set to 0 to\nallocate no time allocated to real-time tasks.\n";
			readonly type: "integer";
			readonly format: "int64";
		};
		readonly CpusetCpus: {
			readonly description: "CPUs in which to allow execution (e.g., `0-3`, `0,1`).\n";
			readonly type: "string";
			readonly example: "0-3";
		};
		readonly CpusetMems: {
			readonly description: "Memory nodes (MEMs) in which to allow execution (0-3, 0,1). Only\neffective on NUMA systems.\n";
			readonly type: "string";
		};
		readonly Devices: {
			readonly description: "A list of devices to add to the container.";
			readonly type: "array";
			readonly items: {
				readonly $ref: "#/definitions/DeviceMapping";
			};
		};
		readonly DeviceCgroupRules: {
			readonly description: "a list of cgroup rules to apply to the container";
			readonly type: "array";
			readonly items: {
				readonly type: "string";
				readonly example: "c 13:* rwm";
			};
		};
		readonly DeviceRequests: {
			readonly description: "A list of requests for devices to be sent to device drivers.\n";
			readonly type: "array";
			readonly items: {
				readonly $ref: "#/definitions/DeviceRequest";
			};
		};
		readonly KernelMemoryTCP: {
			readonly description: "Hard limit for kernel TCP buffer memory (in bytes). Depending on the\nOCI runtime in use, this option may be ignored. It is no longer supported\nby the default (runc) runtime.\n\nThis field is omitted when empty.\n";
			readonly type: "integer";
			readonly format: "int64";
		};
		readonly MemoryReservation: {
			readonly description: "Memory soft limit in bytes.";
			readonly type: "integer";
			readonly format: "int64";
		};
		readonly MemorySwap: {
			readonly description: "Total memory limit (memory + swap). Set as `-1` to enable unlimited\nswap.\n";
			readonly type: "integer";
			readonly format: "int64";
		};
		readonly MemorySwappiness: {
			readonly description: "Tune a container's memory swappiness behavior. Accepts an integer\nbetween 0 and 100.\n";
			readonly type: "integer";
			readonly format: "int64";
			readonly minimum: 0;
			readonly maximum: 100;
		};
		readonly NanoCpus: {
			readonly description: "CPU quota in units of 10<sup>-9</sup> CPUs.";
			readonly type: "integer";
			readonly format: "int64";
		};
		readonly OomKillDisable: {
			readonly description: "Disable OOM Killer for the container.";
			readonly type: "boolean";
		};
		readonly Init: {
			readonly description: "Run an init inside the container that forwards signals and reaps\nprocesses. This field is omitted if empty, and the default (as\nconfigured on the daemon) is used.\n";
			readonly type: "boolean";
			readonly "x-nullable": true;
		};
		readonly PidsLimit: {
			readonly description: "Tune a container's PIDs limit. Set `0` or `-1` for unlimited, or `null`\nto not change.\n";
			readonly type: "integer";
			readonly format: "int64";
			readonly "x-nullable": true;
		};
		readonly Ulimits: {
			readonly description: "A list of resource limits to set in the container. For example:\n\n```\n{\"Name\": \"nofile\", \"Soft\": 1024, \"Hard\": 2048}\n```\n";
			readonly type: "array";
			readonly items: {
				readonly type: "object";
				readonly properties: {
					readonly Name: {
						readonly description: "Name of ulimit";
						readonly type: "string";
					};
					readonly Soft: {
						readonly description: "Soft limit";
						readonly type: "integer";
					};
					readonly Hard: {
						readonly description: "Hard limit";
						readonly type: "integer";
					};
				};
			};
		};
		readonly CpuCount: {
			readonly description: "The number of usable CPUs (Windows only).\n\nOn Windows Server containers, the processor resource controls are\nmutually exclusive. The order of precedence is `CPUCount` first, then\n`CPUShares`, and `CPUPercent` last.\n";
			readonly type: "integer";
			readonly format: "int64";
		};
		readonly CpuPercent: {
			readonly description: "The usable percentage of the available CPUs (Windows only).\n\nOn Windows Server containers, the processor resource controls are\nmutually exclusive. The order of precedence is `CPUCount` first, then\n`CPUShares`, and `CPUPercent` last.\n";
			readonly type: "integer";
			readonly format: "int64";
		};
		readonly IOMaximumIOps: {
			readonly description: "Maximum IOps for the container system drive (Windows only)";
			readonly type: "integer";
			readonly format: "int64";
		};
		readonly IOMaximumBandwidth: {
			readonly description: "Maximum IO in bytes per second for the container system drive\n(Windows only).\n";
			readonly type: "integer";
			readonly format: "int64";
		};
	};
};
export declare const $Limit: {
	readonly description: "An object describing a limit on resources which can be requested by a task.\n";
	readonly type: "object";
	readonly properties: {
		readonly NanoCPUs: {
			readonly type: "integer";
			readonly format: "int64";
			readonly example: 4000000000;
		};
		readonly MemoryBytes: {
			readonly type: "integer";
			readonly format: "int64";
			readonly example: 8272408576;
		};
		readonly Pids: {
			readonly description: "Limits the maximum number of PIDs in the container. Set `0` for unlimited.\n";
			readonly type: "integer";
			readonly format: "int64";
			readonly default: 0;
			readonly example: 100;
		};
	};
};
export declare const $ResourceObject: {
	readonly description: "An object describing the resources which can be advertised by a node and\nrequested by a task.\n";
	readonly type: "object";
	readonly properties: {
		readonly NanoCPUs: {
			readonly type: "integer";
			readonly format: "int64";
			readonly example: 4000000000;
		};
		readonly MemoryBytes: {
			readonly type: "integer";
			readonly format: "int64";
			readonly example: 8272408576;
		};
		readonly GenericResources: {
			readonly $ref: "#/definitions/GenericResources";
		};
	};
};
export declare const $GenericResources: {
	readonly description: "User-defined resources can be either Integer resources (e.g, `SSD=3`) or\nString resources (e.g, `GPU=UUID1`).\n";
	readonly type: "array";
	readonly items: {
		readonly type: "object";
		readonly properties: {
			readonly NamedResourceSpec: {
				readonly type: "object";
				readonly properties: {
					readonly Kind: {
						readonly type: "string";
					};
					readonly Value: {
						readonly type: "string";
					};
				};
			};
			readonly DiscreteResourceSpec: {
				readonly type: "object";
				readonly properties: {
					readonly Kind: {
						readonly type: "string";
					};
					readonly Value: {
						readonly type: "integer";
						readonly format: "int64";
					};
				};
			};
		};
	};
	readonly example: readonly [
		{
			readonly DiscreteResourceSpec: {
				readonly Kind: "SSD";
				readonly Value: 3;
			};
		},
		{
			readonly NamedResourceSpec: {
				readonly Kind: "GPU";
				readonly Value: "UUID1";
			};
		},
		{
			readonly NamedResourceSpec: {
				readonly Kind: "GPU";
				readonly Value: "UUID2";
			};
		}
	];
};
export declare const $HealthConfig: {
	readonly description: "A test to perform to check that the container is healthy.";
	readonly type: "object";
	readonly properties: {
		readonly Test: {
			readonly description: "The test to perform. Possible values are:\n\n- `[]` inherit healthcheck from image or parent image\n- `[\"NONE\"]` disable healthcheck\n- `[\"CMD\", args...]` exec arguments directly\n- `[\"CMD-SHELL\", command]` run command with system's default shell\n";
			readonly type: "array";
			readonly items: {
				readonly type: "string";
			};
		};
		readonly Interval: {
			readonly description: "The time to wait between checks in nanoseconds. It should be 0 or at\nleast 1000000 (1 ms). 0 means inherit.\n";
			readonly type: "integer";
			readonly format: "int64";
		};
		readonly Timeout: {
			readonly description: "The time to wait before considering the check to have hung. It should\nbe 0 or at least 1000000 (1 ms). 0 means inherit.\n";
			readonly type: "integer";
			readonly format: "int64";
		};
		readonly Retries: {
			readonly description: "The number of consecutive failures needed to consider a container as\nunhealthy. 0 means inherit.\n";
			readonly type: "integer";
		};
		readonly StartPeriod: {
			readonly description: "Start period for the container to initialize before starting\nhealth-retries countdown in nanoseconds. It should be 0 or at least\n1000000 (1 ms). 0 means inherit.\n";
			readonly type: "integer";
			readonly format: "int64";
		};
		readonly StartInterval: {
			readonly description: "The time to wait between checks in nanoseconds during the start period.\nIt should be 0 or at least 1000000 (1 ms). 0 means inherit.\n";
			readonly type: "integer";
			readonly format: "int64";
		};
	};
};
export declare const $Health: {
	readonly description: "Health stores information about the container's healthcheck results.\n";
	readonly type: "object";
	readonly "x-nullable": true;
	readonly properties: {
		readonly Status: {
			readonly description: "Status is one of `none`, `starting`, `healthy` or `unhealthy`\n\n- \"none\"      Indicates there is no healthcheck\n- \"starting\"  Starting indicates that the container is not yet ready\n- \"healthy\"   Healthy indicates that the container is running correctly\n- \"unhealthy\" Unhealthy indicates that the container has a problem\n";
			readonly type: "string";
			readonly enum: readonly [
				"none",
				"starting",
				"healthy",
				"unhealthy"
			];
			readonly example: "healthy";
		};
		readonly FailingStreak: {
			readonly description: "FailingStreak is the number of consecutive failures";
			readonly type: "integer";
			readonly example: 0;
		};
		readonly Log: {
			readonly type: "array";
			readonly description: "Log contains the last few results (oldest first)\n";
			readonly items: {
				readonly $ref: "#/definitions/HealthcheckResult";
			};
		};
	};
};
export declare const $HealthcheckResult: {
	readonly description: "HealthcheckResult stores information about a single run of a healthcheck probe\n";
	readonly type: "object";
	readonly "x-nullable": true;
	readonly properties: {
		readonly Start: {
			readonly description: "Date and time at which this check started in\n[RFC 3339](https://www.ietf.org/rfc/rfc3339.txt) format with nano-seconds.\n";
			readonly type: "string";
			readonly format: "date-time";
			readonly example: "2020-01-04T10:44:24.496525531Z";
		};
		readonly End: {
			readonly description: "Date and time at which this check ended in\n[RFC 3339](https://www.ietf.org/rfc/rfc3339.txt) format with nano-seconds.\n";
			readonly type: "string";
			readonly format: "dateTime";
			readonly example: "2020-01-04T10:45:21.364524523Z";
		};
		readonly ExitCode: {
			readonly description: "ExitCode meanings:\n\n- `0` healthy\n- `1` unhealthy\n- `2` reserved (considered unhealthy)\n- other values: error running probe\n";
			readonly type: "integer";
			readonly example: 0;
		};
		readonly Output: {
			readonly description: "Output from last check";
			readonly type: "string";
		};
	};
};
export declare const $HostConfig: {
	readonly description: "Container configuration that depends on the host we are running on";
	readonly allOf: readonly [
		{
			readonly $ref: "#/definitions/Resources";
		},
		{
			readonly type: "object";
			readonly properties: {
				readonly Binds: {
					readonly type: "array";
					readonly description: "A list of volume bindings for this container. Each volume binding\nis a string in one of these forms:\n\n- `host-src:container-dest[:options]` to bind-mount a host path\n  into the container. Both `host-src`, and `container-dest` must\n  be an _absolute_ path.\n- `volume-name:container-dest[:options]` to bind-mount a volume\n  managed by a volume driver into the container. `container-dest`\n  must be an _absolute_ path.\n\n`options` is an optional, comma-delimited list of:\n\n- `nocopy` disables automatic copying of data from the container\n  path to the volume. The `nocopy` flag only applies to named volumes.\n- `[ro|rw]` mounts a volume read-only or read-write, respectively.\n  If omitted or set to `rw`, volumes are mounted read-write.\n- `[z|Z]` applies SELinux labels to allow or deny multiple containers\n  to read and write to the same volume.\n    - `z`: a _shared_ content label is applied to the content. This\n      label indicates that multiple containers can share the volume\n      content, for both reading and writing.\n    - `Z`: a _private unshared_ label is applied to the content.\n      This label indicates that only the current container can use\n      a private volume. Labeling systems such as SELinux require\n      proper labels to be placed on volume content that is mounted\n      into a container. Without a label, the security system can\n      prevent a container's processes from using the content. By\n      default, the labels set by the host operating system are not\n      modified.\n- `[[r]shared|[r]slave|[r]private]` specifies mount\n  [propagation behavior](https://www.kernel.org/doc/Documentation/filesystems/sharedsubtree.txt).\n  This only applies to bind-mounted volumes, not internal volumes\n  or named volumes. Mount propagation requires the source mount\n  point (the location where the source directory is mounted in the\n  host operating system) to have the correct propagation properties.\n  For shared volumes, the source mount point must be set to `shared`.\n  For slave volumes, the mount must be set to either `shared` or\n  `slave`.\n";
					readonly items: {
						readonly type: "string";
					};
				};
				readonly ContainerIDFile: {
					readonly type: "string";
					readonly description: "Path to a file where the container ID is written";
				};
				readonly LogConfig: {
					readonly type: "object";
					readonly description: "The logging configuration for this container";
					readonly properties: {
						readonly Type: {
							readonly type: "string";
							readonly enum: readonly [
								"json-file",
								"syslog",
								"journald",
								"gelf",
								"fluentd",
								"awslogs",
								"splunk",
								"etwlogs",
								"none"
							];
						};
						readonly Config: {
							readonly type: "object";
							readonly additionalProperties: {
								readonly type: "string";
							};
						};
					};
				};
				readonly NetworkMode: {
					readonly type: "string";
					readonly description: "Network mode to use for this container. Supported standard values\nare: `bridge`, `host`, `none`, and `container:<name|id>`. Any\nother value is taken as a custom network's name to which this\ncontainer should connect to.\n";
				};
				readonly PortBindings: {
					readonly $ref: "#/definitions/PortMap";
				};
				readonly RestartPolicy: {
					readonly $ref: "#/definitions/RestartPolicy";
				};
				readonly AutoRemove: {
					readonly type: "boolean";
					readonly description: "Automatically remove the container when the container's process\nexits. This has no effect if `RestartPolicy` is set.\n";
				};
				readonly VolumeDriver: {
					readonly type: "string";
					readonly description: "Driver that this container uses to mount volumes.";
				};
				readonly VolumesFrom: {
					readonly type: "array";
					readonly description: "A list of volumes to inherit from another container, specified in\nthe form `<container name>[:<ro|rw>]`.\n";
					readonly items: {
						readonly type: "string";
					};
				};
				readonly Mounts: {
					readonly description: "Specification for mounts to be added to the container.\n";
					readonly type: "array";
					readonly items: {
						readonly $ref: "#/definitions/Mount";
					};
				};
				readonly ConsoleSize: {
					readonly type: "array";
					readonly description: "Initial console size, as an `[height, width]` array.\n";
					readonly "x-nullable": true;
					readonly minItems: 2;
					readonly maxItems: 2;
					readonly items: {
						readonly type: "integer";
						readonly minimum: 0;
					};
				};
				readonly Annotations: {
					readonly type: "object";
					readonly description: "Arbitrary non-identifying metadata attached to container and\nprovided to the runtime when the container is started.\n";
					readonly additionalProperties: {
						readonly type: "string";
					};
				};
				readonly CapAdd: {
					readonly type: "array";
					readonly description: "A list of kernel capabilities to add to the container. Conflicts\nwith option 'Capabilities'.\n";
					readonly items: {
						readonly type: "string";
					};
				};
				readonly CapDrop: {
					readonly type: "array";
					readonly description: "A list of kernel capabilities to drop from the container. Conflicts\nwith option 'Capabilities'.\n";
					readonly items: {
						readonly type: "string";
					};
				};
				readonly CgroupnsMode: {
					readonly type: "string";
					readonly enum: readonly [
						"private",
						"host"
					];
					readonly description: "cgroup namespace mode for the container. Possible values are:\n\n- `\"private\"`: the container runs in its own private cgroup namespace\n- `\"host\"`: use the host system's cgroup namespace\n\nIf not specified, the daemon default is used, which can either be `\"private\"`\nor `\"host\"`, depending on daemon version, kernel support and configuration.\n";
				};
				readonly Dns: {
					readonly type: "array";
					readonly description: "A list of DNS servers for the container to use.";
					readonly items: {
						readonly type: "string";
					};
				};
				readonly DnsOptions: {
					readonly type: "array";
					readonly description: "A list of DNS options.";
					readonly items: {
						readonly type: "string";
					};
				};
				readonly DnsSearch: {
					readonly type: "array";
					readonly description: "A list of DNS search domains.";
					readonly items: {
						readonly type: "string";
					};
				};
				readonly ExtraHosts: {
					readonly type: "array";
					readonly description: "A list of hostnames/IP mappings to add to the container's `/etc/hosts`\nfile. Specified in the form `[\"hostname:IP\"]`.\n";
					readonly items: {
						readonly type: "string";
					};
				};
				readonly GroupAdd: {
					readonly type: "array";
					readonly description: "A list of additional groups that the container process will run as.\n";
					readonly items: {
						readonly type: "string";
					};
				};
				readonly IpcMode: {
					readonly type: "string";
					readonly description: "IPC sharing mode for the container. Possible values are:\n\n- `\"none\"`: own private IPC namespace, with /dev/shm not mounted\n- `\"private\"`: own private IPC namespace\n- `\"shareable\"`: own private IPC namespace, with a possibility to share it with other containers\n- `\"container:<name|id>\"`: join another (shareable) container's IPC namespace\n- `\"host\"`: use the host system's IPC namespace\n\nIf not specified, daemon default is used, which can either be `\"private\"`\nor `\"shareable\"`, depending on daemon version and configuration.\n";
				};
				readonly Cgroup: {
					readonly type: "string";
					readonly description: "Cgroup to use for the container.";
				};
				readonly Links: {
					readonly type: "array";
					readonly description: "A list of links for the container in the form `container_name:alias`.\n";
					readonly items: {
						readonly type: "string";
					};
				};
				readonly OomScoreAdj: {
					readonly type: "integer";
					readonly description: "An integer value containing the score given to the container in\norder to tune OOM killer preferences.\n";
					readonly example: 500;
				};
				readonly PidMode: {
					readonly type: "string";
					readonly description: "Set the PID (Process) Namespace mode for the container. It can be\neither:\n\n- `\"container:<name|id>\"`: joins another container's PID namespace\n- `\"host\"`: use the host's PID namespace inside the container\n";
				};
				readonly Privileged: {
					readonly type: "boolean";
					readonly description: "Gives the container full access to the host.";
				};
				readonly PublishAllPorts: {
					readonly type: "boolean";
					readonly description: "Allocates an ephemeral host port for all of a container's\nexposed ports.\n\nPorts are de-allocated when the container stops and allocated when\nthe container starts. The allocated port might be changed when\nrestarting the container.\n\nThe port is selected from the ephemeral port range that depends on\nthe kernel. For example, on Linux the range is defined by\n`/proc/sys/net/ipv4/ip_local_port_range`.\n";
				};
				readonly ReadonlyRootfs: {
					readonly type: "boolean";
					readonly description: "Mount the container's root filesystem as read only.";
				};
				readonly SecurityOpt: {
					readonly type: "array";
					readonly description: "A list of string values to customize labels for MLS systems, such\nas SELinux.\n";
					readonly items: {
						readonly type: "string";
					};
				};
				readonly StorageOpt: {
					readonly type: "object";
					readonly description: "Storage driver options for this container, in the form `{\"size\": \"120G\"}`.\n";
					readonly additionalProperties: {
						readonly type: "string";
					};
				};
				readonly Tmpfs: {
					readonly type: "object";
					readonly description: "A map of container directories which should be replaced by tmpfs\nmounts, and their corresponding mount options. For example:\n\n```\n{ \"/run\": \"rw,noexec,nosuid,size=65536k\" }\n```\n";
					readonly additionalProperties: {
						readonly type: "string";
					};
				};
				readonly UTSMode: {
					readonly type: "string";
					readonly description: "UTS namespace to use for the container.";
				};
				readonly UsernsMode: {
					readonly type: "string";
					readonly description: "Sets the usernamespace mode for the container when usernamespace\nremapping option is enabled.\n";
				};
				readonly ShmSize: {
					readonly type: "integer";
					readonly format: "int64";
					readonly description: "Size of `/dev/shm` in bytes. If omitted, the system uses 64MB.\n";
					readonly minimum: 0;
				};
				readonly Sysctls: {
					readonly type: "object";
					readonly description: "A list of kernel parameters (sysctls) to set in the container.\nFor example:\n\n```\n{\"net.ipv4.ip_forward\": \"1\"}\n```\n";
					readonly additionalProperties: {
						readonly type: "string";
					};
				};
				readonly Runtime: {
					readonly type: "string";
					readonly description: "Runtime to use with this container.";
				};
				readonly Isolation: {
					readonly type: "string";
					readonly description: "Isolation technology of the container. (Windows only)\n";
					readonly enum: readonly [
						"default",
						"process",
						"hyperv"
					];
				};
				readonly MaskedPaths: {
					readonly type: "array";
					readonly description: "The list of paths to be masked inside the container (this overrides\nthe default set of paths).\n";
					readonly items: {
						readonly type: "string";
					};
				};
				readonly ReadonlyPaths: {
					readonly type: "array";
					readonly description: "The list of paths to be set as read-only inside the container\n(this overrides the default set of paths).\n";
					readonly items: {
						readonly type: "string";
					};
				};
			};
		}
	];
};
export declare const $ContainerConfig: {
	readonly description: "Configuration for a container that is portable between hosts.\n\nWhen used as `ContainerConfig` field in an image, `ContainerConfig` is an\noptional field containing the configuration of the container that was last\ncommitted when creating the image.\n\nPrevious versions of Docker builder used this field to store build cache,\nand it is not in active use anymore.\n";
	readonly type: "object";
	readonly properties: {
		readonly Hostname: {
			readonly description: "The hostname to use for the container, as a valid RFC 1123 hostname.\n";
			readonly type: "string";
			readonly example: "439f4e91bd1d";
		};
		readonly Domainname: {
			readonly description: "The domain name to use for the container.\n";
			readonly type: "string";
		};
		readonly User: {
			readonly description: "The user that commands are run as inside the container.";
			readonly type: "string";
		};
		readonly AttachStdin: {
			readonly description: "Whether to attach to `stdin`.";
			readonly type: "boolean";
			readonly default: false;
		};
		readonly AttachStdout: {
			readonly description: "Whether to attach to `stdout`.";
			readonly type: "boolean";
			readonly default: true;
		};
		readonly AttachStderr: {
			readonly description: "Whether to attach to `stderr`.";
			readonly type: "boolean";
			readonly default: true;
		};
		readonly ExposedPorts: {
			readonly description: "An object mapping ports to an empty object in the form:\n\n`{\"<port>/<tcp|udp|sctp>\": {}}`\n";
			readonly type: "object";
			readonly "x-nullable": true;
			readonly additionalProperties: {
				readonly type: "object";
				readonly enum: readonly [
					{}
				];
				readonly default: {};
			};
			readonly example: {
				readonly "80/tcp": {};
				readonly "443/tcp": {};
			};
		};
		readonly Tty: {
			readonly description: "Attach standard streams to a TTY, including `stdin` if it is not closed.\n";
			readonly type: "boolean";
			readonly default: false;
		};
		readonly OpenStdin: {
			readonly description: "Open `stdin`";
			readonly type: "boolean";
			readonly default: false;
		};
		readonly StdinOnce: {
			readonly description: "Close `stdin` after one attached client disconnects";
			readonly type: "boolean";
			readonly default: false;
		};
		readonly Env: {
			readonly description: "A list of environment variables to set inside the container in the\nform `[\"VAR=value\", ...]`. A variable without `=` is removed from the\nenvironment, rather than to have an empty value.\n";
			readonly type: "array";
			readonly items: {
				readonly type: "string";
			};
			readonly example: readonly [
				"PATH=/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin"
			];
		};
		readonly Cmd: {
			readonly description: "Command to run specified as a string or an array of strings.\n";
			readonly type: "array";
			readonly items: {
				readonly type: "string";
			};
			readonly example: readonly [
				"/bin/sh"
			];
		};
		readonly Healthcheck: {
			readonly $ref: "#/definitions/HealthConfig";
		};
		readonly ArgsEscaped: {
			readonly description: "Command is already escaped (Windows only)";
			readonly type: "boolean";
			readonly default: false;
			readonly example: false;
			readonly "x-nullable": true;
		};
		readonly Image: {
			readonly description: "The name (or reference) of the image to use when creating the container,\nor which was used when the container was created.\n";
			readonly type: "string";
			readonly example: "example-image:1.0";
		};
		readonly Volumes: {
			readonly description: "An object mapping mount point paths inside the container to empty\nobjects.\n";
			readonly type: "object";
			readonly additionalProperties: {
				readonly type: "object";
				readonly enum: readonly [
					{}
				];
				readonly default: {};
			};
		};
		readonly WorkingDir: {
			readonly description: "The working directory for commands to run in.";
			readonly type: "string";
			readonly example: "/public/";
		};
		readonly Entrypoint: {
			readonly description: "The entry point for the container as a string or an array of strings.\n\nIf the array consists of exactly one empty string (`[\"\"]`) then the\nentry point is reset to system default (i.e., the entry point used by\ndocker when there is no `ENTRYPOINT` instruction in the `Dockerfile`).\n";
			readonly type: "array";
			readonly items: {
				readonly type: "string";
			};
			readonly example: readonly [
			];
		};
		readonly NetworkDisabled: {
			readonly description: "Disable networking for the container.";
			readonly type: "boolean";
			readonly "x-nullable": true;
		};
		readonly MacAddress: {
			readonly description: "MAC address of the container.\n\nDeprecated: this field is deprecated in API v1.44 and up. Use EndpointSettings.MacAddress instead.\n";
			readonly type: "string";
			readonly "x-nullable": true;
		};
		readonly OnBuild: {
			readonly description: "`ONBUILD` metadata that were defined in the image's `Dockerfile`.\n";
			readonly type: "array";
			readonly "x-nullable": true;
			readonly items: {
				readonly type: "string";
			};
			readonly example: readonly [
			];
		};
		readonly Labels: {
			readonly description: "User-defined key/value metadata.";
			readonly type: "object";
			readonly additionalProperties: {
				readonly type: "string";
			};
			readonly example: {
				readonly "com.example.some-label": "some-value";
				readonly "com.example.some-other-label": "some-other-value";
			};
		};
		readonly StopSignal: {
			readonly description: "Signal to stop a container as a string or unsigned integer.\n";
			readonly type: "string";
			readonly example: "SIGTERM";
			readonly "x-nullable": true;
		};
		readonly StopTimeout: {
			readonly description: "Timeout to stop a container in seconds.";
			readonly type: "integer";
			readonly default: 10;
			readonly "x-nullable": true;
		};
		readonly Shell: {
			readonly description: "Shell for when `RUN`, `CMD`, and `ENTRYPOINT` uses a shell.\n";
			readonly type: "array";
			readonly "x-nullable": true;
			readonly items: {
				readonly type: "string";
			};
			readonly example: readonly [
				"/bin/sh",
				"-c"
			];
		};
	};
};
export declare const $NetworkingConfig: {
	readonly description: "NetworkingConfig represents the container's networking configuration for\neach of its interfaces.\nIt is used for the networking configs specified in the `docker create`\nand `docker network connect` commands.\n";
	readonly type: "object";
	readonly properties: {
		readonly EndpointsConfig: {
			readonly description: "A mapping of network name to endpoint configuration for that network.\nThe endpoint configuration can be left empty to connect to that\nnetwork with no particular endpoint configuration.\n";
			readonly type: "object";
			readonly additionalProperties: {
				readonly $ref: "#/definitions/EndpointSettings";
			};
		};
	};
	readonly example: {
		readonly EndpointsConfig: {
			readonly isolated_nw: {
				readonly IPAMConfig: {
					readonly IPv4Address: "172.20.30.33";
					readonly IPv6Address: "2001:db8:abcd::3033";
					readonly LinkLocalIPs: readonly [
						"169.254.34.68",
						"fe80::3468"
					];
				};
				readonly MacAddress: "02:42:ac:12:05:02";
				readonly Links: readonly [
					"container_1",
					"container_2"
				];
				readonly Aliases: readonly [
					"server_x",
					"server_y"
				];
			};
			readonly database_nw: {};
		};
	};
};
export declare const $NetworkSettings: {
	readonly description: "NetworkSettings exposes the network settings in the API";
	readonly type: "object";
	readonly properties: {
		readonly Bridge: {
			readonly description: "Name of the default bridge interface when dockerd's --bridge flag is set.\n";
			readonly type: "string";
			readonly example: "docker0";
		};
		readonly SandboxID: {
			readonly description: "SandboxID uniquely represents a container's network stack.";
			readonly type: "string";
			readonly example: "9d12daf2c33f5959c8bf90aa513e4f65b561738661003029ec84830cd503a0c3";
		};
		readonly HairpinMode: {
			readonly description: "Indicates if hairpin NAT should be enabled on the virtual interface.\n\nDeprecated: This field is never set and will be removed in a future release.\n";
			readonly type: "boolean";
			readonly example: false;
		};
		readonly LinkLocalIPv6Address: {
			readonly description: "IPv6 unicast address using the link-local prefix.\n\nDeprecated: This field is never set and will be removed in a future release.\n";
			readonly type: "string";
			readonly example: "";
		};
		readonly LinkLocalIPv6PrefixLen: {
			readonly description: "Prefix length of the IPv6 unicast address.\n\nDeprecated: This field is never set and will be removed in a future release.\n";
			readonly type: "integer";
			readonly example: "";
		};
		readonly Ports: {
			readonly $ref: "#/definitions/PortMap";
		};
		readonly SandboxKey: {
			readonly description: "SandboxKey is the full path of the netns handle";
			readonly type: "string";
			readonly example: "/var/run/docker/netns/8ab54b426c38";
		};
		readonly SecondaryIPAddresses: {
			readonly description: "Deprecated: This field is never set and will be removed in a future release.";
			readonly type: "array";
			readonly items: {
				readonly $ref: "#/definitions/Address";
			};
			readonly "x-nullable": true;
		};
		readonly SecondaryIPv6Addresses: {
			readonly description: "Deprecated: This field is never set and will be removed in a future release.";
			readonly type: "array";
			readonly items: {
				readonly $ref: "#/definitions/Address";
			};
			readonly "x-nullable": true;
		};
		readonly EndpointID: {
			readonly description: "EndpointID uniquely represents a service endpoint in a Sandbox.\n\n<p><br /></p>\n\n> **Deprecated**: This field is only propagated when attached to the\n> default \"bridge\" network. Use the information from the \"bridge\"\n> network inside the `Networks` map instead, which contains the same\n> information. This field was deprecated in Docker 1.9 and is scheduled\n> to be removed in Docker 17.12.0\n";
			readonly type: "string";
			readonly example: "b88f5b905aabf2893f3cbc4ee42d1ea7980bbc0a92e2c8922b1e1795298afb0b";
		};
		readonly Gateway: {
			readonly description: "Gateway address for the default \"bridge\" network.\n\n<p><br /></p>\n\n> **Deprecated**: This field is only propagated when attached to the\n> default \"bridge\" network. Use the information from the \"bridge\"\n> network inside the `Networks` map instead, which contains the same\n> information. This field was deprecated in Docker 1.9 and is scheduled\n> to be removed in Docker 17.12.0\n";
			readonly type: "string";
			readonly example: "172.17.0.1";
		};
		readonly GlobalIPv6Address: {
			readonly description: "Global IPv6 address for the default \"bridge\" network.\n\n<p><br /></p>\n\n> **Deprecated**: This field is only propagated when attached to the\n> default \"bridge\" network. Use the information from the \"bridge\"\n> network inside the `Networks` map instead, which contains the same\n> information. This field was deprecated in Docker 1.9 and is scheduled\n> to be removed in Docker 17.12.0\n";
			readonly type: "string";
			readonly example: "2001:db8::5689";
		};
		readonly GlobalIPv6PrefixLen: {
			readonly description: "Mask length of the global IPv6 address.\n\n<p><br /></p>\n\n> **Deprecated**: This field is only propagated when attached to the\n> default \"bridge\" network. Use the information from the \"bridge\"\n> network inside the `Networks` map instead, which contains the same\n> information. This field was deprecated in Docker 1.9 and is scheduled\n> to be removed in Docker 17.12.0\n";
			readonly type: "integer";
			readonly example: 64;
		};
		readonly IPAddress: {
			readonly description: "IPv4 address for the default \"bridge\" network.\n\n<p><br /></p>\n\n> **Deprecated**: This field is only propagated when attached to the\n> default \"bridge\" network. Use the information from the \"bridge\"\n> network inside the `Networks` map instead, which contains the same\n> information. This field was deprecated in Docker 1.9 and is scheduled\n> to be removed in Docker 17.12.0\n";
			readonly type: "string";
			readonly example: "172.17.0.4";
		};
		readonly IPPrefixLen: {
			readonly description: "Mask length of the IPv4 address.\n\n<p><br /></p>\n\n> **Deprecated**: This field is only propagated when attached to the\n> default \"bridge\" network. Use the information from the \"bridge\"\n> network inside the `Networks` map instead, which contains the same\n> information. This field was deprecated in Docker 1.9 and is scheduled\n> to be removed in Docker 17.12.0\n";
			readonly type: "integer";
			readonly example: 16;
		};
		readonly IPv6Gateway: {
			readonly description: "IPv6 gateway address for this network.\n\n<p><br /></p>\n\n> **Deprecated**: This field is only propagated when attached to the\n> default \"bridge\" network. Use the information from the \"bridge\"\n> network inside the `Networks` map instead, which contains the same\n> information. This field was deprecated in Docker 1.9 and is scheduled\n> to be removed in Docker 17.12.0\n";
			readonly type: "string";
			readonly example: "2001:db8:2::100";
		};
		readonly MacAddress: {
			readonly description: "MAC address for the container on the default \"bridge\" network.\n\n<p><br /></p>\n\n> **Deprecated**: This field is only propagated when attached to the\n> default \"bridge\" network. Use the information from the \"bridge\"\n> network inside the `Networks` map instead, which contains the same\n> information. This field was deprecated in Docker 1.9 and is scheduled\n> to be removed in Docker 17.12.0\n";
			readonly type: "string";
			readonly example: "02:42:ac:11:00:04";
		};
		readonly Networks: {
			readonly description: "Information about all networks that the container is connected to.\n";
			readonly type: "object";
			readonly additionalProperties: {
				readonly $ref: "#/definitions/EndpointSettings";
			};
		};
	};
};
export declare const $Address: {
	readonly description: "Address represents an IPv4 or IPv6 IP address.";
	readonly type: "object";
	readonly properties: {
		readonly Addr: {
			readonly description: "IP address.";
			readonly type: "string";
		};
		readonly PrefixLen: {
			readonly description: "Mask length of the IP address.";
			readonly type: "integer";
		};
	};
};
export declare const $PortMap: {
	readonly description: "PortMap describes the mapping of container ports to host ports, using the\ncontainer's port-number and protocol as key in the format `<port>/<protocol>`,\nfor example, `80/udp`.\n\nIf a container's port is mapped for multiple protocols, separate entries\nare added to the mapping table.\n";
	readonly type: "object";
	readonly additionalProperties: {
		readonly type: "array";
		readonly "x-nullable": true;
		readonly items: {
			readonly $ref: "#/definitions/PortBinding";
		};
	};
	readonly example: {
		readonly "443/tcp": readonly [
			{
				readonly HostIp: "127.0.0.1";
				readonly HostPort: "4443";
			}
		];
		readonly "80/tcp": readonly [
			{
				readonly HostIp: "0.0.0.0";
				readonly HostPort: "80";
			},
			{
				readonly HostIp: "0.0.0.0";
				readonly HostPort: "8080";
			}
		];
		readonly "80/udp": readonly [
			{
				readonly HostIp: "0.0.0.0";
				readonly HostPort: "80";
			}
		];
		readonly "53/udp": readonly [
			{
				readonly HostIp: "0.0.0.0";
				readonly HostPort: "53";
			}
		];
		readonly "2377/tcp": null;
	};
};
export declare const $PortBinding: {
	readonly description: "PortBinding represents a binding between a host IP address and a host\nport.\n";
	readonly type: "object";
	readonly properties: {
		readonly HostIp: {
			readonly description: "Host IP address that the container's port is mapped to.";
			readonly type: "string";
			readonly example: "127.0.0.1";
		};
		readonly HostPort: {
			readonly description: "Host port number that the container's port is mapped to.";
			readonly type: "string";
			readonly example: "4443";
		};
	};
};
export declare const $GraphDriverData: {
	readonly description: "Information about the storage driver used to store the container's and\nimage's filesystem.\n";
	readonly type: "object";
	readonly required: readonly [
		"Name",
		"Data"
	];
	readonly properties: {
		readonly Name: {
			readonly description: "Name of the storage driver.";
			readonly type: "string";
			readonly "x-nullable": false;
			readonly example: "overlay2";
		};
		readonly Data: {
			readonly description: "Low-level storage metadata, provided as key/value pairs.\n\nThis information is driver-specific, and depends on the storage-driver\nin use, and should be used for informational purposes only.\n";
			readonly type: "object";
			readonly "x-nullable": false;
			readonly additionalProperties: {
				readonly type: "string";
			};
			readonly example: {
				readonly MergedDir: "/var/lib/docker/overlay2/ef749362d13333e65fc95c572eb525abbe0052e16e086cb64bc3b98ae9aa6d74/merged";
				readonly UpperDir: "/var/lib/docker/overlay2/ef749362d13333e65fc95c572eb525abbe0052e16e086cb64bc3b98ae9aa6d74/diff";
				readonly WorkDir: "/var/lib/docker/overlay2/ef749362d13333e65fc95c572eb525abbe0052e16e086cb64bc3b98ae9aa6d74/work";
			};
		};
	};
};
export declare const $FilesystemChange: {
	readonly description: "Change in the container's filesystem.\n";
	readonly type: "object";
	readonly required: readonly [
		"Path",
		"Kind"
	];
	readonly properties: {
		readonly Path: {
			readonly description: "Path to file or directory that has changed.\n";
			readonly type: "string";
			readonly "x-nullable": false;
		};
		readonly Kind: {
			readonly $ref: "#/definitions/ChangeType";
		};
	};
};
export declare const $ChangeType: {
	readonly description: "Kind of change\n\nCan be one of:\n\n- `0`: Modified (\"C\")\n- `1`: Added (\"A\")\n- `2`: Deleted (\"D\")\n";
	readonly type: "integer";
	readonly format: "uint8";
	readonly enum: readonly [
		0,
		1,
		2
	];
	readonly "x-nullable": false;
};
export declare const $ImageInspect: {
	readonly description: "Information about an image in the local image cache.\n";
	readonly type: "object";
	readonly properties: {
		readonly Id: {
			readonly description: "ID is the content-addressable ID of an image.\n\nThis identifier is a content-addressable digest calculated from the\nimage's configuration (which includes the digests of layers used by\nthe image).\n\nNote that this digest differs from the `RepoDigests` below, which\nholds digests of image manifests that reference the image.\n";
			readonly type: "string";
			readonly "x-nullable": false;
			readonly example: "sha256:ec3f0931a6e6b6855d76b2d7b0be30e81860baccd891b2e243280bf1cd8ad710";
		};
		readonly RepoTags: {
			readonly description: "List of image names/tags in the local image cache that reference this\nimage.\n\nMultiple image tags can refer to the same image, and this list may be\nempty if no tags reference the image, in which case the image is\n\"untagged\", in which case it can still be referenced by its ID.\n";
			readonly type: "array";
			readonly items: {
				readonly type: "string";
			};
			readonly example: readonly [
				"example:1.0",
				"example:latest",
				"example:stable",
				"internal.registry.example.com:5000/example:1.0"
			];
		};
		readonly RepoDigests: {
			readonly description: "List of content-addressable digests of locally available image manifests\nthat the image is referenced from. Multiple manifests can refer to the\nsame image.\n\nThese digests are usually only available if the image was either pulled\nfrom a registry, or if the image was pushed to a registry, which is when\nthe manifest is generated and its digest calculated.\n";
			readonly type: "array";
			readonly items: {
				readonly type: "string";
			};
			readonly example: readonly [
				"example@sha256:afcc7f1ac1b49db317a7196c902e61c6c3c4607d63599ee1a82d702d249a0ccb",
				"internal.registry.example.com:5000/example@sha256:b69959407d21e8a062e0416bf13405bb2b71ed7a84dde4158ebafacfa06f5578"
			];
		};
		readonly Parent: {
			readonly description: "ID of the parent image.\n\nDepending on how the image was created, this field may be empty and\nis only set for images that were built/created locally. This field\nis empty if the image was pulled from an image registry.\n";
			readonly type: "string";
			readonly "x-nullable": false;
			readonly example: "";
		};
		readonly Comment: {
			readonly description: "Optional message that was set when committing or importing the image.\n";
			readonly type: "string";
			readonly "x-nullable": false;
			readonly example: "";
		};
		readonly Created: {
			readonly description: "Date and time at which the image was created, formatted in\n[RFC 3339](https://www.ietf.org/rfc/rfc3339.txt) format with nano-seconds.\n\nThis information is only available if present in the image,\nand omitted otherwise.\n";
			readonly type: "string";
			readonly format: "dateTime";
			readonly "x-nullable": true;
			readonly example: "2022-02-04T21:20:12.497794809Z";
		};
		readonly Container: {
			readonly description: "The ID of the container that was used to create the image.\n\nDepending on how the image was created, this field may be empty.\n\n**Deprecated**: this field is kept for backward compatibility, but\nwill be removed in API v1.45.\n";
			readonly type: "string";
			readonly example: "65974bc86f1770ae4bff79f651ebdbce166ae9aada632ee3fa9af3a264911735";
		};
		readonly ContainerConfig: {
			readonly description: "**Deprecated**: this field is kept for backward compatibility, but\nwill be removed in API v1.45.\n";
			readonly $ref: "#/definitions/ContainerConfig";
		};
		readonly DockerVersion: {
			readonly description: "The version of Docker that was used to build the image.\n\nDepending on how the image was created, this field may be empty.\n";
			readonly type: "string";
			readonly "x-nullable": false;
			readonly example: "20.10.7";
		};
		readonly Author: {
			readonly description: "Name of the author that was specified when committing the image, or as\nspecified through MAINTAINER (deprecated) in the Dockerfile.\n";
			readonly type: "string";
			readonly "x-nullable": false;
			readonly example: "";
		};
		readonly Config: {
			readonly $ref: "#/definitions/ContainerConfig";
		};
		readonly Architecture: {
			readonly description: "Hardware CPU architecture that the image runs on.\n";
			readonly type: "string";
			readonly "x-nullable": false;
			readonly example: "arm";
		};
		readonly Variant: {
			readonly description: "CPU architecture variant (presently ARM-only).\n";
			readonly type: "string";
			readonly "x-nullable": true;
			readonly example: "v7";
		};
		readonly Os: {
			readonly description: "Operating System the image is built to run on.\n";
			readonly type: "string";
			readonly "x-nullable": false;
			readonly example: "linux";
		};
		readonly OsVersion: {
			readonly description: "Operating System version the image is built to run on (especially\nfor Windows).\n";
			readonly type: "string";
			readonly example: "";
			readonly "x-nullable": true;
		};
		readonly Size: {
			readonly description: "Total size of the image including all layers it is composed of.\n";
			readonly type: "integer";
			readonly format: "int64";
			readonly "x-nullable": false;
			readonly example: 1239828;
		};
		readonly VirtualSize: {
			readonly description: "Total size of the image including all layers it is composed of.\n\nDeprecated: this field is omitted in API v1.44, but kept for backward compatibility. Use Size instead.\n";
			readonly type: "integer";
			readonly format: "int64";
			readonly example: 1239828;
		};
		readonly GraphDriver: {
			readonly $ref: "#/definitions/GraphDriverData";
		};
		readonly RootFS: {
			readonly description: "Information about the image's RootFS, including the layer IDs.\n";
			readonly type: "object";
			readonly required: readonly [
				"Type"
			];
			readonly properties: {
				readonly Type: {
					readonly type: "string";
					readonly "x-nullable": false;
					readonly example: "layers";
				};
				readonly Layers: {
					readonly type: "array";
					readonly items: {
						readonly type: "string";
					};
					readonly example: readonly [
						"sha256:1834950e52ce4d5a88a1bbd131c537f4d0e56d10ff0dd69e66be3b7dfa9df7e6",
						"sha256:5f70bf18a086007016e948b04aed3b82103a36bea41755b6cddfaf10ace3c6ef"
					];
				};
			};
		};
		readonly Metadata: {
			readonly description: "Additional metadata of the image in the local cache. This information\nis local to the daemon, and not part of the image itself.\n";
			readonly type: "object";
			readonly properties: {
				readonly LastTagTime: {
					readonly description: "Date and time at which the image was last tagged in\n[RFC 3339](https://www.ietf.org/rfc/rfc3339.txt) format with nano-seconds.\n\nThis information is only available if the image was tagged locally,\nand omitted otherwise.\n";
					readonly type: "string";
					readonly format: "dateTime";
					readonly example: "2022-02-28T14:40:02.623929178Z";
					readonly "x-nullable": true;
				};
			};
		};
	};
};
export declare const $ImageSummary: {
	readonly type: "object";
	readonly "x-go-name": "Summary";
	readonly required: readonly [
		"Id",
		"ParentId",
		"RepoTags",
		"RepoDigests",
		"Created",
		"Size",
		"SharedSize",
		"Labels",
		"Containers"
	];
	readonly properties: {
		readonly Id: {
			readonly description: "ID is the content-addressable ID of an image.\n\nThis identifier is a content-addressable digest calculated from the\nimage's configuration (which includes the digests of layers used by\nthe image).\n\nNote that this digest differs from the `RepoDigests` below, which\nholds digests of image manifests that reference the image.\n";
			readonly type: "string";
			readonly "x-nullable": false;
			readonly example: "sha256:ec3f0931a6e6b6855d76b2d7b0be30e81860baccd891b2e243280bf1cd8ad710";
		};
		readonly ParentId: {
			readonly description: "ID of the parent image.\n\nDepending on how the image was created, this field may be empty and\nis only set for images that were built/created locally. This field\nis empty if the image was pulled from an image registry.\n";
			readonly type: "string";
			readonly "x-nullable": false;
			readonly example: "";
		};
		readonly RepoTags: {
			readonly description: "List of image names/tags in the local image cache that reference this\nimage.\n\nMultiple image tags can refer to the same image, and this list may be\nempty if no tags reference the image, in which case the image is\n\"untagged\", in which case it can still be referenced by its ID.\n";
			readonly type: "array";
			readonly "x-nullable": false;
			readonly items: {
				readonly type: "string";
			};
			readonly example: readonly [
				"example:1.0",
				"example:latest",
				"example:stable",
				"internal.registry.example.com:5000/example:1.0"
			];
		};
		readonly RepoDigests: {
			readonly description: "List of content-addressable digests of locally available image manifests\nthat the image is referenced from. Multiple manifests can refer to the\nsame image.\n\nThese digests are usually only available if the image was either pulled\nfrom a registry, or if the image was pushed to a registry, which is when\nthe manifest is generated and its digest calculated.\n";
			readonly type: "array";
			readonly "x-nullable": false;
			readonly items: {
				readonly type: "string";
			};
			readonly example: readonly [
				"example@sha256:afcc7f1ac1b49db317a7196c902e61c6c3c4607d63599ee1a82d702d249a0ccb",
				"internal.registry.example.com:5000/example@sha256:b69959407d21e8a062e0416bf13405bb2b71ed7a84dde4158ebafacfa06f5578"
			];
		};
		readonly Created: {
			readonly description: "Date and time at which the image was created as a Unix timestamp\n(number of seconds sinds EPOCH).\n";
			readonly type: "integer";
			readonly "x-nullable": false;
			readonly example: "1644009612";
		};
		readonly Size: {
			readonly description: "Total size of the image including all layers it is composed of.\n";
			readonly type: "integer";
			readonly format: "int64";
			readonly "x-nullable": false;
			readonly example: 172064416;
		};
		readonly SharedSize: {
			readonly description: "Total size of image layers that are shared between this image and other\nimages.\n\nThis size is not calculated by default. `-1` indicates that the value\nhas not been set / calculated.\n";
			readonly type: "integer";
			readonly format: "int64";
			readonly "x-nullable": false;
			readonly example: 1239828;
		};
		readonly VirtualSize: {
			readonly description: "Total size of the image including all layers it is composed of.\n\nDeprecated: this field is omitted in API v1.44, but kept for backward compatibility. Use Size instead.";
			readonly type: "integer";
			readonly format: "int64";
			readonly example: 172064416;
		};
		readonly Labels: {
			readonly description: "User-defined key/value metadata.";
			readonly type: "object";
			readonly "x-nullable": false;
			readonly additionalProperties: {
				readonly type: "string";
			};
			readonly example: {
				readonly "com.example.some-label": "some-value";
				readonly "com.example.some-other-label": "some-other-value";
			};
		};
		readonly Containers: {
			readonly description: "Number of containers using this image. Includes both stopped and running\ncontainers.\n\nThis size is not calculated by default, and depends on which API endpoint\nis used. `-1` indicates that the value has not been set / calculated.\n";
			readonly "x-nullable": false;
			readonly type: "integer";
			readonly example: 2;
		};
	};
};
export declare const $AuthConfig: {
	readonly type: "object";
	readonly properties: {
		readonly username: {
			readonly type: "string";
		};
		readonly password: {
			readonly type: "string";
		};
		readonly email: {
			readonly type: "string";
		};
		readonly serveraddress: {
			readonly type: "string";
		};
	};
	readonly example: {
		readonly username: "hannibal";
		readonly password: "xxxx";
		readonly serveraddress: "https://index.docker.io/v1/";
	};
};
export declare const $ProcessConfig: {
	readonly type: "object";
	readonly properties: {
		readonly privileged: {
			readonly type: "boolean";
		};
		readonly user: {
			readonly type: "string";
		};
		readonly tty: {
			readonly type: "boolean";
		};
		readonly entrypoint: {
			readonly type: "string";
		};
		readonly arguments: {
			readonly type: "array";
			readonly items: {
				readonly type: "string";
			};
		};
	};
};
export declare const $Volume: {
	readonly type: "object";
	readonly required: readonly [
		"Name",
		"Driver",
		"Mountpoint",
		"Labels",
		"Scope",
		"Options"
	];
	readonly properties: {
		readonly Name: {
			readonly type: "string";
			readonly description: "Name of the volume.";
			readonly "x-nullable": false;
			readonly example: "tardis";
		};
		readonly Driver: {
			readonly type: "string";
			readonly description: "Name of the volume driver used by the volume.";
			readonly "x-nullable": false;
			readonly example: "custom";
		};
		readonly Mountpoint: {
			readonly type: "string";
			readonly description: "Mount path of the volume on the host.";
			readonly "x-nullable": false;
			readonly example: "/var/lib/docker/volumes/tardis";
		};
		readonly CreatedAt: {
			readonly type: "string";
			readonly format: "dateTime";
			readonly description: "Date/Time the volume was created.";
			readonly example: "2016-06-07T20:31:11.853781916Z";
		};
		readonly Status: {
			readonly type: "object";
			readonly description: "Low-level details about the volume, provided by the volume driver.\nDetails are returned as a map with key/value pairs:\n`{\"key\":\"value\",\"key2\":\"value2\"}`.\n\nThe `Status` field is optional, and is omitted if the volume driver\ndoes not support this feature.\n";
			readonly additionalProperties: {
				readonly type: "object";
			};
			readonly example: {
				readonly hello: "world";
			};
		};
		readonly Labels: {
			readonly type: "object";
			readonly description: "User-defined key/value metadata.";
			readonly "x-nullable": false;
			readonly additionalProperties: {
				readonly type: "string";
			};
			readonly example: {
				readonly "com.example.some-label": "some-value";
				readonly "com.example.some-other-label": "some-other-value";
			};
		};
		readonly Scope: {
			readonly type: "string";
			readonly description: "The level at which the volume exists. Either `global` for cluster-wide,\nor `local` for machine level.\n";
			readonly default: "local";
			readonly "x-nullable": false;
			readonly enum: readonly [
				"local",
				"global"
			];
			readonly example: "local";
		};
		readonly ClusterVolume: {
			readonly $ref: "#/definitions/ClusterVolume";
		};
		readonly Options: {
			readonly type: "object";
			readonly description: "The driver specific options used when creating the volume.\n";
			readonly additionalProperties: {
				readonly type: "string";
			};
			readonly example: {
				readonly device: "tmpfs";
				readonly o: "size=100m,uid=1000";
				readonly type: "tmpfs";
			};
		};
		readonly UsageData: {
			readonly type: "object";
			readonly "x-nullable": true;
			readonly "x-go-name": "UsageData";
			readonly required: readonly [
				"Size",
				"RefCount"
			];
			readonly description: "Usage details about the volume. This information is used by the\n`GET /system/df` endpoint, and omitted in other endpoints.\n";
			readonly properties: {
				readonly Size: {
					readonly type: "integer";
					readonly format: "int64";
					readonly default: -1;
					readonly description: "Amount of disk space used by the volume (in bytes). This information\nis only available for volumes created with the `\"local\"` volume\ndriver. For volumes created with other volume drivers, this field\nis set to `-1` (\"not available\")\n";
					readonly "x-nullable": false;
				};
				readonly RefCount: {
					readonly type: "integer";
					readonly format: "int64";
					readonly default: -1;
					readonly description: "The number of containers referencing this volume. This field\nis set to `-1` if the reference-count is not available.\n";
					readonly "x-nullable": false;
				};
			};
		};
	};
};
export declare const $VolumeCreateOptions: {
	readonly description: "Volume configuration";
	readonly type: "object";
	readonly title: "VolumeConfig";
	readonly "x-go-name": "CreateOptions";
	readonly properties: {
		readonly Name: {
			readonly description: "The new volume's name. If not specified, Docker generates a name.\n";
			readonly type: "string";
			readonly "x-nullable": false;
			readonly example: "tardis";
		};
		readonly Driver: {
			readonly description: "Name of the volume driver to use.";
			readonly type: "string";
			readonly default: "local";
			readonly "x-nullable": false;
			readonly example: "custom";
		};
		readonly DriverOpts: {
			readonly description: "A mapping of driver options and values. These options are\npassed directly to the driver and are driver specific.\n";
			readonly type: "object";
			readonly additionalProperties: {
				readonly type: "string";
			};
			readonly example: {
				readonly device: "tmpfs";
				readonly o: "size=100m,uid=1000";
				readonly type: "tmpfs";
			};
		};
		readonly Labels: {
			readonly description: "User-defined key/value metadata.";
			readonly type: "object";
			readonly additionalProperties: {
				readonly type: "string";
			};
			readonly example: {
				readonly "com.example.some-label": "some-value";
				readonly "com.example.some-other-label": "some-other-value";
			};
		};
		readonly ClusterVolumeSpec: {
			readonly $ref: "#/definitions/ClusterVolumeSpec";
		};
	};
};
export declare const $VolumeListResponse: {
	readonly type: "object";
	readonly title: "VolumeListResponse";
	readonly "x-go-name": "ListResponse";
	readonly description: "Volume list response";
	readonly properties: {
		readonly Volumes: {
			readonly type: "array";
			readonly description: "List of volumes";
			readonly items: {
				readonly $ref: "#/definitions/Volume";
			};
		};
		readonly Warnings: {
			readonly type: "array";
			readonly description: "Warnings that occurred when fetching the list of volumes.\n";
			readonly items: {
				readonly type: "string";
			};
			readonly example: readonly [
			];
		};
	};
};
export declare const $Network: {
	readonly type: "object";
	readonly properties: {
		readonly Name: {
			readonly type: "string";
		};
		readonly Id: {
			readonly type: "string";
		};
		readonly Created: {
			readonly type: "string";
			readonly format: "dateTime";
		};
		readonly Scope: {
			readonly type: "string";
		};
		readonly Driver: {
			readonly type: "string";
		};
		readonly EnableIPv6: {
			readonly type: "boolean";
		};
		readonly IPAM: {
			readonly $ref: "#/definitions/IPAM";
		};
		readonly Internal: {
			readonly type: "boolean";
		};
		readonly Attachable: {
			readonly type: "boolean";
		};
		readonly Ingress: {
			readonly type: "boolean";
		};
		readonly Containers: {
			readonly type: "object";
			readonly additionalProperties: {
				readonly $ref: "#/definitions/NetworkContainer";
			};
		};
		readonly Options: {
			readonly type: "object";
			readonly additionalProperties: {
				readonly type: "string";
			};
		};
		readonly Labels: {
			readonly type: "object";
			readonly additionalProperties: {
				readonly type: "string";
			};
		};
	};
	readonly example: {
		readonly Name: "net01";
		readonly Id: "7d86d31b1478e7cca9ebed7e73aa0fdeec46c5ca29497431d3007d2d9e15ed99";
		readonly Created: "2016-10-19T04:33:30.360899459Z";
		readonly Scope: "local";
		readonly Driver: "bridge";
		readonly EnableIPv6: false;
		readonly IPAM: {
			readonly Driver: "default";
			readonly Config: readonly [
				{
					readonly Subnet: "172.19.0.0/16";
					readonly Gateway: "172.19.0.1";
				}
			];
			readonly Options: {
				readonly foo: "bar";
			};
		};
		readonly Internal: false;
		readonly Attachable: false;
		readonly Ingress: false;
		readonly Containers: {
			readonly "19a4d5d687db25203351ed79d478946f861258f018fe384f229f2efa4b23513c": {
				readonly Name: "test";
				readonly EndpointID: "628cadb8bcb92de107b2a1e516cbffe463e321f548feb37697cce00ad694f21a";
				readonly MacAddress: "02:42:ac:13:00:02";
				readonly IPv4Address: "172.19.0.2/16";
				readonly IPv6Address: "";
			};
		};
		readonly Options: {
			readonly "com.docker.network.bridge.default_bridge": "true";
			readonly "com.docker.network.bridge.enable_icc": "true";
			readonly "com.docker.network.bridge.enable_ip_masquerade": "true";
			readonly "com.docker.network.bridge.host_binding_ipv4": "0.0.0.0";
			readonly "com.docker.network.bridge.name": "docker0";
			readonly "com.docker.network.driver.mtu": "1500";
		};
		readonly Labels: {
			readonly "com.example.some-label": "some-value";
			readonly "com.example.some-other-label": "some-other-value";
		};
	};
};
export declare const $IPAM: {
	readonly type: "object";
	readonly properties: {
		readonly Driver: {
			readonly description: "Name of the IPAM driver to use.";
			readonly type: "string";
			readonly default: "default";
		};
		readonly Config: {
			readonly description: "List of IPAM configuration options, specified as a map:\n\n```\n{\"Subnet\": <CIDR>, \"IPRange\": <CIDR>, \"Gateway\": <IP address>, \"AuxAddress\": <device_name:IP address>}\n```\n";
			readonly type: "array";
			readonly items: {
				readonly $ref: "#/definitions/IPAMConfig";
			};
		};
		readonly Options: {
			readonly description: "Driver-specific options, specified as a map.";
			readonly type: "object";
			readonly additionalProperties: {
				readonly type: "string";
			};
		};
	};
};
export declare const $IPAMConfig: {
	readonly type: "object";
	readonly properties: {
		readonly Subnet: {
			readonly type: "string";
		};
		readonly IPRange: {
			readonly type: "string";
		};
		readonly Gateway: {
			readonly type: "string";
		};
		readonly AuxiliaryAddresses: {
			readonly type: "object";
			readonly additionalProperties: {
				readonly type: "string";
			};
		};
	};
};
export declare const $NetworkContainer: {
	readonly type: "object";
	readonly properties: {
		readonly Name: {
			readonly type: "string";
		};
		readonly EndpointID: {
			readonly type: "string";
		};
		readonly MacAddress: {
			readonly type: "string";
		};
		readonly IPv4Address: {
			readonly type: "string";
		};
		readonly IPv6Address: {
			readonly type: "string";
		};
	};
};
export declare const $BuildInfo: {
	readonly type: "object";
	readonly properties: {
		readonly id: {
			readonly type: "string";
		};
		readonly stream: {
			readonly type: "string";
		};
		readonly error: {
			readonly type: "string";
		};
		readonly errorDetail: {
			readonly $ref: "#/definitions/ErrorDetail";
		};
		readonly status: {
			readonly type: "string";
		};
		readonly progress: {
			readonly type: "string";
		};
		readonly progressDetail: {
			readonly $ref: "#/definitions/ProgressDetail";
		};
		readonly aux: {
			readonly $ref: "#/definitions/ImageID";
		};
	};
};
export declare const $BuildCache: {
	readonly type: "object";
	readonly description: "BuildCache contains information about a build cache record.\n";
	readonly properties: {
		readonly ID: {
			readonly type: "string";
			readonly description: "Unique ID of the build cache record.\n";
			readonly example: "ndlpt0hhvkqcdfkputsk4cq9c";
		};
		readonly Parent: {
			readonly description: "ID of the parent build cache record.\n\n> **Deprecated**: This field is deprecated, and omitted if empty.\n";
			readonly type: "string";
			readonly "x-nullable": true;
			readonly example: "";
		};
		readonly Parents: {
			readonly description: "List of parent build cache record IDs.\n";
			readonly type: "array";
			readonly items: {
				readonly type: "string";
			};
			readonly "x-nullable": true;
			readonly example: readonly [
				"hw53o5aio51xtltp5xjp8v7fx"
			];
		};
		readonly Type: {
			readonly type: "string";
			readonly description: "Cache record type.\n";
			readonly example: "regular";
			readonly enum: readonly [
				"internal",
				"frontend",
				"source.local",
				"source.git.checkout",
				"exec.cachemount",
				"regular"
			];
		};
		readonly Description: {
			readonly type: "string";
			readonly description: "Description of the build-step that produced the build cache.\n";
			readonly example: "mount / from exec /bin/sh -c echo 'Binary::apt::APT::Keep-Downloaded-Packages \"true\";' > /etc/apt/apt.conf.d/keep-cache";
		};
		readonly InUse: {
			readonly type: "boolean";
			readonly description: "Indicates if the build cache is in use.\n";
			readonly example: false;
		};
		readonly Shared: {
			readonly type: "boolean";
			readonly description: "Indicates if the build cache is shared.\n";
			readonly example: true;
		};
		readonly Size: {
			readonly description: "Amount of disk space used by the build cache (in bytes).\n";
			readonly type: "integer";
			readonly example: 51;
		};
		readonly CreatedAt: {
			readonly description: "Date and time at which the build cache was created in\n[RFC 3339](https://www.ietf.org/rfc/rfc3339.txt) format with nano-seconds.\n";
			readonly type: "string";
			readonly format: "dateTime";
			readonly example: "2016-08-18T10:44:24.496525531Z";
		};
		readonly LastUsedAt: {
			readonly description: "Date and time at which the build cache was last used in\n[RFC 3339](https://www.ietf.org/rfc/rfc3339.txt) format with nano-seconds.\n";
			readonly type: "string";
			readonly format: "dateTime";
			readonly "x-nullable": true;
			readonly example: "2017-08-09T07:09:37.632105588Z";
		};
		readonly UsageCount: {
			readonly type: "integer";
			readonly example: 26;
		};
	};
};
export declare const $ImageID: {
	readonly type: "object";
	readonly description: "Image ID or Digest";
	readonly properties: {
		readonly ID: {
			readonly type: "string";
		};
	};
	readonly example: {
		readonly ID: "sha256:85f05633ddc1c50679be2b16a0479ab6f7637f8884e0cfe0f4d20e1ebb3d6e7c";
	};
};
export declare const $CreateImageInfo: {
	readonly type: "object";
	readonly properties: {
		readonly id: {
			readonly type: "string";
		};
		readonly error: {
			readonly type: "string";
		};
		readonly errorDetail: {
			readonly $ref: "#/definitions/ErrorDetail";
		};
		readonly status: {
			readonly type: "string";
		};
		readonly progress: {
			readonly type: "string";
		};
		readonly progressDetail: {
			readonly $ref: "#/definitions/ProgressDetail";
		};
	};
};
export declare const $PushImageInfo: {
	readonly type: "object";
	readonly properties: {
		readonly error: {
			readonly type: "string";
		};
		readonly status: {
			readonly type: "string";
		};
		readonly progress: {
			readonly type: "string";
		};
		readonly progressDetail: {
			readonly $ref: "#/definitions/ProgressDetail";
		};
	};
};
export declare const $ErrorDetail: {
	readonly type: "object";
	readonly properties: {
		readonly code: {
			readonly type: "integer";
		};
		readonly message: {
			readonly type: "string";
		};
	};
};
export declare const $ProgressDetail: {
	readonly type: "object";
	readonly properties: {
		readonly current: {
			readonly type: "integer";
		};
		readonly total: {
			readonly type: "integer";
		};
	};
};
export declare const $ErrorResponse: {
	readonly description: "Represents an error.";
	readonly type: "object";
	readonly required: readonly [
		"message"
	];
	readonly properties: {
		readonly message: {
			readonly description: "The error message.";
			readonly type: "string";
			readonly "x-nullable": false;
		};
	};
	readonly example: {
		readonly message: "Something went wrong.";
	};
};
export declare const $IdResponse: {
	readonly description: "Response to an API call that returns just an Id";
	readonly type: "object";
	readonly required: readonly [
		"Id"
	];
	readonly properties: {
		readonly Id: {
			readonly description: "The id of the newly created object.";
			readonly type: "string";
			readonly "x-nullable": false;
		};
	};
};
export declare const $EndpointSettings: {
	readonly description: "Configuration for a network endpoint.";
	readonly type: "object";
	readonly properties: {
		readonly IPAMConfig: {
			readonly $ref: "#/definitions/EndpointIPAMConfig";
		};
		readonly Links: {
			readonly type: "array";
			readonly items: {
				readonly type: "string";
			};
			readonly example: readonly [
				"container_1",
				"container_2"
			];
		};
		readonly MacAddress: {
			readonly description: "MAC address for the endpoint on this network. The network driver might ignore this parameter.\n";
			readonly type: "string";
			readonly example: "02:42:ac:11:00:04";
		};
		readonly Aliases: {
			readonly type: "array";
			readonly items: {
				readonly type: "string";
			};
			readonly example: readonly [
				"server_x",
				"server_y"
			];
		};
		readonly NetworkID: {
			readonly description: "Unique ID of the network.\n";
			readonly type: "string";
			readonly example: "08754567f1f40222263eab4102e1c733ae697e8e354aa9cd6e18d7402835292a";
		};
		readonly EndpointID: {
			readonly description: "Unique ID for the service endpoint in a Sandbox.\n";
			readonly type: "string";
			readonly example: "b88f5b905aabf2893f3cbc4ee42d1ea7980bbc0a92e2c8922b1e1795298afb0b";
		};
		readonly Gateway: {
			readonly description: "Gateway address for this network.\n";
			readonly type: "string";
			readonly example: "172.17.0.1";
		};
		readonly IPAddress: {
			readonly description: "IPv4 address.\n";
			readonly type: "string";
			readonly example: "172.17.0.4";
		};
		readonly IPPrefixLen: {
			readonly description: "Mask length of the IPv4 address.\n";
			readonly type: "integer";
			readonly example: 16;
		};
		readonly IPv6Gateway: {
			readonly description: "IPv6 gateway address.\n";
			readonly type: "string";
			readonly example: "2001:db8:2::100";
		};
		readonly GlobalIPv6Address: {
			readonly description: "Global IPv6 address.\n";
			readonly type: "string";
			readonly example: "2001:db8::5689";
		};
		readonly GlobalIPv6PrefixLen: {
			readonly description: "Mask length of the global IPv6 address.\n";
			readonly type: "integer";
			readonly format: "int64";
			readonly example: 64;
		};
		readonly DriverOpts: {
			readonly description: "DriverOpts is a mapping of driver options and values. These options\nare passed directly to the driver and are driver specific.\n";
			readonly type: "object";
			readonly "x-nullable": true;
			readonly additionalProperties: {
				readonly type: "string";
			};
			readonly example: {
				readonly "com.example.some-label": "some-value";
				readonly "com.example.some-other-label": "some-other-value";
			};
		};
		readonly DNSNames: {
			readonly description: "List of all DNS names an endpoint has on a specific network. This\nlist is based on the container name, network aliases, container short\nID, and hostname.\n\nThese DNS names are non-fully qualified but can contain several dots.\nYou can get fully qualified DNS names by appending `.<network-name>`.\nFor instance, if container name is `my.ctr` and the network is named\n`testnet`, `DNSNames` will contain `my.ctr` and the FQDN will be\n`my.ctr.testnet`.\n";
			readonly type: "array";
			readonly items: {
				readonly type: "string";
			};
			readonly example: readonly [
				"foobar",
				"server_x",
				"server_y",
				"my.ctr"
			];
		};
	};
};
export declare const $EndpointIPAMConfig: {
	readonly description: "EndpointIPAMConfig represents an endpoint's IPAM configuration.\n";
	readonly type: "object";
	readonly "x-nullable": true;
	readonly properties: {
		readonly IPv4Address: {
			readonly type: "string";
			readonly example: "172.20.30.33";
		};
		readonly IPv6Address: {
			readonly type: "string";
			readonly example: "2001:db8:abcd::3033";
		};
		readonly LinkLocalIPs: {
			readonly type: "array";
			readonly items: {
				readonly type: "string";
			};
			readonly example: readonly [
				"169.254.34.68",
				"fe80::3468"
			];
		};
	};
};
export declare const $PluginMount: {
	readonly type: "object";
	readonly "x-nullable": false;
	readonly required: readonly [
		"Name",
		"Description",
		"Settable",
		"Source",
		"Destination",
		"Type",
		"Options"
	];
	readonly properties: {
		readonly Name: {
			readonly type: "string";
			readonly "x-nullable": false;
			readonly example: "some-mount";
		};
		readonly Description: {
			readonly type: "string";
			readonly "x-nullable": false;
			readonly example: "This is a mount that's used by the plugin.";
		};
		readonly Settable: {
			readonly type: "array";
			readonly items: {
				readonly type: "string";
			};
		};
		readonly Source: {
			readonly type: "string";
			readonly example: "/var/lib/docker/plugins/";
		};
		readonly Destination: {
			readonly type: "string";
			readonly "x-nullable": false;
			readonly example: "/mnt/state";
		};
		readonly Type: {
			readonly type: "string";
			readonly "x-nullable": false;
			readonly example: "bind";
		};
		readonly Options: {
			readonly type: "array";
			readonly items: {
				readonly type: "string";
			};
			readonly example: readonly [
				"rbind",
				"rw"
			];
		};
	};
};
export declare const $PluginDevice: {
	readonly type: "object";
	readonly required: readonly [
		"Name",
		"Description",
		"Settable",
		"Path"
	];
	readonly "x-nullable": false;
	readonly properties: {
		readonly Name: {
			readonly type: "string";
			readonly "x-nullable": false;
		};
		readonly Description: {
			readonly type: "string";
			readonly "x-nullable": false;
		};
		readonly Settable: {
			readonly type: "array";
			readonly items: {
				readonly type: "string";
			};
		};
		readonly Path: {
			readonly type: "string";
			readonly example: "/dev/fuse";
		};
	};
};
export declare const $PluginEnv: {
	readonly type: "object";
	readonly "x-nullable": false;
	readonly required: readonly [
		"Name",
		"Description",
		"Settable",
		"Value"
	];
	readonly properties: {
		readonly Name: {
			readonly "x-nullable": false;
			readonly type: "string";
		};
		readonly Description: {
			readonly "x-nullable": false;
			readonly type: "string";
		};
		readonly Settable: {
			readonly type: "array";
			readonly items: {
				readonly type: "string";
			};
		};
		readonly Value: {
			readonly type: "string";
		};
	};
};
export declare const $PluginInterfaceType: {
	readonly type: "object";
	readonly "x-nullable": false;
	readonly required: readonly [
		"Prefix",
		"Capability",
		"Version"
	];
	readonly properties: {
		readonly Prefix: {
			readonly type: "string";
			readonly "x-nullable": false;
		};
		readonly Capability: {
			readonly type: "string";
			readonly "x-nullable": false;
		};
		readonly Version: {
			readonly type: "string";
			readonly "x-nullable": false;
		};
	};
};
export declare const $PluginPrivilege: {
	readonly description: "Describes a permission the user has to accept upon installing\nthe plugin.\n";
	readonly type: "object";
	readonly "x-go-name": "PluginPrivilege";
	readonly properties: {
		readonly Name: {
			readonly type: "string";
			readonly example: "network";
		};
		readonly Description: {
			readonly type: "string";
		};
		readonly Value: {
			readonly type: "array";
			readonly items: {
				readonly type: "string";
			};
			readonly example: readonly [
				"host"
			];
		};
	};
};
export declare const $Plugin: {
	readonly description: "A plugin for the Engine API";
	readonly type: "object";
	readonly required: readonly [
		"Settings",
		"Enabled",
		"Config",
		"Name"
	];
	readonly properties: {
		readonly Id: {
			readonly type: "string";
			readonly example: "5724e2c8652da337ab2eedd19fc6fc0ec908e4bd907c7421bf6a8dfc70c4c078";
		};
		readonly Name: {
			readonly type: "string";
			readonly "x-nullable": false;
			readonly example: "tiborvass/sample-volume-plugin";
		};
		readonly Enabled: {
			readonly description: "True if the plugin is running. False if the plugin is not running, only installed.";
			readonly type: "boolean";
			readonly "x-nullable": false;
			readonly example: true;
		};
		readonly Settings: {
			readonly description: "Settings that can be modified by users.";
			readonly type: "object";
			readonly "x-nullable": false;
			readonly required: readonly [
				"Args",
				"Devices",
				"Env",
				"Mounts"
			];
			readonly properties: {
				readonly Mounts: {
					readonly type: "array";
					readonly items: {
						readonly $ref: "#/definitions/PluginMount";
					};
				};
				readonly Env: {
					readonly type: "array";
					readonly items: {
						readonly type: "string";
					};
					readonly example: readonly [
						"DEBUG=0"
					];
				};
				readonly Args: {
					readonly type: "array";
					readonly items: {
						readonly type: "string";
					};
				};
				readonly Devices: {
					readonly type: "array";
					readonly items: {
						readonly $ref: "#/definitions/PluginDevice";
					};
				};
			};
		};
		readonly PluginReference: {
			readonly description: "plugin remote reference used to push/pull the plugin";
			readonly type: "string";
			readonly "x-nullable": false;
			readonly example: "localhost:5000/tiborvass/sample-volume-plugin:latest";
		};
		readonly Config: {
			readonly description: "The config of a plugin.";
			readonly type: "object";
			readonly "x-nullable": false;
			readonly required: readonly [
				"Description",
				"Documentation",
				"Interface",
				"Entrypoint",
				"WorkDir",
				"Network",
				"Linux",
				"PidHost",
				"PropagatedMount",
				"IpcHost",
				"Mounts",
				"Env",
				"Args"
			];
			readonly properties: {
				readonly DockerVersion: {
					readonly description: "Docker Version used to create the plugin";
					readonly type: "string";
					readonly "x-nullable": false;
					readonly example: "17.06.0-ce";
				};
				readonly Description: {
					readonly type: "string";
					readonly "x-nullable": false;
					readonly example: "A sample volume plugin for Docker";
				};
				readonly Documentation: {
					readonly type: "string";
					readonly "x-nullable": false;
					readonly example: "https://docs.docker.com/engine/extend/plugins/";
				};
				readonly Interface: {
					readonly description: "The interface between Docker and the plugin";
					readonly "x-nullable": false;
					readonly type: "object";
					readonly required: readonly [
						"Types",
						"Socket"
					];
					readonly properties: {
						readonly Types: {
							readonly type: "array";
							readonly items: {
								readonly $ref: "#/definitions/PluginInterfaceType";
							};
							readonly example: readonly [
								"docker.volumedriver/1.0"
							];
						};
						readonly Socket: {
							readonly type: "string";
							readonly "x-nullable": false;
							readonly example: "plugins.sock";
						};
						readonly ProtocolScheme: {
							readonly type: "string";
							readonly example: "some.protocol/v1.0";
							readonly description: "Protocol to use for clients connecting to the plugin.";
							readonly enum: readonly [
								"",
								"moby.plugins.http/v1"
							];
						};
					};
				};
				readonly Entrypoint: {
					readonly type: "array";
					readonly items: {
						readonly type: "string";
					};
					readonly example: readonly [
						"/usr/bin/sample-volume-plugin",
						"/data"
					];
				};
				readonly WorkDir: {
					readonly type: "string";
					readonly "x-nullable": false;
					readonly example: "/bin/";
				};
				readonly User: {
					readonly type: "object";
					readonly "x-nullable": false;
					readonly properties: {
						readonly UID: {
							readonly type: "integer";
							readonly format: "uint32";
							readonly example: 1000;
						};
						readonly GID: {
							readonly type: "integer";
							readonly format: "uint32";
							readonly example: 1000;
						};
					};
				};
				readonly Network: {
					readonly type: "object";
					readonly "x-nullable": false;
					readonly required: readonly [
						"Type"
					];
					readonly properties: {
						readonly Type: {
							readonly "x-nullable": false;
							readonly type: "string";
							readonly example: "host";
						};
					};
				};
				readonly Linux: {
					readonly type: "object";
					readonly "x-nullable": false;
					readonly required: readonly [
						"Capabilities",
						"AllowAllDevices",
						"Devices"
					];
					readonly properties: {
						readonly Capabilities: {
							readonly type: "array";
							readonly items: {
								readonly type: "string";
							};
							readonly example: readonly [
								"CAP_SYS_ADMIN",
								"CAP_SYSLOG"
							];
						};
						readonly AllowAllDevices: {
							readonly type: "boolean";
							readonly "x-nullable": false;
							readonly example: false;
						};
						readonly Devices: {
							readonly type: "array";
							readonly items: {
								readonly $ref: "#/definitions/PluginDevice";
							};
						};
					};
				};
				readonly PropagatedMount: {
					readonly type: "string";
					readonly "x-nullable": false;
					readonly example: "/mnt/volumes";
				};
				readonly IpcHost: {
					readonly type: "boolean";
					readonly "x-nullable": false;
					readonly example: false;
				};
				readonly PidHost: {
					readonly type: "boolean";
					readonly "x-nullable": false;
					readonly example: false;
				};
				readonly Mounts: {
					readonly type: "array";
					readonly items: {
						readonly $ref: "#/definitions/PluginMount";
					};
				};
				readonly Env: {
					readonly type: "array";
					readonly items: {
						readonly $ref: "#/definitions/PluginEnv";
					};
					readonly example: readonly [
						{
							readonly Name: "DEBUG";
							readonly Description: "If set, prints debug messages";
							readonly Settable: null;
							readonly Value: "0";
						}
					];
				};
				readonly Args: {
					readonly type: "object";
					readonly "x-nullable": false;
					readonly required: readonly [
						"Name",
						"Description",
						"Settable",
						"Value"
					];
					readonly properties: {
						readonly Name: {
							readonly "x-nullable": false;
							readonly type: "string";
							readonly example: "args";
						};
						readonly Description: {
							readonly "x-nullable": false;
							readonly type: "string";
							readonly example: "command line arguments";
						};
						readonly Settable: {
							readonly type: "array";
							readonly items: {
								readonly type: "string";
							};
						};
						readonly Value: {
							readonly type: "array";
							readonly items: {
								readonly type: "string";
							};
						};
					};
				};
				readonly rootfs: {
					readonly type: "object";
					readonly properties: {
						readonly type: {
							readonly type: "string";
							readonly example: "layers";
						};
						readonly diff_ids: {
							readonly type: "array";
							readonly items: {
								readonly type: "string";
							};
							readonly example: readonly [
								"sha256:675532206fbf3030b8458f88d6e26d4eb1577688a25efec97154c94e8b6b4887",
								"sha256:e216a057b1cb1efc11f8a268f37ef62083e70b1b38323ba252e25ac88904a7e8"
							];
						};
					};
				};
			};
		};
	};
};
export declare const $ObjectVersion: {
	readonly description: "The version number of the object such as node, service, etc. This is needed\nto avoid conflicting writes. The client must send the version number along\nwith the modified specification when updating these objects.\n\nThis approach ensures safe concurrency and determinism in that the change\non the object may not be applied if the version number has changed from the\nlast read. In other words, if two update requests specify the same base\nversion, only one of the requests can succeed. As a result, two separate\nupdate requests that happen at the same time will not unintentionally\noverwrite each other.\n";
	readonly type: "object";
	readonly properties: {
		readonly Index: {
			readonly type: "integer";
			readonly format: "uint64";
			readonly example: 373531;
		};
	};
};
export declare const $NodeSpec: {
	readonly type: "object";
	readonly properties: {
		readonly Name: {
			readonly description: "Name for the node.";
			readonly type: "string";
			readonly example: "my-node";
		};
		readonly Labels: {
			readonly description: "User-defined key/value metadata.";
			readonly type: "object";
			readonly additionalProperties: {
				readonly type: "string";
			};
		};
		readonly Role: {
			readonly description: "Role of the node.";
			readonly type: "string";
			readonly enum: readonly [
				"worker",
				"manager"
			];
			readonly example: "manager";
		};
		readonly Availability: {
			readonly description: "Availability of the node.";
			readonly type: "string";
			readonly enum: readonly [
				"active",
				"pause",
				"drain"
			];
			readonly example: "active";
		};
	};
	readonly example: {
		readonly Availability: "active";
		readonly Name: "node-name";
		readonly Role: "manager";
		readonly Labels: {
			readonly foo: "bar";
		};
	};
};
export declare const $Node: {
	readonly type: "object";
	readonly properties: {
		readonly ID: {
			readonly type: "string";
			readonly example: "24ifsmvkjbyhk";
		};
		readonly Version: {
			readonly $ref: "#/definitions/ObjectVersion";
		};
		readonly CreatedAt: {
			readonly description: "Date and time at which the node was added to the swarm in\n[RFC 3339](https://www.ietf.org/rfc/rfc3339.txt) format with nano-seconds.\n";
			readonly type: "string";
			readonly format: "dateTime";
			readonly example: "2016-08-18T10:44:24.496525531Z";
		};
		readonly UpdatedAt: {
			readonly description: "Date and time at which the node was last updated in\n[RFC 3339](https://www.ietf.org/rfc/rfc3339.txt) format with nano-seconds.\n";
			readonly type: "string";
			readonly format: "dateTime";
			readonly example: "2017-08-09T07:09:37.632105588Z";
		};
		readonly Spec: {
			readonly $ref: "#/definitions/NodeSpec";
		};
		readonly Description: {
			readonly $ref: "#/definitions/NodeDescription";
		};
		readonly Status: {
			readonly $ref: "#/definitions/NodeStatus";
		};
		readonly ManagerStatus: {
			readonly $ref: "#/definitions/ManagerStatus";
		};
	};
};
export declare const $NodeDescription: {
	readonly description: "NodeDescription encapsulates the properties of the Node as reported by the\nagent.\n";
	readonly type: "object";
	readonly properties: {
		readonly Hostname: {
			readonly type: "string";
			readonly example: "bf3067039e47";
		};
		readonly Platform: {
			readonly $ref: "#/definitions/Platform";
		};
		readonly Resources: {
			readonly $ref: "#/definitions/ResourceObject";
		};
		readonly Engine: {
			readonly $ref: "#/definitions/EngineDescription";
		};
		readonly TLSInfo: {
			readonly $ref: "#/definitions/TLSInfo";
		};
	};
};
export declare const $Platform: {
	readonly description: "Platform represents the platform (Arch/OS).\n";
	readonly type: "object";
	readonly properties: {
		readonly Architecture: {
			readonly description: "Architecture represents the hardware architecture (for example,\n`x86_64`).\n";
			readonly type: "string";
			readonly example: "x86_64";
		};
		readonly OS: {
			readonly description: "OS represents the Operating System (for example, `linux` or `windows`).\n";
			readonly type: "string";
			readonly example: "linux";
		};
	};
};
export declare const $EngineDescription: {
	readonly description: "EngineDescription provides information about an engine.";
	readonly type: "object";
	readonly properties: {
		readonly EngineVersion: {
			readonly type: "string";
			readonly example: "17.06.0";
		};
		readonly Labels: {
			readonly type: "object";
			readonly additionalProperties: {
				readonly type: "string";
			};
			readonly example: {
				readonly foo: "bar";
			};
		};
		readonly Plugins: {
			readonly type: "array";
			readonly items: {
				readonly type: "object";
				readonly properties: {
					readonly Type: {
						readonly type: "string";
					};
					readonly Name: {
						readonly type: "string";
					};
				};
			};
			readonly example: readonly [
				{
					readonly Type: "Log";
					readonly Name: "awslogs";
				},
				{
					readonly Type: "Log";
					readonly Name: "fluentd";
				},
				{
					readonly Type: "Log";
					readonly Name: "gcplogs";
				},
				{
					readonly Type: "Log";
					readonly Name: "gelf";
				},
				{
					readonly Type: "Log";
					readonly Name: "journald";
				},
				{
					readonly Type: "Log";
					readonly Name: "json-file";
				},
				{
					readonly Type: "Log";
					readonly Name: "splunk";
				},
				{
					readonly Type: "Log";
					readonly Name: "syslog";
				},
				{
					readonly Type: "Network";
					readonly Name: "bridge";
				},
				{
					readonly Type: "Network";
					readonly Name: "host";
				},
				{
					readonly Type: "Network";
					readonly Name: "ipvlan";
				},
				{
					readonly Type: "Network";
					readonly Name: "macvlan";
				},
				{
					readonly Type: "Network";
					readonly Name: "null";
				},
				{
					readonly Type: "Network";
					readonly Name: "overlay";
				},
				{
					readonly Type: "Volume";
					readonly Name: "local";
				},
				{
					readonly Type: "Volume";
					readonly Name: "localhost:5000/vieux/sshfs:latest";
				},
				{
					readonly Type: "Volume";
					readonly Name: "vieux/sshfs:latest";
				}
			];
		};
	};
};
export declare const $TLSInfo: {
	readonly description: "Information about the issuer of leaf TLS certificates and the trusted root\nCA certificate.\n";
	readonly type: "object";
	readonly properties: {
		readonly TrustRoot: {
			readonly description: "The root CA certificate(s) that are used to validate leaf TLS\ncertificates.\n";
			readonly type: "string";
		};
		readonly CertIssuerSubject: {
			readonly description: "The base64-url-safe-encoded raw subject bytes of the issuer.";
			readonly type: "string";
		};
		readonly CertIssuerPublicKey: {
			readonly description: "The base64-url-safe-encoded raw public key bytes of the issuer.\n";
			readonly type: "string";
		};
	};
	readonly example: {
		readonly TrustRoot: "-----BEGIN CERTIFICATE-----\nMIIBajCCARCgAwIBAgIUbYqrLSOSQHoxD8CwG6Bi2PJi9c8wCgYIKoZIzj0EAwIw\nEzERMA8GA1UEAxMIc3dhcm0tY2EwHhcNMTcwNDI0MjE0MzAwWhcNMzcwNDE5MjE0\nMzAwWjATMREwDwYDVQQDEwhzd2FybS1jYTBZMBMGByqGSM49AgEGCCqGSM49AwEH\nA0IABJk/VyMPYdaqDXJb/VXh5n/1Yuv7iNrxV3Qb3l06XD46seovcDWs3IZNV1lf\n3Skyr0ofcchipoiHkXBODojJydSjQjBAMA4GA1UdDwEB/wQEAwIBBjAPBgNVHRMB\nAf8EBTADAQH/MB0GA1UdDgQWBBRUXxuRcnFjDfR/RIAUQab8ZV/n4jAKBggqhkjO\nPQQDAgNIADBFAiAy+JTe6Uc3KyLCMiqGl2GyWGQqQDEcO3/YG36x7om65AIhAJvz\npxv6zFeVEkAEEkqIYi0omA9+CjanB/6Bz4n1uw8H\n-----END CERTIFICATE-----\n";
		readonly CertIssuerSubject: "MBMxETAPBgNVBAMTCHN3YXJtLWNh";
		readonly CertIssuerPublicKey: "MFkwEwYHKoZIzj0CAQYIKoZIzj0DAQcDQgAEmT9XIw9h1qoNclv9VeHmf/Vi6/uI2vFXdBveXTpcPjqx6i9wNazchk1XWV/dKTKvSh9xyGKmiIeRcE4OiMnJ1A==";
	};
};
export declare const $NodeStatus: {
	readonly description: "NodeStatus represents the status of a node.\n\nIt provides the current status of the node, as seen by the manager.\n";
	readonly type: "object";
	readonly properties: {
		readonly State: {
			readonly $ref: "#/definitions/NodeState";
		};
		readonly Message: {
			readonly type: "string";
			readonly example: "";
		};
		readonly Addr: {
			readonly description: "IP address of the node.";
			readonly type: "string";
			readonly example: "172.17.0.2";
		};
	};
};
export declare const $NodeState: {
	readonly description: "NodeState represents the state of a node.";
	readonly type: "string";
	readonly enum: readonly [
		"unknown",
		"down",
		"ready",
		"disconnected"
	];
	readonly example: "ready";
};
export declare const $ManagerStatus: {
	readonly description: "ManagerStatus represents the status of a manager.\n\nIt provides the current status of a node's manager component, if the node\nis a manager.\n";
	readonly "x-nullable": true;
	readonly type: "object";
	readonly properties: {
		readonly Leader: {
			readonly type: "boolean";
			readonly default: false;
			readonly example: true;
		};
		readonly Reachability: {
			readonly $ref: "#/definitions/Reachability";
		};
		readonly Addr: {
			readonly description: "The IP address and port at which the manager is reachable.\n";
			readonly type: "string";
			readonly example: "10.0.0.46:2377";
		};
	};
};
export declare const $Reachability: {
	readonly description: "Reachability represents the reachability of a node.";
	readonly type: "string";
	readonly enum: readonly [
		"unknown",
		"unreachable",
		"reachable"
	];
	readonly example: "reachable";
};
export declare const $SwarmSpec: {
	readonly description: "User modifiable swarm configuration.";
	readonly type: "object";
	readonly properties: {
		readonly Name: {
			readonly description: "Name of the swarm.";
			readonly type: "string";
			readonly example: "default";
		};
		readonly Labels: {
			readonly description: "User-defined key/value metadata.";
			readonly type: "object";
			readonly additionalProperties: {
				readonly type: "string";
			};
			readonly example: {
				readonly "com.example.corp.type": "production";
				readonly "com.example.corp.department": "engineering";
			};
		};
		readonly Orchestration: {
			readonly description: "Orchestration configuration.";
			readonly type: "object";
			readonly "x-nullable": true;
			readonly properties: {
				readonly TaskHistoryRetentionLimit: {
					readonly description: "The number of historic tasks to keep per instance or node. If\nnegative, never remove completed or failed tasks.\n";
					readonly type: "integer";
					readonly format: "int64";
					readonly example: 10;
				};
			};
		};
		readonly Raft: {
			readonly description: "Raft configuration.";
			readonly type: "object";
			readonly properties: {
				readonly SnapshotInterval: {
					readonly description: "The number of log entries between snapshots.";
					readonly type: "integer";
					readonly format: "uint64";
					readonly example: 10000;
				};
				readonly KeepOldSnapshots: {
					readonly description: "The number of snapshots to keep beyond the current snapshot.\n";
					readonly type: "integer";
					readonly format: "uint64";
				};
				readonly LogEntriesForSlowFollowers: {
					readonly description: "The number of log entries to keep around to sync up slow followers\nafter a snapshot is created.\n";
					readonly type: "integer";
					readonly format: "uint64";
					readonly example: 500;
				};
				readonly ElectionTick: {
					readonly description: "The number of ticks that a follower will wait for a message from\nthe leader before becoming a candidate and starting an election.\n`ElectionTick` must be greater than `HeartbeatTick`.\n\nA tick currently defaults to one second, so these translate\ndirectly to seconds currently, but this is NOT guaranteed.\n";
					readonly type: "integer";
					readonly example: 3;
				};
				readonly HeartbeatTick: {
					readonly description: "The number of ticks between heartbeats. Every HeartbeatTick ticks,\nthe leader will send a heartbeat to the followers.\n\nA tick currently defaults to one second, so these translate\ndirectly to seconds currently, but this is NOT guaranteed.\n";
					readonly type: "integer";
					readonly example: 1;
				};
			};
		};
		readonly Dispatcher: {
			readonly description: "Dispatcher configuration.";
			readonly type: "object";
			readonly "x-nullable": true;
			readonly properties: {
				readonly HeartbeatPeriod: {
					readonly description: "The delay for an agent to send a heartbeat to the dispatcher.\n";
					readonly type: "integer";
					readonly format: "int64";
					readonly example: 5000000000;
				};
			};
		};
		readonly CAConfig: {
			readonly description: "CA configuration.";
			readonly type: "object";
			readonly "x-nullable": true;
			readonly properties: {
				readonly NodeCertExpiry: {
					readonly description: "The duration node certificates are issued for.";
					readonly type: "integer";
					readonly format: "int64";
					readonly example: 7776000000000000;
				};
				readonly ExternalCAs: {
					readonly description: "Configuration for forwarding signing requests to an external\ncertificate authority.\n";
					readonly type: "array";
					readonly items: {
						readonly type: "object";
						readonly properties: {
							readonly Protocol: {
								readonly description: "Protocol for communication with the external CA (currently\nonly `cfssl` is supported).\n";
								readonly type: "string";
								readonly enum: readonly [
									"cfssl"
								];
								readonly default: "cfssl";
							};
							readonly URL: {
								readonly description: "URL where certificate signing requests should be sent.\n";
								readonly type: "string";
							};
							readonly Options: {
								readonly description: "An object with key/value pairs that are interpreted as\nprotocol-specific options for the external CA driver.\n";
								readonly type: "object";
								readonly additionalProperties: {
									readonly type: "string";
								};
							};
							readonly CACert: {
								readonly description: "The root CA certificate (in PEM format) this external CA uses\nto issue TLS certificates (assumed to be to the current swarm\nroot CA certificate if not provided).\n";
								readonly type: "string";
							};
						};
					};
				};
				readonly SigningCACert: {
					readonly description: "The desired signing CA certificate for all swarm node TLS leaf\ncertificates, in PEM format.\n";
					readonly type: "string";
				};
				readonly SigningCAKey: {
					readonly description: "The desired signing CA key for all swarm node TLS leaf certificates,\nin PEM format.\n";
					readonly type: "string";
				};
				readonly ForceRotate: {
					readonly description: "An integer whose purpose is to force swarm to generate a new\nsigning CA certificate and key, if none have been specified in\n`SigningCACert` and `SigningCAKey`\n";
					readonly format: "uint64";
					readonly type: "integer";
				};
			};
		};
		readonly EncryptionConfig: {
			readonly description: "Parameters related to encryption-at-rest.";
			readonly type: "object";
			readonly properties: {
				readonly AutoLockManagers: {
					readonly description: "If set, generate a key and use it to lock data stored on the\nmanagers.\n";
					readonly type: "boolean";
					readonly example: false;
				};
			};
		};
		readonly TaskDefaults: {
			readonly description: "Defaults for creating tasks in this cluster.";
			readonly type: "object";
			readonly properties: {
				readonly LogDriver: {
					readonly description: "The log driver to use for tasks created in the orchestrator if\nunspecified by a service.\n\nUpdating this value only affects new tasks. Existing tasks continue\nto use their previously configured log driver until recreated.\n";
					readonly type: "object";
					readonly properties: {
						readonly Name: {
							readonly description: "The log driver to use as a default for new tasks.\n";
							readonly type: "string";
							readonly example: "json-file";
						};
						readonly Options: {
							readonly description: "Driver-specific options for the selectd log driver, specified\nas key/value pairs.\n";
							readonly type: "object";
							readonly additionalProperties: {
								readonly type: "string";
							};
							readonly example: {
								readonly "max-file": "10";
								readonly "max-size": "100m";
							};
						};
					};
				};
			};
		};
	};
};
export declare const $ClusterInfo: {
	readonly description: "ClusterInfo represents information about the swarm as is returned by the\n\"/info\" endpoint. Join-tokens are not included.\n";
	readonly "x-nullable": true;
	readonly type: "object";
	readonly properties: {
		readonly ID: {
			readonly description: "The ID of the swarm.";
			readonly type: "string";
			readonly example: "abajmipo7b4xz5ip2nrla6b11";
		};
		readonly Version: {
			readonly $ref: "#/definitions/ObjectVersion";
		};
		readonly CreatedAt: {
			readonly description: "Date and time at which the swarm was initialised in\n[RFC 3339](https://www.ietf.org/rfc/rfc3339.txt) format with nano-seconds.\n";
			readonly type: "string";
			readonly format: "dateTime";
			readonly example: "2016-08-18T10:44:24.496525531Z";
		};
		readonly UpdatedAt: {
			readonly description: "Date and time at which the swarm was last updated in\n[RFC 3339](https://www.ietf.org/rfc/rfc3339.txt) format with nano-seconds.\n";
			readonly type: "string";
			readonly format: "dateTime";
			readonly example: "2017-08-09T07:09:37.632105588Z";
		};
		readonly Spec: {
			readonly $ref: "#/definitions/SwarmSpec";
		};
		readonly TLSInfo: {
			readonly $ref: "#/definitions/TLSInfo";
		};
		readonly RootRotationInProgress: {
			readonly description: "Whether there is currently a root CA rotation in progress for the swarm\n";
			readonly type: "boolean";
			readonly example: false;
		};
		readonly DataPathPort: {
			readonly description: "DataPathPort specifies the data path port number for data traffic.\nAcceptable port range is 1024 to 49151.\nIf no port is set or is set to 0, the default port (4789) is used.\n";
			readonly type: "integer";
			readonly format: "uint32";
			readonly default: 4789;
			readonly example: 4789;
		};
		readonly DefaultAddrPool: {
			readonly description: "Default Address Pool specifies default subnet pools for global scope\nnetworks.\n";
			readonly type: "array";
			readonly items: {
				readonly type: "string";
				readonly format: "CIDR";
				readonly example: readonly [
					"10.10.0.0/16",
					"20.20.0.0/16"
				];
			};
		};
		readonly SubnetSize: {
			readonly description: "SubnetSize specifies the subnet size of the networks created from the\ndefault subnet pool.\n";
			readonly type: "integer";
			readonly format: "uint32";
			readonly maximum: 29;
			readonly default: 24;
			readonly example: 24;
		};
	};
};
export declare const $JoinTokens: {
	readonly description: "JoinTokens contains the tokens workers and managers need to join the swarm.\n";
	readonly type: "object";
	readonly properties: {
		readonly Worker: {
			readonly description: "The token workers can use to join the swarm.\n";
			readonly type: "string";
			readonly example: "SWMTKN-1-3pu6hszjas19xyp7ghgosyx9k8atbfcr8p2is99znpy26u2lkl-1awxwuwd3z9j1z3puu7rcgdbx";
		};
		readonly Manager: {
			readonly description: "The token managers can use to join the swarm.\n";
			readonly type: "string";
			readonly example: "SWMTKN-1-3pu6hszjas19xyp7ghgosyx9k8atbfcr8p2is99znpy26u2lkl-7p73s1dx5in4tatdymyhg9hu2";
		};
	};
};
export declare const $Swarm: {
	readonly type: "object";
	readonly allOf: readonly [
		{
			readonly $ref: "#/definitions/ClusterInfo";
		},
		{
			readonly type: "object";
			readonly properties: {
				readonly JoinTokens: {
					readonly $ref: "#/definitions/JoinTokens";
				};
			};
		}
	];
};
export declare const $TaskSpec: {
	readonly description: "User modifiable task configuration.";
	readonly type: "object";
	readonly properties: {
		readonly PluginSpec: {
			readonly type: "object";
			readonly description: "Plugin spec for the service.  *(Experimental release only.)*\n\n<p><br /></p>\n\n> **Note**: ContainerSpec, NetworkAttachmentSpec, and PluginSpec are\n> mutually exclusive. PluginSpec is only used when the Runtime field\n> is set to `plugin`. NetworkAttachmentSpec is used when the Runtime\n> field is set to `attachment`.\n";
			readonly properties: {
				readonly Name: {
					readonly description: "The name or 'alias' to use for the plugin.";
					readonly type: "string";
				};
				readonly Remote: {
					readonly description: "The plugin image reference to use.";
					readonly type: "string";
				};
				readonly Disabled: {
					readonly description: "Disable the plugin once scheduled.";
					readonly type: "boolean";
				};
				readonly PluginPrivilege: {
					readonly type: "array";
					readonly items: {
						readonly $ref: "#/definitions/PluginPrivilege";
					};
				};
			};
		};
		readonly ContainerSpec: {
			readonly type: "object";
			readonly description: "Container spec for the service.\n\n<p><br /></p>\n\n> **Note**: ContainerSpec, NetworkAttachmentSpec, and PluginSpec are\n> mutually exclusive. PluginSpec is only used when the Runtime field\n> is set to `plugin`. NetworkAttachmentSpec is used when the Runtime\n> field is set to `attachment`.\n";
			readonly properties: {
				readonly Image: {
					readonly description: "The image name to use for the container";
					readonly type: "string";
				};
				readonly Labels: {
					readonly description: "User-defined key/value data.";
					readonly type: "object";
					readonly additionalProperties: {
						readonly type: "string";
					};
				};
				readonly Command: {
					readonly description: "The command to be run in the image.";
					readonly type: "array";
					readonly items: {
						readonly type: "string";
					};
				};
				readonly Args: {
					readonly description: "Arguments to the command.";
					readonly type: "array";
					readonly items: {
						readonly type: "string";
					};
				};
				readonly Hostname: {
					readonly description: "The hostname to use for the container, as a valid\n[RFC 1123](https://tools.ietf.org/html/rfc1123) hostname.\n";
					readonly type: "string";
				};
				readonly Env: {
					readonly description: "A list of environment variables in the form `VAR=value`.\n";
					readonly type: "array";
					readonly items: {
						readonly type: "string";
					};
				};
				readonly Dir: {
					readonly description: "The working directory for commands to run in.";
					readonly type: "string";
				};
				readonly User: {
					readonly description: "The user inside the container.";
					readonly type: "string";
				};
				readonly Groups: {
					readonly type: "array";
					readonly description: "A list of additional groups that the container process will run as.\n";
					readonly items: {
						readonly type: "string";
					};
				};
				readonly Privileges: {
					readonly type: "object";
					readonly description: "Security options for the container";
					readonly properties: {
						readonly CredentialSpec: {
							readonly type: "object";
							readonly description: "CredentialSpec for managed service account (Windows only)";
							readonly properties: {
								readonly Config: {
									readonly type: "string";
									readonly example: "0bt9dmxjvjiqermk6xrop3ekq";
									readonly description: "Load credential spec from a Swarm Config with the given ID.\nThe specified config must also be present in the Configs\nfield with the Runtime property set.\n\n<p><br /></p>\n\n\n> **Note**: `CredentialSpec.File`, `CredentialSpec.Registry`,\n> and `CredentialSpec.Config` are mutually exclusive.\n";
								};
								readonly File: {
									readonly type: "string";
									readonly example: "spec.json";
									readonly description: "Load credential spec from this file. The file is read by\nthe daemon, and must be present in the `CredentialSpecs`\nsubdirectory in the docker data directory, which defaults\nto `C:ProgramDataDocker` on Windows.\n\nFor example, specifying `spec.json` loads\n`C:ProgramDataDockerCredentialSpecsspec.json`.\n\n<p><br /></p>\n\n> **Note**: `CredentialSpec.File`, `CredentialSpec.Registry`,\n> and `CredentialSpec.Config` are mutually exclusive.\n";
								};
								readonly Registry: {
									readonly type: "string";
									readonly description: "Load credential spec from this value in the Windows\nregistry. The specified registry value must be located in:\n\n`HKLMSOFTWAREMicrosoftWindows NTCurrentVersionVirtualizationContainersCredentialSpecs`\n\n<p><br /></p>\n\n\n> **Note**: `CredentialSpec.File`, `CredentialSpec.Registry`,\n> and `CredentialSpec.Config` are mutually exclusive.\n";
								};
							};
						};
						readonly SELinuxContext: {
							readonly type: "object";
							readonly description: "SELinux labels of the container";
							readonly properties: {
								readonly Disable: {
									readonly type: "boolean";
									readonly description: "Disable SELinux";
								};
								readonly User: {
									readonly type: "string";
									readonly description: "SELinux user label";
								};
								readonly Role: {
									readonly type: "string";
									readonly description: "SELinux role label";
								};
								readonly Type: {
									readonly type: "string";
									readonly description: "SELinux type label";
								};
								readonly Level: {
									readonly type: "string";
									readonly description: "SELinux level label";
								};
							};
						};
						readonly Seccomp: {
							readonly type: "object";
							readonly description: "Options for configuring seccomp on the container";
							readonly properties: {
								readonly Mode: {
									readonly type: "string";
									readonly enum: readonly [
										"default",
										"unconfined",
										"custom"
									];
								};
								readonly Profile: {
									readonly description: "The custom seccomp profile as a json object";
									readonly type: "string";
								};
							};
						};
						readonly AppArmor: {
							readonly type: "object";
							readonly description: "Options for configuring AppArmor on the container";
							readonly properties: {
								readonly Mode: {
									readonly type: "string";
									readonly enum: readonly [
										"default",
										"disabled"
									];
								};
							};
						};
						readonly NoNewPrivileges: {
							readonly type: "boolean";
							readonly description: "Configuration of the no_new_privs bit in the container";
						};
					};
				};
				readonly TTY: {
					readonly description: "Whether a pseudo-TTY should be allocated.";
					readonly type: "boolean";
				};
				readonly OpenStdin: {
					readonly description: "Open `stdin`";
					readonly type: "boolean";
				};
				readonly ReadOnly: {
					readonly description: "Mount the container's root filesystem as read only.";
					readonly type: "boolean";
				};
				readonly Mounts: {
					readonly description: "Specification for mounts to be added to containers created as part\nof the service.\n";
					readonly type: "array";
					readonly items: {
						readonly $ref: "#/definitions/Mount";
					};
				};
				readonly StopSignal: {
					readonly description: "Signal to stop the container.";
					readonly type: "string";
				};
				readonly StopGracePeriod: {
					readonly description: "Amount of time to wait for the container to terminate before\nforcefully killing it.\n";
					readonly type: "integer";
					readonly format: "int64";
				};
				readonly HealthCheck: {
					readonly $ref: "#/definitions/HealthConfig";
				};
				readonly Hosts: {
					readonly type: "array";
					readonly description: "A list of hostname/IP mappings to add to the container's `hosts`\nfile. The format of extra hosts is specified in the\n[hosts(5)](http://man7.org/linux/man-pages/man5/hosts.5.html)\nman page:\n\n    IP_address canonical_hostname [aliases...]\n";
					readonly items: {
						readonly type: "string";
					};
				};
				readonly DNSConfig: {
					readonly description: "Specification for DNS related configurations in resolver configuration\nfile (`resolv.conf`).\n";
					readonly type: "object";
					readonly properties: {
						readonly Nameservers: {
							readonly description: "The IP addresses of the name servers.";
							readonly type: "array";
							readonly items: {
								readonly type: "string";
							};
						};
						readonly Search: {
							readonly description: "A search list for host-name lookup.";
							readonly type: "array";
							readonly items: {
								readonly type: "string";
							};
						};
						readonly Options: {
							readonly description: "A list of internal resolver variables to be modified (e.g.,\n`debug`, `ndots:3`, etc.).\n";
							readonly type: "array";
							readonly items: {
								readonly type: "string";
							};
						};
					};
				};
				readonly Secrets: {
					readonly description: "Secrets contains references to zero or more secrets that will be\nexposed to the service.\n";
					readonly type: "array";
					readonly items: {
						readonly type: "object";
						readonly properties: {
							readonly File: {
								readonly description: "File represents a specific target that is backed by a file.\n";
								readonly type: "object";
								readonly properties: {
									readonly Name: {
										readonly description: "Name represents the final filename in the filesystem.\n";
										readonly type: "string";
									};
									readonly UID: {
										readonly description: "UID represents the file UID.";
										readonly type: "string";
									};
									readonly GID: {
										readonly description: "GID represents the file GID.";
										readonly type: "string";
									};
									readonly Mode: {
										readonly description: "Mode represents the FileMode of the file.";
										readonly type: "integer";
										readonly format: "uint32";
									};
								};
							};
							readonly SecretID: {
								readonly description: "SecretID represents the ID of the specific secret that we're\nreferencing.\n";
								readonly type: "string";
							};
							readonly SecretName: {
								readonly description: "SecretName is the name of the secret that this references,\nbut this is just provided for lookup/display purposes. The\nsecret in the reference will be identified by its ID.\n";
								readonly type: "string";
							};
						};
					};
				};
				readonly Configs: {
					readonly description: "Configs contains references to zero or more configs that will be\nexposed to the service.\n";
					readonly type: "array";
					readonly items: {
						readonly type: "object";
						readonly properties: {
							readonly File: {
								readonly description: "File represents a specific target that is backed by a file.\n\n<p><br /><p>\n\n> **Note**: `Configs.File` and `Configs.Runtime` are mutually exclusive\n";
								readonly type: "object";
								readonly properties: {
									readonly Name: {
										readonly description: "Name represents the final filename in the filesystem.\n";
										readonly type: "string";
									};
									readonly UID: {
										readonly description: "UID represents the file UID.";
										readonly type: "string";
									};
									readonly GID: {
										readonly description: "GID represents the file GID.";
										readonly type: "string";
									};
									readonly Mode: {
										readonly description: "Mode represents the FileMode of the file.";
										readonly type: "integer";
										readonly format: "uint32";
									};
								};
							};
							readonly Runtime: {
								readonly description: "Runtime represents a target that is not mounted into the\ncontainer but is used by the task\n\n<p><br /><p>\n\n> **Note**: `Configs.File` and `Configs.Runtime` are mutually\n> exclusive\n";
								readonly type: "object";
							};
							readonly ConfigID: {
								readonly description: "ConfigID represents the ID of the specific config that we're\nreferencing.\n";
								readonly type: "string";
							};
							readonly ConfigName: {
								readonly description: "ConfigName is the name of the config that this references,\nbut this is just provided for lookup/display purposes. The\nconfig in the reference will be identified by its ID.\n";
								readonly type: "string";
							};
						};
					};
				};
				readonly Isolation: {
					readonly type: "string";
					readonly description: "Isolation technology of the containers running the service.\n(Windows only)\n";
					readonly enum: readonly [
						"default",
						"process",
						"hyperv"
					];
				};
				readonly Init: {
					readonly description: "Run an init inside the container that forwards signals and reaps\nprocesses. This field is omitted if empty, and the default (as\nconfigured on the daemon) is used.\n";
					readonly type: "boolean";
					readonly "x-nullable": true;
				};
				readonly Sysctls: {
					readonly description: "Set kernel namedspaced parameters (sysctls) in the container.\nThe Sysctls option on services accepts the same sysctls as the\nare supported on containers. Note that while the same sysctls are\nsupported, no guarantees or checks are made about their\nsuitability for a clustered environment, and it's up to the user\nto determine whether a given sysctl will work properly in a\nService.\n";
					readonly type: "object";
					readonly additionalProperties: {
						readonly type: "string";
					};
				};
				readonly CapabilityAdd: {
					readonly type: "array";
					readonly description: "A list of kernel capabilities to add to the default set\nfor the container.\n";
					readonly items: {
						readonly type: "string";
					};
					readonly example: readonly [
						"CAP_NET_RAW",
						"CAP_SYS_ADMIN",
						"CAP_SYS_CHROOT",
						"CAP_SYSLOG"
					];
				};
				readonly CapabilityDrop: {
					readonly type: "array";
					readonly description: "A list of kernel capabilities to drop from the default set\nfor the container.\n";
					readonly items: {
						readonly type: "string";
					};
					readonly example: readonly [
						"CAP_NET_RAW"
					];
				};
				readonly Ulimits: {
					readonly description: "A list of resource limits to set in the container. For example: `{\"Name\": \"nofile\", \"Soft\": 1024, \"Hard\": 2048}`\"\n";
					readonly type: "array";
					readonly items: {
						readonly type: "object";
						readonly properties: {
							readonly Name: {
								readonly description: "Name of ulimit";
								readonly type: "string";
							};
							readonly Soft: {
								readonly description: "Soft limit";
								readonly type: "integer";
							};
							readonly Hard: {
								readonly description: "Hard limit";
								readonly type: "integer";
							};
						};
					};
				};
			};
		};
		readonly NetworkAttachmentSpec: {
			readonly description: "Read-only spec type for non-swarm containers attached to swarm overlay\nnetworks.\n\n<p><br /></p>\n\n> **Note**: ContainerSpec, NetworkAttachmentSpec, and PluginSpec are\n> mutually exclusive. PluginSpec is only used when the Runtime field\n> is set to `plugin`. NetworkAttachmentSpec is used when the Runtime\n> field is set to `attachment`.\n";
			readonly type: "object";
			readonly properties: {
				readonly ContainerID: {
					readonly description: "ID of the container represented by this task";
					readonly type: "string";
				};
			};
		};
		readonly Resources: {
			readonly description: "Resource requirements which apply to each individual container created\nas part of the service.\n";
			readonly type: "object";
			readonly properties: {
				readonly Limits: {
					readonly description: "Define resources limits.";
					readonly $ref: "#/definitions/Limit";
				};
				readonly Reservations: {
					readonly description: "Define resources reservation.";
					readonly $ref: "#/definitions/ResourceObject";
				};
			};
		};
		readonly RestartPolicy: {
			readonly description: "Specification for the restart policy which applies to containers\ncreated as part of this service.\n";
			readonly type: "object";
			readonly properties: {
				readonly Condition: {
					readonly description: "Condition for restart.";
					readonly type: "string";
					readonly enum: readonly [
						"none",
						"on-failure",
						"any"
					];
				};
				readonly Delay: {
					readonly description: "Delay between restart attempts.";
					readonly type: "integer";
					readonly format: "int64";
				};
				readonly MaxAttempts: {
					readonly description: "Maximum attempts to restart a given container before giving up\n(default value is 0, which is ignored).\n";
					readonly type: "integer";
					readonly format: "int64";
					readonly default: 0;
				};
				readonly Window: {
					readonly description: "Windows is the time window used to evaluate the restart policy\n(default value is 0, which is unbounded).\n";
					readonly type: "integer";
					readonly format: "int64";
					readonly default: 0;
				};
			};
		};
		readonly Placement: {
			readonly type: "object";
			readonly properties: {
				readonly Constraints: {
					readonly description: "An array of constraint expressions to limit the set of nodes where\na task can be scheduled. Constraint expressions can either use a\n_match_ (`==`) or _exclude_ (`!=`) rule. Multiple constraints find\nnodes that satisfy every expression (AND match). Constraints can\nmatch node or Docker Engine labels as follows:\n\nnode attribute       | matches                        | example\n---------------------|--------------------------------|-----------------------------------------------\n`node.id`            | Node ID                        | `node.id==2ivku8v2gvtg4`\n`node.hostname`      | Node hostname                  | `node.hostname!=node-2`\n`node.role`          | Node role (`manager`/`worker`) | `node.role==manager`\n`node.platform.os`   | Node operating system          | `node.platform.os==windows`\n`node.platform.arch` | Node architecture              | `node.platform.arch==x86_64`\n`node.labels`        | User-defined node labels       | `node.labels.security==high`\n`engine.labels`      | Docker Engine's labels         | `engine.labels.operatingsystem==ubuntu-14.04`\n\n`engine.labels` apply to Docker Engine labels like operating system,\ndrivers, etc. Swarm administrators add `node.labels` for operational\npurposes by using the [`node update endpoint`](#operation/NodeUpdate).\n";
					readonly type: "array";
					readonly items: {
						readonly type: "string";
					};
					readonly example: readonly [
						"node.hostname!=node3.corp.example.com",
						"node.role!=manager",
						"node.labels.type==production",
						"node.platform.os==linux",
						"node.platform.arch==x86_64"
					];
				};
				readonly Preferences: {
					readonly description: "Preferences provide a way to make the scheduler aware of factors\nsuch as topology. They are provided in order from highest to\nlowest precedence.\n";
					readonly type: "array";
					readonly items: {
						readonly type: "object";
						readonly properties: {
							readonly Spread: {
								readonly type: "object";
								readonly properties: {
									readonly SpreadDescriptor: {
										readonly description: "label descriptor, such as `engine.labels.az`.\n";
										readonly type: "string";
									};
								};
							};
						};
					};
					readonly example: readonly [
						{
							readonly Spread: {
								readonly SpreadDescriptor: "node.labels.datacenter";
							};
						},
						{
							readonly Spread: {
								readonly SpreadDescriptor: "node.labels.rack";
							};
						}
					];
				};
				readonly MaxReplicas: {
					readonly description: "Maximum number of replicas for per node (default value is 0, which\nis unlimited)\n";
					readonly type: "integer";
					readonly format: "int64";
					readonly default: 0;
				};
				readonly Platforms: {
					readonly description: "Platforms stores all the platforms that the service's image can\nrun on. This field is used in the platform filter for scheduling.\nIf empty, then the platform filter is off, meaning there are no\nscheduling restrictions.\n";
					readonly type: "array";
					readonly items: {
						readonly $ref: "#/definitions/Platform";
					};
				};
			};
		};
		readonly ForceUpdate: {
			readonly description: "A counter that triggers an update even if no relevant parameters have\nbeen changed.\n";
			readonly type: "integer";
		};
		readonly Runtime: {
			readonly description: "Runtime is the type of runtime specified for the task executor.\n";
			readonly type: "string";
		};
		readonly Networks: {
			readonly description: "Specifies which networks the service should attach to.";
			readonly type: "array";
			readonly items: {
				readonly $ref: "#/definitions/NetworkAttachmentConfig";
			};
		};
		readonly LogDriver: {
			readonly description: "Specifies the log driver to use for tasks created from this spec. If\nnot present, the default one for the swarm will be used, finally\nfalling back to the engine default if not specified.\n";
			readonly type: "object";
			readonly properties: {
				readonly Name: {
					readonly type: "string";
				};
				readonly Options: {
					readonly type: "object";
					readonly additionalProperties: {
						readonly type: "string";
					};
				};
			};
		};
	};
};
export declare const $TaskState: {
	readonly type: "string";
	readonly enum: readonly [
		"new",
		"allocated",
		"pending",
		"assigned",
		"accepted",
		"preparing",
		"ready",
		"starting",
		"running",
		"complete",
		"shutdown",
		"failed",
		"rejected",
		"remove",
		"orphaned"
	];
};
export declare const $ContainerStatus: {
	readonly type: "object";
	readonly description: "represents the status of a container.";
	readonly properties: {
		readonly ContainerID: {
			readonly type: "string";
		};
		readonly PID: {
			readonly type: "integer";
		};
		readonly ExitCode: {
			readonly type: "integer";
		};
	};
};
export declare const $PortStatus: {
	readonly type: "object";
	readonly description: "represents the port status of a task's host ports whose service has published host ports";
	readonly properties: {
		readonly Ports: {
			readonly type: "array";
			readonly items: {
				readonly $ref: "#/definitions/EndpointPortConfig";
			};
		};
	};
};
export declare const $TaskStatus: {
	readonly type: "object";
	readonly description: "represents the status of a task.";
	readonly properties: {
		readonly Timestamp: {
			readonly type: "string";
			readonly format: "dateTime";
		};
		readonly State: {
			readonly $ref: "#/definitions/TaskState";
		};
		readonly Message: {
			readonly type: "string";
		};
		readonly Err: {
			readonly type: "string";
		};
		readonly ContainerStatus: {
			readonly $ref: "#/definitions/ContainerStatus";
		};
		readonly PortStatus: {
			readonly $ref: "#/definitions/PortStatus";
		};
	};
};
export declare const $Task: {
	readonly type: "object";
	readonly properties: {
		readonly ID: {
			readonly description: "The ID of the task.";
			readonly type: "string";
		};
		readonly Version: {
			readonly $ref: "#/definitions/ObjectVersion";
		};
		readonly CreatedAt: {
			readonly type: "string";
			readonly format: "dateTime";
		};
		readonly UpdatedAt: {
			readonly type: "string";
			readonly format: "dateTime";
		};
		readonly Name: {
			readonly description: "Name of the task.";
			readonly type: "string";
		};
		readonly Labels: {
			readonly description: "User-defined key/value metadata.";
			readonly type: "object";
			readonly additionalProperties: {
				readonly type: "string";
			};
		};
		readonly Spec: {
			readonly $ref: "#/definitions/TaskSpec";
		};
		readonly ServiceID: {
			readonly description: "The ID of the service this task is part of.";
			readonly type: "string";
		};
		readonly Slot: {
			readonly type: "integer";
		};
		readonly NodeID: {
			readonly description: "The ID of the node that this task is on.";
			readonly type: "string";
		};
		readonly AssignedGenericResources: {
			readonly $ref: "#/definitions/GenericResources";
		};
		readonly Status: {
			readonly $ref: "#/definitions/TaskStatus";
		};
		readonly DesiredState: {
			readonly $ref: "#/definitions/TaskState";
		};
		readonly JobIteration: {
			readonly description: "If the Service this Task belongs to is a job-mode service, contains\nthe JobIteration of the Service this Task was created for. Absent if\nthe Task was created for a Replicated or Global Service.\n";
			readonly $ref: "#/definitions/ObjectVersion";
		};
	};
	readonly example: {
		readonly ID: "0kzzo1i0y4jz6027t0k7aezc7";
		readonly Version: {
			readonly Index: 71;
		};
		readonly CreatedAt: "2016-06-07T21:07:31.171892745Z";
		readonly UpdatedAt: "2016-06-07T21:07:31.376370513Z";
		readonly Spec: {
			readonly ContainerSpec: {
				readonly Image: "redis";
			};
			readonly Resources: {
				readonly Limits: {};
				readonly Reservations: {};
			};
			readonly RestartPolicy: {
				readonly Condition: "any";
				readonly MaxAttempts: 0;
			};
			readonly Placement: {};
		};
		readonly ServiceID: "9mnpnzenvg8p8tdbtq4wvbkcz";
		readonly Slot: 1;
		readonly NodeID: "60gvrl6tm78dmak4yl7srz94v";
		readonly Status: {
			readonly Timestamp: "2016-06-07T21:07:31.290032978Z";
			readonly State: "running";
			readonly Message: "started";
			readonly ContainerStatus: {
				readonly ContainerID: "e5d62702a1b48d01c3e02ca1e0212a250801fa8d67caca0b6f35919ebc12f035";
				readonly PID: 677;
			};
		};
		readonly DesiredState: "running";
		readonly NetworksAttachments: readonly [
			{
				readonly Network: {
					readonly ID: "4qvuz4ko70xaltuqbt8956gd1";
					readonly Version: {
						readonly Index: 18;
					};
					readonly CreatedAt: "2016-06-07T20:31:11.912919752Z";
					readonly UpdatedAt: "2016-06-07T21:07:29.955277358Z";
					readonly Spec: {
						readonly Name: "ingress";
						readonly Labels: {
							readonly "com.docker.swarm.internal": "true";
						};
						readonly DriverConfiguration: {};
						readonly IPAMOptions: {
							readonly Driver: {};
							readonly Configs: readonly [
								{
									readonly Subnet: "10.255.0.0/16";
									readonly Gateway: "10.255.0.1";
								}
							];
						};
					};
					readonly DriverState: {
						readonly Name: "overlay";
						readonly Options: {
							readonly "com.docker.network.driver.overlay.vxlanid_list": "256";
						};
					};
					readonly IPAMOptions: {
						readonly Driver: {
							readonly Name: "default";
						};
						readonly Configs: readonly [
							{
								readonly Subnet: "10.255.0.0/16";
								readonly Gateway: "10.255.0.1";
							}
						];
					};
				};
				readonly Addresses: readonly [
					"10.255.0.10/16"
				];
			}
		];
		readonly AssignedGenericResources: readonly [
			{
				readonly DiscreteResourceSpec: {
					readonly Kind: "SSD";
					readonly Value: 3;
				};
			},
			{
				readonly NamedResourceSpec: {
					readonly Kind: "GPU";
					readonly Value: "UUID1";
				};
			},
			{
				readonly NamedResourceSpec: {
					readonly Kind: "GPU";
					readonly Value: "UUID2";
				};
			}
		];
	};
};
export declare const $ServiceSpec: {
	readonly description: "User modifiable configuration for a service.";
	readonly type: "object";
	readonly properties: {
		readonly Name: {
			readonly description: "Name of the service.";
			readonly type: "string";
		};
		readonly Labels: {
			readonly description: "User-defined key/value metadata.";
			readonly type: "object";
			readonly additionalProperties: {
				readonly type: "string";
			};
		};
		readonly TaskTemplate: {
			readonly $ref: "#/definitions/TaskSpec";
		};
		readonly Mode: {
			readonly description: "Scheduling mode for the service.";
			readonly type: "object";
			readonly properties: {
				readonly Replicated: {
					readonly type: "object";
					readonly properties: {
						readonly Replicas: {
							readonly type: "integer";
							readonly format: "int64";
						};
					};
				};
				readonly Global: {
					readonly type: "object";
				};
				readonly ReplicatedJob: {
					readonly description: "The mode used for services with a finite number of tasks that run\nto a completed state.\n";
					readonly type: "object";
					readonly properties: {
						readonly MaxConcurrent: {
							readonly description: "The maximum number of replicas to run simultaneously.\n";
							readonly type: "integer";
							readonly format: "int64";
							readonly default: 1;
						};
						readonly TotalCompletions: {
							readonly description: "The total number of replicas desired to reach the Completed\nstate. If unset, will default to the value of `MaxConcurrent`\n";
							readonly type: "integer";
							readonly format: "int64";
						};
					};
				};
				readonly GlobalJob: {
					readonly description: "The mode used for services which run a task to the completed state\non each valid node.\n";
					readonly type: "object";
				};
			};
		};
		readonly UpdateConfig: {
			readonly description: "Specification for the update strategy of the service.";
			readonly type: "object";
			readonly properties: {
				readonly Parallelism: {
					readonly description: "Maximum number of tasks to be updated in one iteration (0 means\nunlimited parallelism).\n";
					readonly type: "integer";
					readonly format: "int64";
				};
				readonly Delay: {
					readonly description: "Amount of time between updates, in nanoseconds.";
					readonly type: "integer";
					readonly format: "int64";
				};
				readonly FailureAction: {
					readonly description: "Action to take if an updated task fails to run, or stops running\nduring the update.\n";
					readonly type: "string";
					readonly enum: readonly [
						"continue",
						"pause",
						"rollback"
					];
				};
				readonly Monitor: {
					readonly description: "Amount of time to monitor each updated task for failures, in\nnanoseconds.\n";
					readonly type: "integer";
					readonly format: "int64";
				};
				readonly MaxFailureRatio: {
					readonly description: "The fraction of tasks that may fail during an update before the\nfailure action is invoked, specified as a floating point number\nbetween 0 and 1.\n";
					readonly type: "number";
					readonly default: 0;
				};
				readonly Order: {
					readonly description: "The order of operations when rolling out an updated task. Either\nthe old task is shut down before the new task is started, or the\nnew task is started before the old task is shut down.\n";
					readonly type: "string";
					readonly enum: readonly [
						"stop-first",
						"start-first"
					];
				};
			};
		};
		readonly RollbackConfig: {
			readonly description: "Specification for the rollback strategy of the service.";
			readonly type: "object";
			readonly properties: {
				readonly Parallelism: {
					readonly description: "Maximum number of tasks to be rolled back in one iteration (0 means\nunlimited parallelism).\n";
					readonly type: "integer";
					readonly format: "int64";
				};
				readonly Delay: {
					readonly description: "Amount of time between rollback iterations, in nanoseconds.\n";
					readonly type: "integer";
					readonly format: "int64";
				};
				readonly FailureAction: {
					readonly description: "Action to take if an rolled back task fails to run, or stops\nrunning during the rollback.\n";
					readonly type: "string";
					readonly enum: readonly [
						"continue",
						"pause"
					];
				};
				readonly Monitor: {
					readonly description: "Amount of time to monitor each rolled back task for failures, in\nnanoseconds.\n";
					readonly type: "integer";
					readonly format: "int64";
				};
				readonly MaxFailureRatio: {
					readonly description: "The fraction of tasks that may fail during a rollback before the\nfailure action is invoked, specified as a floating point number\nbetween 0 and 1.\n";
					readonly type: "number";
					readonly default: 0;
				};
				readonly Order: {
					readonly description: "The order of operations when rolling back a task. Either the old\ntask is shut down before the new task is started, or the new task\nis started before the old task is shut down.\n";
					readonly type: "string";
					readonly enum: readonly [
						"stop-first",
						"start-first"
					];
				};
			};
		};
		readonly Networks: {
			readonly description: "Specifies which networks the service should attach to.\n\nDeprecated: This field is deprecated since v1.44. The Networks field in TaskSpec should be used instead.\n";
			readonly type: "array";
			readonly items: {
				readonly $ref: "#/definitions/NetworkAttachmentConfig";
			};
		};
		readonly EndpointSpec: {
			readonly $ref: "#/definitions/EndpointSpec";
		};
	};
};
export declare const $EndpointPortConfig: {
	readonly type: "object";
	readonly properties: {
		readonly Name: {
			readonly type: "string";
		};
		readonly Protocol: {
			readonly type: "string";
			readonly enum: readonly [
				"tcp",
				"udp",
				"sctp"
			];
		};
		readonly TargetPort: {
			readonly description: "The port inside the container.";
			readonly type: "integer";
		};
		readonly PublishedPort: {
			readonly description: "The port on the swarm hosts.";
			readonly type: "integer";
		};
		readonly PublishMode: {
			readonly description: "The mode in which port is published.\n\n<p><br /></p>\n\n- \"ingress\" makes the target port accessible on every node,\n  regardless of whether there is a task for the service running on\n  that node or not.\n- \"host\" bypasses the routing mesh and publish the port directly on\n  the swarm node where that service is running.\n";
			readonly type: "string";
			readonly enum: readonly [
				"ingress",
				"host"
			];
			readonly default: "ingress";
			readonly example: "ingress";
		};
	};
};
export declare const $EndpointSpec: {
	readonly description: "Properties that can be configured to access and load balance a service.";
	readonly type: "object";
	readonly properties: {
		readonly Mode: {
			readonly description: "The mode of resolution to use for internal load balancing between tasks.\n";
			readonly type: "string";
			readonly enum: readonly [
				"vip",
				"dnsrr"
			];
			readonly default: "vip";
		};
		readonly Ports: {
			readonly description: "List of exposed ports that this service is accessible on from the\noutside. Ports can only be provided if `vip` resolution mode is used.\n";
			readonly type: "array";
			readonly items: {
				readonly $ref: "#/definitions/EndpointPortConfig";
			};
		};
	};
};
export declare const $Service: {
	readonly type: "object";
	readonly properties: {
		readonly ID: {
			readonly type: "string";
		};
		readonly Version: {
			readonly $ref: "#/definitions/ObjectVersion";
		};
		readonly CreatedAt: {
			readonly type: "string";
			readonly format: "dateTime";
		};
		readonly UpdatedAt: {
			readonly type: "string";
			readonly format: "dateTime";
		};
		readonly Spec: {
			readonly $ref: "#/definitions/ServiceSpec";
		};
		readonly Endpoint: {
			readonly type: "object";
			readonly properties: {
				readonly Spec: {
					readonly $ref: "#/definitions/EndpointSpec";
				};
				readonly Ports: {
					readonly type: "array";
					readonly items: {
						readonly $ref: "#/definitions/EndpointPortConfig";
					};
				};
				readonly VirtualIPs: {
					readonly type: "array";
					readonly items: {
						readonly type: "object";
						readonly properties: {
							readonly NetworkID: {
								readonly type: "string";
							};
							readonly Addr: {
								readonly type: "string";
							};
						};
					};
				};
			};
		};
		readonly UpdateStatus: {
			readonly description: "The status of a service update.";
			readonly type: "object";
			readonly properties: {
				readonly State: {
					readonly type: "string";
					readonly enum: readonly [
						"updating",
						"paused",
						"completed"
					];
				};
				readonly StartedAt: {
					readonly type: "string";
					readonly format: "dateTime";
				};
				readonly CompletedAt: {
					readonly type: "string";
					readonly format: "dateTime";
				};
				readonly Message: {
					readonly type: "string";
				};
			};
		};
		readonly ServiceStatus: {
			readonly description: "The status of the service's tasks. Provided only when requested as\npart of a ServiceList operation.\n";
			readonly type: "object";
			readonly properties: {
				readonly RunningTasks: {
					readonly description: "The number of tasks for the service currently in the Running state.\n";
					readonly type: "integer";
					readonly format: "uint64";
					readonly example: 7;
				};
				readonly DesiredTasks: {
					readonly description: "The number of tasks for the service desired to be running.\nFor replicated services, this is the replica count from the\nservice spec. For global services, this is computed by taking\ncount of all tasks for the service with a Desired State other\nthan Shutdown.\n";
					readonly type: "integer";
					readonly format: "uint64";
					readonly example: 10;
				};
				readonly CompletedTasks: {
					readonly description: "The number of tasks for a job that are in the Completed state.\nThis field must be cross-referenced with the service type, as the\nvalue of 0 may mean the service is not in a job mode, or it may\nmean the job-mode service has no tasks yet Completed.\n";
					readonly type: "integer";
					readonly format: "uint64";
				};
			};
		};
		readonly JobStatus: {
			readonly description: "The status of the service when it is in one of ReplicatedJob or\nGlobalJob modes. Absent on Replicated and Global mode services. The\nJobIteration is an ObjectVersion, but unlike the Service's version,\ndoes not need to be sent with an update request.\n";
			readonly type: "object";
			readonly properties: {
				readonly JobIteration: {
					readonly description: "JobIteration is a value increased each time a Job is executed,\nsuccessfully or otherwise. \"Executed\", in this case, means the\njob as a whole has been started, not that an individual Task has\nbeen launched. A job is \"Executed\" when its ServiceSpec is\nupdated. JobIteration can be used to disambiguate Tasks belonging\nto different executions of a job.  Though JobIteration will\nincrease with each subsequent execution, it may not necessarily\nincrease by 1, and so JobIteration should not be used to\n";
					readonly $ref: "#/definitions/ObjectVersion";
				};
				readonly LastExecution: {
					readonly description: "The last time, as observed by the server, that this job was\nstarted.\n";
					readonly type: "string";
					readonly format: "dateTime";
				};
			};
		};
	};
	readonly example: {
		readonly ID: "9mnpnzenvg8p8tdbtq4wvbkcz";
		readonly Version: {
			readonly Index: 19;
		};
		readonly CreatedAt: "2016-06-07T21:05:51.880065305Z";
		readonly UpdatedAt: "2016-06-07T21:07:29.962229872Z";
		readonly Spec: {
			readonly Name: "hopeful_cori";
			readonly TaskTemplate: {
				readonly ContainerSpec: {
					readonly Image: "redis";
				};
				readonly Resources: {
					readonly Limits: {};
					readonly Reservations: {};
				};
				readonly RestartPolicy: {
					readonly Condition: "any";
					readonly MaxAttempts: 0;
				};
				readonly Placement: {};
				readonly ForceUpdate: 0;
			};
			readonly Mode: {
				readonly Replicated: {
					readonly Replicas: 1;
				};
			};
			readonly UpdateConfig: {
				readonly Parallelism: 1;
				readonly Delay: 1000000000;
				readonly FailureAction: "pause";
				readonly Monitor: 15000000000;
				readonly MaxFailureRatio: 0.15;
			};
			readonly RollbackConfig: {
				readonly Parallelism: 1;
				readonly Delay: 1000000000;
				readonly FailureAction: "pause";
				readonly Monitor: 15000000000;
				readonly MaxFailureRatio: 0.15;
			};
			readonly EndpointSpec: {
				readonly Mode: "vip";
				readonly Ports: readonly [
					{
						readonly Protocol: "tcp";
						readonly TargetPort: 6379;
						readonly PublishedPort: 30001;
					}
				];
			};
		};
		readonly Endpoint: {
			readonly Spec: {
				readonly Mode: "vip";
				readonly Ports: readonly [
					{
						readonly Protocol: "tcp";
						readonly TargetPort: 6379;
						readonly PublishedPort: 30001;
					}
				];
			};
			readonly Ports: readonly [
				{
					readonly Protocol: "tcp";
					readonly TargetPort: 6379;
					readonly PublishedPort: 30001;
				}
			];
			readonly VirtualIPs: readonly [
				{
					readonly NetworkID: "4qvuz4ko70xaltuqbt8956gd1";
					readonly Addr: "10.255.0.2/16";
				},
				{
					readonly NetworkID: "4qvuz4ko70xaltuqbt8956gd1";
					readonly Addr: "10.255.0.3/16";
				}
			];
		};
	};
};
export declare const $ImageDeleteResponseItem: {
	readonly type: "object";
	readonly "x-go-name": "DeleteResponse";
	readonly properties: {
		readonly Untagged: {
			readonly description: "The image ID of an image that was untagged";
			readonly type: "string";
		};
		readonly Deleted: {
			readonly description: "The image ID of an image that was deleted";
			readonly type: "string";
		};
	};
};
export declare const $ServiceCreateResponse: {
	readonly type: "object";
	readonly description: "contains the information returned to a client on the\ncreation of a new service.\n";
	readonly properties: {
		readonly ID: {
			readonly description: "The ID of the created service.";
			readonly type: "string";
			readonly "x-nullable": false;
			readonly example: "ak7w3gjqoa3kuz8xcpnyy0pvl";
		};
		readonly Warnings: {
			readonly description: "Optional warning message.\n\nFIXME(thaJeztah): this should have \"omitempty\" in the generated type.\n";
			readonly type: "array";
			readonly "x-nullable": true;
			readonly items: {
				readonly type: "string";
			};
			readonly example: readonly [
				"unable to pin image doesnotexist:latest to digest: image library/doesnotexist:latest not found"
			];
		};
	};
};
export declare const $ServiceUpdateResponse: {
	readonly type: "object";
	readonly properties: {
		readonly Warnings: {
			readonly description: "Optional warning messages";
			readonly type: "array";
			readonly items: {
				readonly type: "string";
			};
		};
	};
	readonly example: {
		readonly Warnings: readonly [
			"unable to pin image doesnotexist:latest to digest: image library/doesnotexist:latest not found"
		];
	};
};
export declare const $ContainerSummary: {
	readonly type: "object";
	readonly properties: {
		readonly Id: {
			readonly description: "The ID of this container";
			readonly type: "string";
			readonly "x-go-name": "ID";
		};
		readonly Names: {
			readonly description: "The names that this container has been given";
			readonly type: "array";
			readonly items: {
				readonly type: "string";
			};
		};
		readonly Image: {
			readonly description: "The name of the image used when creating this container";
			readonly type: "string";
		};
		readonly ImageID: {
			readonly description: "The ID of the image that this container was created from";
			readonly type: "string";
		};
		readonly Command: {
			readonly description: "Command to run when starting the container";
			readonly type: "string";
		};
		readonly Created: {
			readonly description: "When the container was created";
			readonly type: "integer";
			readonly format: "int64";
		};
		readonly Ports: {
			readonly description: "The ports exposed by this container";
			readonly type: "array";
			readonly items: {
				readonly $ref: "#/definitions/Port";
			};
		};
		readonly SizeRw: {
			readonly description: "The size of files that have been created or changed by this container";
			readonly type: "integer";
			readonly format: "int64";
		};
		readonly SizeRootFs: {
			readonly description: "The total size of all the files in this container";
			readonly type: "integer";
			readonly format: "int64";
		};
		readonly Labels: {
			readonly description: "User-defined key/value metadata.";
			readonly type: "object";
			readonly additionalProperties: {
				readonly type: "string";
			};
		};
		readonly State: {
			readonly description: "The state of this container (e.g. `Exited`)";
			readonly type: "string";
		};
		readonly Status: {
			readonly description: "Additional human-readable status of this container (e.g. `Exit 0`)";
			readonly type: "string";
		};
		readonly HostConfig: {
			readonly type: "object";
			readonly properties: {
				readonly NetworkMode: {
					readonly type: "string";
				};
			};
		};
		readonly NetworkSettings: {
			readonly description: "A summary of the container's network settings";
			readonly type: "object";
			readonly properties: {
				readonly Networks: {
					readonly type: "object";
					readonly additionalProperties: {
						readonly $ref: "#/definitions/EndpointSettings";
					};
				};
			};
		};
		readonly Mounts: {
			readonly type: "array";
			readonly items: {
				readonly $ref: "#/definitions/MountPoint";
			};
		};
	};
};
export declare const $Driver: {
	readonly description: "Driver represents a driver (network, logging, secrets).";
	readonly type: "object";
	readonly required: readonly [
		"Name"
	];
	readonly properties: {
		readonly Name: {
			readonly description: "Name of the driver.";
			readonly type: "string";
			readonly "x-nullable": false;
			readonly example: "some-driver";
		};
		readonly Options: {
			readonly description: "Key/value map of driver-specific options.";
			readonly type: "object";
			readonly "x-nullable": false;
			readonly additionalProperties: {
				readonly type: "string";
			};
			readonly example: {
				readonly OptionA: "value for driver-specific option A";
				readonly OptionB: "value for driver-specific option B";
			};
		};
	};
};
export declare const $SecretSpec: {
	readonly type: "object";
	readonly properties: {
		readonly Name: {
			readonly description: "User-defined name of the secret.";
			readonly type: "string";
		};
		readonly Labels: {
			readonly description: "User-defined key/value metadata.";
			readonly type: "object";
			readonly additionalProperties: {
				readonly type: "string";
			};
			readonly example: {
				readonly "com.example.some-label": "some-value";
				readonly "com.example.some-other-label": "some-other-value";
			};
		};
		readonly Data: {
			readonly description: "Base64-url-safe-encoded ([RFC 4648](https://tools.ietf.org/html/rfc4648#section-5))\ndata to store as secret.\n\nThis field is only used to _create_ a secret, and is not returned by\nother endpoints.\n";
			readonly type: "string";
			readonly example: "";
		};
		readonly Driver: {
			readonly description: "Name of the secrets driver used to fetch the secret's value from an\nexternal secret store.\n";
			readonly $ref: "#/definitions/Driver";
		};
		readonly Templating: {
			readonly description: "Templating driver, if applicable\n\nTemplating controls whether and how to evaluate the config payload as\na template. If no driver is set, no templating is used.\n";
			readonly $ref: "#/definitions/Driver";
		};
	};
};
export declare const $Secret: {
	readonly type: "object";
	readonly properties: {
		readonly ID: {
			readonly type: "string";
			readonly example: "blt1owaxmitz71s9v5zh81zun";
		};
		readonly Version: {
			readonly $ref: "#/definitions/ObjectVersion";
		};
		readonly CreatedAt: {
			readonly type: "string";
			readonly format: "dateTime";
			readonly example: "2017-07-20T13:55:28.678958722Z";
		};
		readonly UpdatedAt: {
			readonly type: "string";
			readonly format: "dateTime";
			readonly example: "2017-07-20T13:55:28.678958722Z";
		};
		readonly Spec: {
			readonly $ref: "#/definitions/SecretSpec";
		};
	};
};
export declare const $ConfigSpec: {
	readonly type: "object";
	readonly properties: {
		readonly Name: {
			readonly description: "User-defined name of the config.";
			readonly type: "string";
		};
		readonly Labels: {
			readonly description: "User-defined key/value metadata.";
			readonly type: "object";
			readonly additionalProperties: {
				readonly type: "string";
			};
		};
		readonly Data: {
			readonly description: "Base64-url-safe-encoded ([RFC 4648](https://tools.ietf.org/html/rfc4648#section-5))\nconfig data.\n";
			readonly type: "string";
		};
		readonly Templating: {
			readonly description: "Templating driver, if applicable\n\nTemplating controls whether and how to evaluate the config payload as\na template. If no driver is set, no templating is used.\n";
			readonly $ref: "#/definitions/Driver";
		};
	};
};
export declare const $Config: {
	readonly type: "object";
	readonly properties: {
		readonly ID: {
			readonly type: "string";
		};
		readonly Version: {
			readonly $ref: "#/definitions/ObjectVersion";
		};
		readonly CreatedAt: {
			readonly type: "string";
			readonly format: "dateTime";
		};
		readonly UpdatedAt: {
			readonly type: "string";
			readonly format: "dateTime";
		};
		readonly Spec: {
			readonly $ref: "#/definitions/ConfigSpec";
		};
	};
};
export declare const $ContainerState: {
	readonly description: "ContainerState stores container's running state. It's part of ContainerJSONBase\nand will be returned by the \"inspect\" command.\n";
	readonly type: "object";
	readonly "x-nullable": true;
	readonly properties: {
		readonly Status: {
			readonly description: "String representation of the container state. Can be one of \"created\",\n\"running\", \"paused\", \"restarting\", \"removing\", \"exited\", or \"dead\".\n";
			readonly type: "string";
			readonly enum: readonly [
				"created",
				"running",
				"paused",
				"restarting",
				"removing",
				"exited",
				"dead"
			];
			readonly example: "running";
		};
		readonly Running: {
			readonly description: "Whether this container is running.\n\nNote that a running container can be _paused_. The `Running` and `Paused`\nbooleans are not mutually exclusive:\n\nWhen pausing a container (on Linux), the freezer cgroup is used to suspend\nall processes in the container. Freezing the process requires the process to\nbe running. As a result, paused containers are both `Running` _and_ `Paused`.\n\nUse the `Status` field instead to determine if a container's state is \"running\".\n";
			readonly type: "boolean";
			readonly example: true;
		};
		readonly Paused: {
			readonly description: "Whether this container is paused.";
			readonly type: "boolean";
			readonly example: false;
		};
		readonly Restarting: {
			readonly description: "Whether this container is restarting.";
			readonly type: "boolean";
			readonly example: false;
		};
		readonly OOMKilled: {
			readonly description: "Whether a process within this container has been killed because it ran\nout of memory since the container was last started.\n";
			readonly type: "boolean";
			readonly example: false;
		};
		readonly Dead: {
			readonly type: "boolean";
			readonly example: false;
		};
		readonly Pid: {
			readonly description: "The process ID of this container";
			readonly type: "integer";
			readonly example: 1234;
		};
		readonly ExitCode: {
			readonly description: "The last exit code of this container";
			readonly type: "integer";
			readonly example: 0;
		};
		readonly Error: {
			readonly type: "string";
		};
		readonly StartedAt: {
			readonly description: "The time when this container was last started.";
			readonly type: "string";
			readonly example: "2020-01-06T09:06:59.461876391Z";
		};
		readonly FinishedAt: {
			readonly description: "The time when this container last exited.";
			readonly type: "string";
			readonly example: "2020-01-06T09:07:59.461876391Z";
		};
		readonly Health: {
			readonly $ref: "#/definitions/Health";
		};
	};
};
export declare const $ContainerCreateResponse: {
	readonly description: "OK response to ContainerCreate operation";
	readonly type: "object";
	readonly title: "ContainerCreateResponse";
	readonly "x-go-name": "CreateResponse";
	readonly required: readonly [
		"Id",
		"Warnings"
	];
	readonly properties: {
		readonly Id: {
			readonly description: "The ID of the created container";
			readonly type: "string";
			readonly "x-nullable": false;
			readonly example: "ede54ee1afda366ab42f824e8a5ffd195155d853ceaec74a927f249ea270c743";
		};
		readonly Warnings: {
			readonly description: "Warnings encountered when creating the container";
			readonly type: "array";
			readonly "x-nullable": false;
			readonly items: {
				readonly type: "string";
			};
			readonly example: readonly [
			];
		};
	};
};
export declare const $ContainerWaitResponse: {
	readonly description: "OK response to ContainerWait operation";
	readonly type: "object";
	readonly "x-go-name": "WaitResponse";
	readonly title: "ContainerWaitResponse";
	readonly required: readonly [
		"StatusCode"
	];
	readonly properties: {
		readonly StatusCode: {
			readonly description: "Exit code of the container";
			readonly type: "integer";
			readonly format: "int64";
			readonly "x-nullable": false;
		};
		readonly Error: {
			readonly $ref: "#/definitions/ContainerWaitExitError";
		};
	};
};
export declare const $ContainerWaitExitError: {
	readonly description: "container waiting error, if any";
	readonly type: "object";
	readonly "x-go-name": "WaitExitError";
	readonly properties: {
		readonly Message: {
			readonly description: "Details of an error";
			readonly type: "string";
		};
	};
};
export declare const $SystemVersion: {
	readonly type: "object";
	readonly description: "Response of Engine API: GET \"/version\"\n";
	readonly properties: {
		readonly Platform: {
			readonly type: "object";
			readonly required: readonly [
				"Name"
			];
			readonly properties: {
				readonly Name: {
					readonly type: "string";
				};
			};
		};
		readonly Components: {
			readonly type: "array";
			readonly description: "Information about system components\n";
			readonly items: {
				readonly type: "object";
				readonly "x-go-name": "ComponentVersion";
				readonly required: readonly [
					"Name",
					"Version"
				];
				readonly properties: {
					readonly Name: {
						readonly description: "Name of the component\n";
						readonly type: "string";
						readonly example: "Engine";
					};
					readonly Version: {
						readonly description: "Version of the component\n";
						readonly type: "string";
						readonly "x-nullable": false;
						readonly example: "19.03.12";
					};
					readonly Details: {
						readonly description: "Key/value pairs of strings with additional information about the\ncomponent. These values are intended for informational purposes\nonly, and their content is not defined, and not part of the API\nspecification.\n\nThese messages can be printed by the client as information to the user.\n";
						readonly type: "object";
						readonly "x-nullable": true;
					};
				};
			};
		};
		readonly Version: {
			readonly description: "The version of the daemon";
			readonly type: "string";
			readonly example: "19.03.12";
		};
		readonly ApiVersion: {
			readonly description: "The default (and highest) API version that is supported by the daemon\n";
			readonly type: "string";
			readonly example: "1.40";
		};
		readonly MinAPIVersion: {
			readonly description: "The minimum API version that is supported by the daemon\n";
			readonly type: "string";
			readonly example: "1.12";
		};
		readonly GitCommit: {
			readonly description: "The Git commit of the source code that was used to build the daemon\n";
			readonly type: "string";
			readonly example: "48a66213fe";
		};
		readonly GoVersion: {
			readonly description: "The version Go used to compile the daemon, and the version of the Go\nruntime in use.\n";
			readonly type: "string";
			readonly example: "go1.13.14";
		};
		readonly Os: {
			readonly description: "The operating system that the daemon is running on (\"linux\" or \"windows\")\n";
			readonly type: "string";
			readonly example: "linux";
		};
		readonly Arch: {
			readonly description: "The architecture that the daemon is running on\n";
			readonly type: "string";
			readonly example: "amd64";
		};
		readonly KernelVersion: {
			readonly description: "The kernel version (`uname -r`) that the daemon is running on.\n\nThis field is omitted when empty.\n";
			readonly type: "string";
			readonly example: "4.19.76-linuxkit";
		};
		readonly Experimental: {
			readonly description: "Indicates if the daemon is started with experimental features enabled.\n\nThis field is omitted when empty / false.\n";
			readonly type: "boolean";
			readonly example: true;
		};
		readonly BuildTime: {
			readonly description: "The date and time that the daemon was compiled.\n";
			readonly type: "string";
			readonly example: "2020-06-22T15:49:27.000000000+00:00";
		};
	};
};
export declare const $SystemInfo: {
	readonly type: "object";
	readonly properties: {
		readonly ID: {
			readonly description: "Unique identifier of the daemon.\n\n<p><br /></p>\n\n> **Note**: The format of the ID itself is not part of the API, and\n> should not be considered stable.\n";
			readonly type: "string";
			readonly example: "7TRN:IPZB:QYBB:VPBQ:UMPP:KARE:6ZNR:XE6T:7EWV:PKF4:ZOJD:TPYS";
		};
		readonly Containers: {
			readonly description: "Total number of containers on the host.";
			readonly type: "integer";
			readonly example: 14;
		};
		readonly ContainersRunning: {
			readonly description: "Number of containers with status `\"running\"`.\n";
			readonly type: "integer";
			readonly example: 3;
		};
		readonly ContainersPaused: {
			readonly description: "Number of containers with status `\"paused\"`.\n";
			readonly type: "integer";
			readonly example: 1;
		};
		readonly ContainersStopped: {
			readonly description: "Number of containers with status `\"stopped\"`.\n";
			readonly type: "integer";
			readonly example: 10;
		};
		readonly Images: {
			readonly description: "Total number of images on the host.\n\nBoth _tagged_ and _untagged_ (dangling) images are counted.\n";
			readonly type: "integer";
			readonly example: 508;
		};
		readonly Driver: {
			readonly description: "Name of the storage driver in use.";
			readonly type: "string";
			readonly example: "overlay2";
		};
		readonly DriverStatus: {
			readonly description: "Information specific to the storage driver, provided as\n\"label\" / \"value\" pairs.\n\nThis information is provided by the storage driver, and formatted\nin a way consistent with the output of `docker info` on the command\nline.\n\n<p><br /></p>\n\n> **Note**: The information returned in this field, including the\n> formatting of values and labels, should not be considered stable,\n> and may change without notice.\n";
			readonly type: "array";
			readonly items: {
				readonly type: "array";
				readonly items: {
					readonly type: "string";
				};
			};
			readonly example: readonly [
				readonly [
					"Backing Filesystem",
					"extfs"
				],
				readonly [
					"Supports d_type",
					"true"
				],
				readonly [
					"Native Overlay Diff",
					"true"
				]
			];
		};
		readonly DockerRootDir: {
			readonly description: "Root directory of persistent Docker state.\n\nDefaults to `/var/lib/docker` on Linux, and `C:ProgramDatadocker`\non Windows.\n";
			readonly type: "string";
			readonly example: "/var/lib/docker";
		};
		readonly Plugins: {
			readonly $ref: "#/definitions/PluginsInfo";
		};
		readonly MemoryLimit: {
			readonly description: "Indicates if the host has memory limit support enabled.";
			readonly type: "boolean";
			readonly example: true;
		};
		readonly SwapLimit: {
			readonly description: "Indicates if the host has memory swap limit support enabled.";
			readonly type: "boolean";
			readonly example: true;
		};
		readonly KernelMemoryTCP: {
			readonly description: "Indicates if the host has kernel memory TCP limit support enabled. This\nfield is omitted if not supported.\n\nKernel memory TCP limits are not supported when using cgroups v2, which\ndoes not support the corresponding `memory.kmem.tcp.limit_in_bytes` cgroup.\n";
			readonly type: "boolean";
			readonly example: true;
		};
		readonly CpuCfsPeriod: {
			readonly description: "Indicates if CPU CFS(Completely Fair Scheduler) period is supported by\nthe host.\n";
			readonly type: "boolean";
			readonly example: true;
		};
		readonly CpuCfsQuota: {
			readonly description: "Indicates if CPU CFS(Completely Fair Scheduler) quota is supported by\nthe host.\n";
			readonly type: "boolean";
			readonly example: true;
		};
		readonly CPUShares: {
			readonly description: "Indicates if CPU Shares limiting is supported by the host.\n";
			readonly type: "boolean";
			readonly example: true;
		};
		readonly CPUSet: {
			readonly description: "Indicates if CPUsets (cpuset.cpus, cpuset.mems) are supported by the host.\n\nSee [cpuset(7)](https://www.kernel.org/doc/Documentation/cgroup-v1/cpusets.txt)\n";
			readonly type: "boolean";
			readonly example: true;
		};
		readonly PidsLimit: {
			readonly description: "Indicates if the host kernel has PID limit support enabled.";
			readonly type: "boolean";
			readonly example: true;
		};
		readonly OomKillDisable: {
			readonly description: "Indicates if OOM killer disable is supported on the host.";
			readonly type: "boolean";
		};
		readonly IPv4Forwarding: {
			readonly description: "Indicates IPv4 forwarding is enabled.";
			readonly type: "boolean";
			readonly example: true;
		};
		readonly BridgeNfIptables: {
			readonly description: "Indicates if `bridge-nf-call-iptables` is available on the host.";
			readonly type: "boolean";
			readonly example: true;
		};
		readonly BridgeNfIp6tables: {
			readonly description: "Indicates if `bridge-nf-call-ip6tables` is available on the host.";
			readonly type: "boolean";
			readonly example: true;
		};
		readonly Debug: {
			readonly description: "Indicates if the daemon is running in debug-mode / with debug-level\nlogging enabled.\n";
			readonly type: "boolean";
			readonly example: true;
		};
		readonly NFd: {
			readonly description: "The total number of file Descriptors in use by the daemon process.\n\nThis information is only returned if debug-mode is enabled.\n";
			readonly type: "integer";
			readonly example: 64;
		};
		readonly NGoroutines: {
			readonly description: "The  number of goroutines that currently exist.\n\nThis information is only returned if debug-mode is enabled.\n";
			readonly type: "integer";
			readonly example: 174;
		};
		readonly SystemTime: {
			readonly description: "Current system-time in [RFC 3339](https://www.ietf.org/rfc/rfc3339.txt)\nformat with nano-seconds.\n";
			readonly type: "string";
			readonly example: "2017-08-08T20:28:29.06202363Z";
		};
		readonly LoggingDriver: {
			readonly description: "The logging driver to use as a default for new containers.\n";
			readonly type: "string";
		};
		readonly CgroupDriver: {
			readonly description: "The driver to use for managing cgroups.\n";
			readonly type: "string";
			readonly enum: readonly [
				"cgroupfs",
				"systemd",
				"none"
			];
			readonly default: "cgroupfs";
			readonly example: "cgroupfs";
		};
		readonly CgroupVersion: {
			readonly description: "The version of the cgroup.\n";
			readonly type: "string";
			readonly enum: readonly [
				"1",
				"2"
			];
			readonly default: "1";
			readonly example: "1";
		};
		readonly NEventsListener: {
			readonly description: "Number of event listeners subscribed.";
			readonly type: "integer";
			readonly example: 30;
		};
		readonly KernelVersion: {
			readonly description: "Kernel version of the host.\n\nOn Linux, this information obtained from `uname`. On Windows this\ninformation is queried from the <kbd>HKEY_LOCAL_MACHINE\\SOFTWARE\\Microsoft\\Windows NT\\CurrentVersion\\</kbd>\nregistry value, for example _\"10.0 14393 (14393.1198.amd64fre.rs1_release_sec.170427-1353)\"_.\n";
			readonly type: "string";
			readonly example: "4.9.38-moby";
		};
		readonly OperatingSystem: {
			readonly description: "Name of the host's operating system, for example: \"Ubuntu 16.04.2 LTS\"\nor \"Windows Server 2016 Datacenter\"\n";
			readonly type: "string";
			readonly example: "Alpine Linux v3.5";
		};
		readonly OSVersion: {
			readonly description: "Version of the host's operating system\n\n<p><br /></p>\n\n> **Note**: The information returned in this field, including its\n> very existence, and the formatting of values, should not be considered\n> stable, and may change without notice.\n";
			readonly type: "string";
			readonly example: "16.04";
		};
		readonly OSType: {
			readonly description: "Generic type of the operating system of the host, as returned by the\nGo runtime (`GOOS`).\n\nCurrently returned values are \"linux\" and \"windows\". A full list of\npossible values can be found in the [Go documentation](https://go.dev/doc/install/source#environment).\n";
			readonly type: "string";
			readonly example: "linux";
		};
		readonly Architecture: {
			readonly description: "Hardware architecture of the host, as returned by the Go runtime\n(`GOARCH`).\n\nA full list of possible values can be found in the [Go documentation](https://go.dev/doc/install/source#environment).\n";
			readonly type: "string";
			readonly example: "x86_64";
		};
		readonly NCPU: {
			readonly description: "The number of logical CPUs usable by the daemon.\n\nThe number of available CPUs is checked by querying the operating\nsystem when the daemon starts. Changes to operating system CPU\nallocation after the daemon is started are not reflected.\n";
			readonly type: "integer";
			readonly example: 4;
		};
		readonly MemTotal: {
			readonly description: "Total amount of physical memory available on the host, in bytes.\n";
			readonly type: "integer";
			readonly format: "int64";
			readonly example: 2095882240;
		};
		readonly IndexServerAddress: {
			readonly description: "Address / URL of the index server that is used for image search,\nand as a default for user authentication for Docker Hub and Docker Cloud.\n";
			readonly default: "https://index.docker.io/v1/";
			readonly type: "string";
			readonly example: "https://index.docker.io/v1/";
		};
		readonly RegistryConfig: {
			readonly $ref: "#/definitions/RegistryServiceConfig";
		};
		readonly GenericResources: {
			readonly $ref: "#/definitions/GenericResources";
		};
		readonly HttpProxy: {
			readonly description: "HTTP-proxy configured for the daemon. This value is obtained from the\n[`HTTP_PROXY`](https://www.gnu.org/software/wget/manual/html_node/Proxies.html) environment variable.\nCredentials ([user info component](https://tools.ietf.org/html/rfc3986#section-3.2.1)) in the proxy URL\nare masked in the API response.\n\nContainers do not automatically inherit this configuration.\n";
			readonly type: "string";
			readonly example: "http://xxxxx:xxxxx@proxy.corp.example.com:8080";
		};
		readonly HttpsProxy: {
			readonly description: "HTTPS-proxy configured for the daemon. This value is obtained from the\n[`HTTPS_PROXY`](https://www.gnu.org/software/wget/manual/html_node/Proxies.html) environment variable.\nCredentials ([user info component](https://tools.ietf.org/html/rfc3986#section-3.2.1)) in the proxy URL\nare masked in the API response.\n\nContainers do not automatically inherit this configuration.\n";
			readonly type: "string";
			readonly example: "https://xxxxx:xxxxx@proxy.corp.example.com:4443";
		};
		readonly NoProxy: {
			readonly description: "Comma-separated list of domain extensions for which no proxy should be\nused. This value is obtained from the [`NO_PROXY`](https://www.gnu.org/software/wget/manual/html_node/Proxies.html)\nenvironment variable.\n\nContainers do not automatically inherit this configuration.\n";
			readonly type: "string";
			readonly example: "*.local, 169.254/16";
		};
		readonly Name: {
			readonly description: "Hostname of the host.";
			readonly type: "string";
			readonly example: "node5.corp.example.com";
		};
		readonly Labels: {
			readonly description: "User-defined labels (key/value metadata) as set on the daemon.\n\n<p><br /></p>\n\n> **Note**: When part of a Swarm, nodes can both have _daemon_ labels,\n> set through the daemon configuration, and _node_ labels, set from a\n> manager node in the Swarm. Node labels are not included in this\n> field. Node labels can be retrieved using the `/nodes/(id)` endpoint\n> on a manager node in the Swarm.\n";
			readonly type: "array";
			readonly items: {
				readonly type: "string";
			};
			readonly example: readonly [
				"storage=ssd",
				"production"
			];
		};
		readonly ExperimentalBuild: {
			readonly description: "Indicates if experimental features are enabled on the daemon.\n";
			readonly type: "boolean";
			readonly example: true;
		};
		readonly ServerVersion: {
			readonly description: "Version string of the daemon.\n";
			readonly type: "string";
			readonly example: "24.0.2";
		};
		readonly Runtimes: {
			readonly description: "List of [OCI compliant](https://github.com/opencontainers/runtime-spec)\nruntimes configured on the daemon. Keys hold the \"name\" used to\nreference the runtime.\n\nThe Docker daemon relies on an OCI compliant runtime (invoked via the\n`containerd` daemon) as its interface to the Linux kernel namespaces,\ncgroups, and SELinux.\n\nThe default runtime is `runc`, and automatically configured. Additional\nruntimes can be configured by the user and will be listed here.\n";
			readonly type: "object";
			readonly additionalProperties: {
				readonly $ref: "#/definitions/Runtime";
			};
			readonly default: {
				readonly runc: {
					readonly path: "runc";
				};
			};
			readonly example: {
				readonly runc: {
					readonly path: "runc";
				};
				readonly "runc-master": {
					readonly path: "/go/bin/runc";
				};
				readonly custom: {
					readonly path: "/usr/local/bin/my-oci-runtime";
					readonly runtimeArgs: readonly [
						"--debug",
						"--systemd-cgroup=false"
					];
				};
			};
		};
		readonly DefaultRuntime: {
			readonly description: "Name of the default OCI runtime that is used when starting containers.\n\nThe default can be overridden per-container at create time.\n";
			readonly type: "string";
			readonly default: "runc";
			readonly example: "runc";
		};
		readonly Swarm: {
			readonly $ref: "#/definitions/SwarmInfo";
		};
		readonly LiveRestoreEnabled: {
			readonly description: "Indicates if live restore is enabled.\n\nIf enabled, containers are kept running when the daemon is shutdown\nor upon daemon start if running containers are detected.\n";
			readonly type: "boolean";
			readonly default: false;
			readonly example: false;
		};
		readonly Isolation: {
			readonly description: "Represents the isolation technology to use as a default for containers.\nThe supported values are platform-specific.\n\nIf no isolation value is specified on daemon start, on Windows client,\nthe default is `hyperv`, and on Windows server, the default is `process`.\n\nThis option is currently not used on other platforms.\n";
			readonly default: "default";
			readonly type: "string";
			readonly enum: readonly [
				"default",
				"hyperv",
				"process"
			];
		};
		readonly InitBinary: {
			readonly description: "Name and, optional, path of the `docker-init` binary.\n\nIf the path is omitted, the daemon searches the host's `$PATH` for the\nbinary and uses the first result.\n";
			readonly type: "string";
			readonly example: "docker-init";
		};
		readonly ContainerdCommit: {
			readonly $ref: "#/definitions/Commit";
		};
		readonly RuncCommit: {
			readonly $ref: "#/definitions/Commit";
		};
		readonly InitCommit: {
			readonly $ref: "#/definitions/Commit";
		};
		readonly SecurityOptions: {
			readonly description: "List of security features that are enabled on the daemon, such as\napparmor, seccomp, SELinux, user-namespaces (userns), rootless and\nno-new-privileges.\n\nAdditional configuration options for each security feature may\nbe present, and are included as a comma-separated list of key/value\npairs.\n";
			readonly type: "array";
			readonly items: {
				readonly type: "string";
			};
			readonly example: readonly [
				"name=apparmor",
				"name=seccomp,profile=default",
				"name=selinux",
				"name=userns",
				"name=rootless"
			];
		};
		readonly ProductLicense: {
			readonly description: "Reports a summary of the product license on the daemon.\n\nIf a commercial license has been applied to the daemon, information\nsuch as number of nodes, and expiration are included.\n";
			readonly type: "string";
			readonly example: "Community Engine";
		};
		readonly DefaultAddressPools: {
			readonly description: "List of custom default address pools for local networks, which can be\nspecified in the daemon.json file or dockerd option.\n\nExample: a Base \"10.10.0.0/16\" with Size 24 will define the set of 256\n10.10.[0-255].0/24 address pools.\n";
			readonly type: "array";
			readonly items: {
				readonly type: "object";
				readonly properties: {
					readonly Base: {
						readonly description: "The network address in CIDR format";
						readonly type: "string";
						readonly example: "10.10.0.0/16";
					};
					readonly Size: {
						readonly description: "The network pool size";
						readonly type: "integer";
						readonly example: "24";
					};
				};
			};
		};
		readonly Warnings: {
			readonly description: "List of warnings / informational messages about missing features, or\nissues related to the daemon configuration.\n\nThese messages can be printed by the client as information to the user.\n";
			readonly type: "array";
			readonly items: {
				readonly type: "string";
			};
			readonly example: readonly [
				"WARNING: No memory limit support",
				"WARNING: bridge-nf-call-iptables is disabled",
				"WARNING: bridge-nf-call-ip6tables is disabled"
			];
		};
		readonly CDISpecDirs: {
			readonly description: "List of directories where (Container Device Interface) CDI\nspecifications are located.\n\nThese specifications define vendor-specific modifications to an OCI\nruntime specification for a container being created.\n\nAn empty list indicates that CDI device injection is disabled.\n\nNote that since using CDI device injection requires the daemon to have\nexperimental enabled. For non-experimental daemons an empty list will\nalways be returned.\n";
			readonly type: "array";
			readonly items: {
				readonly type: "string";
			};
			readonly example: readonly [
				"/etc/cdi",
				"/var/run/cdi"
			];
		};
	};
};
export declare const $PluginsInfo: {
	readonly description: "Available plugins per type.\n\n<p><br /></p>\n\n> **Note**: Only unmanaged (V1) plugins are included in this list.\n> V1 plugins are \"lazily\" loaded, and are not returned in this list\n> if there is no resource using the plugin.\n";
	readonly type: "object";
	readonly properties: {
		readonly Volume: {
			readonly description: "Names of available volume-drivers, and network-driver plugins.";
			readonly type: "array";
			readonly items: {
				readonly type: "string";
			};
			readonly example: readonly [
				"local"
			];
		};
		readonly Network: {
			readonly description: "Names of available network-drivers, and network-driver plugins.";
			readonly type: "array";
			readonly items: {
				readonly type: "string";
			};
			readonly example: readonly [
				"bridge",
				"host",
				"ipvlan",
				"macvlan",
				"null",
				"overlay"
			];
		};
		readonly Authorization: {
			readonly description: "Names of available authorization plugins.";
			readonly type: "array";
			readonly items: {
				readonly type: "string";
			};
			readonly example: readonly [
				"img-authz-plugin",
				"hbm"
			];
		};
		readonly Log: {
			readonly description: "Names of available logging-drivers, and logging-driver plugins.";
			readonly type: "array";
			readonly items: {
				readonly type: "string";
			};
			readonly example: readonly [
				"awslogs",
				"fluentd",
				"gcplogs",
				"gelf",
				"journald",
				"json-file",
				"splunk",
				"syslog"
			];
		};
	};
};
export declare const $RegistryServiceConfig: {
	readonly description: "RegistryServiceConfig stores daemon registry services configuration.\n";
	readonly type: "object";
	readonly "x-nullable": true;
	readonly properties: {
		readonly AllowNondistributableArtifactsCIDRs: {
			readonly description: "List of IP ranges to which nondistributable artifacts can be pushed,\nusing the CIDR syntax [RFC 4632](https://tools.ietf.org/html/4632).\n\nSome images (for example, Windows base images) contain artifacts\nwhose distribution is restricted by license. When these images are\npushed to a registry, restricted artifacts are not included.\n\nThis configuration override this behavior, and enables the daemon to\npush nondistributable artifacts to all registries whose resolved IP\naddress is within the subnet described by the CIDR syntax.\n\nThis option is useful when pushing images containing\nnondistributable artifacts to a registry on an air-gapped network so\nhosts on that network can pull the images without connecting to\nanother server.\n\n> **Warning**: Nondistributable artifacts typically have restrictions\n> on how and where they can be distributed and shared. Only use this\n> feature to push artifacts to private registries and ensure that you\n> are in compliance with any terms that cover redistributing\n> nondistributable artifacts.\n";
			readonly type: "array";
			readonly items: {
				readonly type: "string";
			};
			readonly example: readonly [
				"::1/128",
				"127.0.0.0/8"
			];
		};
		readonly AllowNondistributableArtifactsHostnames: {
			readonly description: "List of registry hostnames to which nondistributable artifacts can be\npushed, using the format `<hostname>[:<port>]` or `<IP address>[:<port>]`.\n\nSome images (for example, Windows base images) contain artifacts\nwhose distribution is restricted by license. When these images are\npushed to a registry, restricted artifacts are not included.\n\nThis configuration override this behavior for the specified\nregistries.\n\nThis option is useful when pushing images containing\nnondistributable artifacts to a registry on an air-gapped network so\nhosts on that network can pull the images without connecting to\nanother server.\n\n> **Warning**: Nondistributable artifacts typically have restrictions\n> on how and where they can be distributed and shared. Only use this\n> feature to push artifacts to private registries and ensure that you\n> are in compliance with any terms that cover redistributing\n> nondistributable artifacts.\n";
			readonly type: "array";
			readonly items: {
				readonly type: "string";
			};
			readonly example: readonly [
				"registry.internal.corp.example.com:3000",
				"[2001:db8:a0b:12f0::1]:443"
			];
		};
		readonly InsecureRegistryCIDRs: {
			readonly description: "List of IP ranges of insecure registries, using the CIDR syntax\n([RFC 4632](https://tools.ietf.org/html/4632)). Insecure registries\naccept un-encrypted (HTTP) and/or untrusted (HTTPS with certificates\nfrom unknown CAs) communication.\n\nBy default, local registries (`127.0.0.0/8`) are configured as\ninsecure. All other registries are secure. Communicating with an\ninsecure registry is not possible if the daemon assumes that registry\nis secure.\n\nThis configuration override this behavior, insecure communication with\nregistries whose resolved IP address is within the subnet described by\nthe CIDR syntax.\n\nRegistries can also be marked insecure by hostname. Those registries\nare listed under `IndexConfigs` and have their `Secure` field set to\n`false`.\n\n> **Warning**: Using this option can be useful when running a local\n> registry, but introduces security vulnerabilities. This option\n> should therefore ONLY be used for testing purposes. For increased\n> security, users should add their CA to their system's list of trusted\n> CAs instead of enabling this option.\n";
			readonly type: "array";
			readonly items: {
				readonly type: "string";
			};
			readonly example: readonly [
				"::1/128",
				"127.0.0.0/8"
			];
		};
		readonly IndexConfigs: {
			readonly type: "object";
			readonly additionalProperties: {
				readonly $ref: "#/definitions/IndexInfo";
			};
			readonly example: {
				readonly "127.0.0.1:5000": {
					readonly Name: "127.0.0.1:5000";
					readonly Mirrors: readonly [
					];
					readonly Secure: false;
					readonly Official: false;
				};
				readonly "[2001:db8:a0b:12f0::1]:80": {
					readonly Name: "[2001:db8:a0b:12f0::1]:80";
					readonly Mirrors: readonly [
					];
					readonly Secure: false;
					readonly Official: false;
				};
				readonly "docker.io": {
					readonly Name: "docker.io";
					readonly Mirrors: readonly [
						"https://hub-mirror.corp.example.com:5000/"
					];
					readonly Secure: true;
					readonly Official: true;
				};
				readonly "registry.internal.corp.example.com:3000": {
					readonly Name: "registry.internal.corp.example.com:3000";
					readonly Mirrors: readonly [
					];
					readonly Secure: false;
					readonly Official: false;
				};
			};
		};
		readonly Mirrors: {
			readonly description: "List of registry URLs that act as a mirror for the official\n(`docker.io`) registry.\n";
			readonly type: "array";
			readonly items: {
				readonly type: "string";
			};
			readonly example: readonly [
				"https://hub-mirror.corp.example.com:5000/",
				"https://[2001:db8:a0b:12f0::1]/"
			];
		};
	};
};
export declare const $IndexInfo: {
	readonly description: "IndexInfo contains information about a registry.";
	readonly type: "object";
	readonly "x-nullable": true;
	readonly properties: {
		readonly Name: {
			readonly description: "Name of the registry, such as \"docker.io\".\n";
			readonly type: "string";
			readonly example: "docker.io";
		};
		readonly Mirrors: {
			readonly description: "List of mirrors, expressed as URIs.\n";
			readonly type: "array";
			readonly items: {
				readonly type: "string";
			};
			readonly example: readonly [
				"https://hub-mirror.corp.example.com:5000/",
				"https://registry-2.docker.io/",
				"https://registry-3.docker.io/"
			];
		};
		readonly Secure: {
			readonly description: "Indicates if the registry is part of the list of insecure\nregistries.\n\nIf `false`, the registry is insecure. Insecure registries accept\nun-encrypted (HTTP) and/or untrusted (HTTPS with certificates from\nunknown CAs) communication.\n\n> **Warning**: Insecure registries can be useful when running a local\n> registry. However, because its use creates security vulnerabilities\n> it should ONLY be enabled for testing purposes. For increased\n> security, users should add their CA to their system's list of\n> trusted CAs instead of enabling this option.\n";
			readonly type: "boolean";
			readonly example: true;
		};
		readonly Official: {
			readonly description: "Indicates whether this is an official registry (i.e., Docker Hub / docker.io)\n";
			readonly type: "boolean";
			readonly example: true;
		};
	};
};
export declare const $Runtime: {
	readonly description: "Runtime describes an [OCI compliant](https://github.com/opencontainers/runtime-spec)\nruntime.\n\nThe runtime is invoked by the daemon via the `containerd` daemon. OCI\nruntimes act as an interface to the Linux kernel namespaces, cgroups,\nand SELinux.\n";
	readonly type: "object";
	readonly properties: {
		readonly path: {
			readonly description: "Name and, optional, path, of the OCI executable binary.\n\nIf the path is omitted, the daemon searches the host's `$PATH` for the\nbinary and uses the first result.\n";
			readonly type: "string";
			readonly example: "/usr/local/bin/my-oci-runtime";
		};
		readonly runtimeArgs: {
			readonly description: "List of command-line arguments to pass to the runtime when invoked.\n";
			readonly type: "array";
			readonly "x-nullable": true;
			readonly items: {
				readonly type: "string";
			};
			readonly example: readonly [
				"--debug",
				"--systemd-cgroup=false"
			];
		};
		readonly status: {
			readonly description: "Information specific to the runtime.\n\nWhile this API specification does not define data provided by runtimes,\nthe following well-known properties may be provided by runtimes:\n\n`org.opencontainers.runtime-spec.features`: features structure as defined\nin the [OCI Runtime Specification](https://github.com/opencontainers/runtime-spec/blob/main/features.md),\nin a JSON string representation.\n\n<p><br /></p>\n\n> **Note**: The information returned in this field, including the\n> formatting of values and labels, should not be considered stable,\n> and may change without notice.\n";
			readonly type: "object";
			readonly "x-nullable": true;
			readonly additionalProperties: {
				readonly type: "string";
			};
			readonly example: {
				readonly "org.opencontainers.runtime-spec.features": "{\"ociVersionMin\":\"1.0.0\",\"ociVersionMax\":\"1.1.0\",\"...\":\"...\"}";
			};
		};
	};
};
export declare const $Commit: {
	readonly description: "Commit holds the Git-commit (SHA1) that a binary was built from, as\nreported in the version-string of external tools, such as `containerd`,\nor `runC`.\n";
	readonly type: "object";
	readonly properties: {
		readonly ID: {
			readonly description: "Actual commit ID of external tool.";
			readonly type: "string";
			readonly example: "cfb82a876ecc11b5ca0977d1733adbe58599088a";
		};
		readonly Expected: {
			readonly description: "Commit ID of external tool expected by dockerd as set at build time.\n";
			readonly type: "string";
			readonly example: "2d41c047c83e09a6d61d464906feb2a2f3c52aa4";
		};
	};
};
export declare const $SwarmInfo: {
	readonly description: "Represents generic information about swarm.\n";
	readonly type: "object";
	readonly properties: {
		readonly NodeID: {
			readonly description: "Unique identifier of for this node in the swarm.";
			readonly type: "string";
			readonly default: "";
			readonly example: "k67qz4598weg5unwwffg6z1m1";
		};
		readonly NodeAddr: {
			readonly description: "IP address at which this node can be reached by other nodes in the\nswarm.\n";
			readonly type: "string";
			readonly default: "";
			readonly example: "10.0.0.46";
		};
		readonly LocalNodeState: {
			readonly $ref: "#/definitions/LocalNodeState";
		};
		readonly ControlAvailable: {
			readonly type: "boolean";
			readonly default: false;
			readonly example: true;
		};
		readonly Error: {
			readonly type: "string";
			readonly default: "";
		};
		readonly RemoteManagers: {
			readonly description: "List of ID's and addresses of other managers in the swarm.\n";
			readonly type: "array";
			readonly default: null;
			readonly "x-nullable": true;
			readonly items: {
				readonly $ref: "#/definitions/PeerNode";
			};
			readonly example: readonly [
				{
					readonly NodeID: "71izy0goik036k48jg985xnds";
					readonly Addr: "10.0.0.158:2377";
				},
				{
					readonly NodeID: "79y6h1o4gv8n120drcprv5nmc";
					readonly Addr: "10.0.0.159:2377";
				},
				{
					readonly NodeID: "k67qz4598weg5unwwffg6z1m1";
					readonly Addr: "10.0.0.46:2377";
				}
			];
		};
		readonly Nodes: {
			readonly description: "Total number of nodes in the swarm.";
			readonly type: "integer";
			readonly "x-nullable": true;
			readonly example: 4;
		};
		readonly Managers: {
			readonly description: "Total number of managers in the swarm.";
			readonly type: "integer";
			readonly "x-nullable": true;
			readonly example: 3;
		};
		readonly Cluster: {
			readonly $ref: "#/definitions/ClusterInfo";
		};
	};
};
export declare const $LocalNodeState: {
	readonly description: "Current local status of this node.";
	readonly type: "string";
	readonly default: "";
	readonly enum: readonly [
		"",
		"inactive",
		"pending",
		"active",
		"error",
		"locked"
	];
	readonly example: "active";
};
export declare const $PeerNode: {
	readonly description: "Represents a peer-node in the swarm";
	readonly type: "object";
	readonly properties: {
		readonly NodeID: {
			readonly description: "Unique identifier of for this node in the swarm.";
			readonly type: "string";
		};
		readonly Addr: {
			readonly description: "IP address and ports at which this node can be reached.\n";
			readonly type: "string";
		};
	};
};
export declare const $NetworkAttachmentConfig: {
	readonly description: "Specifies how a service should be attached to a particular network.\n";
	readonly type: "object";
	readonly properties: {
		readonly Target: {
			readonly description: "The target network for attachment. Must be a network name or ID.\n";
			readonly type: "string";
		};
		readonly Aliases: {
			readonly description: "Discoverable alternate names for the service on this network.\n";
			readonly type: "array";
			readonly items: {
				readonly type: "string";
			};
		};
		readonly DriverOpts: {
			readonly description: "Driver attachment options for the network target.\n";
			readonly type: "object";
			readonly additionalProperties: {
				readonly type: "string";
			};
		};
	};
};
export declare const $EventActor: {
	readonly description: "Actor describes something that generates events, like a container, network,\nor a volume.\n";
	readonly type: "object";
	readonly properties: {
		readonly ID: {
			readonly description: "The ID of the object emitting the event";
			readonly type: "string";
			readonly example: "ede54ee1afda366ab42f824e8a5ffd195155d853ceaec74a927f249ea270c743";
		};
		readonly Attributes: {
			readonly description: "Various key/value attributes of the object, depending on its type.\n";
			readonly type: "object";
			readonly additionalProperties: {
				readonly type: "string";
			};
			readonly example: {
				readonly "com.example.some-label": "some-label-value";
				readonly image: "alpine:latest";
				readonly name: "my-container";
			};
		};
	};
};
export declare const $EventMessage: {
	readonly description: "EventMessage represents the information an event contains.\n";
	readonly type: "object";
	readonly title: "SystemEventsResponse";
	readonly properties: {
		readonly Type: {
			readonly description: "The type of object emitting the event";
			readonly type: "string";
			readonly enum: readonly [
				"builder",
				"config",
				"container",
				"daemon",
				"image",
				"network",
				"node",
				"plugin",
				"secret",
				"service",
				"volume"
			];
			readonly example: "container";
		};
		readonly Action: {
			readonly description: "The type of event";
			readonly type: "string";
			readonly example: "create";
		};
		readonly Actor: {
			readonly $ref: "#/definitions/EventActor";
		};
		readonly scope: {
			readonly description: "Scope of the event. Engine events are `local` scope. Cluster (Swarm)\nevents are `swarm` scope.\n";
			readonly type: "string";
			readonly enum: readonly [
				"local",
				"swarm"
			];
		};
		readonly time: {
			readonly description: "Timestamp of event";
			readonly type: "integer";
			readonly format: "int64";
			readonly example: 1629574695;
		};
		readonly timeNano: {
			readonly description: "Timestamp of event, with nanosecond accuracy";
			readonly type: "integer";
			readonly format: "int64";
			readonly example: 1629574695515050000;
		};
	};
};
export declare const $OCIDescriptor: {
	readonly type: "object";
	readonly "x-go-name": "Descriptor";
	readonly description: "A descriptor struct containing digest, media type, and size, as defined in\nthe [OCI Content Descriptors Specification](https://github.com/opencontainers/image-spec/blob/v1.0.1/descriptor.md).\n";
	readonly properties: {
		readonly mediaType: {
			readonly description: "The media type of the object this schema refers to.\n";
			readonly type: "string";
			readonly example: "application/vnd.docker.distribution.manifest.v2+json";
		};
		readonly digest: {
			readonly description: "The digest of the targeted content.\n";
			readonly type: "string";
			readonly example: "sha256:c0537ff6a5218ef531ece93d4984efc99bbf3f7497c0a7726c88e2bb7584dc96";
		};
		readonly size: {
			readonly description: "The size in bytes of the blob.\n";
			readonly type: "integer";
			readonly format: "int64";
			readonly example: 3987495;
		};
	};
};
export declare const $OCIPlatform: {
	readonly type: "object";
	readonly "x-go-name": "Platform";
	readonly description: "Describes the platform which the image in the manifest runs on, as defined\nin the [OCI Image Index Specification](https://github.com/opencontainers/image-spec/blob/v1.0.1/image-index.md).\n";
	readonly properties: {
		readonly architecture: {
			readonly description: "The CPU architecture, for example `amd64` or `ppc64`.\n";
			readonly type: "string";
			readonly example: "arm";
		};
		readonly os: {
			readonly description: "The operating system, for example `linux` or `windows`.\n";
			readonly type: "string";
			readonly example: "windows";
		};
		readonly "os.version": {
			readonly description: "Optional field specifying the operating system version, for example on\nWindows `10.0.19041.1165`.\n";
			readonly type: "string";
			readonly example: "10.0.19041.1165";
		};
		readonly "os.features": {
			readonly description: "Optional field specifying an array of strings, each listing a required\nOS feature (for example on Windows `win32k`).\n";
			readonly type: "array";
			readonly items: {
				readonly type: "string";
			};
			readonly example: readonly [
				"win32k"
			];
		};
		readonly variant: {
			readonly description: "Optional field specifying a variant of the CPU, for example `v7` to\nspecify ARMv7 when architecture is `arm`.\n";
			readonly type: "string";
			readonly example: "v7";
		};
	};
};
export declare const $DistributionInspect: {
	readonly type: "object";
	readonly "x-go-name": "DistributionInspect";
	readonly title: "DistributionInspectResponse";
	readonly required: readonly [
		"Descriptor",
		"Platforms"
	];
	readonly description: "Describes the result obtained from contacting the registry to retrieve\nimage metadata.\n";
	readonly properties: {
		readonly Descriptor: {
			readonly $ref: "#/definitions/OCIDescriptor";
		};
		readonly Platforms: {
			readonly type: "array";
			readonly description: "An array containing all platforms supported by the image.\n";
			readonly items: {
				readonly $ref: "#/definitions/OCIPlatform";
			};
		};
	};
};
export declare const $ClusterVolume: {
	readonly type: "object";
	readonly description: "Options and information specific to, and only present on, Swarm CSI\ncluster volumes.\n";
	readonly properties: {
		readonly ID: {
			readonly type: "string";
			readonly description: "The Swarm ID of this volume. Because cluster volumes are Swarm\nobjects, they have an ID, unlike non-cluster volumes. This ID can\nbe used to refer to the Volume instead of the name.\n";
		};
		readonly Version: {
			readonly $ref: "#/definitions/ObjectVersion";
		};
		readonly CreatedAt: {
			readonly type: "string";
			readonly format: "dateTime";
		};
		readonly UpdatedAt: {
			readonly type: "string";
			readonly format: "dateTime";
		};
		readonly Spec: {
			readonly $ref: "#/definitions/ClusterVolumeSpec";
		};
		readonly Info: {
			readonly type: "object";
			readonly description: "Information about the global status of the volume.\n";
			readonly properties: {
				readonly CapacityBytes: {
					readonly type: "integer";
					readonly format: "int64";
					readonly description: "The capacity of the volume in bytes. A value of 0 indicates that\nthe capacity is unknown.\n";
				};
				readonly VolumeContext: {
					readonly type: "object";
					readonly description: "A map of strings to strings returned from the storage plugin when\nthe volume is created.\n";
					readonly additionalProperties: {
						readonly type: "string";
					};
				};
				readonly VolumeID: {
					readonly type: "string";
					readonly description: "The ID of the volume as returned by the CSI storage plugin. This\nis distinct from the volume's ID as provided by Docker. This ID\nis never used by the user when communicating with Docker to refer\nto this volume. If the ID is blank, then the Volume has not been\nsuccessfully created in the plugin yet.\n";
				};
				readonly AccessibleTopology: {
					readonly type: "array";
					readonly description: "The topology this volume is actually accessible from.\n";
					readonly items: {
						readonly $ref: "#/definitions/Topology";
					};
				};
			};
		};
		readonly PublishStatus: {
			readonly type: "array";
			readonly description: "The status of the volume as it pertains to its publishing and use on\nspecific nodes\n";
			readonly items: {
				readonly type: "object";
				readonly properties: {
					readonly NodeID: {
						readonly type: "string";
						readonly description: "The ID of the Swarm node the volume is published on.\n";
					};
					readonly State: {
						readonly type: "string";
						readonly description: "The published state of the volume.\n* `pending-publish` The volume should be published to this node, but the call to the controller plugin to do so has not yet been successfully completed.\n* `published` The volume is published successfully to the node.\n* `pending-node-unpublish` The volume should be unpublished from the node, and the manager is awaiting confirmation from the worker that it has done so.\n* `pending-controller-unpublish` The volume is successfully unpublished from the node, but has not yet been successfully unpublished on the controller.\n";
						readonly enum: readonly [
							"pending-publish",
							"published",
							"pending-node-unpublish",
							"pending-controller-unpublish"
						];
					};
					readonly PublishContext: {
						readonly type: "object";
						readonly description: "A map of strings to strings returned by the CSI controller\nplugin when a volume is published.\n";
						readonly additionalProperties: {
							readonly type: "string";
						};
					};
				};
			};
		};
	};
};
export declare const $ClusterVolumeSpec: {
	readonly type: "object";
	readonly description: "Cluster-specific options used to create the volume.\n";
	readonly properties: {
		readonly Group: {
			readonly type: "string";
			readonly description: "Group defines the volume group of this volume. Volumes belonging to\nthe same group can be referred to by group name when creating\nServices.  Referring to a volume by group instructs Swarm to treat\nvolumes in that group interchangeably for the purpose of scheduling.\nVolumes with an empty string for a group technically all belong to\nthe same, emptystring group.\n";
		};
		readonly AccessMode: {
			readonly type: "object";
			readonly description: "Defines how the volume is used by tasks.\n";
			readonly properties: {
				readonly Scope: {
					readonly type: "string";
					readonly description: "The set of nodes this volume can be used on at one time.\n- `single` The volume may only be scheduled to one node at a time.\n- `multi` the volume may be scheduled to any supported number of nodes at a time.\n";
					readonly default: "single";
					readonly enum: readonly [
						"single",
						"multi"
					];
					readonly "x-nullable": false;
				};
				readonly Sharing: {
					readonly type: "string";
					readonly description: "The number and way that different tasks can use this volume\nat one time.\n- `none` The volume may only be used by one task at a time.\n- `readonly` The volume may be used by any number of tasks, but they all must mount the volume as readonly\n- `onewriter` The volume may be used by any number of tasks, but only one may mount it as read/write.\n- `all` The volume may have any number of readers and writers.\n";
					readonly default: "none";
					readonly enum: readonly [
						"none",
						"readonly",
						"onewriter",
						"all"
					];
					readonly "x-nullable": false;
				};
				readonly MountVolume: {
					readonly type: "object";
					readonly description: "Options for using this volume as a Mount-type volume.\n\n    Either MountVolume or BlockVolume, but not both, must be\n    present.\n  properties:\n    FsType:\n      type: \"string\"\n      description: |\n        Specifies the filesystem type for the mount volume.\n        Optional.\n    MountFlags:\n      type: \"array\"\n      description: |\n        Flags to pass when mounting the volume. Optional.\n      items:\n        type: \"string\"\nBlockVolume:\n  type: \"object\"\n  description: |\n    Options for using this volume as a Block-type volume.\n    Intentionally empty.\n";
				};
				readonly Secrets: {
					readonly type: "array";
					readonly description: "Swarm Secrets that are passed to the CSI storage plugin when\noperating on this volume.\n";
					readonly items: {
						readonly type: "object";
						readonly description: "One cluster volume secret entry. Defines a key-value pair that\nis passed to the plugin.\n";
						readonly properties: {
							readonly Key: {
								readonly type: "string";
								readonly description: "Key is the name of the key of the key-value pair passed to\nthe plugin.\n";
							};
							readonly Secret: {
								readonly type: "string";
								readonly description: "Secret is the swarm Secret object from which to read data.\nThis can be a Secret name or ID. The Secret data is\nretrieved by swarm and used as the value of the key-value\npair passed to the plugin.\n";
							};
						};
					};
				};
				readonly AccessibilityRequirements: {
					readonly type: "object";
					readonly description: "Requirements for the accessible topology of the volume. These\nfields are optional. For an in-depth description of what these\nfields mean, see the CSI specification.\n";
					readonly properties: {
						readonly Requisite: {
							readonly type: "array";
							readonly description: "A list of required topologies, at least one of which the\nvolume must be accessible from.\n";
							readonly items: {
								readonly $ref: "#/definitions/Topology";
							};
						};
						readonly Preferred: {
							readonly type: "array";
							readonly description: "A list of topologies that the volume should attempt to be\nprovisioned in.\n";
							readonly items: {
								readonly $ref: "#/definitions/Topology";
							};
						};
					};
				};
				readonly CapacityRange: {
					readonly type: "object";
					readonly description: "The desired capacity that the volume should be created with. If\nempty, the plugin will decide the capacity.\n";
					readonly properties: {
						readonly RequiredBytes: {
							readonly type: "integer";
							readonly format: "int64";
							readonly description: "The volume must be at least this big. The value of 0\nindicates an unspecified minimum\n";
						};
						readonly LimitBytes: {
							readonly type: "integer";
							readonly format: "int64";
							readonly description: "The volume must not be bigger than this. The value of 0\nindicates an unspecified maximum.\n";
						};
					};
				};
				readonly Availability: {
					readonly type: "string";
					readonly description: "The availability of the volume for use in tasks.\n- `active` The volume is fully available for scheduling on the cluster\n- `pause` No new workloads should use the volume, but existing workloads are not stopped.\n- `drain` All workloads using this volume should be stopped and rescheduled, and no new ones should be started.\n";
					readonly default: "active";
					readonly "x-nullable": false;
					readonly enum: readonly [
						"active",
						"pause",
						"drain"
					];
				};
			};
		};
	};
};
export declare const $Topology: {
	readonly description: "A map of topological domains to topological segments. For in depth\ndetails, see documentation for the Topology object in the CSI\nspecification.\n";
	readonly type: "object";
	readonly additionalProperties: {
		readonly type: "string";
	};
};
export interface ConnectRequestProperties {
	readonly method: string;
	readonly url: string;
	readonly body?: string | string[] | Record<string, unknown> | Record<string, unknown>[] | Blob | File;
	readonly query?: Record<string, string | string[] | boolean | number | undefined>;
	readonly path?: Record<string, string | undefined>;
	readonly headers?: Record<string, string | undefined>;
	readonly errors?: Record<number | string, string>;
	readonly responseHeader?: string;
}
export interface RequestOptions {
	connectProperties: ConnectRequestProperties;
	socketPath?: string;
	endpoint?: string;
	port?: number;
	cookies?: Record<string, string>;
	mediaType?: string;
	tls?: boolean;
	registryAuthentication?: string;
}
export type DockerResponse<T = string> = Response;
export interface RegistryAuthentication {
	username: string;
	password: string;
	email: string;
	serveraddress: string;
}
export type ConnectOptions = Omit<RequestOptions, "connectProperties">;
declare class DockerClient {
	private client;
	constructor(options: ConnectOptions);
	request<T>(options: ConnectRequestProperties): Promise<DockerResponse<T>>;
}
/**
 * An open port on a container
 */
export type Port = {
	/**
	 * Host IP address that the container's port is mapped to
	 */
	IP?: string;
	/**
	 * Port on the container
	 */
	PrivatePort: number;
	/**
	 * Port exposed on the host
	 */
	PublicPort?: number;
	Type: "tcp" | "udp" | "sctp";
};
/**
 * MountPoint represents a mount point configuration inside the container.
 * This is used for reporting the mountpoints in use by a container.
 *
 */
export type MountPoint = {
	/**
	 * The mount type:
	 *
	 * - `bind` a mount of a file or directory from the host into the container.
	 * - `volume` a docker volume with the given `Name`.
	 * - `tmpfs` a `tmpfs`.
	 * - `npipe` a named pipe from the host into the container.
	 * - `cluster` a Swarm cluster volume
	 *
	 */
	Type?: "bind" | "volume" | "tmpfs" | "npipe" | "cluster";
	/**
	 * Name is the name reference to the underlying data defined by `Source`
	 * e.g., the volume name.
	 *
	 */
	Name?: string;
	/**
	 * Source location of the mount.
	 *
	 * For volumes, this contains the storage location of the volume (within
	 * `/var/lib/docker/volumes/`). For bind-mounts, and `npipe`, this contains
	 * the source (host) part of the bind-mount. For `tmpfs` mount points, this
	 * field is empty.
	 *
	 */
	Source?: string;
	/**
	 * Destination is the path relative to the container root (`/`) where
	 * the `Source` is mounted inside the container.
	 *
	 */
	Destination?: string;
	/**
	 * Driver is the volume driver used to create the volume (if it is a volume).
	 *
	 */
	Driver?: string;
	/**
	 * Mode is a comma separated list of options supplied by the user when
	 * creating the bind/volume mount.
	 *
	 * The default is platform-specific (`"z"` on Linux, empty on Windows).
	 *
	 */
	Mode?: string;
	/**
	 * Whether the mount is mounted writable (read-write).
	 *
	 */
	RW?: boolean;
	/**
	 * Propagation describes how mounts are propagated from the host into the
	 * mount point, and vice-versa. Refer to the [Linux kernel documentation](https://www.kernel.org/doc/Documentation/filesystems/sharedsubtree.txt)
	 * for details. This field is not used on Windows.
	 *
	 */
	Propagation?: string;
};
/**
 * A device mapping between the host and container
 */
export type DeviceMapping = {
	PathOnHost?: string;
	PathInContainer?: string;
	CgroupPermissions?: string;
};
/**
 * A request for devices to be sent to device drivers
 */
export type DeviceRequest = {
	Driver?: string;
	Count?: number;
	DeviceIDs?: Array<(string)>;
	/**
	 * A list of capabilities; an OR list of AND lists of capabilities.
	 *
	 */
	Capabilities?: Array<Array<(string)>>;
	/**
	 * Driver-specific options, specified as a key/value pairs. These options
	 * are passed directly to the driver.
	 *
	 */
	Options?: {
		[key: string]: (string);
	};
};
export type ThrottleDevice = {
	/**
	 * Device path
	 */
	Path?: string;
	/**
	 * Rate
	 */
	Rate?: number;
};
export type Mount = {
	/**
	 * Container path.
	 */
	Target?: string;
	/**
	 * Mount source (e.g. a volume name, a host path).
	 */
	Source?: string;
	/**
	 * The mount type. Available types:
	 *
	 * - `bind` Mounts a file or directory from the host into the container. Must exist prior to creating the container.
	 * - `volume` Creates a volume with the given name and options (or uses a pre-existing volume with the same name and options). These are **not** removed when the container is removed.
	 * - `tmpfs` Create a tmpfs with the given options. The mount source cannot be specified for tmpfs.
	 * - `npipe` Mounts a named pipe from the host into the container. Must exist prior to creating the container.
	 * - `cluster` a Swarm cluster volume
	 *
	 */
	Type?: "bind" | "volume" | "tmpfs" | "npipe" | "cluster";
	/**
	 * Whether the mount should be read-only.
	 */
	ReadOnly?: boolean;
	/**
	 * The consistency requirement for the mount: `default`, `consistent`, `cached`, or `delegated`.
	 */
	Consistency?: string;
	/**
	 * Optional configuration for the `bind` type.
	 */
	BindOptions?: {
		/**
		 * A propagation mode with the value `[r]private`, `[r]shared`, or `[r]slave`.
		 */
		Propagation?: "private" | "rprivate" | "shared" | "rshared" | "slave" | "rslave";
		/**
		 * Disable recursive bind mount.
		 */
		NonRecursive?: boolean;
		/**
		 * Create mount point on host if missing
		 */
		CreateMountpoint?: boolean;
		/**
		 * Make the mount non-recursively read-only, but still leave the mount recursive
		 * (unless NonRecursive is set to `true` in conjunction).
		 *
		 * Addded in v1.44, before that version all read-only mounts were
		 * non-recursive by default. To match the previous behaviour this
		 * will default to `true` for clients on versions prior to v1.44.
		 *
		 */
		ReadOnlyNonRecursive?: boolean;
		/**
		 * Raise an error if the mount cannot be made recursively read-only.
		 */
		ReadOnlyForceRecursive?: boolean;
	};
	/**
	 * Optional configuration for the `volume` type.
	 */
	VolumeOptions?: {
		/**
		 * Populate volume with data from the target.
		 */
		NoCopy?: boolean;
		/**
		 * User-defined key/value metadata.
		 */
		Labels?: {
			[key: string]: (string);
		};
		/**
		 * Map of driver specific options
		 */
		DriverConfig?: {
			/**
			 * Name of the driver to use to create the volume.
			 */
			Name?: string;
			/**
			 * key/value map of driver specific options.
			 */
			Options?: {
				[key: string]: (string);
			};
		};
		/**
		 * Source path inside the volume. Must be relative without any back traversals.
		 */
		Subpath?: string;
	};
	/**
	 * Optional configuration for the `tmpfs` type.
	 */
	TmpfsOptions?: {
		/**
		 * The size for the tmpfs mount in bytes.
		 */
		SizeBytes?: number;
		/**
		 * The permission mode for the tmpfs mount in an integer.
		 */
		Mode?: number;
	};
};
/**
 * The behavior to apply when the container exits. The default is not to
 * restart.
 *
 * An ever increasing delay (double the previous delay, starting at 100ms) is
 * added before each restart to prevent flooding the server.
 *
 */
export type RestartPolicy = {
	/**
	 * - Empty string means not to restart
	 * - `no` Do not automatically restart
	 * - `always` Always restart
	 * - `unless-stopped` Restart always except when the user has manually stopped the container
	 * - `on-failure` Restart only when the container exit code is non-zero
	 *
	 */
	Name?: "" | "no" | "always" | "unless-stopped" | "on-failure";
	/**
	 * If `on-failure` is used, the number of times to retry before giving up.
	 *
	 */
	MaximumRetryCount?: number;
};
/**
 * A container's resources (cgroups config, ulimits, etc)
 */
export type Resources = {
	/**
	 * An integer value representing this container's relative CPU weight
	 * versus other containers.
	 *
	 */
	CpuShares?: number;
	/**
	 * Memory limit in bytes.
	 */
	Memory?: number;
	/**
	 * Path to `cgroups` under which the container's `cgroup` is created. If
	 * the path is not absolute, the path is considered to be relative to the
	 * `cgroups` path of the init process. Cgroups are created if they do not
	 * already exist.
	 *
	 */
	CgroupParent?: string;
	/**
	 * Block IO weight (relative weight).
	 */
	BlkioWeight?: number;
	/**
	 * Block IO weight (relative device weight) in the form:
	 *
	 * ```
	 * [{"Path": "device_path", "Weight": weight}]
	 * ```
	 *
	 */
	BlkioWeightDevice?: Array<{
		Path?: string;
		Weight?: number;
	}>;
	/**
	 * Limit read rate (bytes per second) from a device, in the form:
	 *
	 * ```
	 * [{"Path": "device_path", "Rate": rate}]
	 * ```
	 *
	 */
	BlkioDeviceReadBps?: Array<ThrottleDevice>;
	/**
	 * Limit write rate (bytes per second) to a device, in the form:
	 *
	 * ```
	 * [{"Path": "device_path", "Rate": rate}]
	 * ```
	 *
	 */
	BlkioDeviceWriteBps?: Array<ThrottleDevice>;
	/**
	 * Limit read rate (IO per second) from a device, in the form:
	 *
	 * ```
	 * [{"Path": "device_path", "Rate": rate}]
	 * ```
	 *
	 */
	BlkioDeviceReadIOps?: Array<ThrottleDevice>;
	/**
	 * Limit write rate (IO per second) to a device, in the form:
	 *
	 * ```
	 * [{"Path": "device_path", "Rate": rate}]
	 * ```
	 *
	 */
	BlkioDeviceWriteIOps?: Array<ThrottleDevice>;
	/**
	 * The length of a CPU period in microseconds.
	 */
	CpuPeriod?: number;
	/**
	 * Microseconds of CPU time that the container can get in a CPU period.
	 *
	 */
	CpuQuota?: number;
	/**
	 * The length of a CPU real-time period in microseconds. Set to 0 to
	 * allocate no time allocated to real-time tasks.
	 *
	 */
	CpuRealtimePeriod?: number;
	/**
	 * The length of a CPU real-time runtime in microseconds. Set to 0 to
	 * allocate no time allocated to real-time tasks.
	 *
	 */
	CpuRealtimeRuntime?: number;
	/**
	 * CPUs in which to allow execution (e.g., `0-3`, `0,1`).
	 *
	 */
	CpusetCpus?: string;
	/**
	 * Memory nodes (MEMs) in which to allow execution (0-3, 0,1). Only
	 * effective on NUMA systems.
	 *
	 */
	CpusetMems?: string;
	/**
	 * A list of devices to add to the container.
	 */
	Devices?: Array<DeviceMapping>;
	/**
	 * a list of cgroup rules to apply to the container
	 */
	DeviceCgroupRules?: Array<(string)>;
	/**
	 * A list of requests for devices to be sent to device drivers.
	 *
	 */
	DeviceRequests?: Array<DeviceRequest>;
	/**
	 * Hard limit for kernel TCP buffer memory (in bytes). Depending on the
	 * OCI runtime in use, this option may be ignored. It is no longer supported
	 * by the default (runc) runtime.
	 *
	 * This field is omitted when empty.
	 *
	 */
	KernelMemoryTCP?: number;
	/**
	 * Memory soft limit in bytes.
	 */
	MemoryReservation?: number;
	/**
	 * Total memory limit (memory + swap). Set as `-1` to enable unlimited
	 * swap.
	 *
	 */
	MemorySwap?: number;
	/**
	 * Tune a container's memory swappiness behavior. Accepts an integer
	 * between 0 and 100.
	 *
	 */
	MemorySwappiness?: number;
	/**
	 * CPU quota in units of 10<sup>-9</sup> CPUs.
	 */
	NanoCpus?: number;
	/**
	 * Disable OOM Killer for the container.
	 */
	OomKillDisable?: boolean;
	/**
	 * Run an init inside the container that forwards signals and reaps
	 * processes. This field is omitted if empty, and the default (as
	 * configured on the daemon) is used.
	 *
	 */
	Init?: boolean | null;
	/**
	 * Tune a container's PIDs limit. Set `0` or `-1` for unlimited, or `null`
	 * to not change.
	 *
	 */
	PidsLimit?: number | null;
	/**
	 * A list of resource limits to set in the container. For example:
	 *
	 * ```
	 * {"Name": "nofile", "Soft": 1024, "Hard": 2048}
	 * ```
	 *
	 */
	Ulimits?: Array<{
		/**
		 * Name of ulimit
		 */
		Name?: string;
		/**
		 * Soft limit
		 */
		Soft?: number;
		/**
		 * Hard limit
		 */
		Hard?: number;
	}>;
	/**
	 * The number of usable CPUs (Windows only).
	 *
	 * On Windows Server containers, the processor resource controls are
	 * mutually exclusive. The order of precedence is `CPUCount` first, then
	 * `CPUShares`, and `CPUPercent` last.
	 *
	 */
	CpuCount?: number;
	/**
	 * The usable percentage of the available CPUs (Windows only).
	 *
	 * On Windows Server containers, the processor resource controls are
	 * mutually exclusive. The order of precedence is `CPUCount` first, then
	 * `CPUShares`, and `CPUPercent` last.
	 *
	 */
	CpuPercent?: number;
	/**
	 * Maximum IOps for the container system drive (Windows only)
	 */
	IOMaximumIOps?: number;
	/**
	 * Maximum IO in bytes per second for the container system drive
	 * (Windows only).
	 *
	 */
	IOMaximumBandwidth?: number;
};
/**
 * An object describing a limit on resources which can be requested by a task.
 *
 */
export type Limit = {
	NanoCPUs?: number;
	MemoryBytes?: number;
	/**
	 * Limits the maximum number of PIDs in the container. Set `0` for unlimited.
	 *
	 */
	Pids?: number;
};
/**
 * An object describing the resources which can be advertised by a node and
 * requested by a task.
 *
 */
export type ResourceObject = {
	NanoCPUs?: number;
	MemoryBytes?: number;
	GenericResources?: GenericResources;
};
/**
 * User-defined resources can be either Integer resources (e.g, `SSD=3`) or
 * String resources (e.g, `GPU=UUID1`).
 *
 */
export type GenericResources = Array<{
	NamedResourceSpec?: {
		Kind?: string;
		Value?: string;
	};
	DiscreteResourceSpec?: {
		Kind?: string;
		Value?: number;
	};
}>;
/**
 * A test to perform to check that the container is healthy.
 */
export type HealthConfig = {
	/**
	 * The test to perform. Possible values are:
	 *
	 * - `[]` inherit healthcheck from image or parent image
	 * - `["NONE"]` disable healthcheck
	 * - `["CMD", args...]` exec arguments directly
	 * - `["CMD-SHELL", command]` run command with system's default shell
	 *
	 */
	Test?: Array<(string)>;
	/**
	 * The time to wait between checks in nanoseconds. It should be 0 or at
	 * least 1000000 (1 ms). 0 means inherit.
	 *
	 */
	Interval?: number;
	/**
	 * The time to wait before considering the check to have hung. It should
	 * be 0 or at least 1000000 (1 ms). 0 means inherit.
	 *
	 */
	Timeout?: number;
	/**
	 * The number of consecutive failures needed to consider a container as
	 * unhealthy. 0 means inherit.
	 *
	 */
	Retries?: number;
	/**
	 * Start period for the container to initialize before starting
	 * health-retries countdown in nanoseconds. It should be 0 or at least
	 * 1000000 (1 ms). 0 means inherit.
	 *
	 */
	StartPeriod?: number;
	/**
	 * The time to wait between checks in nanoseconds during the start period.
	 * It should be 0 or at least 1000000 (1 ms). 0 means inherit.
	 *
	 */
	StartInterval?: number;
};
/**
 * Health stores information about the container's healthcheck results.
 *
 */
export type Health = {
	/**
	 * Status is one of `none`, `starting`, `healthy` or `unhealthy`
	 *
	 * - "none"      Indicates there is no healthcheck
	 * - "starting"  Starting indicates that the container is not yet ready
	 * - "healthy"   Healthy indicates that the container is running correctly
	 * - "unhealthy" Unhealthy indicates that the container has a problem
	 *
	 */
	Status?: "none" | "starting" | "healthy" | "unhealthy";
	/**
	 * FailingStreak is the number of consecutive failures
	 */
	FailingStreak?: number;
	/**
	 * Log contains the last few results (oldest first)
	 *
	 */
	Log?: Array<HealthcheckResult>;
} | null;
/**
 * HealthcheckResult stores information about a single run of a healthcheck probe
 *
 */
export type HealthcheckResult = {
	/**
	 * Date and time at which this check started in
	 * [RFC 3339](https://www.ietf.org/rfc/rfc3339.txt) format with nano-seconds.
	 *
	 */
	Start?: string;
	/**
	 * Date and time at which this check ended in
	 * [RFC 3339](https://www.ietf.org/rfc/rfc3339.txt) format with nano-seconds.
	 *
	 */
	End?: string;
	/**
	 * ExitCode meanings:
	 *
	 * - `0` healthy
	 * - `1` unhealthy
	 * - `2` reserved (considered unhealthy)
	 * - other values: error running probe
	 *
	 */
	ExitCode?: number;
	/**
	 * Output from last check
	 */
	Output?: string;
} | null;
/**
 * Container configuration that depends on the host we are running on
 */
export type HostConfig = Resources & {
	/**
	 * A list of volume bindings for this container. Each volume binding
	 * is a string in one of these forms:
	 *
	 * - `host-src:container-dest[:options]` to bind-mount a host path
	 * into the container. Both `host-src`, and `container-dest` must
	 * be an _absolute_ path.
	 * - `volume-name:container-dest[:options]` to bind-mount a volume
	 * managed by a volume driver into the container. `container-dest`
	 * must be an _absolute_ path.
	 *
	 * `options` is an optional, comma-delimited list of:
	 *
	 * - `nocopy` disables automatic copying of data from the container
	 * path to the volume. The `nocopy` flag only applies to named volumes.
	 * - `[ro|rw]` mounts a volume read-only or read-write, respectively.
	 * If omitted or set to `rw`, volumes are mounted read-write.
	 * - `[z|Z]` applies SELinux labels to allow or deny multiple containers
	 * to read and write to the same volume.
	 * - `z`: a _shared_ content label is applied to the content. This
	 * label indicates that multiple containers can share the volume
	 * content, for both reading and writing.
	 * - `Z`: a _private unshared_ label is applied to the content.
	 * This label indicates that only the current container can use
	 * a private volume. Labeling systems such as SELinux require
	 * proper labels to be placed on volume content that is mounted
	 * into a container. Without a label, the security system can
	 * prevent a container's processes from using the content. By
	 * default, the labels set by the host operating system are not
	 * modified.
	 * - `[[r]shared|[r]slave|[r]private]` specifies mount
	 * [propagation behavior](https://www.kernel.org/doc/Documentation/filesystems/sharedsubtree.txt).
	 * This only applies to bind-mounted volumes, not internal volumes
	 * or named volumes. Mount propagation requires the source mount
	 * point (the location where the source directory is mounted in the
	 * host operating system) to have the correct propagation properties.
	 * For shared volumes, the source mount point must be set to `shared`.
	 * For slave volumes, the mount must be set to either `shared` or
	 * `slave`.
	 *
	 */
	Binds?: Array<(string)>;
	/**
	 * Path to a file where the container ID is written
	 */
	ContainerIDFile?: string;
	/**
	 * The logging configuration for this container
	 */
	LogConfig?: {
		Type?: "json-file" | "syslog" | "journald" | "gelf" | "fluentd" | "awslogs" | "splunk" | "etwlogs" | "none";
		Config?: {
			[key: string]: (string);
		};
	};
	/**
	 * Network mode to use for this container. Supported standard values
	 * are: `bridge`, `host`, `none`, and `container:<name|id>`. Any
	 * other value is taken as a custom network's name to which this
	 * container should connect to.
	 *
	 */
	NetworkMode?: string;
	PortBindings?: PortMap;
	RestartPolicy?: RestartPolicy;
	/**
	 * Automatically remove the container when the container's process
	 * exits. This has no effect if `RestartPolicy` is set.
	 *
	 */
	AutoRemove?: boolean;
	/**
	 * Driver that this container uses to mount volumes.
	 */
	VolumeDriver?: string;
	/**
	 * A list of volumes to inherit from another container, specified in
	 * the form `<container name>[:<ro|rw>]`.
	 *
	 */
	VolumesFrom?: Array<(string)>;
	/**
	 * Specification for mounts to be added to the container.
	 *
	 */
	Mounts?: Array<Mount>;
	/**
	 * Initial console size, as an `[height, width]` array.
	 *
	 */
	ConsoleSize?: [
		number,
		number
	] | null;
	/**
	 * Arbitrary non-identifying metadata attached to container and
	 * provided to the runtime when the container is started.
	 *
	 */
	Annotations?: {
		[key: string]: (string);
	};
	/**
	 * A list of kernel capabilities to add to the container. Conflicts
	 * with option 'Capabilities'.
	 *
	 */
	CapAdd?: Array<(string)>;
	/**
	 * A list of kernel capabilities to drop from the container. Conflicts
	 * with option 'Capabilities'.
	 *
	 */
	CapDrop?: Array<(string)>;
	/**
	 * cgroup namespace mode for the container. Possible values are:
	 *
	 * - `"private"`: the container runs in its own private cgroup namespace
	 * - `"host"`: use the host system's cgroup namespace
	 *
	 * If not specified, the daemon default is used, which can either be `"private"`
	 * or `"host"`, depending on daemon version, kernel support and configuration.
	 *
	 */
	CgroupnsMode?: "private" | "host";
	/**
	 * A list of DNS servers for the container to use.
	 */
	Dns?: Array<(string)>;
	/**
	 * A list of DNS options.
	 */
	DnsOptions?: Array<(string)>;
	/**
	 * A list of DNS search domains.
	 */
	DnsSearch?: Array<(string)>;
	/**
	 * A list of hostnames/IP mappings to add to the container's `/etc/hosts`
	 * file. Specified in the form `["hostname:IP"]`.
	 *
	 */
	ExtraHosts?: Array<(string)>;
	/**
	 * A list of additional groups that the container process will run as.
	 *
	 */
	GroupAdd?: Array<(string)>;
	/**
	 * IPC sharing mode for the container. Possible values are:
	 *
	 * - `"none"`: own private IPC namespace, with /dev/shm not mounted
	 * - `"private"`: own private IPC namespace
	 * - `"shareable"`: own private IPC namespace, with a possibility to share it with other containers
	 * - `"container:<name|id>"`: join another (shareable) container's IPC namespace
	 * - `"host"`: use the host system's IPC namespace
	 *
	 * If not specified, daemon default is used, which can either be `"private"`
	 * or `"shareable"`, depending on daemon version and configuration.
	 *
	 */
	IpcMode?: string;
	/**
	 * Cgroup to use for the container.
	 */
	Cgroup?: string;
	/**
	 * A list of links for the container in the form `container_name:alias`.
	 *
	 */
	Links?: Array<(string)>;
	/**
	 * An integer value containing the score given to the container in
	 * order to tune OOM killer preferences.
	 *
	 */
	OomScoreAdj?: number;
	/**
	 * Set the PID (Process) Namespace mode for the container. It can be
	 * either:
	 *
	 * - `"container:<name|id>"`: joins another container's PID namespace
	 * - `"host"`: use the host's PID namespace inside the container
	 *
	 */
	PidMode?: string;
	/**
	 * Gives the container full access to the host.
	 */
	Privileged?: boolean;
	/**
	 * Allocates an ephemeral host port for all of a container's
	 * exposed ports.
	 *
	 * Ports are de-allocated when the container stops and allocated when
	 * the container starts. The allocated port might be changed when
	 * restarting the container.
	 *
	 * The port is selected from the ephemeral port range that depends on
	 * the kernel. For example, on Linux the range is defined by
	 * `/proc/sys/net/ipv4/ip_local_port_range`.
	 *
	 */
	PublishAllPorts?: boolean;
	/**
	 * Mount the container's root filesystem as read only.
	 */
	ReadonlyRootfs?: boolean;
	/**
	 * A list of string values to customize labels for MLS systems, such
	 * as SELinux.
	 *
	 */
	SecurityOpt?: Array<(string)>;
	/**
	 * Storage driver options for this container, in the form `{"size": "120G"}`.
	 *
	 */
	StorageOpt?: {
		[key: string]: (string);
	};
	/**
	 * A map of container directories which should be replaced by tmpfs
	 * mounts, and their corresponding mount options. For example:
	 *
	 * ```
	 * { "/run": "rw,noexec,nosuid,size=65536k" }
	 * ```
	 *
	 */
	Tmpfs?: {
		[key: string]: (string);
	};
	/**
	 * UTS namespace to use for the container.
	 */
	UTSMode?: string;
	/**
	 * Sets the usernamespace mode for the container when usernamespace
	 * remapping option is enabled.
	 *
	 */
	UsernsMode?: string;
	/**
	 * Size of `/dev/shm` in bytes. If omitted, the system uses 64MB.
	 *
	 */
	ShmSize?: number;
	/**
	 * A list of kernel parameters (sysctls) to set in the container.
	 * For example:
	 *
	 * ```
	 * {"net.ipv4.ip_forward": "1"}
	 * ```
	 *
	 */
	Sysctls?: {
		[key: string]: (string);
	};
	/**
	 * Runtime to use with this container.
	 */
	Runtime?: string;
	/**
	 * Isolation technology of the container. (Windows only)
	 *
	 */
	Isolation?: "default" | "process" | "hyperv";
	/**
	 * The list of paths to be masked inside the container (this overrides
	 * the default set of paths).
	 *
	 */
	MaskedPaths?: Array<(string)>;
	/**
	 * The list of paths to be set as read-only inside the container
	 * (this overrides the default set of paths).
	 *
	 */
	ReadonlyPaths?: Array<(string)>;
};
/**
 * Configuration for a container that is portable between hosts.
 *
 * When used as `ContainerConfig` field in an image, `ContainerConfig` is an
 * optional field containing the configuration of the container that was last
 * committed when creating the image.
 *
 * Previous versions of Docker builder used this field to store build cache,
 * and it is not in active use anymore.
 *
 */
export type ContainerConfig = {
	/**
	 * The hostname to use for the container, as a valid RFC 1123 hostname.
	 *
	 */
	Hostname?: string;
	/**
	 * The domain name to use for the container.
	 *
	 */
	Domainname?: string;
	/**
	 * The user that commands are run as inside the container.
	 */
	User?: string;
	/**
	 * Whether to attach to `stdin`.
	 */
	AttachStdin?: boolean;
	/**
	 * Whether to attach to `stdout`.
	 */
	AttachStdout?: boolean;
	/**
	 * Whether to attach to `stderr`.
	 */
	AttachStderr?: boolean;
	/**
	 * An object mapping ports to an empty object in the form:
	 *
	 * `{"<port>/<tcp|udp|sctp>": {}}`
	 *
	 */
	ExposedPorts?: {
		[key: string]: unknown;
	} | null;
	/**
	 * Attach standard streams to a TTY, including `stdin` if it is not closed.
	 *
	 */
	Tty?: boolean;
	/**
	 * Open `stdin`
	 */
	OpenStdin?: boolean;
	/**
	 * Close `stdin` after one attached client disconnects
	 */
	StdinOnce?: boolean;
	/**
	 * A list of environment variables to set inside the container in the
	 * form `["VAR=value", ...]`. A variable without `=` is removed from the
	 * environment, rather than to have an empty value.
	 *
	 */
	Env?: Array<(string)>;
	/**
	 * Command to run specified as a string or an array of strings.
	 *
	 */
	Cmd?: Array<(string)>;
	Healthcheck?: HealthConfig;
	/**
	 * Command is already escaped (Windows only)
	 */
	ArgsEscaped?: boolean | null;
	/**
	 * The name (or reference) of the image to use when creating the container,
	 * or which was used when the container was created.
	 *
	 */
	Image?: string;
	/**
	 * An object mapping mount point paths inside the container to empty
	 * objects.
	 *
	 */
	Volumes?: {
		[key: string]: unknown;
	};
	/**
	 * The working directory for commands to run in.
	 */
	WorkingDir?: string;
	/**
	 * The entry point for the container as a string or an array of strings.
	 *
	 * If the array consists of exactly one empty string (`[""]`) then the
	 * entry point is reset to system default (i.e., the entry point used by
	 * docker when there is no `ENTRYPOINT` instruction in the `Dockerfile`).
	 *
	 */
	Entrypoint?: Array<(string)>;
	/**
	 * Disable networking for the container.
	 */
	NetworkDisabled?: boolean | null;
	/**
	 * MAC address of the container.
	 *
	 * Deprecated: this field is deprecated in API v1.44 and up. Use EndpointSettings.MacAddress instead.
	 *
	 */
	MacAddress?: string | null;
	/**
	 * `ONBUILD` metadata that were defined in the image's `Dockerfile`.
	 *
	 */
	OnBuild?: Array<(string)> | null;
	/**
	 * User-defined key/value metadata.
	 */
	Labels?: {
		[key: string]: (string);
	};
	/**
	 * Signal to stop a container as a string or unsigned integer.
	 *
	 */
	StopSignal?: string | null;
	/**
	 * Timeout to stop a container in seconds.
	 */
	StopTimeout?: number | null;
	/**
	 * Shell for when `RUN`, `CMD`, and `ENTRYPOINT` uses a shell.
	 *
	 */
	Shell?: Array<(string)> | null;
};
/**
 * NetworkingConfig represents the container's networking configuration for
 * each of its interfaces.
 * It is used for the networking configs specified in the `docker create`
 * and `docker network connect` commands.
 *
 */
export type NetworkingConfig = {
	/**
	 * A mapping of network name to endpoint configuration for that network.
	 * The endpoint configuration can be left empty to connect to that
	 * network with no particular endpoint configuration.
	 *
	 */
	EndpointsConfig?: {
		[key: string]: EndpointSettings;
	};
};
/**
 * NetworkSettings exposes the network settings in the API
 */
export type NetworkSettings = {
	/**
	 * Name of the default bridge interface when dockerd's --bridge flag is set.
	 *
	 */
	Bridge?: string;
	/**
	 * SandboxID uniquely represents a container's network stack.
	 */
	SandboxID?: string;
	/**
	 * Indicates if hairpin NAT should be enabled on the virtual interface.
	 *
	 * Deprecated: This field is never set and will be removed in a future release.
	 *
	 */
	HairpinMode?: boolean;
	/**
	 * IPv6 unicast address using the link-local prefix.
	 *
	 * Deprecated: This field is never set and will be removed in a future release.
	 *
	 */
	LinkLocalIPv6Address?: string;
	/**
	 * Prefix length of the IPv6 unicast address.
	 *
	 * Deprecated: This field is never set and will be removed in a future release.
	 *
	 */
	LinkLocalIPv6PrefixLen?: number;
	Ports?: PortMap;
	/**
	 * SandboxKey is the full path of the netns handle
	 */
	SandboxKey?: string;
	/**
	 * Deprecated: This field is never set and will be removed in a future release.
	 */
	SecondaryIPAddresses?: Array<Address> | null;
	/**
	 * Deprecated: This field is never set and will be removed in a future release.
	 */
	SecondaryIPv6Addresses?: Array<Address> | null;
	/**
	 * EndpointID uniquely represents a service endpoint in a Sandbox.
	 *
	 * <p><br /></p>
	 *
	 * > **Deprecated**: This field is only propagated when attached to the
	 * > default "bridge" network. Use the information from the "bridge"
	 * > network inside the `Networks` map instead, which contains the same
	 * > information. This field was deprecated in Docker 1.9 and is scheduled
	 * > to be removed in Docker 17.12.0
	 *
	 */
	EndpointID?: string;
	/**
	 * Gateway address for the default "bridge" network.
	 *
	 * <p><br /></p>
	 *
	 * > **Deprecated**: This field is only propagated when attached to the
	 * > default "bridge" network. Use the information from the "bridge"
	 * > network inside the `Networks` map instead, which contains the same
	 * > information. This field was deprecated in Docker 1.9 and is scheduled
	 * > to be removed in Docker 17.12.0
	 *
	 */
	Gateway?: string;
	/**
	 * Global IPv6 address for the default "bridge" network.
	 *
	 * <p><br /></p>
	 *
	 * > **Deprecated**: This field is only propagated when attached to the
	 * > default "bridge" network. Use the information from the "bridge"
	 * > network inside the `Networks` map instead, which contains the same
	 * > information. This field was deprecated in Docker 1.9 and is scheduled
	 * > to be removed in Docker 17.12.0
	 *
	 */
	GlobalIPv6Address?: string;
	/**
	 * Mask length of the global IPv6 address.
	 *
	 * <p><br /></p>
	 *
	 * > **Deprecated**: This field is only propagated when attached to the
	 * > default "bridge" network. Use the information from the "bridge"
	 * > network inside the `Networks` map instead, which contains the same
	 * > information. This field was deprecated in Docker 1.9 and is scheduled
	 * > to be removed in Docker 17.12.0
	 *
	 */
	GlobalIPv6PrefixLen?: number;
	/**
	 * IPv4 address for the default "bridge" network.
	 *
	 * <p><br /></p>
	 *
	 * > **Deprecated**: This field is only propagated when attached to the
	 * > default "bridge" network. Use the information from the "bridge"
	 * > network inside the `Networks` map instead, which contains the same
	 * > information. This field was deprecated in Docker 1.9 and is scheduled
	 * > to be removed in Docker 17.12.0
	 *
	 */
	IPAddress?: string;
	/**
	 * Mask length of the IPv4 address.
	 *
	 * <p><br /></p>
	 *
	 * > **Deprecated**: This field is only propagated when attached to the
	 * > default "bridge" network. Use the information from the "bridge"
	 * > network inside the `Networks` map instead, which contains the same
	 * > information. This field was deprecated in Docker 1.9 and is scheduled
	 * > to be removed in Docker 17.12.0
	 *
	 */
	IPPrefixLen?: number;
	/**
	 * IPv6 gateway address for this network.
	 *
	 * <p><br /></p>
	 *
	 * > **Deprecated**: This field is only propagated when attached to the
	 * > default "bridge" network. Use the information from the "bridge"
	 * > network inside the `Networks` map instead, which contains the same
	 * > information. This field was deprecated in Docker 1.9 and is scheduled
	 * > to be removed in Docker 17.12.0
	 *
	 */
	IPv6Gateway?: string;
	/**
	 * MAC address for the container on the default "bridge" network.
	 *
	 * <p><br /></p>
	 *
	 * > **Deprecated**: This field is only propagated when attached to the
	 * > default "bridge" network. Use the information from the "bridge"
	 * > network inside the `Networks` map instead, which contains the same
	 * > information. This field was deprecated in Docker 1.9 and is scheduled
	 * > to be removed in Docker 17.12.0
	 *
	 */
	MacAddress?: string;
	/**
	 * Information about all networks that the container is connected to.
	 *
	 */
	Networks?: {
		[key: string]: EndpointSettings;
	};
};
/**
 * Address represents an IPv4 or IPv6 IP address.
 */
export type Address = {
	/**
	 * IP address.
	 */
	Addr?: string;
	/**
	 * Mask length of the IP address.
	 */
	PrefixLen?: number;
};
/**
 * PortMap describes the mapping of container ports to host ports, using the
 * container's port-number and protocol as key in the format `<port>/<protocol>`,
 * for example, `80/udp`.
 *
 * If a container's port is mapped for multiple protocols, separate entries
 * are added to the mapping table.
 *
 */
export type PortMap = {
	[key: string]: (Array<PortBinding> | null);
};
/**
 * PortBinding represents a binding between a host IP address and a host
 * port.
 *
 */
export type PortBinding = {
	/**
	 * Host IP address that the container's port is mapped to.
	 */
	HostIp?: string;
	/**
	 * Host port number that the container's port is mapped to.
	 */
	HostPort?: string;
};
/**
 * Information about the storage driver used to store the container's and
 * image's filesystem.
 *
 */
export type GraphDriverData = {
	/**
	 * Name of the storage driver.
	 */
	Name: string;
	/**
	 * Low-level storage metadata, provided as key/value pairs.
	 *
	 * This information is driver-specific, and depends on the storage-driver
	 * in use, and should be used for informational purposes only.
	 *
	 */
	Data: {
		[key: string]: (string);
	};
};
/**
 * Change in the container's filesystem.
 *
 */
export type FilesystemChange = {
	/**
	 * Path to file or directory that has changed.
	 *
	 */
	Path: string;
	Kind: ChangeType;
};
/**
 * Kind of change
 *
 * Can be one of:
 *
 * - `0`: Modified ("C")
 * - `1`: Added ("A")
 * - `2`: Deleted ("D")
 *
 */
export declare enum ChangeType {
	"_0" = 0,
	"_1" = 1,
	"_2" = 2
}
/**
 * Information about an image in the local image cache.
 *
 */
export type ImageInspect = {
	/**
	 * ID is the content-addressable ID of an image.
	 *
	 * This identifier is a content-addressable digest calculated from the
	 * image's configuration (which includes the digests of layers used by
	 * the image).
	 *
	 * Note that this digest differs from the `RepoDigests` below, which
	 * holds digests of image manifests that reference the image.
	 *
	 */
	Id?: string;
	/**
	 * List of image names/tags in the local image cache that reference this
	 * image.
	 *
	 * Multiple image tags can refer to the same image, and this list may be
	 * empty if no tags reference the image, in which case the image is
	 * "untagged", in which case it can still be referenced by its ID.
	 *
	 */
	RepoTags?: Array<(string)>;
	/**
	 * List of content-addressable digests of locally available image manifests
	 * that the image is referenced from. Multiple manifests can refer to the
	 * same image.
	 *
	 * These digests are usually only available if the image was either pulled
	 * from a registry, or if the image was pushed to a registry, which is when
	 * the manifest is generated and its digest calculated.
	 *
	 */
	RepoDigests?: Array<(string)>;
	/**
	 * ID of the parent image.
	 *
	 * Depending on how the image was created, this field may be empty and
	 * is only set for images that were built/created locally. This field
	 * is empty if the image was pulled from an image registry.
	 *
	 */
	Parent?: string;
	/**
	 * Optional message that was set when committing or importing the image.
	 *
	 */
	Comment?: string;
	/**
	 * Date and time at which the image was created, formatted in
	 * [RFC 3339](https://www.ietf.org/rfc/rfc3339.txt) format with nano-seconds.
	 *
	 * This information is only available if present in the image,
	 * and omitted otherwise.
	 *
	 */
	Created?: string | null;
	/**
	 * The ID of the container that was used to create the image.
	 *
	 * Depending on how the image was created, this field may be empty.
	 *
	 * **Deprecated**: this field is kept for backward compatibility, but
	 * will be removed in API v1.45.
	 *
	 */
	Container?: string;
	/**
	 * **Deprecated**: this field is kept for backward compatibility, but
	 * will be removed in API v1.45.
	 *
	 */
	ContainerConfig?: ContainerConfig;
	/**
	 * The version of Docker that was used to build the image.
	 *
	 * Depending on how the image was created, this field may be empty.
	 *
	 */
	DockerVersion?: string;
	/**
	 * Name of the author that was specified when committing the image, or as
	 * specified through MAINTAINER (deprecated) in the Dockerfile.
	 *
	 */
	Author?: string;
	Config?: ContainerConfig;
	/**
	 * Hardware CPU architecture that the image runs on.
	 *
	 */
	Architecture?: string;
	/**
	 * CPU architecture variant (presently ARM-only).
	 *
	 */
	Variant?: string | null;
	/**
	 * Operating System the image is built to run on.
	 *
	 */
	Os?: string;
	/**
	 * Operating System version the image is built to run on (especially
	 * for Windows).
	 *
	 */
	OsVersion?: string | null;
	/**
	 * Total size of the image including all layers it is composed of.
	 *
	 */
	Size?: number;
	/**
	 * Total size of the image including all layers it is composed of.
	 *
	 * Deprecated: this field is omitted in API v1.44, but kept for backward compatibility. Use Size instead.
	 *
	 */
	VirtualSize?: number;
	GraphDriver?: GraphDriverData;
	/**
	 * Information about the image's RootFS, including the layer IDs.
	 *
	 */
	RootFS?: {
		Type: string;
		Layers?: Array<(string)>;
	};
	/**
	 * Additional metadata of the image in the local cache. This information
	 * is local to the daemon, and not part of the image itself.
	 *
	 */
	Metadata?: {
		/**
		 * Date and time at which the image was last tagged in
		 * [RFC 3339](https://www.ietf.org/rfc/rfc3339.txt) format with nano-seconds.
		 *
		 * This information is only available if the image was tagged locally,
		 * and omitted otherwise.
		 *
		 */
		LastTagTime?: string | null;
	};
};
export type ImageSummary = {
	/**
	 * ID is the content-addressable ID of an image.
	 *
	 * This identifier is a content-addressable digest calculated from the
	 * image's configuration (which includes the digests of layers used by
	 * the image).
	 *
	 * Note that this digest differs from the `RepoDigests` below, which
	 * holds digests of image manifests that reference the image.
	 *
	 */
	Id: string;
	/**
	 * ID of the parent image.
	 *
	 * Depending on how the image was created, this field may be empty and
	 * is only set for images that were built/created locally. This field
	 * is empty if the image was pulled from an image registry.
	 *
	 */
	ParentId: string;
	/**
	 * List of image names/tags in the local image cache that reference this
	 * image.
	 *
	 * Multiple image tags can refer to the same image, and this list may be
	 * empty if no tags reference the image, in which case the image is
	 * "untagged", in which case it can still be referenced by its ID.
	 *
	 */
	RepoTags: Array<(string)>;
	/**
	 * List of content-addressable digests of locally available image manifests
	 * that the image is referenced from. Multiple manifests can refer to the
	 * same image.
	 *
	 * These digests are usually only available if the image was either pulled
	 * from a registry, or if the image was pushed to a registry, which is when
	 * the manifest is generated and its digest calculated.
	 *
	 */
	RepoDigests: Array<(string)>;
	/**
	 * Date and time at which the image was created as a Unix timestamp
	 * (number of seconds sinds EPOCH).
	 *
	 */
	Created: number;
	/**
	 * Total size of the image including all layers it is composed of.
	 *
	 */
	Size: number;
	/**
	 * Total size of image layers that are shared between this image and other
	 * images.
	 *
	 * This size is not calculated by default. `-1` indicates that the value
	 * has not been set / calculated.
	 *
	 */
	SharedSize: number;
	/**
	 * Total size of the image including all layers it is composed of.
	 *
	 * Deprecated: this field is omitted in API v1.44, but kept for backward compatibility. Use Size instead.
	 */
	VirtualSize?: number;
	/**
	 * User-defined key/value metadata.
	 */
	Labels: {
		[key: string]: (string);
	};
	/**
	 * Number of containers using this image. Includes both stopped and running
	 * containers.
	 *
	 * This size is not calculated by default, and depends on which API endpoint
	 * is used. `-1` indicates that the value has not been set / calculated.
	 *
	 */
	Containers: number;
};
export type AuthConfig = {
	username?: string;
	password?: string;
	email?: string;
	serveraddress?: string;
};
export type ProcessConfig = {
	privileged?: boolean;
	user?: string;
	tty?: boolean;
	entrypoint?: string;
	arguments?: Array<(string)>;
};
export type Volume = {
	/**
	 * Name of the volume.
	 */
	Name: string;
	/**
	 * Name of the volume driver used by the volume.
	 */
	Driver: string;
	/**
	 * Mount path of the volume on the host.
	 */
	Mountpoint: string;
	/**
	 * Date/Time the volume was created.
	 */
	CreatedAt?: string;
	/**
	 * Low-level details about the volume, provided by the volume driver.
	 * Details are returned as a map with key/value pairs:
	 * `{"key":"value","key2":"value2"}`.
	 *
	 * The `Status` field is optional, and is omitted if the volume driver
	 * does not support this feature.
	 *
	 */
	Status?: {
		[key: string]: unknown;
	};
	/**
	 * User-defined key/value metadata.
	 */
	Labels: {
		[key: string]: (string);
	};
	/**
	 * The level at which the volume exists. Either `global` for cluster-wide,
	 * or `local` for machine level.
	 *
	 */
	Scope: "local" | "global";
	ClusterVolume?: ClusterVolume;
	/**
	 * The driver specific options used when creating the volume.
	 *
	 */
	Options: {
		[key: string]: (string);
	};
	/**
	 * Usage details about the volume. This information is used by the
	 * `GET /system/df` endpoint, and omitted in other endpoints.
	 *
	 */
	UsageData?: {
		/**
		 * Amount of disk space used by the volume (in bytes). This information
		 * is only available for volumes created with the `"local"` volume
		 * driver. For volumes created with other volume drivers, this field
		 * is set to `-1` ("not available")
		 *
		 */
		Size: number;
		/**
		 * The number of containers referencing this volume. This field
		 * is set to `-1` if the reference-count is not available.
		 *
		 */
		RefCount: number;
	} | null;
};
/**
 * Volume configuration
 */
export type VolumeCreateOptions = {
	/**
	 * The new volume's name. If not specified, Docker generates a name.
	 *
	 */
	Name?: string;
	/**
	 * Name of the volume driver to use.
	 */
	Driver?: string;
	/**
	 * A mapping of driver options and values. These options are
	 * passed directly to the driver and are driver specific.
	 *
	 */
	DriverOpts?: {
		[key: string]: (string);
	};
	/**
	 * User-defined key/value metadata.
	 */
	Labels?: {
		[key: string]: (string);
	};
	ClusterVolumeSpec?: ClusterVolumeSpec;
};
/**
 * Volume list response
 */
export type VolumeListResponse = {
	/**
	 * List of volumes
	 */
	Volumes?: Array<Volume>;
	/**
	 * Warnings that occurred when fetching the list of volumes.
	 *
	 */
	Warnings?: Array<(string)>;
};
export type Network = {
	Name?: string;
	Id?: string;
	Created?: string;
	Scope?: string;
	Driver?: string;
	EnableIPv6?: boolean;
	IPAM?: IPAM;
	Internal?: boolean;
	Attachable?: boolean;
	Ingress?: boolean;
	Containers?: {
		[key: string]: NetworkContainer;
	};
	Options?: {
		[key: string]: (string);
	};
	Labels?: {
		[key: string]: (string);
	};
};
export type IPAM = {
	/**
	 * Name of the IPAM driver to use.
	 */
	Driver?: string;
	/**
	 * List of IPAM configuration options, specified as a map:
	 *
	 * ```
	 * {"Subnet": <CIDR>, "IPRange": <CIDR>, "Gateway": <IP address>, "AuxAddress": <device_name:IP address>}
	 * ```
	 *
	 */
	Config?: Array<IPAMConfig>;
	/**
	 * Driver-specific options, specified as a map.
	 */
	Options?: {
		[key: string]: (string);
	};
};
export type IPAMConfig = {
	Subnet?: string;
	IPRange?: string;
	Gateway?: string;
	AuxiliaryAddresses?: {
		[key: string]: (string);
	};
};
export type NetworkContainer = {
	Name?: string;
	EndpointID?: string;
	MacAddress?: string;
	IPv4Address?: string;
	IPv6Address?: string;
};
export type BuildInfo = {
	id?: string;
	stream?: string;
	error?: string;
	errorDetail?: ErrorDetail;
	status?: string;
	progress?: string;
	progressDetail?: ProgressDetail;
	aux?: ImageID;
};
/**
 * BuildCache contains information about a build cache record.
 *
 */
export type BuildCache = {
	/**
	 * Unique ID of the build cache record.
	 *
	 */
	ID?: string;
	/**
	 * ID of the parent build cache record.
	 *
	 * > **Deprecated**: This field is deprecated, and omitted if empty.
	 *
	 */
	Parent?: string | null;
	/**
	 * List of parent build cache record IDs.
	 *
	 */
	Parents?: Array<(string)> | null;
	/**
	 * Cache record type.
	 *
	 */
	Type?: "internal" | "frontend" | "source.local" | "source.git.checkout" | "exec.cachemount" | "regular";
	/**
	 * Description of the build-step that produced the build cache.
	 *
	 */
	Description?: string;
	/**
	 * Indicates if the build cache is in use.
	 *
	 */
	InUse?: boolean;
	/**
	 * Indicates if the build cache is shared.
	 *
	 */
	Shared?: boolean;
	/**
	 * Amount of disk space used by the build cache (in bytes).
	 *
	 */
	Size?: number;
	/**
	 * Date and time at which the build cache was created in
	 * [RFC 3339](https://www.ietf.org/rfc/rfc3339.txt) format with nano-seconds.
	 *
	 */
	CreatedAt?: string;
	/**
	 * Date and time at which the build cache was last used in
	 * [RFC 3339](https://www.ietf.org/rfc/rfc3339.txt) format with nano-seconds.
	 *
	 */
	LastUsedAt?: string | null;
	UsageCount?: number;
};
/**
 * Image ID or Digest
 */
export type ImageID = {
	ID?: string;
};
export type CreateImageInfo = {
	id?: string;
	error?: string;
	errorDetail?: ErrorDetail;
	status?: string;
	progress?: string;
	progressDetail?: ProgressDetail;
};
export type PushImageInfo = {
	error?: string;
	status?: string;
	progress?: string;
	progressDetail?: ProgressDetail;
};
export type ErrorDetail = {
	code?: number;
	message?: string;
};
export type ProgressDetail = {
	current?: number;
	total?: number;
};
/**
 * Represents an error.
 */
export type ErrorResponse = {
	/**
	 * The error message.
	 */
	message: string;
};
/**
 * Response to an API call that returns just an Id
 */
export type IdResponse = {
	/**
	 * The id of the newly created object.
	 */
	Id: string;
};
/**
 * Configuration for a network endpoint.
 */
export type EndpointSettings = {
	IPAMConfig?: EndpointIPAMConfig;
	Links?: Array<(string)>;
	/**
	 * MAC address for the endpoint on this network. The network driver might ignore this parameter.
	 *
	 */
	MacAddress?: string;
	Aliases?: Array<(string)>;
	/**
	 * Unique ID of the network.
	 *
	 */
	NetworkID?: string;
	/**
	 * Unique ID for the service endpoint in a Sandbox.
	 *
	 */
	EndpointID?: string;
	/**
	 * Gateway address for this network.
	 *
	 */
	Gateway?: string;
	/**
	 * IPv4 address.
	 *
	 */
	IPAddress?: string;
	/**
	 * Mask length of the IPv4 address.
	 *
	 */
	IPPrefixLen?: number;
	/**
	 * IPv6 gateway address.
	 *
	 */
	IPv6Gateway?: string;
	/**
	 * Global IPv6 address.
	 *
	 */
	GlobalIPv6Address?: string;
	/**
	 * Mask length of the global IPv6 address.
	 *
	 */
	GlobalIPv6PrefixLen?: number;
	/**
	 * DriverOpts is a mapping of driver options and values. These options
	 * are passed directly to the driver and are driver specific.
	 *
	 */
	DriverOpts?: {
		[key: string]: (string);
	} | null;
	/**
	 * List of all DNS names an endpoint has on a specific network. This
	 * list is based on the container name, network aliases, container short
	 * ID, and hostname.
	 *
	 * These DNS names are non-fully qualified but can contain several dots.
	 * You can get fully qualified DNS names by appending `.<network-name>`.
	 * For instance, if container name is `my.ctr` and the network is named
	 * `testnet`, `DNSNames` will contain `my.ctr` and the FQDN will be
	 * `my.ctr.testnet`.
	 *
	 */
	DNSNames?: Array<(string)>;
};
/**
 * EndpointIPAMConfig represents an endpoint's IPAM configuration.
 *
 */
export type EndpointIPAMConfig = {
	IPv4Address?: string;
	IPv6Address?: string;
	LinkLocalIPs?: Array<(string)>;
} | null;
export type PluginMount = {
	Name: string;
	Description: string;
	Settable: Array<(string)>;
	Source: string;
	Destination: string;
	Type: string;
	Options: Array<(string)>;
};
export type PluginDevice = {
	Name: string;
	Description: string;
	Settable: Array<(string)>;
	Path: string;
};
export type PluginEnv = {
	Name: string;
	Description: string;
	Settable: Array<(string)>;
	Value: string;
};
export type PluginInterfaceType = {
	Prefix: string;
	Capability: string;
	Version: string;
};
/**
 * Describes a permission the user has to accept upon installing
 * the plugin.
 *
 */
export type PluginPrivilege = {
	Name?: string;
	Description?: string;
	Value?: Array<(string)>;
};
/**
 * A plugin for the Engine API
 */
type Plugin$1 = {
	Id?: string;
	Name: string;
	/**
	 * True if the plugin is running. False if the plugin is not running, only installed.
	 */
	Enabled: boolean;
	/**
	 * Settings that can be modified by users.
	 */
	Settings: {
		Mounts: Array<PluginMount>;
		Env: Array<(string)>;
		Args: Array<(string)>;
		Devices: Array<PluginDevice>;
	};
	/**
	 * plugin remote reference used to push/pull the plugin
	 */
	PluginReference?: string;
	/**
	 * The config of a plugin.
	 */
	Config: {
		/**
		 * Docker Version used to create the plugin
		 */
		DockerVersion?: string;
		Description: string;
		Documentation: string;
		/**
		 * The interface between Docker and the plugin
		 */
		Interface: {
			Types: Array<PluginInterfaceType>;
			Socket: string;
			/**
			 * Protocol to use for clients connecting to the plugin.
			 */
			ProtocolScheme?: "" | "moby.plugins.http/v1";
		};
		Entrypoint: Array<(string)>;
		WorkDir: string;
		User?: {
			UID?: number;
			GID?: number;
		};
		Network: {
			Type: string;
		};
		Linux: {
			Capabilities: Array<(string)>;
			AllowAllDevices: boolean;
			Devices: Array<PluginDevice>;
		};
		PropagatedMount: string;
		IpcHost: boolean;
		PidHost: boolean;
		Mounts: Array<PluginMount>;
		Env: Array<PluginEnv>;
		Args: {
			Name: string;
			Description: string;
			Settable: Array<(string)>;
			Value: Array<(string)>;
		};
		rootfs?: {
			type?: string;
			diff_ids?: Array<(string)>;
		};
	};
};
/**
 * The version number of the object such as node, service, etc. This is needed
 * to avoid conflicting writes. The client must send the version number along
 * with the modified specification when updating these objects.
 *
 * This approach ensures safe concurrency and determinism in that the change
 * on the object may not be applied if the version number has changed from the
 * last read. In other words, if two update requests specify the same base
 * version, only one of the requests can succeed. As a result, two separate
 * update requests that happen at the same time will not unintentionally
 * overwrite each other.
 *
 */
export type ObjectVersion = {
	Index?: number;
};
export type NodeSpec = {
	/**
	 * Name for the node.
	 */
	Name?: string;
	/**
	 * User-defined key/value metadata.
	 */
	Labels?: {
		[key: string]: (string);
	};
	/**
	 * Role of the node.
	 */
	Role?: "worker" | "manager";
	/**
	 * Availability of the node.
	 */
	Availability?: "active" | "pause" | "drain";
};
type Node$1 = {
	ID?: string;
	Version?: ObjectVersion;
	/**
	 * Date and time at which the node was added to the swarm in
	 * [RFC 3339](https://www.ietf.org/rfc/rfc3339.txt) format with nano-seconds.
	 *
	 */
	CreatedAt?: string;
	/**
	 * Date and time at which the node was last updated in
	 * [RFC 3339](https://www.ietf.org/rfc/rfc3339.txt) format with nano-seconds.
	 *
	 */
	UpdatedAt?: string;
	Spec?: NodeSpec;
	Description?: NodeDescription;
	Status?: NodeStatus;
	ManagerStatus?: ManagerStatus;
};
/**
 * NodeDescription encapsulates the properties of the Node as reported by the
 * agent.
 *
 */
export type NodeDescription = {
	Hostname?: string;
	Platform?: Platform;
	Resources?: ResourceObject;
	Engine?: EngineDescription;
	TLSInfo?: TLSInfo;
};
/**
 * Platform represents the platform (Arch/OS).
 *
 */
export type Platform = {
	/**
	 * Architecture represents the hardware architecture (for example,
	 * `x86_64`).
	 *
	 */
	Architecture?: string;
	/**
	 * OS represents the Operating System (for example, `linux` or `windows`).
	 *
	 */
	OS?: string;
};
/**
 * EngineDescription provides information about an engine.
 */
export type EngineDescription = {
	EngineVersion?: string;
	Labels?: {
		[key: string]: (string);
	};
	Plugins?: Array<{
		Type?: string;
		Name?: string;
	}>;
};
/**
 * Information about the issuer of leaf TLS certificates and the trusted root
 * CA certificate.
 *
 */
export type TLSInfo = {
	/**
	 * The root CA certificate(s) that are used to validate leaf TLS
	 * certificates.
	 *
	 */
	TrustRoot?: string;
	/**
	 * The base64-url-safe-encoded raw subject bytes of the issuer.
	 */
	CertIssuerSubject?: string;
	/**
	 * The base64-url-safe-encoded raw public key bytes of the issuer.
	 *
	 */
	CertIssuerPublicKey?: string;
};
/**
 * NodeStatus represents the status of a node.
 *
 * It provides the current status of the node, as seen by the manager.
 *
 */
export type NodeStatus = {
	State?: NodeState;
	Message?: string;
	/**
	 * IP address of the node.
	 */
	Addr?: string;
};
/**
 * NodeState represents the state of a node.
 */
export declare enum NodeState {
	UNKNOWN = "unknown",
	DOWN = "down",
	READY = "ready",
	DISCONNECTED = "disconnected"
}
/**
 * ManagerStatus represents the status of a manager.
 *
 * It provides the current status of a node's manager component, if the node
 * is a manager.
 *
 */
export type ManagerStatus = {
	Leader?: boolean;
	Reachability?: Reachability;
	/**
	 * The IP address and port at which the manager is reachable.
	 *
	 */
	Addr?: string;
} | null;
/**
 * Reachability represents the reachability of a node.
 */
export declare enum Reachability {
	UNKNOWN = "unknown",
	UNREACHABLE = "unreachable",
	REACHABLE = "reachable"
}
/**
 * User modifiable swarm configuration.
 */
export type SwarmSpec = {
	/**
	 * Name of the swarm.
	 */
	Name?: string;
	/**
	 * User-defined key/value metadata.
	 */
	Labels?: {
		[key: string]: (string);
	};
	/**
	 * Orchestration configuration.
	 */
	Orchestration?: {
		/**
		 * The number of historic tasks to keep per instance or node. If
		 * negative, never remove completed or failed tasks.
		 *
		 */
		TaskHistoryRetentionLimit?: number;
	} | null;
	/**
	 * Raft configuration.
	 */
	Raft?: {
		/**
		 * The number of log entries between snapshots.
		 */
		SnapshotInterval?: number;
		/**
		 * The number of snapshots to keep beyond the current snapshot.
		 *
		 */
		KeepOldSnapshots?: number;
		/**
		 * The number of log entries to keep around to sync up slow followers
		 * after a snapshot is created.
		 *
		 */
		LogEntriesForSlowFollowers?: number;
		/**
		 * The number of ticks that a follower will wait for a message from
		 * the leader before becoming a candidate and starting an election.
		 * `ElectionTick` must be greater than `HeartbeatTick`.
		 *
		 * A tick currently defaults to one second, so these translate
		 * directly to seconds currently, but this is NOT guaranteed.
		 *
		 */
		ElectionTick?: number;
		/**
		 * The number of ticks between heartbeats. Every HeartbeatTick ticks,
		 * the leader will send a heartbeat to the followers.
		 *
		 * A tick currently defaults to one second, so these translate
		 * directly to seconds currently, but this is NOT guaranteed.
		 *
		 */
		HeartbeatTick?: number;
	};
	/**
	 * Dispatcher configuration.
	 */
	Dispatcher?: {
		/**
		 * The delay for an agent to send a heartbeat to the dispatcher.
		 *
		 */
		HeartbeatPeriod?: number;
	} | null;
	/**
	 * CA configuration.
	 */
	CAConfig?: {
		/**
		 * The duration node certificates are issued for.
		 */
		NodeCertExpiry?: number;
		/**
		 * Configuration for forwarding signing requests to an external
		 * certificate authority.
		 *
		 */
		ExternalCAs?: Array<{
			/**
			 * Protocol for communication with the external CA (currently
			 * only `cfssl` is supported).
			 *
			 */
			Protocol?: "cfssl";
			/**
			 * URL where certificate signing requests should be sent.
			 *
			 */
			URL?: string;
			/**
			 * An object with key/value pairs that are interpreted as
			 * protocol-specific options for the external CA driver.
			 *
			 */
			Options?: {
				[key: string]: (string);
			};
			/**
			 * The root CA certificate (in PEM format) this external CA uses
			 * to issue TLS certificates (assumed to be to the current swarm
			 * root CA certificate if not provided).
			 *
			 */
			CACert?: string;
		}>;
		/**
		 * The desired signing CA certificate for all swarm node TLS leaf
		 * certificates, in PEM format.
		 *
		 */
		SigningCACert?: string;
		/**
		 * The desired signing CA key for all swarm node TLS leaf certificates,
		 * in PEM format.
		 *
		 */
		SigningCAKey?: string;
		/**
		 * An integer whose purpose is to force swarm to generate a new
		 * signing CA certificate and key, if none have been specified in
		 * `SigningCACert` and `SigningCAKey`
		 *
		 */
		ForceRotate?: number;
	} | null;
	/**
	 * Parameters related to encryption-at-rest.
	 */
	EncryptionConfig?: {
		/**
		 * If set, generate a key and use it to lock data stored on the
		 * managers.
		 *
		 */
		AutoLockManagers?: boolean;
	};
	/**
	 * Defaults for creating tasks in this cluster.
	 */
	TaskDefaults?: {
		/**
		 * The log driver to use for tasks created in the orchestrator if
		 * unspecified by a service.
		 *
		 * Updating this value only affects new tasks. Existing tasks continue
		 * to use their previously configured log driver until recreated.
		 *
		 */
		LogDriver?: {
			/**
			 * The log driver to use as a default for new tasks.
			 *
			 */
			Name?: string;
			/**
			 * Driver-specific options for the selectd log driver, specified
			 * as key/value pairs.
			 *
			 */
			Options?: {
				[key: string]: (string);
			};
		};
	};
};
/**
 * ClusterInfo represents information about the swarm as is returned by the
 * "/info" endpoint. Join-tokens are not included.
 *
 */
export type ClusterInfo = {
	/**
	 * The ID of the swarm.
	 */
	ID?: string;
	Version?: ObjectVersion;
	/**
	 * Date and time at which the swarm was initialised in
	 * [RFC 3339](https://www.ietf.org/rfc/rfc3339.txt) format with nano-seconds.
	 *
	 */
	CreatedAt?: string;
	/**
	 * Date and time at which the swarm was last updated in
	 * [RFC 3339](https://www.ietf.org/rfc/rfc3339.txt) format with nano-seconds.
	 *
	 */
	UpdatedAt?: string;
	Spec?: SwarmSpec;
	TLSInfo?: TLSInfo;
	/**
	 * Whether there is currently a root CA rotation in progress for the swarm
	 *
	 */
	RootRotationInProgress?: boolean;
	/**
	 * DataPathPort specifies the data path port number for data traffic.
	 * Acceptable port range is 1024 to 49151.
	 * If no port is set or is set to 0, the default port (4789) is used.
	 *
	 */
	DataPathPort?: number;
	/**
	 * Default Address Pool specifies default subnet pools for global scope
	 * networks.
	 *
	 */
	DefaultAddrPool?: Array<(string)>;
	/**
	 * SubnetSize specifies the subnet size of the networks created from the
	 * default subnet pool.
	 *
	 */
	SubnetSize?: number;
} | null;
/**
 * JoinTokens contains the tokens workers and managers need to join the swarm.
 *
 */
export type JoinTokens = {
	/**
	 * The token workers can use to join the swarm.
	 *
	 */
	Worker?: string;
	/**
	 * The token managers can use to join the swarm.
	 *
	 */
	Manager?: string;
};
export type Swarm = ClusterInfo & {
	JoinTokens?: JoinTokens;
};
/**
 * User modifiable task configuration.
 */
export type TaskSpec = {
	/**
	 * Plugin spec for the service.  *(Experimental release only.)*
	 *
	 * <p><br /></p>
	 *
	 * > **Note**: ContainerSpec, NetworkAttachmentSpec, and PluginSpec are
	 * > mutually exclusive. PluginSpec is only used when the Runtime field
	 * > is set to `plugin`. NetworkAttachmentSpec is used when the Runtime
	 * > field is set to `attachment`.
	 *
	 */
	PluginSpec?: {
		/**
		 * The name or 'alias' to use for the plugin.
		 */
		Name?: string;
		/**
		 * The plugin image reference to use.
		 */
		Remote?: string;
		/**
		 * Disable the plugin once scheduled.
		 */
		Disabled?: boolean;
		PluginPrivilege?: Array<PluginPrivilege>;
	};
	/**
	 * Container spec for the service.
	 *
	 * <p><br /></p>
	 *
	 * > **Note**: ContainerSpec, NetworkAttachmentSpec, and PluginSpec are
	 * > mutually exclusive. PluginSpec is only used when the Runtime field
	 * > is set to `plugin`. NetworkAttachmentSpec is used when the Runtime
	 * > field is set to `attachment`.
	 *
	 */
	ContainerSpec?: {
		/**
		 * The image name to use for the container
		 */
		Image?: string;
		/**
		 * User-defined key/value data.
		 */
		Labels?: {
			[key: string]: (string);
		};
		/**
		 * The command to be run in the image.
		 */
		Command?: Array<(string)>;
		/**
		 * Arguments to the command.
		 */
		Args?: Array<(string)>;
		/**
		 * The hostname to use for the container, as a valid
		 * [RFC 1123](https://tools.ietf.org/html/rfc1123) hostname.
		 *
		 */
		Hostname?: string;
		/**
		 * A list of environment variables in the form `VAR=value`.
		 *
		 */
		Env?: Array<(string)>;
		/**
		 * The working directory for commands to run in.
		 */
		Dir?: string;
		/**
		 * The user inside the container.
		 */
		User?: string;
		/**
		 * A list of additional groups that the container process will run as.
		 *
		 */
		Groups?: Array<(string)>;
		/**
		 * Security options for the container
		 */
		Privileges?: {
			/**
			 * CredentialSpec for managed service account (Windows only)
			 */
			CredentialSpec?: {
				/**
				 * Load credential spec from a Swarm Config with the given ID.
				 * The specified config must also be present in the Configs
				 * field with the Runtime property set.
				 *
				 * <p><br /></p>
				 *
				 *
				 * > **Note**: `CredentialSpec.File`, `CredentialSpec.Registry`,
				 * > and `CredentialSpec.Config` are mutually exclusive.
				 *
				 */
				Config?: string;
				/**
				 * Load credential spec from this file. The file is read by
				 * the daemon, and must be present in the `CredentialSpecs`
				 * subdirectory in the docker data directory, which defaults
				 * to `C:\ProgramData\Docker\` on Windows.
				 *
				 * For example, specifying `spec.json` loads
				 * `C:\ProgramData\Docker\CredentialSpecs\spec.json`.
				 *
				 * <p><br /></p>
				 *
				 * > **Note**: `CredentialSpec.File`, `CredentialSpec.Registry`,
				 * > and `CredentialSpec.Config` are mutually exclusive.
				 *
				 */
				File?: string;
				/**
				 * Load credential spec from this value in the Windows
				 * registry. The specified registry value must be located in:
				 *
				 * `HKLM\SOFTWARE\Microsoft\Windows NT\CurrentVersion\Virtualization\Containers\CredentialSpecs`
				 *
				 * <p><br /></p>
				 *
				 *
				 * > **Note**: `CredentialSpec.File`, `CredentialSpec.Registry`,
				 * > and `CredentialSpec.Config` are mutually exclusive.
				 *
				 */
				Registry?: string;
			};
			/**
			 * SELinux labels of the container
			 */
			SELinuxContext?: {
				/**
				 * Disable SELinux
				 */
				Disable?: boolean;
				/**
				 * SELinux user label
				 */
				User?: string;
				/**
				 * SELinux role label
				 */
				Role?: string;
				/**
				 * SELinux type label
				 */
				Type?: string;
				/**
				 * SELinux level label
				 */
				Level?: string;
			};
			/**
			 * Options for configuring seccomp on the container
			 */
			Seccomp?: {
				Mode?: "default" | "unconfined" | "custom";
				/**
				 * The custom seccomp profile as a json object
				 */
				Profile?: string;
			};
			/**
			 * Options for configuring AppArmor on the container
			 */
			AppArmor?: {
				Mode?: "default" | "disabled";
			};
			/**
			 * Configuration of the no_new_privs bit in the container
			 */
			NoNewPrivileges?: boolean;
		};
		/**
		 * Whether a pseudo-TTY should be allocated.
		 */
		TTY?: boolean;
		/**
		 * Open `stdin`
		 */
		OpenStdin?: boolean;
		/**
		 * Mount the container's root filesystem as read only.
		 */
		ReadOnly?: boolean;
		/**
		 * Specification for mounts to be added to containers created as part
		 * of the service.
		 *
		 */
		Mounts?: Array<Mount>;
		/**
		 * Signal to stop the container.
		 */
		StopSignal?: string;
		/**
		 * Amount of time to wait for the container to terminate before
		 * forcefully killing it.
		 *
		 */
		StopGracePeriod?: number;
		HealthCheck?: HealthConfig;
		/**
		 * A list of hostname/IP mappings to add to the container's `hosts`
		 * file. The format of extra hosts is specified in the
		 * [hosts(5)](http://man7.org/linux/man-pages/man5/hosts.5.html)
		 * man page:
		 *
		 * IP_address canonical_hostname [aliases...]
		 *
		 */
		Hosts?: Array<(string)>;
		/**
		 * Specification for DNS related configurations in resolver configuration
		 * file (`resolv.conf`).
		 *
		 */
		DNSConfig?: {
			/**
			 * The IP addresses of the name servers.
			 */
			Nameservers?: Array<(string)>;
			/**
			 * A search list for host-name lookup.
			 */
			Search?: Array<(string)>;
			/**
			 * A list of internal resolver variables to be modified (e.g.,
			 * `debug`, `ndots:3`, etc.).
			 *
			 */
			Options?: Array<(string)>;
		};
		/**
		 * Secrets contains references to zero or more secrets that will be
		 * exposed to the service.
		 *
		 */
		Secrets?: Array<{
			/**
			 * File represents a specific target that is backed by a file.
			 *
			 */
			File?: {
				/**
				 * Name represents the final filename in the filesystem.
				 *
				 */
				Name?: string;
				/**
				 * UID represents the file UID.
				 */
				UID?: string;
				/**
				 * GID represents the file GID.
				 */
				GID?: string;
				/**
				 * Mode represents the FileMode of the file.
				 */
				Mode?: number;
			};
			/**
			 * SecretID represents the ID of the specific secret that we're
			 * referencing.
			 *
			 */
			SecretID?: string;
			/**
			 * SecretName is the name of the secret that this references,
			 * but this is just provided for lookup/display purposes. The
			 * secret in the reference will be identified by its ID.
			 *
			 */
			SecretName?: string;
		}>;
		/**
		 * Configs contains references to zero or more configs that will be
		 * exposed to the service.
		 *
		 */
		Configs?: Array<{
			/**
			 * File represents a specific target that is backed by a file.
			 *
			 * <p><br /><p>
			 *
			 * > **Note**: `Configs.File` and `Configs.Runtime` are mutually exclusive
			 *
			 */
			File?: {
				/**
				 * Name represents the final filename in the filesystem.
				 *
				 */
				Name?: string;
				/**
				 * UID represents the file UID.
				 */
				UID?: string;
				/**
				 * GID represents the file GID.
				 */
				GID?: string;
				/**
				 * Mode represents the FileMode of the file.
				 */
				Mode?: number;
			};
			/**
			 * Runtime represents a target that is not mounted into the
			 * container but is used by the task
			 *
			 * <p><br /><p>
			 *
			 * > **Note**: `Configs.File` and `Configs.Runtime` are mutually
			 * > exclusive
			 *
			 */
			Runtime?: unknown;
			/**
			 * ConfigID represents the ID of the specific config that we're
			 * referencing.
			 *
			 */
			ConfigID?: string;
			/**
			 * ConfigName is the name of the config that this references,
			 * but this is just provided for lookup/display purposes. The
			 * config in the reference will be identified by its ID.
			 *
			 */
			ConfigName?: string;
		}>;
		/**
		 * Isolation technology of the containers running the service.
		 * (Windows only)
		 *
		 */
		Isolation?: "default" | "process" | "hyperv";
		/**
		 * Run an init inside the container that forwards signals and reaps
		 * processes. This field is omitted if empty, and the default (as
		 * configured on the daemon) is used.
		 *
		 */
		Init?: boolean | null;
		/**
		 * Set kernel namedspaced parameters (sysctls) in the container.
		 * The Sysctls option on services accepts the same sysctls as the
		 * are supported on containers. Note that while the same sysctls are
		 * supported, no guarantees or checks are made about their
		 * suitability for a clustered environment, and it's up to the user
		 * to determine whether a given sysctl will work properly in a
		 * Service.
		 *
		 */
		Sysctls?: {
			[key: string]: (string);
		};
		/**
		 * A list of kernel capabilities to add to the default set
		 * for the container.
		 *
		 */
		CapabilityAdd?: Array<(string)>;
		/**
		 * A list of kernel capabilities to drop from the default set
		 * for the container.
		 *
		 */
		CapabilityDrop?: Array<(string)>;
		/**
		 * A list of resource limits to set in the container. For example: `{"Name": "nofile", "Soft": 1024, "Hard": 2048}`"
		 *
		 */
		Ulimits?: Array<{
			/**
			 * Name of ulimit
			 */
			Name?: string;
			/**
			 * Soft limit
			 */
			Soft?: number;
			/**
			 * Hard limit
			 */
			Hard?: number;
		}>;
	};
	/**
	 * Read-only spec type for non-swarm containers attached to swarm overlay
	 * networks.
	 *
	 * <p><br /></p>
	 *
	 * > **Note**: ContainerSpec, NetworkAttachmentSpec, and PluginSpec are
	 * > mutually exclusive. PluginSpec is only used when the Runtime field
	 * > is set to `plugin`. NetworkAttachmentSpec is used when the Runtime
	 * > field is set to `attachment`.
	 *
	 */
	NetworkAttachmentSpec?: {
		/**
		 * ID of the container represented by this task
		 */
		ContainerID?: string;
	};
	/**
	 * Resource requirements which apply to each individual container created
	 * as part of the service.
	 *
	 */
	Resources?: {
		/**
		 * Define resources limits.
		 */
		Limits?: Limit;
		/**
		 * Define resources reservation.
		 */
		Reservations?: ResourceObject;
	};
	/**
	 * Specification for the restart policy which applies to containers
	 * created as part of this service.
	 *
	 */
	RestartPolicy?: {
		/**
		 * Condition for restart.
		 */
		Condition?: "none" | "on-failure" | "any";
		/**
		 * Delay between restart attempts.
		 */
		Delay?: number;
		/**
		 * Maximum attempts to restart a given container before giving up
		 * (default value is 0, which is ignored).
		 *
		 */
		MaxAttempts?: number;
		/**
		 * Windows is the time window used to evaluate the restart policy
		 * (default value is 0, which is unbounded).
		 *
		 */
		Window?: number;
	};
	Placement?: {
		/**
		 * An array of constraint expressions to limit the set of nodes where
		 * a task can be scheduled. Constraint expressions can either use a
		 * _match_ (`==`) or _exclude_ (`!=`) rule. Multiple constraints find
		 * nodes that satisfy every expression (AND match). Constraints can
		 * match node or Docker Engine labels as follows:
		 *
		 * node attribute       | matches                        | example
		 * ---------------------|--------------------------------|-----------------------------------------------
		 * `node.id`            | Node ID                        | `node.id==2ivku8v2gvtg4`
		 * `node.hostname`      | Node hostname                  | `node.hostname!=node-2`
		 * `node.role`          | Node role (`manager`/`worker`) | `node.role==manager`
		 * `node.platform.os`   | Node operating system          | `node.platform.os==windows`
		 * `node.platform.arch` | Node architecture              | `node.platform.arch==x86_64`
		 * `node.labels`        | User-defined node labels       | `node.labels.security==high`
		 * `engine.labels`      | Docker Engine's labels         | `engine.labels.operatingsystem==ubuntu-14.04`
		 *
		 * `engine.labels` apply to Docker Engine labels like operating system,
		 * drivers, etc. Swarm administrators add `node.labels` for operational
		 * purposes by using the [`node update endpoint`](#operation/NodeUpdate).
		 *
		 */
		Constraints?: Array<(string)>;
		/**
		 * Preferences provide a way to make the scheduler aware of factors
		 * such as topology. They are provided in order from highest to
		 * lowest precedence.
		 *
		 */
		Preferences?: Array<{
			Spread?: {
				/**
				 * label descriptor, such as `engine.labels.az`.
				 *
				 */
				SpreadDescriptor?: string;
			};
		}>;
		/**
		 * Maximum number of replicas for per node (default value is 0, which
		 * is unlimited)
		 *
		 */
		MaxReplicas?: number;
		/**
		 * Platforms stores all the platforms that the service's image can
		 * run on. This field is used in the platform filter for scheduling.
		 * If empty, then the platform filter is off, meaning there are no
		 * scheduling restrictions.
		 *
		 */
		Platforms?: Array<Platform>;
	};
	/**
	 * A counter that triggers an update even if no relevant parameters have
	 * been changed.
	 *
	 */
	ForceUpdate?: number;
	/**
	 * Runtime is the type of runtime specified for the task executor.
	 *
	 */
	Runtime?: string;
	/**
	 * Specifies which networks the service should attach to.
	 */
	Networks?: Array<NetworkAttachmentConfig>;
	/**
	 * Specifies the log driver to use for tasks created from this spec. If
	 * not present, the default one for the swarm will be used, finally
	 * falling back to the engine default if not specified.
	 *
	 */
	LogDriver?: {
		Name?: string;
		Options?: {
			[key: string]: (string);
		};
	};
};
export declare enum TaskState {
	NEW = "new",
	ALLOCATED = "allocated",
	PENDING = "pending",
	ASSIGNED = "assigned",
	ACCEPTED = "accepted",
	PREPARING = "preparing",
	READY = "ready",
	STARTING = "starting",
	RUNNING = "running",
	COMPLETE = "complete",
	SHUTDOWN = "shutdown",
	FAILED = "failed",
	REJECTED = "rejected",
	REMOVE = "remove",
	ORPHANED = "orphaned"
}
/**
 * represents the status of a container.
 */
export type ContainerStatus = {
	ContainerID?: string;
	PID?: number;
	ExitCode?: number;
};
/**
 * represents the port status of a task's host ports whose service has published host ports
 */
export type PortStatus = {
	Ports?: Array<EndpointPortConfig>;
};
/**
 * represents the status of a task.
 */
export type TaskStatus = {
	Timestamp?: string;
	State?: TaskState;
	Message?: string;
	Err?: string;
	ContainerStatus?: ContainerStatus;
	PortStatus?: PortStatus;
};
export type Task = {
	/**
	 * The ID of the task.
	 */
	ID?: string;
	Version?: ObjectVersion;
	CreatedAt?: string;
	UpdatedAt?: string;
	/**
	 * Name of the task.
	 */
	Name?: string;
	/**
	 * User-defined key/value metadata.
	 */
	Labels?: {
		[key: string]: (string);
	};
	Spec?: TaskSpec;
	/**
	 * The ID of the service this task is part of.
	 */
	ServiceID?: string;
	Slot?: number;
	/**
	 * The ID of the node that this task is on.
	 */
	NodeID?: string;
	AssignedGenericResources?: GenericResources;
	Status?: TaskStatus;
	DesiredState?: TaskState;
	/**
	 * If the Service this Task belongs to is a job-mode service, contains
	 * the JobIteration of the Service this Task was created for. Absent if
	 * the Task was created for a Replicated or Global Service.
	 *
	 */
	JobIteration?: ObjectVersion;
};
/**
 * User modifiable configuration for a service.
 */
export type ServiceSpec = {
	/**
	 * Name of the service.
	 */
	Name?: string;
	/**
	 * User-defined key/value metadata.
	 */
	Labels?: {
		[key: string]: (string);
	};
	TaskTemplate?: TaskSpec;
	/**
	 * Scheduling mode for the service.
	 */
	Mode?: {
		Replicated?: {
			Replicas?: number;
		};
		Global?: unknown;
		/**
		 * The mode used for services with a finite number of tasks that run
		 * to a completed state.
		 *
		 */
		ReplicatedJob?: {
			/**
			 * The maximum number of replicas to run simultaneously.
			 *
			 */
			MaxConcurrent?: number;
			/**
			 * The total number of replicas desired to reach the Completed
			 * state. If unset, will default to the value of `MaxConcurrent`
			 *
			 */
			TotalCompletions?: number;
		};
		/**
		 * The mode used for services which run a task to the completed state
		 * on each valid node.
		 *
		 */
		GlobalJob?: unknown;
	};
	/**
	 * Specification for the update strategy of the service.
	 */
	UpdateConfig?: {
		/**
		 * Maximum number of tasks to be updated in one iteration (0 means
		 * unlimited parallelism).
		 *
		 */
		Parallelism?: number;
		/**
		 * Amount of time between updates, in nanoseconds.
		 */
		Delay?: number;
		/**
		 * Action to take if an updated task fails to run, or stops running
		 * during the update.
		 *
		 */
		FailureAction?: "continue" | "pause" | "rollback";
		/**
		 * Amount of time to monitor each updated task for failures, in
		 * nanoseconds.
		 *
		 */
		Monitor?: number;
		/**
		 * The fraction of tasks that may fail during an update before the
		 * failure action is invoked, specified as a floating point number
		 * between 0 and 1.
		 *
		 */
		MaxFailureRatio?: number;
		/**
		 * The order of operations when rolling out an updated task. Either
		 * the old task is shut down before the new task is started, or the
		 * new task is started before the old task is shut down.
		 *
		 */
		Order?: "stop-first" | "start-first";
	};
	/**
	 * Specification for the rollback strategy of the service.
	 */
	RollbackConfig?: {
		/**
		 * Maximum number of tasks to be rolled back in one iteration (0 means
		 * unlimited parallelism).
		 *
		 */
		Parallelism?: number;
		/**
		 * Amount of time between rollback iterations, in nanoseconds.
		 *
		 */
		Delay?: number;
		/**
		 * Action to take if an rolled back task fails to run, or stops
		 * running during the rollback.
		 *
		 */
		FailureAction?: "continue" | "pause";
		/**
		 * Amount of time to monitor each rolled back task for failures, in
		 * nanoseconds.
		 *
		 */
		Monitor?: number;
		/**
		 * The fraction of tasks that may fail during a rollback before the
		 * failure action is invoked, specified as a floating point number
		 * between 0 and 1.
		 *
		 */
		MaxFailureRatio?: number;
		/**
		 * The order of operations when rolling back a task. Either the old
		 * task is shut down before the new task is started, or the new task
		 * is started before the old task is shut down.
		 *
		 */
		Order?: "stop-first" | "start-first";
	};
	/**
	 * Specifies which networks the service should attach to.
	 *
	 * Deprecated: This field is deprecated since v1.44. The Networks field in TaskSpec should be used instead.
	 *
	 */
	Networks?: Array<NetworkAttachmentConfig>;
	EndpointSpec?: EndpointSpec;
};
export type EndpointPortConfig = {
	Name?: string;
	Protocol?: "tcp" | "udp" | "sctp";
	/**
	 * The port inside the container.
	 */
	TargetPort?: number;
	/**
	 * The port on the swarm hosts.
	 */
	PublishedPort?: number;
	/**
	 * The mode in which port is published.
	 *
	 * <p><br /></p>
	 *
	 * - "ingress" makes the target port accessible on every node,
	 * regardless of whether there is a task for the service running on
	 * that node or not.
	 * - "host" bypasses the routing mesh and publish the port directly on
	 * the swarm node where that service is running.
	 *
	 */
	PublishMode?: "ingress" | "host";
};
/**
 * Properties that can be configured to access and load balance a service.
 */
export type EndpointSpec = {
	/**
	 * The mode of resolution to use for internal load balancing between tasks.
	 *
	 */
	Mode?: "vip" | "dnsrr";
	/**
	 * List of exposed ports that this service is accessible on from the
	 * outside. Ports can only be provided if `vip` resolution mode is used.
	 *
	 */
	Ports?: Array<EndpointPortConfig>;
};
export type Service = {
	ID?: string;
	Version?: ObjectVersion;
	CreatedAt?: string;
	UpdatedAt?: string;
	Spec?: ServiceSpec;
	Endpoint?: {
		Spec?: EndpointSpec;
		Ports?: Array<EndpointPortConfig>;
		VirtualIPs?: Array<{
			NetworkID?: string;
			Addr?: string;
		}>;
	};
	/**
	 * The status of a service update.
	 */
	UpdateStatus?: {
		State?: "updating" | "paused" | "completed";
		StartedAt?: string;
		CompletedAt?: string;
		Message?: string;
	};
	/**
	 * The status of the service's tasks. Provided only when requested as
	 * part of a ServiceList operation.
	 *
	 */
	ServiceStatus?: {
		/**
		 * The number of tasks for the service currently in the Running state.
		 *
		 */
		RunningTasks?: number;
		/**
		 * The number of tasks for the service desired to be running.
		 * For replicated services, this is the replica count from the
		 * service spec. For global services, this is computed by taking
		 * count of all tasks for the service with a Desired State other
		 * than Shutdown.
		 *
		 */
		DesiredTasks?: number;
		/**
		 * The number of tasks for a job that are in the Completed state.
		 * This field must be cross-referenced with the service type, as the
		 * value of 0 may mean the service is not in a job mode, or it may
		 * mean the job-mode service has no tasks yet Completed.
		 *
		 */
		CompletedTasks?: number;
	};
	/**
	 * The status of the service when it is in one of ReplicatedJob or
	 * GlobalJob modes. Absent on Replicated and Global mode services. The
	 * JobIteration is an ObjectVersion, but unlike the Service's version,
	 * does not need to be sent with an update request.
	 *
	 */
	JobStatus?: {
		/**
		 * JobIteration is a value increased each time a Job is executed,
		 * successfully or otherwise. "Executed", in this case, means the
		 * job as a whole has been started, not that an individual Task has
		 * been launched. A job is "Executed" when its ServiceSpec is
		 * updated. JobIteration can be used to disambiguate Tasks belonging
		 * to different executions of a job.  Though JobIteration will
		 * increase with each subsequent execution, it may not necessarily
		 * increase by 1, and so JobIteration should not be used to
		 *
		 */
		JobIteration?: ObjectVersion;
		/**
		 * The last time, as observed by the server, that this job was
		 * started.
		 *
		 */
		LastExecution?: string;
	};
};
export type ImageDeleteResponseItem = {
	/**
	 * The image ID of an image that was untagged
	 */
	Untagged?: string;
	/**
	 * The image ID of an image that was deleted
	 */
	Deleted?: string;
};
/**
 * contains the information returned to a client on the
 * creation of a new service.
 *
 */
export type ServiceCreateResponse = {
	/**
	 * The ID of the created service.
	 */
	ID?: string;
	/**
	 * Optional warning message.
	 *
	 * FIXME(thaJeztah): this should have "omitempty" in the generated type.
	 *
	 */
	Warnings?: Array<(string)> | null;
};
export type ServiceUpdateResponse = {
	/**
	 * Optional warning messages
	 */
	Warnings?: Array<(string)>;
};
export type ContainerSummary = {
	/**
	 * The ID of this container
	 */
	Id?: string;
	/**
	 * The names that this container has been given
	 */
	Names?: Array<(string)>;
	/**
	 * The name of the image used when creating this container
	 */
	Image?: string;
	/**
	 * The ID of the image that this container was created from
	 */
	ImageID?: string;
	/**
	 * Command to run when starting the container
	 */
	Command?: string;
	/**
	 * When the container was created
	 */
	Created?: number;
	/**
	 * The ports exposed by this container
	 */
	Ports?: Array<Port>;
	/**
	 * The size of files that have been created or changed by this container
	 */
	SizeRw?: number;
	/**
	 * The total size of all the files in this container
	 */
	SizeRootFs?: number;
	/**
	 * User-defined key/value metadata.
	 */
	Labels?: {
		[key: string]: (string);
	};
	/**
	 * The state of this container (e.g. `Exited`)
	 */
	State?: string;
	/**
	 * Additional human-readable status of this container (e.g. `Exit 0`)
	 */
	Status?: string;
	HostConfig?: {
		NetworkMode?: string;
	};
	/**
	 * A summary of the container's network settings
	 */
	NetworkSettings?: {
		Networks?: {
			[key: string]: EndpointSettings;
		};
	};
	Mounts?: Array<MountPoint>;
};
/**
 * Driver represents a driver (network, logging, secrets).
 */
export type Driver = {
	/**
	 * Name of the driver.
	 */
	Name: string;
	/**
	 * Key/value map of driver-specific options.
	 */
	Options?: {
		[key: string]: (string);
	};
};
export type SecretSpec = {
	/**
	 * User-defined name of the secret.
	 */
	Name?: string;
	/**
	 * User-defined key/value metadata.
	 */
	Labels?: {
		[key: string]: (string);
	};
	/**
	 * Base64-url-safe-encoded ([RFC 4648](https://tools.ietf.org/html/rfc4648#section-5))
	 * data to store as secret.
	 *
	 * This field is only used to _create_ a secret, and is not returned by
	 * other endpoints.
	 *
	 */
	Data?: string;
	/**
	 * Name of the secrets driver used to fetch the secret's value from an
	 * external secret store.
	 *
	 */
	Driver?: Driver;
	/**
	 * Templating driver, if applicable
	 *
	 * Templating controls whether and how to evaluate the config payload as
	 * a template. If no driver is set, no templating is used.
	 *
	 */
	Templating?: Driver;
};
export type Secret = {
	ID?: string;
	Version?: ObjectVersion;
	CreatedAt?: string;
	UpdatedAt?: string;
	Spec?: SecretSpec;
};
export type ConfigSpec = {
	/**
	 * User-defined name of the config.
	 */
	Name?: string;
	/**
	 * User-defined key/value metadata.
	 */
	Labels?: {
		[key: string]: (string);
	};
	/**
	 * Base64-url-safe-encoded ([RFC 4648](https://tools.ietf.org/html/rfc4648#section-5))
	 * config data.
	 *
	 */
	Data?: string;
	/**
	 * Templating driver, if applicable
	 *
	 * Templating controls whether and how to evaluate the config payload as
	 * a template. If no driver is set, no templating is used.
	 *
	 */
	Templating?: Driver;
};
export type Config = {
	ID?: string;
	Version?: ObjectVersion;
	CreatedAt?: string;
	UpdatedAt?: string;
	Spec?: ConfigSpec;
};
/**
 * ContainerState stores container's running state. It's part of ContainerJSONBase
 * and will be returned by the "inspect" command.
 *
 */
export type ContainerState = {
	/**
	 * String representation of the container state. Can be one of "created",
	 * "running", "paused", "restarting", "removing", "exited", or "dead".
	 *
	 */
	Status?: "created" | "running" | "paused" | "restarting" | "removing" | "exited" | "dead";
	/**
	 * Whether this container is running.
	 *
	 * Note that a running container can be _paused_. The `Running` and `Paused`
	 * booleans are not mutually exclusive:
	 *
	 * When pausing a container (on Linux), the freezer cgroup is used to suspend
	 * all processes in the container. Freezing the process requires the process to
	 * be running. As a result, paused containers are both `Running` _and_ `Paused`.
	 *
	 * Use the `Status` field instead to determine if a container's state is "running".
	 *
	 */
	Running?: boolean;
	/**
	 * Whether this container is paused.
	 */
	Paused?: boolean;
	/**
	 * Whether this container is restarting.
	 */
	Restarting?: boolean;
	/**
	 * Whether a process within this container has been killed because it ran
	 * out of memory since the container was last started.
	 *
	 */
	OOMKilled?: boolean;
	Dead?: boolean;
	/**
	 * The process ID of this container
	 */
	Pid?: number;
	/**
	 * The last exit code of this container
	 */
	ExitCode?: number;
	Error?: string;
	/**
	 * The time when this container was last started.
	 */
	StartedAt?: string;
	/**
	 * The time when this container last exited.
	 */
	FinishedAt?: string;
	Health?: Health;
} | null;
/**
 * OK response to ContainerCreate operation
 */
export type ContainerCreateResponse = {
	/**
	 * The ID of the created container
	 */
	Id: string;
	/**
	 * Warnings encountered when creating the container
	 */
	Warnings: Array<(string)>;
};
/**
 * OK response to ContainerWait operation
 */
export type ContainerWaitResponse = {
	/**
	 * Exit code of the container
	 */
	StatusCode: number;
	Error?: ContainerWaitExitError;
};
/**
 * container waiting error, if any
 */
export type ContainerWaitExitError = {
	/**
	 * Details of an error
	 */
	Message?: string;
};
/**
 * Response of Engine API: GET "/version"
 *
 */
export type SystemVersion = {
	Platform?: {
		Name: string;
	};
	/**
	 * Information about system components
	 *
	 */
	Components?: Array<{
		/**
		 * Name of the component
		 *
		 */
		Name: string;
		/**
		 * Version of the component
		 *
		 */
		Version: string;
		/**
		 * Key/value pairs of strings with additional information about the
		 * component. These values are intended for informational purposes
		 * only, and their content is not defined, and not part of the API
		 * specification.
		 *
		 * These messages can be printed by the client as information to the user.
		 *
		 */
		Details?: unknown;
	}>;
	/**
	 * The version of the daemon
	 */
	Version?: string;
	/**
	 * The default (and highest) API version that is supported by the daemon
	 *
	 */
	ApiVersion?: string;
	/**
	 * The minimum API version that is supported by the daemon
	 *
	 */
	MinAPIVersion?: string;
	/**
	 * The Git commit of the source code that was used to build the daemon
	 *
	 */
	GitCommit?: string;
	/**
	 * The version Go used to compile the daemon, and the version of the Go
	 * runtime in use.
	 *
	 */
	GoVersion?: string;
	/**
	 * The operating system that the daemon is running on ("linux" or "windows")
	 *
	 */
	Os?: string;
	/**
	 * The architecture that the daemon is running on
	 *
	 */
	Arch?: string;
	/**
	 * The kernel version (`uname -r`) that the daemon is running on.
	 *
	 * This field is omitted when empty.
	 *
	 */
	KernelVersion?: string;
	/**
	 * Indicates if the daemon is started with experimental features enabled.
	 *
	 * This field is omitted when empty / false.
	 *
	 */
	Experimental?: boolean;
	/**
	 * The date and time that the daemon was compiled.
	 *
	 */
	BuildTime?: string;
};
export type SystemInfo = {
	/**
	 * Unique identifier of the daemon.
	 *
	 * <p><br /></p>
	 *
	 * > **Note**: The format of the ID itself is not part of the API, and
	 * > should not be considered stable.
	 *
	 */
	ID?: string;
	/**
	 * Total number of containers on the host.
	 */
	Containers?: number;
	/**
	 * Number of containers with status `"running"`.
	 *
	 */
	ContainersRunning?: number;
	/**
	 * Number of containers with status `"paused"`.
	 *
	 */
	ContainersPaused?: number;
	/**
	 * Number of containers with status `"stopped"`.
	 *
	 */
	ContainersStopped?: number;
	/**
	 * Total number of images on the host.
	 *
	 * Both _tagged_ and _untagged_ (dangling) images are counted.
	 *
	 */
	Images?: number;
	/**
	 * Name of the storage driver in use.
	 */
	Driver?: string;
	/**
	 * Information specific to the storage driver, provided as
	 * "label" / "value" pairs.
	 *
	 * This information is provided by the storage driver, and formatted
	 * in a way consistent with the output of `docker info` on the command
	 * line.
	 *
	 * <p><br /></p>
	 *
	 * > **Note**: The information returned in this field, including the
	 * > formatting of values and labels, should not be considered stable,
	 * > and may change without notice.
	 *
	 */
	DriverStatus?: Array<Array<(string)>>;
	/**
	 * Root directory of persistent Docker state.
	 *
	 * Defaults to `/var/lib/docker` on Linux, and `C:\ProgramData\docker`
	 * on Windows.
	 *
	 */
	DockerRootDir?: string;
	Plugins?: PluginsInfo;
	/**
	 * Indicates if the host has memory limit support enabled.
	 */
	MemoryLimit?: boolean;
	/**
	 * Indicates if the host has memory swap limit support enabled.
	 */
	SwapLimit?: boolean;
	/**
	 * Indicates if the host has kernel memory TCP limit support enabled. This
	 * field is omitted if not supported.
	 *
	 * Kernel memory TCP limits are not supported when using cgroups v2, which
	 * does not support the corresponding `memory.kmem.tcp.limit_in_bytes` cgroup.
	 *
	 */
	KernelMemoryTCP?: boolean;
	/**
	 * Indicates if CPU CFS(Completely Fair Scheduler) period is supported by
	 * the host.
	 *
	 */
	CpuCfsPeriod?: boolean;
	/**
	 * Indicates if CPU CFS(Completely Fair Scheduler) quota is supported by
	 * the host.
	 *
	 */
	CpuCfsQuota?: boolean;
	/**
	 * Indicates if CPU Shares limiting is supported by the host.
	 *
	 */
	CPUShares?: boolean;
	/**
	 * Indicates if CPUsets (cpuset.cpus, cpuset.mems) are supported by the host.
	 *
	 * See [cpuset(7)](https://www.kernel.org/doc/Documentation/cgroup-v1/cpusets.txt)
	 *
	 */
	CPUSet?: boolean;
	/**
	 * Indicates if the host kernel has PID limit support enabled.
	 */
	PidsLimit?: boolean;
	/**
	 * Indicates if OOM killer disable is supported on the host.
	 */
	OomKillDisable?: boolean;
	/**
	 * Indicates IPv4 forwarding is enabled.
	 */
	IPv4Forwarding?: boolean;
	/**
	 * Indicates if `bridge-nf-call-iptables` is available on the host.
	 */
	BridgeNfIptables?: boolean;
	/**
	 * Indicates if `bridge-nf-call-ip6tables` is available on the host.
	 */
	BridgeNfIp6tables?: boolean;
	/**
	 * Indicates if the daemon is running in debug-mode / with debug-level
	 * logging enabled.
	 *
	 */
	Debug?: boolean;
	/**
	 * The total number of file Descriptors in use by the daemon process.
	 *
	 * This information is only returned if debug-mode is enabled.
	 *
	 */
	NFd?: number;
	/**
	 * The  number of goroutines that currently exist.
	 *
	 * This information is only returned if debug-mode is enabled.
	 *
	 */
	NGoroutines?: number;
	/**
	 * Current system-time in [RFC 3339](https://www.ietf.org/rfc/rfc3339.txt)
	 * format with nano-seconds.
	 *
	 */
	SystemTime?: string;
	/**
	 * The logging driver to use as a default for new containers.
	 *
	 */
	LoggingDriver?: string;
	/**
	 * The driver to use for managing cgroups.
	 *
	 */
	CgroupDriver?: "cgroupfs" | "systemd" | "none";
	/**
	 * The version of the cgroup.
	 *
	 */
	CgroupVersion?: "1" | "2";
	/**
	 * Number of event listeners subscribed.
	 */
	NEventsListener?: number;
	/**
	 * Kernel version of the host.
	 *
	 * On Linux, this information obtained from `uname`. On Windows this
	 * information is queried from the <kbd>HKEY_LOCAL_MACHINE\\SOFTWARE\\Microsoft\\Windows NT\\CurrentVersion\\</kbd>
	 * registry value, for example _"10.0 14393 (14393.1198.amd64fre.rs1_release_sec.170427-1353)"_.
	 *
	 */
	KernelVersion?: string;
	/**
	 * Name of the host's operating system, for example: "Ubuntu 16.04.2 LTS"
	 * or "Windows Server 2016 Datacenter"
	 *
	 */
	OperatingSystem?: string;
	/**
	 * Version of the host's operating system
	 *
	 * <p><br /></p>
	 *
	 * > **Note**: The information returned in this field, including its
	 * > very existence, and the formatting of values, should not be considered
	 * > stable, and may change without notice.
	 *
	 */
	OSVersion?: string;
	/**
	 * Generic type of the operating system of the host, as returned by the
	 * Go runtime (`GOOS`).
	 *
	 * Currently returned values are "linux" and "windows". A full list of
	 * possible values can be found in the [Go documentation](https://go.dev/doc/install/source#environment).
	 *
	 */
	OSType?: string;
	/**
	 * Hardware architecture of the host, as returned by the Go runtime
	 * (`GOARCH`).
	 *
	 * A full list of possible values can be found in the [Go documentation](https://go.dev/doc/install/source#environment).
	 *
	 */
	Architecture?: string;
	/**
	 * The number of logical CPUs usable by the daemon.
	 *
	 * The number of available CPUs is checked by querying the operating
	 * system when the daemon starts. Changes to operating system CPU
	 * allocation after the daemon is started are not reflected.
	 *
	 */
	NCPU?: number;
	/**
	 * Total amount of physical memory available on the host, in bytes.
	 *
	 */
	MemTotal?: number;
	/**
	 * Address / URL of the index server that is used for image search,
	 * and as a default for user authentication for Docker Hub and Docker Cloud.
	 *
	 */
	IndexServerAddress?: string;
	RegistryConfig?: RegistryServiceConfig;
	GenericResources?: GenericResources;
	/**
	 * HTTP-proxy configured for the daemon. This value is obtained from the
	 * [`HTTP_PROXY`](https://www.gnu.org/software/wget/manual/html_node/Proxies.html) environment variable.
	 * Credentials ([user info component](https://tools.ietf.org/html/rfc3986#section-3.2.1)) in the proxy URL
	 * are masked in the API response.
	 *
	 * Containers do not automatically inherit this configuration.
	 *
	 */
	HttpProxy?: string;
	/**
	 * HTTPS-proxy configured for the daemon. This value is obtained from the
	 * [`HTTPS_PROXY`](https://www.gnu.org/software/wget/manual/html_node/Proxies.html) environment variable.
	 * Credentials ([user info component](https://tools.ietf.org/html/rfc3986#section-3.2.1)) in the proxy URL
	 * are masked in the API response.
	 *
	 * Containers do not automatically inherit this configuration.
	 *
	 */
	HttpsProxy?: string;
	/**
	 * Comma-separated list of domain extensions for which no proxy should be
	 * used. This value is obtained from the [`NO_PROXY`](https://www.gnu.org/software/wget/manual/html_node/Proxies.html)
	 * environment variable.
	 *
	 * Containers do not automatically inherit this configuration.
	 *
	 */
	NoProxy?: string;
	/**
	 * Hostname of the host.
	 */
	Name?: string;
	/**
	 * User-defined labels (key/value metadata) as set on the daemon.
	 *
	 * <p><br /></p>
	 *
	 * > **Note**: When part of a Swarm, nodes can both have _daemon_ labels,
	 * > set through the daemon configuration, and _node_ labels, set from a
	 * > manager node in the Swarm. Node labels are not included in this
	 * > field. Node labels can be retrieved using the `/nodes/(id)` endpoint
	 * > on a manager node in the Swarm.
	 *
	 */
	Labels?: Array<(string)>;
	/**
	 * Indicates if experimental features are enabled on the daemon.
	 *
	 */
	ExperimentalBuild?: boolean;
	/**
	 * Version string of the daemon.
	 *
	 */
	ServerVersion?: string;
	/**
	 * List of [OCI compliant](https://github.com/opencontainers/runtime-spec)
	 * runtimes configured on the daemon. Keys hold the "name" used to
	 * reference the runtime.
	 *
	 * The Docker daemon relies on an OCI compliant runtime (invoked via the
	 * `containerd` daemon) as its interface to the Linux kernel namespaces,
	 * cgroups, and SELinux.
	 *
	 * The default runtime is `runc`, and automatically configured. Additional
	 * runtimes can be configured by the user and will be listed here.
	 *
	 */
	Runtimes?: {
		[key: string]: Runtime;
	};
	/**
	 * Name of the default OCI runtime that is used when starting containers.
	 *
	 * The default can be overridden per-container at create time.
	 *
	 */
	DefaultRuntime?: string;
	Swarm?: SwarmInfo;
	/**
	 * Indicates if live restore is enabled.
	 *
	 * If enabled, containers are kept running when the daemon is shutdown
	 * or upon daemon start if running containers are detected.
	 *
	 */
	LiveRestoreEnabled?: boolean;
	/**
	 * Represents the isolation technology to use as a default for containers.
	 * The supported values are platform-specific.
	 *
	 * If no isolation value is specified on daemon start, on Windows client,
	 * the default is `hyperv`, and on Windows server, the default is `process`.
	 *
	 * This option is currently not used on other platforms.
	 *
	 */
	Isolation?: "default" | "hyperv" | "process";
	/**
	 * Name and, optional, path of the `docker-init` binary.
	 *
	 * If the path is omitted, the daemon searches the host's `$PATH` for the
	 * binary and uses the first result.
	 *
	 */
	InitBinary?: string;
	ContainerdCommit?: Commit;
	RuncCommit?: Commit;
	InitCommit?: Commit;
	/**
	 * List of security features that are enabled on the daemon, such as
	 * apparmor, seccomp, SELinux, user-namespaces (userns), rootless and
	 * no-new-privileges.
	 *
	 * Additional configuration options for each security feature may
	 * be present, and are included as a comma-separated list of key/value
	 * pairs.
	 *
	 */
	SecurityOptions?: Array<(string)>;
	/**
	 * Reports a summary of the product license on the daemon.
	 *
	 * If a commercial license has been applied to the daemon, information
	 * such as number of nodes, and expiration are included.
	 *
	 */
	ProductLicense?: string;
	/**
	 * List of custom default address pools for local networks, which can be
	 * specified in the daemon.json file or dockerd option.
	 *
	 * Example: a Base "10.10.0.0/16" with Size 24 will define the set of 256
	 * 10.10.[0-255].0/24 address pools.
	 *
	 */
	DefaultAddressPools?: Array<{
		/**
		 * The network address in CIDR format
		 */
		Base?: string;
		/**
		 * The network pool size
		 */
		Size?: number;
	}>;
	/**
	 * List of warnings / informational messages about missing features, or
	 * issues related to the daemon configuration.
	 *
	 * These messages can be printed by the client as information to the user.
	 *
	 */
	Warnings?: Array<(string)>;
	/**
	 * List of directories where (Container Device Interface) CDI
	 * specifications are located.
	 *
	 * These specifications define vendor-specific modifications to an OCI
	 * runtime specification for a container being created.
	 *
	 * An empty list indicates that CDI device injection is disabled.
	 *
	 * Note that since using CDI device injection requires the daemon to have
	 * experimental enabled. For non-experimental daemons an empty list will
	 * always be returned.
	 *
	 */
	CDISpecDirs?: Array<(string)>;
};
/**
 * Available plugins per type.
 *
 * <p><br /></p>
 *
 * > **Note**: Only unmanaged (V1) plugins are included in this list.
 * > V1 plugins are "lazily" loaded, and are not returned in this list
 * > if there is no resource using the plugin.
 *
 */
export type PluginsInfo = {
	/**
	 * Names of available volume-drivers, and network-driver plugins.
	 */
	Volume?: Array<(string)>;
	/**
	 * Names of available network-drivers, and network-driver plugins.
	 */
	Network?: Array<(string)>;
	/**
	 * Names of available authorization plugins.
	 */
	Authorization?: Array<(string)>;
	/**
	 * Names of available logging-drivers, and logging-driver plugins.
	 */
	Log?: Array<(string)>;
};
/**
 * RegistryServiceConfig stores daemon registry services configuration.
 *
 */
export type RegistryServiceConfig = {
	/**
	 * List of IP ranges to which nondistributable artifacts can be pushed,
	 * using the CIDR syntax [RFC 4632](https://tools.ietf.org/html/4632).
	 *
	 * Some images (for example, Windows base images) contain artifacts
	 * whose distribution is restricted by license. When these images are
	 * pushed to a registry, restricted artifacts are not included.
	 *
	 * This configuration override this behavior, and enables the daemon to
	 * push nondistributable artifacts to all registries whose resolved IP
	 * address is within the subnet described by the CIDR syntax.
	 *
	 * This option is useful when pushing images containing
	 * nondistributable artifacts to a registry on an air-gapped network so
	 * hosts on that network can pull the images without connecting to
	 * another server.
	 *
	 * > **Warning**: Nondistributable artifacts typically have restrictions
	 * > on how and where they can be distributed and shared. Only use this
	 * > feature to push artifacts to private registries and ensure that you
	 * > are in compliance with any terms that cover redistributing
	 * > nondistributable artifacts.
	 *
	 */
	AllowNondistributableArtifactsCIDRs?: Array<(string)>;
	/**
	 * List of registry hostnames to which nondistributable artifacts can be
	 * pushed, using the format `<hostname>[:<port>]` or `<IP address>[:<port>]`.
	 *
	 * Some images (for example, Windows base images) contain artifacts
	 * whose distribution is restricted by license. When these images are
	 * pushed to a registry, restricted artifacts are not included.
	 *
	 * This configuration override this behavior for the specified
	 * registries.
	 *
	 * This option is useful when pushing images containing
	 * nondistributable artifacts to a registry on an air-gapped network so
	 * hosts on that network can pull the images without connecting to
	 * another server.
	 *
	 * > **Warning**: Nondistributable artifacts typically have restrictions
	 * > on how and where they can be distributed and shared. Only use this
	 * > feature to push artifacts to private registries and ensure that you
	 * > are in compliance with any terms that cover redistributing
	 * > nondistributable artifacts.
	 *
	 */
	AllowNondistributableArtifactsHostnames?: Array<(string)>;
	/**
	 * List of IP ranges of insecure registries, using the CIDR syntax
	 * ([RFC 4632](https://tools.ietf.org/html/4632)). Insecure registries
	 * accept un-encrypted (HTTP) and/or untrusted (HTTPS with certificates
	 * from unknown CAs) communication.
	 *
	 * By default, local registries (`127.0.0.0/8`) are configured as
	 * insecure. All other registries are secure. Communicating with an
	 * insecure registry is not possible if the daemon assumes that registry
	 * is secure.
	 *
	 * This configuration override this behavior, insecure communication with
	 * registries whose resolved IP address is within the subnet described by
	 * the CIDR syntax.
	 *
	 * Registries can also be marked insecure by hostname. Those registries
	 * are listed under `IndexConfigs` and have their `Secure` field set to
	 * `false`.
	 *
	 * > **Warning**: Using this option can be useful when running a local
	 * > registry, but introduces security vulnerabilities. This option
	 * > should therefore ONLY be used for testing purposes. For increased
	 * > security, users should add their CA to their system's list of trusted
	 * > CAs instead of enabling this option.
	 *
	 */
	InsecureRegistryCIDRs?: Array<(string)>;
	IndexConfigs?: {
		[key: string]: IndexInfo;
	};
	/**
	 * List of registry URLs that act as a mirror for the official
	 * (`docker.io`) registry.
	 *
	 */
	Mirrors?: Array<(string)>;
} | null;
/**
 * IndexInfo contains information about a registry.
 */
export type IndexInfo = {
	/**
	 * Name of the registry, such as "docker.io".
	 *
	 */
	Name?: string;
	/**
	 * List of mirrors, expressed as URIs.
	 *
	 */
	Mirrors?: Array<(string)>;
	/**
	 * Indicates if the registry is part of the list of insecure
	 * registries.
	 *
	 * If `false`, the registry is insecure. Insecure registries accept
	 * un-encrypted (HTTP) and/or untrusted (HTTPS with certificates from
	 * unknown CAs) communication.
	 *
	 * > **Warning**: Insecure registries can be useful when running a local
	 * > registry. However, because its use creates security vulnerabilities
	 * > it should ONLY be enabled for testing purposes. For increased
	 * > security, users should add their CA to their system's list of
	 * > trusted CAs instead of enabling this option.
	 *
	 */
	Secure?: boolean;
	/**
	 * Indicates whether this is an official registry (i.e., Docker Hub / docker.io)
	 *
	 */
	Official?: boolean;
} | null;
/**
 * Runtime describes an [OCI compliant](https://github.com/opencontainers/runtime-spec)
 * runtime.
 *
 * The runtime is invoked by the daemon via the `containerd` daemon. OCI
 * runtimes act as an interface to the Linux kernel namespaces, cgroups,
 * and SELinux.
 *
 */
export type Runtime = {
	/**
	 * Name and, optional, path, of the OCI executable binary.
	 *
	 * If the path is omitted, the daemon searches the host's `$PATH` for the
	 * binary and uses the first result.
	 *
	 */
	path?: string;
	/**
	 * List of command-line arguments to pass to the runtime when invoked.
	 *
	 */
	runtimeArgs?: Array<(string)> | null;
	/**
	 * Information specific to the runtime.
	 *
	 * While this API specification does not define data provided by runtimes,
	 * the following well-known properties may be provided by runtimes:
	 *
	 * `org.opencontainers.runtime-spec.features`: features structure as defined
	 * in the [OCI Runtime Specification](https://github.com/opencontainers/runtime-spec/blob/main/features.md),
	 * in a JSON string representation.
	 *
	 * <p><br /></p>
	 *
	 * > **Note**: The information returned in this field, including the
	 * > formatting of values and labels, should not be considered stable,
	 * > and may change without notice.
	 *
	 */
	status?: {
		[key: string]: (string);
	} | null;
};
/**
 * Commit holds the Git-commit (SHA1) that a binary was built from, as
 * reported in the version-string of external tools, such as `containerd`,
 * or `runC`.
 *
 */
export type Commit = {
	/**
	 * Actual commit ID of external tool.
	 */
	ID?: string;
	/**
	 * Commit ID of external tool expected by dockerd as set at build time.
	 *
	 */
	Expected?: string;
};
/**
 * Represents generic information about swarm.
 *
 */
export type SwarmInfo = {
	/**
	 * Unique identifier of for this node in the swarm.
	 */
	NodeID?: string;
	/**
	 * IP address at which this node can be reached by other nodes in the
	 * swarm.
	 *
	 */
	NodeAddr?: string;
	LocalNodeState?: LocalNodeState;
	ControlAvailable?: boolean;
	Error?: string;
	/**
	 * List of ID's and addresses of other managers in the swarm.
	 *
	 */
	RemoteManagers?: Array<PeerNode> | null;
	/**
	 * Total number of nodes in the swarm.
	 */
	Nodes?: number | null;
	/**
	 * Total number of managers in the swarm.
	 */
	Managers?: number | null;
	Cluster?: ClusterInfo;
};
/**
 * Current local status of this node.
 */
export declare enum LocalNodeState {
	EMPTY_STRING = "",
	INACTIVE = "inactive",
	PENDING = "pending",
	ACTIVE = "active",
	ERROR = "error",
	LOCKED = "locked"
}
/**
 * Represents a peer-node in the swarm
 */
export type PeerNode = {
	/**
	 * Unique identifier of for this node in the swarm.
	 */
	NodeID?: string;
	/**
	 * IP address and ports at which this node can be reached.
	 *
	 */
	Addr?: string;
};
/**
 * Specifies how a service should be attached to a particular network.
 *
 */
export type NetworkAttachmentConfig = {
	/**
	 * The target network for attachment. Must be a network name or ID.
	 *
	 */
	Target?: string;
	/**
	 * Discoverable alternate names for the service on this network.
	 *
	 */
	Aliases?: Array<(string)>;
	/**
	 * Driver attachment options for the network target.
	 *
	 */
	DriverOpts?: {
		[key: string]: (string);
	};
};
/**
 * Actor describes something that generates events, like a container, network,
 * or a volume.
 *
 */
export type EventActor = {
	/**
	 * The ID of the object emitting the event
	 */
	ID?: string;
	/**
	 * Various key/value attributes of the object, depending on its type.
	 *
	 */
	Attributes?: {
		[key: string]: (string);
	};
};
/**
 * EventMessage represents the information an event contains.
 *
 */
export type EventMessage = {
	/**
	 * The type of object emitting the event
	 */
	Type?: "builder" | "config" | "container" | "daemon" | "image" | "network" | "node" | "plugin" | "secret" | "service" | "volume";
	/**
	 * The type of event
	 */
	Action?: string;
	Actor?: EventActor;
	/**
	 * Scope of the event. Engine events are `local` scope. Cluster (Swarm)
	 * events are `swarm` scope.
	 *
	 */
	scope?: "local" | "swarm";
	/**
	 * Timestamp of event
	 */
	time?: number;
	/**
	 * Timestamp of event, with nanosecond accuracy
	 */
	timeNano?: number;
};
/**
 * A descriptor struct containing digest, media type, and size, as defined in
 * the [OCI Content Descriptors Specification](https://github.com/opencontainers/image-spec/blob/v1.0.1/descriptor.md).
 *
 */
export type OCIDescriptor = {
	/**
	 * The media type of the object this schema refers to.
	 *
	 */
	mediaType?: string;
	/**
	 * The digest of the targeted content.
	 *
	 */
	digest?: string;
	/**
	 * The size in bytes of the blob.
	 *
	 */
	size?: number;
};
/**
 * Describes the platform which the image in the manifest runs on, as defined
 * in the [OCI Image Index Specification](https://github.com/opencontainers/image-spec/blob/v1.0.1/image-index.md).
 *
 */
export type OCIPlatform = {
	/**
	 * The CPU architecture, for example `amd64` or `ppc64`.
	 *
	 */
	architecture?: string;
	/**
	 * The operating system, for example `linux` or `windows`.
	 *
	 */
	os?: string;
	/**
	 * Optional field specifying the operating system version, for example on
	 * Windows `10.0.19041.1165`.
	 *
	 */
	"os.version"?: string;
	/**
	 * Optional field specifying an array of strings, each listing a required
	 * OS feature (for example on Windows `win32k`).
	 *
	 */
	"os.features"?: Array<(string)>;
	/**
	 * Optional field specifying a variant of the CPU, for example `v7` to
	 * specify ARMv7 when architecture is `arm`.
	 *
	 */
	variant?: string;
};
/**
 * Describes the result obtained from contacting the registry to retrieve
 * image metadata.
 *
 */
export type DistributionInspect = {
	Descriptor: OCIDescriptor;
	/**
	 * An array containing all platforms supported by the image.
	 *
	 */
	Platforms: Array<OCIPlatform>;
};
/**
 * Options and information specific to, and only present on, Swarm CSI
 * cluster volumes.
 *
 */
export type ClusterVolume = {
	/**
	 * The Swarm ID of this volume. Because cluster volumes are Swarm
	 * objects, they have an ID, unlike non-cluster volumes. This ID can
	 * be used to refer to the Volume instead of the name.
	 *
	 */
	ID?: string;
	Version?: ObjectVersion;
	CreatedAt?: string;
	UpdatedAt?: string;
	Spec?: ClusterVolumeSpec;
	/**
	 * Information about the global status of the volume.
	 *
	 */
	Info?: {
		/**
		 * The capacity of the volume in bytes. A value of 0 indicates that
		 * the capacity is unknown.
		 *
		 */
		CapacityBytes?: number;
		/**
		 * A map of strings to strings returned from the storage plugin when
		 * the volume is created.
		 *
		 */
		VolumeContext?: {
			[key: string]: (string);
		};
		/**
		 * The ID of the volume as returned by the CSI storage plugin. This
		 * is distinct from the volume's ID as provided by Docker. This ID
		 * is never used by the user when communicating with Docker to refer
		 * to this volume. If the ID is blank, then the Volume has not been
		 * successfully created in the plugin yet.
		 *
		 */
		VolumeID?: string;
		/**
		 * The topology this volume is actually accessible from.
		 *
		 */
		AccessibleTopology?: Array<Topology>;
	};
	/**
	 * The status of the volume as it pertains to its publishing and use on
	 * specific nodes
	 *
	 */
	PublishStatus?: Array<{
		/**
		 * The ID of the Swarm node the volume is published on.
		 *
		 */
		NodeID?: string;
		/**
		 * The published state of the volume.
		 * * `pending-publish` The volume should be published to this node, but the call to the controller plugin to do so has not yet been successfully completed.
		 * * `published` The volume is published successfully to the node.
		 * * `pending-node-unpublish` The volume should be unpublished from the node, and the manager is awaiting confirmation from the worker that it has done so.
		 * * `pending-controller-unpublish` The volume is successfully unpublished from the node, but has not yet been successfully unpublished on the controller.
		 *
		 */
		State?: "pending-publish" | "published" | "pending-node-unpublish" | "pending-controller-unpublish";
		/**
		 * A map of strings to strings returned by the CSI controller
		 * plugin when a volume is published.
		 *
		 */
		PublishContext?: {
			[key: string]: (string);
		};
	}>;
};
/**
 * Cluster-specific options used to create the volume.
 *
 */
export type ClusterVolumeSpec = {
	/**
	 * Group defines the volume group of this volume. Volumes belonging to
	 * the same group can be referred to by group name when creating
	 * Services.  Referring to a volume by group instructs Swarm to treat
	 * volumes in that group interchangeably for the purpose of scheduling.
	 * Volumes with an empty string for a group technically all belong to
	 * the same, emptystring group.
	 *
	 */
	Group?: string;
	/**
	 * Defines how the volume is used by tasks.
	 *
	 */
	AccessMode?: {
		/**
		 * The set of nodes this volume can be used on at one time.
		 * - `single` The volume may only be scheduled to one node at a time.
		 * - `multi` the volume may be scheduled to any supported number of nodes at a time.
		 *
		 */
		Scope?: "single" | "multi";
		/**
		 * The number and way that different tasks can use this volume
		 * at one time.
		 * - `none` The volume may only be used by one task at a time.
		 * - `readonly` The volume may be used by any number of tasks, but they all must mount the volume as readonly
		 * - `onewriter` The volume may be used by any number of tasks, but only one may mount it as read/write.
		 * - `all` The volume may have any number of readers and writers.
		 *
		 */
		Sharing?: "none" | "readonly" | "onewriter" | "all";
		/**
		 * Options for using this volume as a Mount-type volume.
		 *
		 * Either MountVolume or BlockVolume, but not both, must be
		 * present.
		 * properties:
		 * FsType:
		 * type: "string"
		 * description: |
		 * Specifies the filesystem type for the mount volume.
		 * Optional.
		 * MountFlags:
		 * type: "array"
		 * description: |
		 * Flags to pass when mounting the volume. Optional.
		 * items:
		 * type: "string"
		 * BlockVolume:
		 * type: "object"
		 * description: |
		 * Options for using this volume as a Block-type volume.
		 * Intentionally empty.
		 *
		 */
		MountVolume?: unknown;
		/**
		 * Swarm Secrets that are passed to the CSI storage plugin when
		 * operating on this volume.
		 *
		 */
		Secrets?: Array<{
			/**
			 * Key is the name of the key of the key-value pair passed to
			 * the plugin.
			 *
			 */
			Key?: string;
			/**
			 * Secret is the swarm Secret object from which to read data.
			 * This can be a Secret name or ID. The Secret data is
			 * retrieved by swarm and used as the value of the key-value
			 * pair passed to the plugin.
			 *
			 */
			Secret?: string;
		}>;
		/**
		 * Requirements for the accessible topology of the volume. These
		 * fields are optional. For an in-depth description of what these
		 * fields mean, see the CSI specification.
		 *
		 */
		AccessibilityRequirements?: {
			/**
			 * A list of required topologies, at least one of which the
			 * volume must be accessible from.
			 *
			 */
			Requisite?: Array<Topology>;
			/**
			 * A list of topologies that the volume should attempt to be
			 * provisioned in.
			 *
			 */
			Preferred?: Array<Topology>;
		};
		/**
		 * The desired capacity that the volume should be created with. If
		 * empty, the plugin will decide the capacity.
		 *
		 */
		CapacityRange?: {
			/**
			 * The volume must be at least this big. The value of 0
			 * indicates an unspecified minimum
			 *
			 */
			RequiredBytes?: number;
			/**
			 * The volume must not be bigger than this. The value of 0
			 * indicates an unspecified maximum.
			 *
			 */
			LimitBytes?: number;
		};
		/**
		 * The availability of the volume for use in tasks.
		 * - `active` The volume is fully available for scheduling on the cluster
		 * - `pause` No new workloads should use the volume, but existing workloads are not stopped.
		 * - `drain` All workloads using this volume should be stopped and rescheduled, and no new ones should be started.
		 *
		 */
		Availability?: "active" | "pause" | "drain";
	};
};
/**
 * A map of topological domains to topological segments. For in depth
 * details, see documentation for the Topology object in the CSI
 * specification.
 *
 */
export type Topology = {
	[key: string]: (string);
};
export type ContainerListData = {
	/**
	 * Return all containers. By default, only running containers are shown.
	 *
	 */
	all?: boolean;
	/**
	 * Filters to process on the container list, encoded as JSON (a
	 * `map[string][]string`). For example, `{"status": ["paused"]}` will
	 * only return paused containers.
	 *
	 * Available filters:
	 *
	 * - `ancestor`=(`<image-name>[:<tag>]`, `<image id>`, or `<image@digest>`)
	 * - `before`=(`<container id>` or `<container name>`)
	 * - `expose`=(`<port>[/<proto>]`|`<startport-endport>/[<proto>]`)
	 * - `exited=<int>` containers with exit code of `<int>`
	 * - `health`=(`starting`|`healthy`|`unhealthy`|`none`)
	 * - `id=<ID>` a container's ID
	 * - `isolation=`(`default`|`process`|`hyperv`) (Windows daemon only)
	 * - `is-task=`(`true`|`false`)
	 * - `label=key` or `label="key=value"` of a container label
	 * - `name=<name>` a container's name
	 * - `network`=(`<network id>` or `<network name>`)
	 * - `publish`=(`<port>[/<proto>]`|`<startport-endport>/[<proto>]`)
	 * - `since`=(`<container id>` or `<container name>`)
	 * - `status=`(`created`|`restarting`|`running`|`removing`|`paused`|`exited`|`dead`)
	 * - `volume`=(`<volume name>` or `<mount point destination>`)
	 *
	 */
	filters?: string;
	/**
	 * Return this number of most recently created containers, including
	 * non-running ones.
	 *
	 */
	limit?: number;
	/**
	 * Return the size of container as fields `SizeRw` and `SizeRootFs`.
	 *
	 */
	size?: boolean;
};
export type ContainerListResponse = Array<ContainerSummary>;
export type ContainerCreateData = {
	/**
	 * Container to create
	 */
	body: ContainerConfig & {
		HostConfig?: HostConfig;
		NetworkingConfig?: NetworkingConfig;
	};
	/**
	 * Assign the specified name to the container. Must match
	 * `/?[a-zA-Z0-9][a-zA-Z0-9_.-]+`.
	 *
	 */
	name?: string;
	/**
	 * Platform in the format `os[/arch[/variant]]` used for image lookup.
	 *
	 * When specified, the daemon checks if the requested image is present
	 * in the local image cache with the given OS and Architecture, and
	 * otherwise returns a `404` status.
	 *
	 * If the option is not set, the host's native OS and Architecture are
	 * used to look up the image in the image cache. However, if no platform
	 * is passed and the given image does exist in the local image cache,
	 * but its OS or architecture does not match, the container is created
	 * with the available image, and a warning is added to the `Warnings`
	 * field in the response, for example;
	 *
	 * WARNING: The requested image's platform (linux/arm64/v8) does not
	 * match the detected host platform (linux/amd64) and no
	 * specific platform was requested
	 *
	 */
	platform?: string;
};
export type ContainerCreateResponse2 = ContainerCreateResponse;
export type ContainerInspectData = {
	/**
	 * ID or name of the container
	 */
	id: string;
	/**
	 * Return the size of container as fields `SizeRw` and `SizeRootFs`
	 */
	size?: boolean;
};
export type ContainerInspectResponse = {
	/**
	 * The ID of the container
	 */
	Id?: string;
	/**
	 * The time the container was created
	 */
	Created?: string;
	/**
	 * The path to the command being run
	 */
	Path?: string;
	/**
	 * The arguments to the command being run
	 */
	Args?: Array<(string)>;
	State?: ContainerState;
	/**
	 * The container's image ID
	 */
	Image?: string;
	ResolvConfPath?: string;
	HostnamePath?: string;
	HostsPath?: string;
	LogPath?: string;
	Name?: string;
	RestartCount?: number;
	Driver?: string;
	Platform?: string;
	MountLabel?: string;
	ProcessLabel?: string;
	AppArmorProfile?: string;
	/**
	 * IDs of exec instances that are running in the container.
	 */
	ExecIDs?: Array<(string)> | null;
	HostConfig?: HostConfig;
	GraphDriver?: GraphDriverData;
	/**
	 * The size of files that have been created or changed by this
	 * container.
	 *
	 */
	SizeRw?: number;
	/**
	 * The total size of all the files in this container.
	 */
	SizeRootFs?: number;
	Mounts?: Array<MountPoint>;
	Config?: ContainerConfig;
	NetworkSettings?: NetworkSettings;
};
export type ContainerTopData = {
	/**
	 * ID or name of the container
	 */
	id: string;
	/**
	 * The arguments to pass to `ps`. For example, `aux`
	 */
	psArgs?: string;
};
export type ContainerTopResponse = {
	/**
	 * The ps column titles
	 */
	Titles?: Array<(string)>;
	/**
	 * Each process running in the container, where each is process
	 * is an array of values corresponding to the titles.
	 *
	 */
	Processes?: Array<Array<(string)>>;
};
export type ContainerLogsData = {
	/**
	 * Keep connection after returning logs.
	 */
	follow?: boolean;
	/**
	 * ID or name of the container
	 */
	id: string;
	/**
	 * Only return logs since this time, as a UNIX timestamp
	 */
	since?: number;
	/**
	 * Return logs from `stderr`
	 */
	stderr?: boolean;
	/**
	 * Return logs from `stdout`
	 */
	stdout?: boolean;
	/**
	 * Only return this number of log lines from the end of the logs.
	 * Specify as an integer or `all` to output all log lines.
	 *
	 */
	tail?: string;
	/**
	 * Add timestamps to every log line
	 */
	timestamps?: boolean;
	/**
	 * Only return logs before this time, as a UNIX timestamp
	 */
	until?: number;
};
export type ContainerLogsResponse = (Blob | File);
export type ContainerChangesData = {
	/**
	 * ID or name of the container
	 */
	id: string;
};
export type ContainerChangesResponse = Array<FilesystemChange>;
export type ContainerExportData = {
	/**
	 * ID or name of the container
	 */
	id: string;
};
export type ContainerExportResponse = unknown;
export type ContainerStatsData = {
	/**
	 * ID or name of the container
	 */
	id: string;
	/**
	 * Only get a single stat instead of waiting for 2 cycles. Must be used
	 * with `stream=false`.
	 *
	 */
	oneShot?: boolean;
	/**
	 * Stream the output. If false, the stats will be output once and then
	 * it will disconnect.
	 *
	 */
	stream?: boolean;
};
export type ContainerStatsResponse = unknown;
export type ContainerResizeData = {
	/**
	 * Height of the TTY session in characters
	 */
	h?: number;
	/**
	 * ID or name of the container
	 */
	id: string;
	/**
	 * Width of the TTY session in characters
	 */
	w?: number;
};
export type ContainerResizeResponse = unknown;
export type ContainerStartData = {
	/**
	 * Override the key sequence for detaching a container. Format is a
	 * single character `[a-Z]` or `ctrl-<value>` where `<value>` is one
	 * of: `a-z`, `@`, `^`, `[`, `,` or `_`.
	 *
	 */
	detachKeys?: string;
	/**
	 * ID or name of the container
	 */
	id: string;
};
export type ContainerStartResponse = void;
export type ContainerStopData = {
	/**
	 * ID or name of the container
	 */
	id: string;
	/**
	 * Signal to send to the container as an integer or string (e.g. `SIGINT`).
	 *
	 */
	signal?: string;
	/**
	 * Number of seconds to wait before killing the container
	 */
	t?: number;
};
export type ContainerStopResponse = void;
export type ContainerRestartData = {
	/**
	 * ID or name of the container
	 */
	id: string;
	/**
	 * Signal to send to the container as an integer or string (e.g. `SIGINT`).
	 *
	 */
	signal?: string;
	/**
	 * Number of seconds to wait before killing the container
	 */
	t?: number;
};
export type ContainerRestartResponse = void;
export type ContainerKillData = {
	/**
	 * ID or name of the container
	 */
	id: string;
	/**
	 * Signal to send to the container as an integer or string (e.g. `SIGINT`).
	 *
	 */
	signal?: string;
};
export type ContainerKillResponse = void;
export type ContainerUpdateData = {
	/**
	 * ID or name of the container
	 */
	id: string;
	update: Resources & {
		RestartPolicy?: RestartPolicy;
	};
};
export type ContainerUpdateResponse = {
	Warnings?: Array<(string)>;
};
export type ContainerRenameData = {
	/**
	 * ID or name of the container
	 */
	id: string;
	/**
	 * New name for the container
	 */
	name: string;
};
export type ContainerRenameResponse = void;
export type ContainerPauseData = {
	/**
	 * ID or name of the container
	 */
	id: string;
};
export type ContainerPauseResponse = void;
export type ContainerUnpauseData = {
	/**
	 * ID or name of the container
	 */
	id: string;
};
export type ContainerUnpauseResponse = void;
export type ContainerAttachData = {
	/**
	 * Override the key sequence for detaching a container.Format is a single
	 * character `[a-Z]` or `ctrl-<value>` where `<value>` is one of: `a-z`,
	 * `@`, `^`, `[`, `,` or `_`.
	 *
	 */
	detachKeys?: string;
	/**
	 * ID or name of the container
	 */
	id: string;
	/**
	 * Replay previous logs from the container.
	 *
	 * This is useful for attaching to a container that has started and you
	 * want to output everything since the container started.
	 *
	 * If `stream` is also enabled, once all the previous output has been
	 * returned, it will seamlessly transition into streaming current
	 * output.
	 *
	 */
	logs?: boolean;
	/**
	 * Attach to `stderr`
	 */
	stderr?: boolean;
	/**
	 * Attach to `stdin`
	 */
	stdin?: boolean;
	/**
	 * Attach to `stdout`
	 */
	stdout?: boolean;
	/**
	 * Stream attached streams from the time the request was made onwards.
	 *
	 */
	stream?: boolean;
};
export type ContainerAttachResponse = unknown;
export type ContainerAttachWebsocketData = {
	/**
	 * Override the key sequence for detaching a container.Format is a single
	 * character `[a-Z]` or `ctrl-<value>` where `<value>` is one of: `a-z`,
	 * `@`, `^`, `[`, `,`, or `_`.
	 *
	 */
	detachKeys?: string;
	/**
	 * ID or name of the container
	 */
	id: string;
	/**
	 * Return logs
	 */
	logs?: boolean;
	/**
	 * Attach to `stderr`
	 */
	stderr?: boolean;
	/**
	 * Attach to `stdin`
	 */
	stdin?: boolean;
	/**
	 * Attach to `stdout`
	 */
	stdout?: boolean;
	/**
	 * Return stream
	 */
	stream?: boolean;
};
export type ContainerAttachWebsocketResponse = unknown;
export type ContainerWaitData = {
	/**
	 * Wait until a container state reaches the given condition.
	 *
	 * Defaults to `not-running` if omitted or empty.
	 *
	 */
	condition?: "not-running" | "next-exit" | "removed";
	/**
	 * ID or name of the container
	 */
	id: string;
};
export type ContainerWaitResponse2 = ContainerWaitResponse;
export type ContainerDeleteData = {
	/**
	 * If the container is running, kill it before removing it.
	 */
	force?: boolean;
	/**
	 * ID or name of the container
	 */
	id: string;
	/**
	 * Remove the specified link associated with the container.
	 */
	link?: boolean;
	/**
	 * Remove anonymous volumes associated with the container.
	 */
	v?: boolean;
};
export type ContainerDeleteResponse = void;
export type ContainerArchiveInfoData = {
	/**
	 * ID or name of the container
	 */
	id: string;
	/**
	 * Resource in the container’s filesystem to archive.
	 */
	path: string;
};
export type ContainerArchiveInfoResponse = string;
export type ContainerArchiveData = {
	/**
	 * ID or name of the container
	 */
	id: string;
	/**
	 * Resource in the container’s filesystem to archive.
	 */
	path: string;
};
export type ContainerArchiveResponse = unknown;
export type PutContainerArchiveData = {
	/**
	 * If `1`, `true`, then it will copy UID/GID maps to the dest file or
	 * dir
	 *
	 */
	copyUidgid?: string;
	/**
	 * ID or name of the container
	 */
	id: string;
	/**
	 * The input stream must be a tar archive compressed with one of the
	 * following algorithms: `identity` (no compression), `gzip`, `bzip2`,
	 * or `xz`.
	 *
	 */
	inputStream: (Blob | File);
	/**
	 * If `1`, `true`, or `True` then it will be an error if unpacking the
	 * given content would cause an existing directory to be replaced with
	 * a non-directory and vice versa.
	 *
	 */
	noOverwriteDirNonDir?: string;
	/**
	 * Path to a directory in the container to extract the archive’s contents into.
	 */
	path: string;
};
export type PutContainerArchiveResponse = unknown;
export type ContainerPruneData = {
	/**
	 * Filters to process on the prune list, encoded as JSON (a `map[string][]string`).
	 *
	 * Available filters:
	 * - `until=<timestamp>` Prune containers created before this timestamp. The `<timestamp>` can be Unix timestamps, date formatted timestamps, or Go duration strings (e.g. `10m`, `1h30m`) computed relative to the daemon machine’s time.
	 * - `label` (`label=<key>`, `label=<key>=<value>`, `label!=<key>`, or `label!=<key>=<value>`) Prune containers with (or without, in case `label!=...` is used) the specified labels.
	 *
	 */
	filters?: string;
};
export type ContainerPruneResponse = {
	/**
	 * Container IDs that were deleted
	 */
	ContainersDeleted?: Array<(string)>;
	/**
	 * Disk space reclaimed in bytes
	 */
	SpaceReclaimed?: number;
};
export type ImageListData = {
	/**
	 * Show all images. Only images from a final layer (no children) are shown by default.
	 */
	all?: boolean;
	/**
	 * Show digest information as a `RepoDigests` field on each image.
	 */
	digests?: boolean;
	/**
	 * A JSON encoded value of the filters (a `map[string][]string`) to
	 * process on the images list.
	 *
	 * Available filters:
	 *
	 * - `before`=(`<image-name>[:<tag>]`,  `<image id>` or `<image@digest>`)
	 * - `dangling=true`
	 * - `label=key` or `label="key=value"` of an image label
	 * - `reference`=(`<image-name>[:<tag>]`)
	 * - `since`=(`<image-name>[:<tag>]`,  `<image id>` or `<image@digest>`)
	 * - `until=<timestamp>`
	 *
	 */
	filters?: string;
	/**
	 * Compute and show shared size as a `SharedSize` field on each image.
	 */
	sharedSize?: boolean;
};
export type ImageListResponse = Array<ImageSummary>;
export type ImageBuildData = {
	/**
	 * JSON map of string pairs for build-time variables. Users pass these values at build-time. Docker uses the buildargs as the environment context for commands run via the `Dockerfile` RUN instruction, or for variable expansion in other `Dockerfile` instructions. This is not meant for passing secret values.
	 *
	 * For example, the build arg `FOO=bar` would become `{"FOO":"bar"}` in JSON. This would result in the query parameter `buildargs={"FOO":"bar"}`. Note that `{"FOO":"bar"}` should be URI component encoded.
	 *
	 * [Read more about the buildargs instruction.](https://docs.docker.com/engine/reference/builder/#arg)
	 *
	 */
	buildargs?: string;
	/**
	 * JSON array of images used for build cache resolution.
	 */
	cachefrom?: string;
	contentType?: "application/x-tar";
	/**
	 * The length of a CPU period in microseconds.
	 */
	cpuperiod?: number;
	/**
	 * Microseconds of CPU time that the container can get in a CPU period.
	 */
	cpuquota?: number;
	/**
	 * CPUs in which to allow execution (e.g., `0-3`, `0,1`).
	 */
	cpusetcpus?: string;
	/**
	 * CPU shares (relative weight).
	 */
	cpushares?: number;
	/**
	 * Path within the build context to the `Dockerfile`. This is ignored if `remote` is specified and points to an external `Dockerfile`.
	 */
	dockerfile?: string;
	/**
	 * Extra hosts to add to /etc/hosts
	 */
	extrahosts?: string;
	/**
	 * Always remove intermediate containers, even upon failure.
	 */
	forcerm?: boolean;
	/**
	 * A tar archive compressed with one of the following algorithms: identity (no compression), gzip, bzip2, xz.
	 */
	inputStream?: (Blob | File);
	/**
	 * Arbitrary key/value labels to set on the image, as a JSON map of string pairs.
	 */
	labels?: string;
	/**
	 * Set memory limit for build.
	 */
	memory?: number;
	/**
	 * Total memory (memory + swap). Set as `-1` to disable swap.
	 */
	memswap?: number;
	/**
	 * Sets the networking mode for the run commands during build. Supported
	 * standard values are: `bridge`, `host`, `none`, and `container:<name|id>`.
	 * Any other value is taken as a custom network's name or ID to which this
	 * container should connect to.
	 *
	 */
	networkmode?: string;
	/**
	 * Do not use the cache when building the image.
	 */
	nocache?: boolean;
	/**
	 * BuildKit output configuration
	 */
	outputs?: string;
	/**
	 * Platform in the format os[/arch[/variant]]
	 */
	platform?: string;
	/**
	 * Attempt to pull the image even if an older image exists locally.
	 */
	pull?: string;
	/**
	 * Suppress verbose build output.
	 */
	q?: boolean;
	/**
	 * A Git repository URI or HTTP/HTTPS context URI. If the URI points to a single text file, the file’s contents are placed into a file called `Dockerfile` and the image is built from that file. If the URI points to a tarball, the file is downloaded by the daemon and the contents therein used as the context for the build. If the URI points to a tarball and the `dockerfile` parameter is also specified, there must be a file with the corresponding path inside the tarball.
	 */
	remote?: string;
	/**
	 * Remove intermediate containers after a successful build.
	 */
	rm?: boolean;
	/**
	 * Size of `/dev/shm` in bytes. The size must be greater than 0. If omitted the system uses 64MB.
	 */
	shmsize?: number;
	/**
	 * Squash the resulting images layers into a single layer. *(Experimental release only.)*
	 */
	squash?: boolean;
	/**
	 * A name and optional tag to apply to the image in the `name:tag` format. If you omit the tag the default `latest` value is assumed. You can provide several `t` parameters.
	 */
	t?: string;
	/**
	 * Target build stage
	 */
	target?: string;
	/**
	 * Version of the builder backend to use.
	 *
	 * - `1` is the first generation classic (deprecated) builder in the Docker daemon (default)
	 * - `2` is [BuildKit](https://github.com/moby/buildkit)
	 *
	 */
	version?: "1" | "2";
	/**
	 * This is a base64-encoded JSON object with auth configurations for multiple registries that a build may refer to.
	 *
	 * The key is a registry URL, and the value is an auth configuration object, [as described in the authentication section](#section/Authentication). For example:
	 *
	 * ```
	 * {
	 * "docker.example.com": {
	 * "username": "janedoe",
	 * "password": "hunter2"
	 * },
	 * "https://index.docker.io/v1/": {
	 * "username": "mobydock",
	 * "password": "conta1n3rize14"
	 * }
	 * }
	 * ```
	 *
	 * Only the registry domain name (and port if not the default 443) are required. However, for legacy reasons, the Docker Hub registry must be specified with both a `https://` prefix and a `/v1/` suffix even though Docker will prefer to use the v2 registry API.
	 *
	 */
	xRegistryConfig?: string;
};
export type ImageBuildResponse = unknown;
export type BuildPruneData = {
	/**
	 * Remove all types of build cache
	 */
	all?: boolean;
	/**
	 * A JSON encoded value of the filters (a `map[string][]string`) to
	 * process on the list of build cache objects.
	 *
	 * Available filters:
	 *
	 * - `until=<timestamp>` remove cache older than `<timestamp>`. The `<timestamp>` can be Unix timestamps, date formatted timestamps, or Go duration strings (e.g. `10m`, `1h30m`) computed relative to the daemon's local time.
	 * - `id=<id>`
	 * - `parent=<id>`
	 * - `type=<string>`
	 * - `description=<string>`
	 * - `inuse`
	 * - `shared`
	 * - `private`
	 *
	 */
	filters?: string;
	/**
	 * Amount of disk space in bytes to keep for cache
	 */
	keepStorage?: number;
};
export type BuildPruneResponse = {
	CachesDeleted?: Array<(string)>;
	/**
	 * Disk space reclaimed in bytes
	 */
	SpaceReclaimed?: number;
};
export type ImageCreateData = {
	/**
	 * Apply `Dockerfile` instructions to the image that is created,
	 * for example: `changes=ENV DEBUG=true`.
	 * Note that `ENV DEBUG=true` should be URI component encoded.
	 *
	 * Supported `Dockerfile` instructions:
	 * `CMD`|`ENTRYPOINT`|`ENV`|`EXPOSE`|`ONBUILD`|`USER`|`VOLUME`|`WORKDIR`
	 *
	 */
	changes?: Array<string>;
	/**
	 * Name of the image to pull. The name may include a tag or digest. This parameter may only be used when pulling an image. The pull is cancelled if the HTTP connection is closed.
	 */
	fromImage?: string;
	/**
	 * Source to import. The value may be a URL from which the image can be retrieved or `-` to read the image from the request body. This parameter may only be used when importing an image.
	 */
	fromSrc?: string;
	/**
	 * Image content if the value `-` has been specified in fromSrc query parameter
	 */
	inputImage?: string;
	/**
	 * Set commit message for imported image.
	 */
	message?: string;
	/**
	 * Platform in the format os[/arch[/variant]].
	 *
	 * When used in combination with the `fromImage` option, the daemon checks
	 * if the given image is present in the local image cache with the given
	 * OS and Architecture, and otherwise attempts to pull the image. If the
	 * option is not set, the host's native OS and Architecture are used.
	 * If the given image does not exist in the local image cache, the daemon
	 * attempts to pull the image with the host's native OS and Architecture.
	 * If the given image does exists in the local image cache, but its OS or
	 * architecture does not match, a warning is produced.
	 *
	 * When used with the `fromSrc` option to import an image from an archive,
	 * this option sets the platform information for the imported image. If
	 * the option is not set, the host's native OS and Architecture are used
	 * for the imported image.
	 *
	 */
	platform?: string;
	/**
	 * Repository name given to an image when it is imported. The repo may include a tag. This parameter may only be used when importing an image.
	 */
	repo?: string;
	/**
	 * Tag or digest. If empty when pulling an image, this causes all tags for the given image to be pulled.
	 */
	tag?: string;
	/**
	 * A base64url-encoded auth configuration.
	 *
	 * Refer to the [authentication section](#section/Authentication) for
	 * details.
	 *
	 */
	xRegistryAuth?: string;
};
export type ImageCreateResponse = unknown;
export type ImageInspectData = {
	/**
	 * Image name or id
	 */
	name: string;
};
export type ImageInspectResponse = ImageInspect;
export type ImageHistoryData = {
	/**
	 * Image name or ID
	 */
	name: string;
};
export type ImageHistoryResponse = Array<{
	Id: string;
	Created: number;
	CreatedBy: string;
	Tags: Array<(string)>;
	Size: number;
	Comment: string;
}>;
export type ImagePushData = {
	/**
	 * Image name or ID.
	 */
	name: string;
	/**
	 * The tag to associate with the image on the registry.
	 */
	tag?: string;
	/**
	 * A base64url-encoded auth configuration.
	 *
	 * Refer to the [authentication section](#section/Authentication) for
	 * details.
	 *
	 */
	xRegistryAuth: string;
};
export type ImagePushResponse = unknown;
export type ImageTagData = {
	/**
	 * Image name or ID to tag.
	 */
	name: string;
	/**
	 * The repository to tag in. For example, `someuser/someimage`.
	 */
	repo?: string;
	/**
	 * The name of the new tag.
	 */
	tag?: string;
};
export type ImageTagResponse = unknown;
export type ImageDeleteData = {
	/**
	 * Remove the image even if it is being used by stopped containers or has other tags
	 */
	force?: boolean;
	/**
	 * Image name or ID
	 */
	name: string;
	/**
	 * Do not delete untagged parent images
	 */
	noprune?: boolean;
};
export type ImageDeleteResponse = Array<ImageDeleteResponseItem>;
export type ImageSearchData = {
	/**
	 * A JSON encoded value of the filters (a `map[string][]string`) to process on the images list. Available filters:
	 *
	 * - `is-official=(true|false)`
	 * - `stars=<number>` Matches images that has at least 'number' stars.
	 *
	 */
	filters?: string;
	/**
	 * Maximum number of results to return
	 */
	limit?: number;
	/**
	 * Term to search
	 */
	term: string;
};
export type ImageSearchResponse = Array<{
	description?: string;
	is_official?: boolean;
	/**
	 * Whether this repository has automated builds enabled.
	 *
	 * <p><br /></p>
	 *
	 * > **Deprecated**: This field is deprecated and will always be "false".
	 *
	 */
	is_automated?: boolean;
	name?: string;
	star_count?: number;
}>;
export type ImagePruneData = {
	/**
	 * Filters to process on the prune list, encoded as JSON (a `map[string][]string`). Available filters:
	 *
	 * - `dangling=<boolean>` When set to `true` (or `1`), prune only
	 * unused *and* untagged images. When set to `false`
	 * (or `0`), all unused images are pruned.
	 * - `until=<string>` Prune images created before this timestamp. The `<timestamp>` can be Unix timestamps, date formatted timestamps, or Go duration strings (e.g. `10m`, `1h30m`) computed relative to the daemon machine’s time.
	 * - `label` (`label=<key>`, `label=<key>=<value>`, `label!=<key>`, or `label!=<key>=<value>`) Prune images with (or without, in case `label!=...` is used) the specified labels.
	 *
	 */
	filters?: string;
};
export type ImagePruneResponse = {
	/**
	 * Images that were deleted
	 */
	ImagesDeleted?: Array<ImageDeleteResponseItem>;
	/**
	 * Disk space reclaimed in bytes
	 */
	SpaceReclaimed?: number;
};
export type ImageCommitData = {
	/**
	 * Author of the image (e.g., `John Hannibal Smith <hannibal@a-team.com>`)
	 */
	author?: string;
	/**
	 * `Dockerfile` instructions to apply while committing
	 */
	changes?: string;
	/**
	 * Commit message
	 */
	comment?: string;
	/**
	 * The ID or name of the container to commit
	 */
	container?: string;
	/**
	 * The container configuration
	 */
	containerConfig?: ContainerConfig;
	/**
	 * Whether to pause the container before committing
	 */
	pause?: boolean;
	/**
	 * Repository name for the created image
	 */
	repo?: string;
	/**
	 * Tag name for the create image
	 */
	tag?: string;
};
export type ImageCommitResponse = IdResponse;
export type ImageGetData = {
	/**
	 * Image name or ID
	 */
	name: string;
};
export type ImageGetResponse = (Blob | File);
export type ImageGetAllData = {
	/**
	 * Image names to filter by
	 */
	names?: Array<string>;
};
export type ImageGetAllResponse = (Blob | File);
export type ImageLoadData = {
	/**
	 * Tar archive containing images
	 */
	imagesTarball?: (Blob | File);
	/**
	 * Suppress progress details during load.
	 */
	quiet?: boolean;
};
export type ImageLoadResponse = unknown;
export type SystemAuthData = {
	/**
	 * Authentication to check
	 */
	authConfig?: AuthConfig;
};
export type SystemAuthResponse = {
	/**
	 * The status of the authentication
	 */
	Status: string;
	/**
	 * An opaque token used to authenticate a user after a successful login
	 */
	IdentityToken?: string;
} | void;
export type SystemInfoResponse = SystemInfo;
export type SystemVersionResponse = SystemVersion;
export type SystemPingResponse = string;
export type SystemPingHeadResponse = string;
export type SystemEventsData = {
	/**
	 * A JSON encoded value of filters (a `map[string][]string`) to process on the event list. Available filters:
	 *
	 * - `config=<string>` config name or ID
	 * - `container=<string>` container name or ID
	 * - `daemon=<string>` daemon name or ID
	 * - `event=<string>` event type
	 * - `image=<string>` image name or ID
	 * - `label=<string>` image or container label
	 * - `network=<string>` network name or ID
	 * - `node=<string>` node ID
	 * - `plugin`=<string> plugin name or ID
	 * - `scope`=<string> local or swarm
	 * - `secret=<string>` secret name or ID
	 * - `service=<string>` service name or ID
	 * - `type=<string>` object to filter by, one of `container`, `image`, `volume`, `network`, `daemon`, `plugin`, `node`, `service`, `secret` or `config`
	 * - `volume=<string>` volume name
	 *
	 */
	filters?: string;
	/**
	 * Show events created since this timestamp then stream new events.
	 */
	since?: string;
	/**
	 * Show events created until this timestamp then stop streaming.
	 */
	until?: string;
};
export type SystemEventsResponse = EventMessage;
export type SystemDataUsageData = {
	/**
	 * Object types, for which to compute and return data.
	 *
	 */
	type?: Array<string>;
};
export type SystemDataUsageResponse = {
	LayersSize?: number;
	Images?: Array<ImageSummary>;
	Containers?: Array<ContainerSummary>;
	Volumes?: Array<Volume>;
	BuildCache?: Array<BuildCache>;
};
export type ContainerExecData = {
	/**
	 * Exec configuration
	 */
	execConfig: {
		/**
		 * Attach to `stdin` of the exec command.
		 */
		AttachStdin?: boolean;
		/**
		 * Attach to `stdout` of the exec command.
		 */
		AttachStdout?: boolean;
		/**
		 * Attach to `stderr` of the exec command.
		 */
		AttachStderr?: boolean;
		/**
		 * Initial console size, as an `[height, width]` array.
		 */
		ConsoleSize?: [
			number,
			number
		] | null;
		/**
		 * Override the key sequence for detaching a container. Format is
		 * a single character `[a-Z]` or `ctrl-<value>` where `<value>`
		 * is one of: `a-z`, `@`, `^`, `[`, `,` or `_`.
		 *
		 */
		DetachKeys?: string;
		/**
		 * Allocate a pseudo-TTY.
		 */
		Tty?: boolean;
		/**
		 * A list of environment variables in the form `["VAR=value", ...]`.
		 *
		 */
		Env?: Array<(string)>;
		/**
		 * Command to run, as a string or array of strings.
		 */
		Cmd?: Array<(string)>;
		/**
		 * Runs the exec process with extended privileges.
		 */
		Privileged?: boolean;
		/**
		 * The user, and optionally, group to run the exec process inside
		 * the container. Format is one of: `user`, `user:group`, `uid`,
		 * or `uid:gid`.
		 *
		 */
		User?: string;
		/**
		 * The working directory for the exec process inside the container.
		 *
		 */
		WorkingDir?: string;
	};
	/**
	 * ID or name of container
	 */
	id: string;
};
export type ContainerExecResponse = IdResponse;
export type ExecStartData = {
	execStartConfig?: {
		/**
		 * Detach from the command.
		 */
		Detach?: boolean;
		/**
		 * Allocate a pseudo-TTY.
		 */
		Tty?: boolean;
		/**
		 * Initial console size, as an `[height, width]` array.
		 */
		ConsoleSize?: [
			number,
			number
		] | null;
	};
	/**
	 * Exec instance ID
	 */
	id: string;
};
export type ExecStartResponse = unknown;
export type ExecResizeData = {
	/**
	 * Height of the TTY session in characters
	 */
	h?: number;
	/**
	 * Exec instance ID
	 */
	id: string;
	/**
	 * Width of the TTY session in characters
	 */
	w?: number;
};
export type ExecResizeResponse = unknown;
export type ExecInspectData = {
	/**
	 * Exec instance ID
	 */
	id: string;
};
export type ExecInspectResponse = {
	CanRemove?: boolean;
	DetachKeys?: string;
	ID?: string;
	Running?: boolean;
	ExitCode?: number;
	ProcessConfig?: ProcessConfig;
	OpenStdin?: boolean;
	OpenStderr?: boolean;
	OpenStdout?: boolean;
	ContainerID?: string;
	/**
	 * The system process ID for the exec process.
	 */
	Pid?: number;
};
export type VolumeListData = {
	/**
	 * JSON encoded value of the filters (a `map[string][]string`) to
	 * process on the volumes list. Available filters:
	 *
	 * - `dangling=<boolean>` When set to `true` (or `1`), returns all
	 * volumes that are not in use by a container. When set to `false`
	 * (or `0`), only volumes that are in use by one or more
	 * containers are returned.
	 * - `driver=<volume-driver-name>` Matches volumes based on their driver.
	 * - `label=<key>` or `label=<key>:<value>` Matches volumes based on
	 * the presence of a `label` alone or a `label` and a value.
	 * - `name=<volume-name>` Matches all or part of a volume name.
	 *
	 */
	filters?: string;
};
export type VolumeListResponse2 = VolumeListResponse;
export type VolumeCreateData = {
	/**
	 * Volume configuration
	 */
	volumeConfig: VolumeCreateOptions;
};
export type VolumeCreateResponse = Volume;
export type VolumeInspectData = {
	/**
	 * Volume name or ID
	 */
	name: string;
};
export type VolumeInspectResponse = Volume;
export type VolumeUpdateData = {
	/**
	 * The spec of the volume to update. Currently, only Availability may
	 * change. All other fields must remain unchanged.
	 *
	 */
	body?: {
		Spec?: ClusterVolumeSpec;
	};
	/**
	 * The name or ID of the volume
	 */
	name: string;
	/**
	 * The version number of the volume being updated. This is required to
	 * avoid conflicting writes. Found in the volume's `ClusterVolume`
	 * field.
	 *
	 */
	version: number;
};
export type VolumeUpdateResponse = unknown;
export type VolumeDeleteData = {
	/**
	 * Force the removal of the volume
	 */
	force?: boolean;
	/**
	 * Volume name or ID
	 */
	name: string;
};
export type VolumeDeleteResponse = void;
export type VolumePruneData = {
	/**
	 * Filters to process on the prune list, encoded as JSON (a `map[string][]string`).
	 *
	 * Available filters:
	 * - `label` (`label=<key>`, `label=<key>=<value>`, `label!=<key>`, or `label!=<key>=<value>`) Prune volumes with (or without, in case `label!=...` is used) the specified labels.
	 * - `all` (`all=true`) - Consider all (local) volumes for pruning and not just anonymous volumes.
	 *
	 */
	filters?: string;
};
export type VolumePruneResponse = {
	/**
	 * Volumes that were deleted
	 */
	VolumesDeleted?: Array<(string)>;
	/**
	 * Disk space reclaimed in bytes
	 */
	SpaceReclaimed?: number;
};
export type NetworkListData = {
	/**
	 * JSON encoded value of the filters (a `map[string][]string`) to process
	 * on the networks list.
	 *
	 * Available filters:
	 *
	 * - `dangling=<boolean>` When set to `true` (or `1`), returns all
	 * networks that are not in use by a container. When set to `false`
	 * (or `0`), only networks that are in use by one or more
	 * containers are returned.
	 * - `driver=<driver-name>` Matches a network's driver.
	 * - `id=<network-id>` Matches all or part of a network ID.
	 * - `label=<key>` or `label=<key>=<value>` of a network label.
	 * - `name=<network-name>` Matches all or part of a network name.
	 * - `scope=["swarm"|"global"|"local"]` Filters networks by scope (`swarm`, `global`, or `local`).
	 * - `type=["custom"|"builtin"]` Filters networks by type. The `custom` keyword returns all user-defined networks.
	 *
	 */
	filters?: string;
};
export type NetworkListResponse = Array<Network>;
export type NetworkInspectData = {
	/**
	 * Network ID or name
	 */
	id: string;
	/**
	 * Filter the network by scope (swarm, global, or local)
	 */
	scope?: string;
	/**
	 * Detailed inspect output for troubleshooting
	 */
	verbose?: boolean;
};
export type NetworkInspectResponse = Network;
export type NetworkDeleteData = {
	/**
	 * Network ID or name
	 */
	id: string;
};
export type NetworkDeleteResponse = void;
export type NetworkCreateData = {
	/**
	 * Network configuration
	 */
	networkConfig: {
		/**
		 * The network's name.
		 */
		Name: string;
		/**
		 * Deprecated: CheckDuplicate is now always enabled.
		 *
		 */
		CheckDuplicate?: boolean;
		/**
		 * Name of the network driver plugin to use.
		 */
		Driver?: string;
		/**
		 * Restrict external access to the network.
		 */
		Internal?: boolean;
		/**
		 * Globally scoped network is manually attachable by regular
		 * containers from workers in swarm mode.
		 *
		 */
		Attachable?: boolean;
		/**
		 * Ingress network is the network which provides the routing-mesh
		 * in swarm mode.
		 *
		 */
		Ingress?: boolean;
		/**
		 * Optional custom IP scheme for the network.
		 */
		IPAM?: IPAM;
		/**
		 * Enable IPv6 on the network.
		 */
		EnableIPv6?: boolean;
		/**
		 * Network specific options to be used by the drivers.
		 */
		Options?: {
			[key: string]: (string);
		};
		/**
		 * User-defined key/value metadata.
		 */
		Labels?: {
			[key: string]: (string);
		};
	};
};
export type NetworkCreateResponse = {
	/**
	 * The ID of the created network.
	 */
	Id?: string;
	Warning?: string;
};
export type NetworkConnectData = {
	container: {
		/**
		 * The ID or name of the container to connect to the network.
		 */
		Container?: string;
		EndpointConfig?: EndpointSettings;
	};
	/**
	 * Network ID or name
	 */
	id: string;
};
export type NetworkConnectResponse = unknown;
export type NetworkDisconnectData = {
	container: {
		/**
		 * The ID or name of the container to disconnect from the network.
		 *
		 */
		Container?: string;
		/**
		 * Force the container to disconnect from the network.
		 *
		 */
		Force?: boolean;
	};
	/**
	 * Network ID or name
	 */
	id: string;
};
export type NetworkDisconnectResponse = unknown;
export type NetworkPruneData = {
	/**
	 * Filters to process on the prune list, encoded as JSON (a `map[string][]string`).
	 *
	 * Available filters:
	 * - `until=<timestamp>` Prune networks created before this timestamp. The `<timestamp>` can be Unix timestamps, date formatted timestamps, or Go duration strings (e.g. `10m`, `1h30m`) computed relative to the daemon machine’s time.
	 * - `label` (`label=<key>`, `label=<key>=<value>`, `label!=<key>`, or `label!=<key>=<value>`) Prune networks with (or without, in case `label!=...` is used) the specified labels.
	 *
	 */
	filters?: string;
};
export type NetworkPruneResponse = {
	/**
	 * Networks that were deleted
	 */
	NetworksDeleted?: Array<(string)>;
};
export type PluginListData = {
	/**
	 * A JSON encoded value of the filters (a `map[string][]string`) to
	 * process on the plugin list.
	 *
	 * Available filters:
	 *
	 * - `capability=<capability name>`
	 * - `enable=<true>|<false>`
	 *
	 */
	filters?: string;
};
export type PluginListResponse = Array<Plugin$1>;
export type GetPluginPrivilegesData = {
	/**
	 * The name of the plugin. The `:latest` tag is optional, and is the
	 * default if omitted.
	 *
	 */
	remote: string;
};
export type GetPluginPrivilegesResponse = Array<PluginPrivilege>;
export type PluginPullData = {
	body?: Array<PluginPrivilege>;
	/**
	 * Local name for the pulled plugin.
	 *
	 * The `:latest` tag is optional, and is used as the default if omitted.
	 *
	 */
	name?: string;
	/**
	 * Remote reference for plugin to install.
	 *
	 * The `:latest` tag is optional, and is used as the default if omitted.
	 *
	 */
	remote: string;
	/**
	 * A base64url-encoded auth configuration to use when pulling a plugin
	 * from a registry.
	 *
	 * Refer to the [authentication section](#section/Authentication) for
	 * details.
	 *
	 */
	xRegistryAuth?: string;
};
export type PluginPullResponse = void;
export type PluginInspectData = {
	/**
	 * The name of the plugin. The `:latest` tag is optional, and is the
	 * default if omitted.
	 *
	 */
	name: string;
};
export type PluginInspectResponse = Plugin$1;
export type PluginDeleteData = {
	/**
	 * Disable the plugin before removing. This may result in issues if the
	 * plugin is in use by a container.
	 *
	 */
	force?: boolean;
	/**
	 * The name of the plugin. The `:latest` tag is optional, and is the
	 * default if omitted.
	 *
	 */
	name: string;
};
export type PluginDeleteResponse = Plugin$1;
export type PluginEnableData = {
	/**
	 * The name of the plugin. The `:latest` tag is optional, and is the
	 * default if omitted.
	 *
	 */
	name: string;
	/**
	 * Set the HTTP client timeout (in seconds)
	 */
	timeout?: number;
};
export type PluginEnableResponse = unknown;
export type PluginDisableData = {
	/**
	 * Force disable a plugin even if still in use.
	 *
	 */
	force?: boolean;
	/**
	 * The name of the plugin. The `:latest` tag is optional, and is the
	 * default if omitted.
	 *
	 */
	name: string;
};
export type PluginDisableResponse = unknown;
export type PluginUpgradeData = {
	body?: Array<PluginPrivilege>;
	/**
	 * The name of the plugin. The `:latest` tag is optional, and is the
	 * default if omitted.
	 *
	 */
	name: string;
	/**
	 * Remote reference to upgrade to.
	 *
	 * The `:latest` tag is optional, and is used as the default if omitted.
	 *
	 */
	remote: string;
	/**
	 * A base64url-encoded auth configuration to use when pulling a plugin
	 * from a registry.
	 *
	 * Refer to the [authentication section](#section/Authentication) for
	 * details.
	 *
	 */
	xRegistryAuth?: string;
};
export type PluginUpgradeResponse = void;
export type PluginCreateData = {
	/**
	 * The name of the plugin. The `:latest` tag is optional, and is the
	 * default if omitted.
	 *
	 */
	name: string;
	/**
	 * Path to tar containing plugin rootfs and manifest
	 */
	tarContext?: (Blob | File);
};
export type PluginCreateResponse = void;
export type PluginPushData = {
	/**
	 * The name of the plugin. The `:latest` tag is optional, and is the
	 * default if omitted.
	 *
	 */
	name: string;
};
export type PluginPushResponse = unknown;
export type PluginSetData = {
	body?: Array<(string)>;
	/**
	 * The name of the plugin. The `:latest` tag is optional, and is the
	 * default if omitted.
	 *
	 */
	name: string;
};
export type PluginSetResponse = void;
export type NodeListData = {
	/**
	 * Filters to process on the nodes list, encoded as JSON (a `map[string][]string`).
	 *
	 * Available filters:
	 * - `id=<node id>`
	 * - `label=<engine label>`
	 * - `membership=`(`accepted`|`pending`)`
	 * - `name=<node name>`
	 * - `node.label=<node label>`
	 * - `role=`(`manager`|`worker`)`
	 *
	 */
	filters?: string;
};
export type NodeListResponse = Array<Node$1>;
export type NodeInspectData = {
	/**
	 * The ID or name of the node
	 */
	id: string;
};
export type NodeInspectResponse = Node$1;
export type NodeDeleteData = {
	/**
	 * Force remove a node from the swarm
	 */
	force?: boolean;
	/**
	 * The ID or name of the node
	 */
	id: string;
};
export type NodeDeleteResponse = unknown;
export type NodeUpdateData = {
	body?: NodeSpec;
	/**
	 * The ID of the node
	 */
	id: string;
	/**
	 * The version number of the node object being updated. This is required
	 * to avoid conflicting writes.
	 *
	 */
	version: number;
};
export type NodeUpdateResponse = unknown;
export type SwarmInspectResponse = Swarm;
export type SwarmInitData = {
	body: {
		/**
		 * Listen address used for inter-manager communication, as well
		 * as determining the networking interface used for the VXLAN
		 * Tunnel Endpoint (VTEP). This can either be an address/port
		 * combination in the form `192.168.1.1:4567`, or an interface
		 * followed by a port number, like `eth0:4567`. If the port number
		 * is omitted, the default swarm listening port is used.
		 *
		 */
		ListenAddr?: string;
		/**
		 * Externally reachable address advertised to other nodes. This
		 * can either be an address/port combination in the form
		 * `192.168.1.1:4567`, or an interface followed by a port number,
		 * like `eth0:4567`. If the port number is omitted, the port
		 * number from the listen address is used. If `AdvertiseAddr` is
		 * not specified, it will be automatically detected when possible.
		 *
		 */
		AdvertiseAddr?: string;
		/**
		 * Address or interface to use for data path traffic (format:
		 * `<ip|interface>`), for example,  `192.168.1.1`, or an interface,
		 * like `eth0`. If `DataPathAddr` is unspecified, the same address
		 * as `AdvertiseAddr` is used.
		 *
		 * The `DataPathAddr` specifies the address that global scope
		 * network drivers will publish towards other  nodes in order to
		 * reach the containers running on this node. Using this parameter
		 * it is possible to separate the container data traffic from the
		 * management traffic of the cluster.
		 *
		 */
		DataPathAddr?: string;
		/**
		 * DataPathPort specifies the data path port number for data traffic.
		 * Acceptable port range is 1024 to 49151.
		 * if no port is set or is set to 0, default port 4789 will be used.
		 *
		 */
		DataPathPort?: number;
		/**
		 * Default Address Pool specifies default subnet pools for global
		 * scope networks.
		 *
		 */
		DefaultAddrPool?: Array<(string)>;
		/**
		 * Force creation of a new swarm.
		 */
		ForceNewCluster?: boolean;
		/**
		 * SubnetSize specifies the subnet size of the networks created
		 * from the default subnet pool.
		 *
		 */
		SubnetSize?: number;
		Spec?: SwarmSpec;
	};
};
export type SwarmInitResponse = string;
export type SwarmJoinData = {
	body: {
		/**
		 * Listen address used for inter-manager communication if the node
		 * gets promoted to manager, as well as determining the networking
		 * interface used for the VXLAN Tunnel Endpoint (VTEP).
		 *
		 */
		ListenAddr?: string;
		/**
		 * Externally reachable address advertised to other nodes. This
		 * can either be an address/port combination in the form
		 * `192.168.1.1:4567`, or an interface followed by a port number,
		 * like `eth0:4567`. If the port number is omitted, the port
		 * number from the listen address is used. If `AdvertiseAddr` is
		 * not specified, it will be automatically detected when possible.
		 *
		 */
		AdvertiseAddr?: string;
		/**
		 * Address or interface to use for data path traffic (format:
		 * `<ip|interface>`), for example,  `192.168.1.1`, or an interface,
		 * like `eth0`. If `DataPathAddr` is unspecified, the same address
		 * as `AdvertiseAddr` is used.
		 *
		 * The `DataPathAddr` specifies the address that global scope
		 * network drivers will publish towards other nodes in order to
		 * reach the containers running on this node. Using this parameter
		 * it is possible to separate the container data traffic from the
		 * management traffic of the cluster.
		 *
		 */
		DataPathAddr?: string;
		/**
		 * Addresses of manager nodes already participating in the swarm.
		 *
		 */
		RemoteAddrs?: Array<(string)>;
		/**
		 * Secret token for joining this swarm.
		 */
		JoinToken?: string;
	};
};
export type SwarmJoinResponse = unknown;
export type SwarmLeaveData = {
	/**
	 * Force leave swarm, even if this is the last manager or that it will
	 * break the cluster.
	 *
	 */
	force?: boolean;
};
export type SwarmLeaveResponse = unknown;
export type SwarmUpdateData = {
	body: SwarmSpec;
	/**
	 * Rotate the manager join token.
	 */
	rotateManagerToken?: boolean;
	/**
	 * Rotate the manager unlock key.
	 */
	rotateManagerUnlockKey?: boolean;
	/**
	 * Rotate the worker join token.
	 */
	rotateWorkerToken?: boolean;
	/**
	 * The version number of the swarm object being updated. This is
	 * required to avoid conflicting writes.
	 *
	 */
	version: number;
};
export type SwarmUpdateResponse = unknown;
export type SwarmUnlockkeyResponse = {
	/**
	 * The swarm's unlock key.
	 */
	UnlockKey?: string;
};
export type SwarmUnlockData = {
	body: {
		/**
		 * The swarm's unlock key.
		 */
		UnlockKey?: string;
	};
};
export type SwarmUnlockResponse = unknown;
export type ServiceListData = {
	/**
	 * A JSON encoded value of the filters (a `map[string][]string`) to
	 * process on the services list.
	 *
	 * Available filters:
	 *
	 * - `id=<service id>`
	 * - `label=<service label>`
	 * - `mode=["replicated"|"global"]`
	 * - `name=<service name>`
	 *
	 */
	filters?: string;
	/**
	 * Include service status, with count of running and desired tasks.
	 *
	 */
	status?: boolean;
};
export type ServiceListResponse = Array<Service>;
export type ServiceCreateData = {
	body: ServiceSpec;
	/**
	 * A base64url-encoded auth configuration for pulling from private
	 * registries.
	 *
	 * Refer to the [authentication section](#section/Authentication) for
	 * details.
	 *
	 */
	xRegistryAuth?: string;
};
export type ServiceCreateResponse2 = ServiceCreateResponse;
export type ServiceInspectData = {
	/**
	 * ID or name of service.
	 */
	id: string;
	/**
	 * Fill empty fields with default values.
	 */
	insertDefaults?: boolean;
};
export type ServiceInspectResponse = Service;
export type ServiceDeleteData = {
	/**
	 * ID or name of service.
	 */
	id: string;
};
export type ServiceDeleteResponse = unknown;
export type ServiceUpdateData = {
	body: ServiceSpec;
	/**
	 * ID or name of service.
	 */
	id: string;
	/**
	 * If the `X-Registry-Auth` header is not specified, this parameter
	 * indicates where to find registry authorization credentials.
	 *
	 */
	registryAuthFrom?: "spec" | "previous-spec";
	/**
	 * Set to this parameter to `previous` to cause a server-side rollback
	 * to the previous service spec. The supplied spec will be ignored in
	 * this case.
	 *
	 */
	rollback?: string;
	/**
	 * The version number of the service object being updated. This is
	 * required to avoid conflicting writes.
	 * This version number should be the value as currently set on the
	 * service *before* the update. You can find the current version by
	 * calling `GET /services/{id}`
	 *
	 */
	version: number;
	/**
	 * A base64url-encoded auth configuration for pulling from private
	 * registries.
	 *
	 * Refer to the [authentication section](#section/Authentication) for
	 * details.
	 *
	 */
	xRegistryAuth?: string;
};
export type ServiceUpdateResponse2 = ServiceUpdateResponse;
export type ServiceLogsData = {
	/**
	 * Show service context and extra details provided to logs.
	 */
	details?: boolean;
	/**
	 * Keep connection after returning logs.
	 */
	follow?: boolean;
	/**
	 * ID or name of the service
	 */
	id: string;
	/**
	 * Only return logs since this time, as a UNIX timestamp
	 */
	since?: number;
	/**
	 * Return logs from `stderr`
	 */
	stderr?: boolean;
	/**
	 * Return logs from `stdout`
	 */
	stdout?: boolean;
	/**
	 * Only return this number of log lines from the end of the logs.
	 * Specify as an integer or `all` to output all log lines.
	 *
	 */
	tail?: string;
	/**
	 * Add timestamps to every log line
	 */
	timestamps?: boolean;
};
export type ServiceLogsResponse = (Blob | File);
export type TaskListData = {
	/**
	 * A JSON encoded value of the filters (a `map[string][]string`) to
	 * process on the tasks list.
	 *
	 * Available filters:
	 *
	 * - `desired-state=(running | shutdown | accepted)`
	 * - `id=<task id>`
	 * - `label=key` or `label="key=value"`
	 * - `name=<task name>`
	 * - `node=<node id or name>`
	 * - `service=<service name>`
	 *
	 */
	filters?: string;
};
export type TaskListResponse = Array<Task>;
export type TaskInspectData = {
	/**
	 * ID of the task
	 */
	id: string;
};
export type TaskInspectResponse = Task;
export type TaskLogsData = {
	/**
	 * Show task context and extra details provided to logs.
	 */
	details?: boolean;
	/**
	 * Keep connection after returning logs.
	 */
	follow?: boolean;
	/**
	 * ID of the task
	 */
	id: string;
	/**
	 * Only return logs since this time, as a UNIX timestamp
	 */
	since?: number;
	/**
	 * Return logs from `stderr`
	 */
	stderr?: boolean;
	/**
	 * Return logs from `stdout`
	 */
	stdout?: boolean;
	/**
	 * Only return this number of log lines from the end of the logs.
	 * Specify as an integer or `all` to output all log lines.
	 *
	 */
	tail?: string;
	/**
	 * Add timestamps to every log line
	 */
	timestamps?: boolean;
};
export type TaskLogsResponse = (Blob | File);
export type SecretListData = {
	/**
	 * A JSON encoded value of the filters (a `map[string][]string`) to
	 * process on the secrets list.
	 *
	 * Available filters:
	 *
	 * - `id=<secret id>`
	 * - `label=<key> or label=<key>=value`
	 * - `name=<secret name>`
	 * - `names=<secret name>`
	 *
	 */
	filters?: string;
};
export type SecretListResponse = Array<Secret>;
export type SecretCreateData = {
	body?: SecretSpec;
};
export type SecretCreateResponse = IdResponse;
export type SecretInspectData = {
	/**
	 * ID of the secret
	 */
	id: string;
};
export type SecretInspectResponse = Secret;
export type SecretDeleteData = {
	/**
	 * ID of the secret
	 */
	id: string;
};
export type SecretDeleteResponse = void;
export type SecretUpdateData = {
	/**
	 * The spec of the secret to update. Currently, only the Labels field
	 * can be updated. All other fields must remain unchanged from the
	 * [SecretInspect endpoint](#operation/SecretInspect) response values.
	 *
	 */
	body?: SecretSpec;
	/**
	 * The ID or name of the secret
	 */
	id: string;
	/**
	 * The version number of the secret object being updated. This is
	 * required to avoid conflicting writes.
	 *
	 */
	version: number;
};
export type SecretUpdateResponse = unknown;
export type ConfigListData = {
	/**
	 * A JSON encoded value of the filters (a `map[string][]string`) to
	 * process on the configs list.
	 *
	 * Available filters:
	 *
	 * - `id=<config id>`
	 * - `label=<key> or label=<key>=value`
	 * - `name=<config name>`
	 * - `names=<config name>`
	 *
	 */
	filters?: string;
};
export type ConfigListResponse = Array<Config>;
export type ConfigCreateData = {
	body?: ConfigSpec;
};
export type ConfigCreateResponse = IdResponse;
export type ConfigInspectData = {
	/**
	 * ID of the config
	 */
	id: string;
};
export type ConfigInspectResponse = Config;
export type ConfigDeleteData = {
	/**
	 * ID of the config
	 */
	id: string;
};
export type ConfigDeleteResponse = void;
export type ConfigUpdateData = {
	/**
	 * The spec of the config to update. Currently, only the Labels field
	 * can be updated. All other fields must remain unchanged from the
	 * [ConfigInspect endpoint](#operation/ConfigInspect) response values.
	 *
	 */
	body?: ConfigSpec;
	/**
	 * The ID or name of the config
	 */
	id: string;
	/**
	 * The version number of the config object being updated. This is
	 * required to avoid conflicting writes.
	 *
	 */
	version: number;
};
export type ConfigUpdateResponse = unknown;
export type DistributionInspectData = {
	/**
	 * Image name or id
	 */
	name: string;
};
export type DistributionInspectResponse = DistributionInspect;
export type $OpenApiTs = {
	"/containers/json": {
		get: {
			req: ContainerListData;
			res: {
				/**
				 * no error
				 */
				200: Array<ContainerSummary>;
				/**
				 * bad parameter
				 */
				400: ErrorResponse;
				/**
				 * server error
				 */
				500: ErrorResponse;
			};
		};
	};
	"/containers/create": {
		post: {
			req: ContainerCreateData;
			res: {
				/**
				 * Container created successfully
				 */
				201: ContainerCreateResponse;
				/**
				 * bad parameter
				 */
				400: ErrorResponse;
				/**
				 * no such image
				 */
				404: ErrorResponse;
				/**
				 * conflict
				 */
				409: ErrorResponse;
				/**
				 * server error
				 */
				500: ErrorResponse;
			};
		};
	};
	"/containers/{id}/json": {
		get: {
			req: ContainerInspectData;
			res: {
				/**
				 * no error
				 */
				200: {
					/**
					 * The ID of the container
					 */
					Id?: string;
					/**
					 * The time the container was created
					 */
					Created?: string;
					/**
					 * The path to the command being run
					 */
					Path?: string;
					/**
					 * The arguments to the command being run
					 */
					Args?: Array<(string)>;
					State?: ContainerState;
					/**
					 * The container's image ID
					 */
					Image?: string;
					ResolvConfPath?: string;
					HostnamePath?: string;
					HostsPath?: string;
					LogPath?: string;
					Name?: string;
					RestartCount?: number;
					Driver?: string;
					Platform?: string;
					MountLabel?: string;
					ProcessLabel?: string;
					AppArmorProfile?: string;
					/**
					 * IDs of exec instances that are running in the container.
					 */
					ExecIDs?: Array<(string)> | null;
					HostConfig?: HostConfig;
					GraphDriver?: GraphDriverData;
					/**
					 * The size of files that have been created or changed by this
					 * container.
					 *
					 */
					SizeRw?: number;
					/**
					 * The total size of all the files in this container.
					 */
					SizeRootFs?: number;
					Mounts?: Array<MountPoint>;
					Config?: ContainerConfig;
					NetworkSettings?: NetworkSettings;
				};
				/**
				 * no such container
				 */
				404: ErrorResponse;
				/**
				 * server error
				 */
				500: ErrorResponse;
			};
		};
	};
	"/containers/{id}/top": {
		get: {
			req: ContainerTopData;
			res: {
				/**
				 * no error
				 */
				200: {
					/**
					 * The ps column titles
					 */
					Titles?: Array<(string)>;
					/**
					 * Each process running in the container, where each is process
					 * is an array of values corresponding to the titles.
					 *
					 */
					Processes?: Array<Array<(string)>>;
				};
				/**
				 * no such container
				 */
				404: ErrorResponse;
				/**
				 * server error
				 */
				500: ErrorResponse;
			};
		};
	};
	"/containers/{id}/logs": {
		get: {
			req: ContainerLogsData;
			res: {
				/**
				 * logs returned as a stream in response body.
				 * For the stream format, [see the documentation for the attach endpoint](#operation/ContainerAttach).
				 * Note that unlike the attach endpoint, the logs endpoint does not
				 * upgrade the connection and does not set Content-Type.
				 *
				 */
				200: (Blob | File);
				/**
				 * no such container
				 */
				404: ErrorResponse;
				/**
				 * server error
				 */
				500: ErrorResponse;
			};
		};
	};
	"/containers/{id}/changes": {
		get: {
			req: ContainerChangesData;
			res: {
				/**
				 * The list of changes
				 */
				200: Array<FilesystemChange>;
				/**
				 * no such container
				 */
				404: ErrorResponse;
				/**
				 * server error
				 */
				500: ErrorResponse;
			};
		};
	};
	"/containers/{id}/export": {
		get: {
			req: ContainerExportData;
			res: {
				/**
				 * no error
				 */
				200: unknown;
				/**
				 * no such container
				 */
				404: ErrorResponse;
				/**
				 * server error
				 */
				500: ErrorResponse;
			};
		};
	};
	"/containers/{id}/stats": {
		get: {
			req: ContainerStatsData;
			res: {
				/**
				 * no error
				 */
				200: unknown;
				/**
				 * no such container
				 */
				404: ErrorResponse;
				/**
				 * server error
				 */
				500: ErrorResponse;
			};
		};
	};
	"/containers/{id}/resize": {
		post: {
			req: ContainerResizeData;
			res: {
				/**
				 * no error
				 */
				200: unknown;
				/**
				 * no such container
				 */
				404: ErrorResponse;
				/**
				 * cannot resize container
				 */
				500: ErrorResponse;
			};
		};
	};
	"/containers/{id}/start": {
		post: {
			req: ContainerStartData;
			res: {
				/**
				 * no error
				 */
				204: void;
				/**
				 * container already started
				 */
				304: unknown;
				/**
				 * no such container
				 */
				404: ErrorResponse;
				/**
				 * server error
				 */
				500: ErrorResponse;
			};
		};
	};
	"/containers/{id}/stop": {
		post: {
			req: ContainerStopData;
			res: {
				/**
				 * no error
				 */
				204: void;
				/**
				 * container already stopped
				 */
				304: unknown;
				/**
				 * no such container
				 */
				404: ErrorResponse;
				/**
				 * server error
				 */
				500: ErrorResponse;
			};
		};
	};
	"/containers/{id}/restart": {
		post: {
			req: ContainerRestartData;
			res: {
				/**
				 * no error
				 */
				204: void;
				/**
				 * no such container
				 */
				404: ErrorResponse;
				/**
				 * server error
				 */
				500: ErrorResponse;
			};
		};
	};
	"/containers/{id}/kill": {
		post: {
			req: ContainerKillData;
			res: {
				/**
				 * no error
				 */
				204: void;
				/**
				 * no such container
				 */
				404: ErrorResponse;
				/**
				 * container is not running
				 */
				409: ErrorResponse;
				/**
				 * server error
				 */
				500: ErrorResponse;
			};
		};
	};
	"/containers/{id}/update": {
		post: {
			req: ContainerUpdateData;
			res: {
				/**
				 * The container has been updated.
				 */
				200: {
					Warnings?: Array<(string)>;
				};
				/**
				 * no such container
				 */
				404: ErrorResponse;
				/**
				 * server error
				 */
				500: ErrorResponse;
			};
		};
	};
	"/containers/{id}/rename": {
		post: {
			req: ContainerRenameData;
			res: {
				/**
				 * no error
				 */
				204: void;
				/**
				 * no such container
				 */
				404: ErrorResponse;
				/**
				 * name already in use
				 */
				409: ErrorResponse;
				/**
				 * server error
				 */
				500: ErrorResponse;
			};
		};
	};
	"/containers/{id}/pause": {
		post: {
			req: ContainerPauseData;
			res: {
				/**
				 * no error
				 */
				204: void;
				/**
				 * no such container
				 */
				404: ErrorResponse;
				/**
				 * server error
				 */
				500: ErrorResponse;
			};
		};
	};
	"/containers/{id}/unpause": {
		post: {
			req: ContainerUnpauseData;
			res: {
				/**
				 * no error
				 */
				204: void;
				/**
				 * no such container
				 */
				404: ErrorResponse;
				/**
				 * server error
				 */
				500: ErrorResponse;
			};
		};
	};
	"/containers/{id}/attach": {
		post: {
			req: ContainerAttachData;
			res: {
				/**
				 * no error, no upgrade header found
				 */
				200: unknown;
				/**
				 * bad parameter
				 */
				400: ErrorResponse;
				/**
				 * no such container
				 */
				404: ErrorResponse;
				/**
				 * server error
				 */
				500: ErrorResponse;
			};
		};
	};
	"/containers/{id}/attach/ws": {
		get: {
			req: ContainerAttachWebsocketData;
			res: {
				/**
				 * no error, no upgrade header found
				 */
				200: unknown;
				/**
				 * bad parameter
				 */
				400: ErrorResponse;
				/**
				 * no such container
				 */
				404: ErrorResponse;
				/**
				 * server error
				 */
				500: ErrorResponse;
			};
		};
	};
	"/containers/{id}/wait": {
		post: {
			req: ContainerWaitData;
			res: {
				/**
				 * The container has exit.
				 */
				200: ContainerWaitResponse;
				/**
				 * bad parameter
				 */
				400: ErrorResponse;
				/**
				 * no such container
				 */
				404: ErrorResponse;
				/**
				 * server error
				 */
				500: ErrorResponse;
			};
		};
	};
	"/containers/{id}": {
		delete: {
			req: ContainerDeleteData;
			res: {
				/**
				 * no error
				 */
				204: void;
				/**
				 * bad parameter
				 */
				400: ErrorResponse;
				/**
				 * no such container
				 */
				404: ErrorResponse;
				/**
				 * conflict
				 */
				409: ErrorResponse;
				/**
				 * server error
				 */
				500: ErrorResponse;
			};
		};
	};
	"/containers/{id}/archive": {
		head: {
			req: ContainerArchiveInfoData;
			res: {
				/**
				 * no error
				 */
				200: string;
				/**
				 * Bad parameter
				 */
				400: ErrorResponse;
				/**
				 * Container or path does not exist
				 */
				404: ErrorResponse;
				/**
				 * Server error
				 */
				500: ErrorResponse;
			};
		};
		get: {
			req: ContainerArchiveData;
			res: {
				/**
				 * no error
				 */
				200: unknown;
				/**
				 * Bad parameter
				 */
				400: ErrorResponse;
				/**
				 * Container or path does not exist
				 */
				404: ErrorResponse;
				/**
				 * server error
				 */
				500: ErrorResponse;
			};
		};
		put: {
			req: PutContainerArchiveData;
			res: {
				/**
				 * The content was extracted successfully
				 */
				200: unknown;
				/**
				 * Bad parameter
				 */
				400: ErrorResponse;
				/**
				 * Permission denied, the volume or container rootfs is marked as read-only.
				 */
				403: ErrorResponse;
				/**
				 * No such container or path does not exist inside the container
				 */
				404: ErrorResponse;
				/**
				 * Server error
				 */
				500: ErrorResponse;
			};
		};
	};
	"/containers/prune": {
		post: {
			req: ContainerPruneData;
			res: {
				/**
				 * No error
				 */
				200: {
					/**
					 * Container IDs that were deleted
					 */
					ContainersDeleted?: Array<(string)>;
					/**
					 * Disk space reclaimed in bytes
					 */
					SpaceReclaimed?: number;
				};
				/**
				 * Server error
				 */
				500: ErrorResponse;
			};
		};
	};
	"/images/json": {
		get: {
			req: ImageListData;
			res: {
				/**
				 * Summary image data for the images matching the query
				 */
				200: Array<ImageSummary>;
				/**
				 * server error
				 */
				500: ErrorResponse;
			};
		};
	};
	"/build": {
		post: {
			req: ImageBuildData;
			res: {
				/**
				 * no error
				 */
				200: unknown;
				/**
				 * Bad parameter
				 */
				400: ErrorResponse;
				/**
				 * server error
				 */
				500: ErrorResponse;
			};
		};
	};
	"/build/prune": {
		post: {
			req: BuildPruneData;
			res: {
				/**
				 * No error
				 */
				200: {
					CachesDeleted?: Array<(string)>;
					/**
					 * Disk space reclaimed in bytes
					 */
					SpaceReclaimed?: number;
				};
				/**
				 * Server error
				 */
				500: ErrorResponse;
			};
		};
	};
	"/images/create": {
		post: {
			req: ImageCreateData;
			res: {
				/**
				 * no error
				 */
				200: unknown;
				/**
				 * repository does not exist or no read access
				 */
				404: ErrorResponse;
				/**
				 * server error
				 */
				500: ErrorResponse;
			};
		};
	};
	"/images/{name}/json": {
		get: {
			req: ImageInspectData;
			res: {
				/**
				 * No error
				 */
				200: ImageInspect;
				/**
				 * No such image
				 */
				404: ErrorResponse;
				/**
				 * Server error
				 */
				500: ErrorResponse;
			};
		};
	};
	"/images/{name}/history": {
		get: {
			req: ImageHistoryData;
			res: {
				/**
				 * List of image layers
				 */
				200: Array<{
					Id: string;
					Created: number;
					CreatedBy: string;
					Tags: Array<(string)>;
					Size: number;
					Comment: string;
				}>;
				/**
				 * No such image
				 */
				404: ErrorResponse;
				/**
				 * Server error
				 */
				500: ErrorResponse;
			};
		};
	};
	"/images/{name}/push": {
		post: {
			req: ImagePushData;
			res: {
				/**
				 * No error
				 */
				200: unknown;
				/**
				 * No such image
				 */
				404: ErrorResponse;
				/**
				 * Server error
				 */
				500: ErrorResponse;
			};
		};
	};
	"/images/{name}/tag": {
		post: {
			req: ImageTagData;
			res: {
				/**
				 * No error
				 */
				201: unknown;
				/**
				 * Bad parameter
				 */
				400: ErrorResponse;
				/**
				 * No such image
				 */
				404: ErrorResponse;
				/**
				 * Conflict
				 */
				409: ErrorResponse;
				/**
				 * Server error
				 */
				500: ErrorResponse;
			};
		};
	};
	"/images/{name}": {
		delete: {
			req: ImageDeleteData;
			res: {
				/**
				 * The image was deleted successfully
				 */
				200: Array<ImageDeleteResponseItem>;
				/**
				 * No such image
				 */
				404: ErrorResponse;
				/**
				 * Conflict
				 */
				409: ErrorResponse;
				/**
				 * Server error
				 */
				500: ErrorResponse;
			};
		};
	};
	"/images/search": {
		get: {
			req: ImageSearchData;
			res: {
				/**
				 * No error
				 */
				200: Array<{
					description?: string;
					is_official?: boolean;
					/**
					 * Whether this repository has automated builds enabled.
					 *
					 * <p><br /></p>
					 *
					 * > **Deprecated**: This field is deprecated and will always be "false".
					 *
					 */
					is_automated?: boolean;
					name?: string;
					star_count?: number;
				}>;
				/**
				 * Server error
				 */
				500: ErrorResponse;
			};
		};
	};
	"/images/prune": {
		post: {
			req: ImagePruneData;
			res: {
				/**
				 * No error
				 */
				200: {
					/**
					 * Images that were deleted
					 */
					ImagesDeleted?: Array<ImageDeleteResponseItem>;
					/**
					 * Disk space reclaimed in bytes
					 */
					SpaceReclaimed?: number;
				};
				/**
				 * Server error
				 */
				500: ErrorResponse;
			};
		};
	};
	"/commit": {
		post: {
			req: ImageCommitData;
			res: {
				/**
				 * no error
				 */
				201: IdResponse;
				/**
				 * no such container
				 */
				404: ErrorResponse;
				/**
				 * server error
				 */
				500: ErrorResponse;
			};
		};
	};
	"/images/{name}/get": {
		get: {
			req: ImageGetData;
			res: {
				/**
				 * no error
				 */
				200: (Blob | File);
				/**
				 * server error
				 */
				500: ErrorResponse;
			};
		};
	};
	"/images/get": {
		get: {
			req: ImageGetAllData;
			res: {
				/**
				 * no error
				 */
				200: (Blob | File);
				/**
				 * server error
				 */
				500: ErrorResponse;
			};
		};
	};
	"/images/load": {
		post: {
			req: ImageLoadData;
			res: {
				/**
				 * no error
				 */
				200: unknown;
				/**
				 * server error
				 */
				500: ErrorResponse;
			};
		};
	};
	"/auth": {
		post: {
			req: SystemAuthData;
			res: {
				/**
				 * An identity token was generated successfully.
				 */
				200: {
					/**
					 * The status of the authentication
					 */
					Status: string;
					/**
					 * An opaque token used to authenticate a user after a successful login
					 */
					IdentityToken?: string;
				};
				/**
				 * No error
				 */
				204: void;
				/**
				 * Auth error
				 */
				401: ErrorResponse;
				/**
				 * Server error
				 */
				500: ErrorResponse;
			};
		};
	};
	"/info": {
		get: {
			res: {
				/**
				 * No error
				 */
				200: SystemInfo;
				/**
				 * Server error
				 */
				500: ErrorResponse;
			};
		};
	};
	"/version": {
		get: {
			res: {
				/**
				 * no error
				 */
				200: SystemVersion;
				/**
				 * server error
				 */
				500: ErrorResponse;
			};
		};
	};
	"/_ping": {
		get: {
			res: {
				/**
				 * no error
				 */
				200: string;
				/**
				 * server error
				 */
				500: ErrorResponse;
			};
		};
		head: {
			res: {
				/**
				 * no error
				 */
				200: string;
				/**
				 * server error
				 */
				500: ErrorResponse;
			};
		};
	};
	"/events": {
		get: {
			req: SystemEventsData;
			res: {
				/**
				 * no error
				 */
				200: EventMessage;
				/**
				 * bad parameter
				 */
				400: ErrorResponse;
				/**
				 * server error
				 */
				500: ErrorResponse;
			};
		};
	};
	"/system/df": {
		get: {
			req: SystemDataUsageData;
			res: {
				/**
				 * no error
				 */
				200: {
					LayersSize?: number;
					Images?: Array<ImageSummary>;
					Containers?: Array<ContainerSummary>;
					Volumes?: Array<Volume>;
					BuildCache?: Array<BuildCache>;
				};
				/**
				 * server error
				 */
				500: ErrorResponse;
			};
		};
	};
	"/containers/{id}/exec": {
		post: {
			req: ContainerExecData;
			res: {
				/**
				 * no error
				 */
				201: IdResponse;
				/**
				 * no such container
				 */
				404: ErrorResponse;
				/**
				 * container is paused
				 */
				409: ErrorResponse;
				/**
				 * Server error
				 */
				500: ErrorResponse;
			};
		};
	};
	"/exec/{id}/start": {
		post: {
			req: ExecStartData;
			res: {
				/**
				 * No error
				 */
				200: unknown;
				/**
				 * No such exec instance
				 */
				404: ErrorResponse;
				/**
				 * Container is stopped or paused
				 */
				409: ErrorResponse;
			};
		};
	};
	"/exec/{id}/resize": {
		post: {
			req: ExecResizeData;
			res: {
				/**
				 * No error
				 */
				200: unknown;
				/**
				 * bad parameter
				 */
				400: ErrorResponse;
				/**
				 * No such exec instance
				 */
				404: ErrorResponse;
				/**
				 * Server error
				 */
				500: ErrorResponse;
			};
		};
	};
	"/exec/{id}/json": {
		get: {
			req: ExecInspectData;
			res: {
				/**
				 * No error
				 */
				200: {
					CanRemove?: boolean;
					DetachKeys?: string;
					ID?: string;
					Running?: boolean;
					ExitCode?: number;
					ProcessConfig?: ProcessConfig;
					OpenStdin?: boolean;
					OpenStderr?: boolean;
					OpenStdout?: boolean;
					ContainerID?: string;
					/**
					 * The system process ID for the exec process.
					 */
					Pid?: number;
				};
				/**
				 * No such exec instance
				 */
				404: ErrorResponse;
				/**
				 * Server error
				 */
				500: ErrorResponse;
			};
		};
	};
	"/volumes": {
		get: {
			req: VolumeListData;
			res: {
				/**
				 * Summary volume data that matches the query
				 */
				200: VolumeListResponse;
				/**
				 * Server error
				 */
				500: ErrorResponse;
			};
		};
	};
	"/volumes/create": {
		post: {
			req: VolumeCreateData;
			res: {
				/**
				 * The volume was created successfully
				 */
				201: Volume;
				/**
				 * Server error
				 */
				500: ErrorResponse;
			};
		};
	};
	"/volumes/{name}": {
		get: {
			req: VolumeInspectData;
			res: {
				/**
				 * No error
				 */
				200: Volume;
				/**
				 * No such volume
				 */
				404: ErrorResponse;
				/**
				 * Server error
				 */
				500: ErrorResponse;
			};
		};
		put: {
			req: VolumeUpdateData;
			res: {
				/**
				 * no error
				 */
				200: unknown;
				/**
				 * bad parameter
				 */
				400: ErrorResponse;
				/**
				 * no such volume
				 */
				404: ErrorResponse;
				/**
				 * server error
				 */
				500: ErrorResponse;
				/**
				 * node is not part of a swarm
				 */
				503: ErrorResponse;
			};
		};
		delete: {
			req: VolumeDeleteData;
			res: {
				/**
				 * The volume was removed
				 */
				204: void;
				/**
				 * No such volume or volume driver
				 */
				404: ErrorResponse;
				/**
				 * Volume is in use and cannot be removed
				 */
				409: ErrorResponse;
				/**
				 * Server error
				 */
				500: ErrorResponse;
			};
		};
	};
	"/volumes/prune": {
		post: {
			req: VolumePruneData;
			res: {
				/**
				 * No error
				 */
				200: {
					/**
					 * Volumes that were deleted
					 */
					VolumesDeleted?: Array<(string)>;
					/**
					 * Disk space reclaimed in bytes
					 */
					SpaceReclaimed?: number;
				};
				/**
				 * Server error
				 */
				500: ErrorResponse;
			};
		};
	};
	"/networks": {
		get: {
			req: NetworkListData;
			res: {
				/**
				 * No error
				 */
				200: Array<Network>;
				/**
				 * Server error
				 */
				500: ErrorResponse;
			};
		};
	};
	"/networks/{id}": {
		get: {
			req: NetworkInspectData;
			res: {
				/**
				 * No error
				 */
				200: Network;
				/**
				 * Network not found
				 */
				404: ErrorResponse;
				/**
				 * Server error
				 */
				500: ErrorResponse;
			};
		};
		delete: {
			req: NetworkDeleteData;
			res: {
				/**
				 * No error
				 */
				204: void;
				/**
				 * operation not supported for pre-defined networks
				 */
				403: ErrorResponse;
				/**
				 * no such network
				 */
				404: ErrorResponse;
				/**
				 * Server error
				 */
				500: ErrorResponse;
			};
		};
	};
	"/networks/create": {
		post: {
			req: NetworkCreateData;
			res: {
				/**
				 * No error
				 */
				201: {
					/**
					 * The ID of the created network.
					 */
					Id?: string;
					Warning?: string;
				};
				/**
				 * bad parameter
				 */
				400: ErrorResponse;
				/**
				 * Forbidden operation. This happens when trying to create a network named after a pre-defined network,
				 * or when trying to create an overlay network on a daemon which is not part of a Swarm cluster.
				 *
				 */
				403: ErrorResponse;
				/**
				 * plugin not found
				 */
				404: ErrorResponse;
				/**
				 * Server error
				 */
				500: ErrorResponse;
			};
		};
	};
	"/networks/{id}/connect": {
		post: {
			req: NetworkConnectData;
			res: {
				/**
				 * No error
				 */
				200: unknown;
				/**
				 * bad parameter
				 */
				400: ErrorResponse;
				/**
				 * Operation forbidden
				 */
				403: ErrorResponse;
				/**
				 * Network or container not found
				 */
				404: ErrorResponse;
				/**
				 * Server error
				 */
				500: ErrorResponse;
			};
		};
	};
	"/networks/{id}/disconnect": {
		post: {
			req: NetworkDisconnectData;
			res: {
				/**
				 * No error
				 */
				200: unknown;
				/**
				 * Operation not supported for swarm scoped networks
				 */
				403: ErrorResponse;
				/**
				 * Network or container not found
				 */
				404: ErrorResponse;
				/**
				 * Server error
				 */
				500: ErrorResponse;
			};
		};
	};
	"/networks/prune": {
		post: {
			req: NetworkPruneData;
			res: {
				/**
				 * No error
				 */
				200: {
					/**
					 * Networks that were deleted
					 */
					NetworksDeleted?: Array<(string)>;
				};
				/**
				 * Server error
				 */
				500: ErrorResponse;
			};
		};
	};
	"/plugins": {
		get: {
			req: PluginListData;
			res: {
				/**
				 * No error
				 */
				200: Array<Plugin$1>;
				/**
				 * Server error
				 */
				500: ErrorResponse;
			};
		};
	};
	"/plugins/privileges": {
		get: {
			req: GetPluginPrivilegesData;
			res: {
				/**
				 * no error
				 */
				200: Array<PluginPrivilege>;
				/**
				 * server error
				 */
				500: ErrorResponse;
			};
		};
	};
	"/plugins/pull": {
		post: {
			req: PluginPullData;
			res: {
				/**
				 * no error
				 */
				204: void;
				/**
				 * server error
				 */
				500: ErrorResponse;
			};
		};
	};
	"/plugins/{name}/json": {
		get: {
			req: PluginInspectData;
			res: {
				/**
				 * no error
				 */
				200: Plugin$1;
				/**
				 * plugin is not installed
				 */
				404: ErrorResponse;
				/**
				 * server error
				 */
				500: ErrorResponse;
			};
		};
	};
	"/plugins/{name}": {
		delete: {
			req: PluginDeleteData;
			res: {
				/**
				 * no error
				 */
				200: Plugin$1;
				/**
				 * plugin is not installed
				 */
				404: ErrorResponse;
				/**
				 * server error
				 */
				500: ErrorResponse;
			};
		};
	};
	"/plugins/{name}/enable": {
		post: {
			req: PluginEnableData;
			res: {
				/**
				 * no error
				 */
				200: unknown;
				/**
				 * plugin is not installed
				 */
				404: ErrorResponse;
				/**
				 * server error
				 */
				500: ErrorResponse;
			};
		};
	};
	"/plugins/{name}/disable": {
		post: {
			req: PluginDisableData;
			res: {
				/**
				 * no error
				 */
				200: unknown;
				/**
				 * plugin is not installed
				 */
				404: ErrorResponse;
				/**
				 * server error
				 */
				500: ErrorResponse;
			};
		};
	};
	"/plugins/{name}/upgrade": {
		post: {
			req: PluginUpgradeData;
			res: {
				/**
				 * no error
				 */
				204: void;
				/**
				 * plugin not installed
				 */
				404: ErrorResponse;
				/**
				 * server error
				 */
				500: ErrorResponse;
			};
		};
	};
	"/plugins/create": {
		post: {
			req: PluginCreateData;
			res: {
				/**
				 * no error
				 */
				204: void;
				/**
				 * server error
				 */
				500: ErrorResponse;
			};
		};
	};
	"/plugins/{name}/push": {
		post: {
			req: PluginPushData;
			res: {
				/**
				 * no error
				 */
				200: unknown;
				/**
				 * plugin not installed
				 */
				404: ErrorResponse;
				/**
				 * server error
				 */
				500: ErrorResponse;
			};
		};
	};
	"/plugins/{name}/set": {
		post: {
			req: PluginSetData;
			res: {
				/**
				 * No error
				 */
				204: void;
				/**
				 * Plugin not installed
				 */
				404: ErrorResponse;
				/**
				 * Server error
				 */
				500: ErrorResponse;
			};
		};
	};
	"/nodes": {
		get: {
			req: NodeListData;
			res: {
				/**
				 * no error
				 */
				200: Array<Node$1>;
				/**
				 * server error
				 */
				500: ErrorResponse;
				/**
				 * node is not part of a swarm
				 */
				503: ErrorResponse;
			};
		};
	};
	"/nodes/{id}": {
		get: {
			req: NodeInspectData;
			res: {
				/**
				 * no error
				 */
				200: Node$1;
				/**
				 * no such node
				 */
				404: ErrorResponse;
				/**
				 * server error
				 */
				500: ErrorResponse;
				/**
				 * node is not part of a swarm
				 */
				503: ErrorResponse;
			};
		};
		delete: {
			req: NodeDeleteData;
			res: {
				/**
				 * no error
				 */
				200: unknown;
				/**
				 * no such node
				 */
				404: ErrorResponse;
				/**
				 * server error
				 */
				500: ErrorResponse;
				/**
				 * node is not part of a swarm
				 */
				503: ErrorResponse;
			};
		};
	};
	"/nodes/{id}/update": {
		post: {
			req: NodeUpdateData;
			res: {
				/**
				 * no error
				 */
				200: unknown;
				/**
				 * bad parameter
				 */
				400: ErrorResponse;
				/**
				 * no such node
				 */
				404: ErrorResponse;
				/**
				 * server error
				 */
				500: ErrorResponse;
				/**
				 * node is not part of a swarm
				 */
				503: ErrorResponse;
			};
		};
	};
	"/swarm": {
		get: {
			res: {
				/**
				 * no error
				 */
				200: Swarm;
				/**
				 * no such swarm
				 */
				404: ErrorResponse;
				/**
				 * server error
				 */
				500: ErrorResponse;
				/**
				 * node is not part of a swarm
				 */
				503: ErrorResponse;
			};
		};
	};
	"/swarm/init": {
		post: {
			req: SwarmInitData;
			res: {
				/**
				 * no error
				 */
				200: string;
				/**
				 * bad parameter
				 */
				400: ErrorResponse;
				/**
				 * server error
				 */
				500: ErrorResponse;
				/**
				 * node is already part of a swarm
				 */
				503: ErrorResponse;
			};
		};
	};
	"/swarm/join": {
		post: {
			req: SwarmJoinData;
			res: {
				/**
				 * no error
				 */
				200: unknown;
				/**
				 * bad parameter
				 */
				400: ErrorResponse;
				/**
				 * server error
				 */
				500: ErrorResponse;
				/**
				 * node is already part of a swarm
				 */
				503: ErrorResponse;
			};
		};
	};
	"/swarm/leave": {
		post: {
			req: SwarmLeaveData;
			res: {
				/**
				 * no error
				 */
				200: unknown;
				/**
				 * server error
				 */
				500: ErrorResponse;
				/**
				 * node is not part of a swarm
				 */
				503: ErrorResponse;
			};
		};
	};
	"/swarm/update": {
		post: {
			req: SwarmUpdateData;
			res: {
				/**
				 * no error
				 */
				200: unknown;
				/**
				 * bad parameter
				 */
				400: ErrorResponse;
				/**
				 * server error
				 */
				500: ErrorResponse;
				/**
				 * node is not part of a swarm
				 */
				503: ErrorResponse;
			};
		};
	};
	"/swarm/unlockkey": {
		get: {
			res: {
				/**
				 * no error
				 */
				200: {
					/**
					 * The swarm's unlock key.
					 */
					UnlockKey?: string;
				};
				/**
				 * server error
				 */
				500: ErrorResponse;
				/**
				 * node is not part of a swarm
				 */
				503: ErrorResponse;
			};
		};
	};
	"/swarm/unlock": {
		post: {
			req: SwarmUnlockData;
			res: {
				/**
				 * no error
				 */
				200: unknown;
				/**
				 * server error
				 */
				500: ErrorResponse;
				/**
				 * node is not part of a swarm
				 */
				503: ErrorResponse;
			};
		};
	};
	"/services": {
		get: {
			req: ServiceListData;
			res: {
				/**
				 * no error
				 */
				200: Array<Service>;
				/**
				 * server error
				 */
				500: ErrorResponse;
				/**
				 * node is not part of a swarm
				 */
				503: ErrorResponse;
			};
		};
	};
	"/services/create": {
		post: {
			req: ServiceCreateData;
			res: {
				/**
				 * no error
				 */
				201: ServiceCreateResponse;
				/**
				 * bad parameter
				 */
				400: ErrorResponse;
				/**
				 * network is not eligible for services
				 */
				403: ErrorResponse;
				/**
				 * name conflicts with an existing service
				 */
				409: ErrorResponse;
				/**
				 * server error
				 */
				500: ErrorResponse;
				/**
				 * node is not part of a swarm
				 */
				503: ErrorResponse;
			};
		};
	};
	"/services/{id}": {
		get: {
			req: ServiceInspectData;
			res: {
				/**
				 * no error
				 */
				200: Service;
				/**
				 * no such service
				 */
				404: ErrorResponse;
				/**
				 * server error
				 */
				500: ErrorResponse;
				/**
				 * node is not part of a swarm
				 */
				503: ErrorResponse;
			};
		};
		delete: {
			req: ServiceDeleteData;
			res: {
				/**
				 * no error
				 */
				200: unknown;
				/**
				 * no such service
				 */
				404: ErrorResponse;
				/**
				 * server error
				 */
				500: ErrorResponse;
				/**
				 * node is not part of a swarm
				 */
				503: ErrorResponse;
			};
		};
	};
	"/services/{id}/update": {
		post: {
			req: ServiceUpdateData;
			res: {
				/**
				 * no error
				 */
				200: ServiceUpdateResponse;
				/**
				 * bad parameter
				 */
				400: ErrorResponse;
				/**
				 * no such service
				 */
				404: ErrorResponse;
				/**
				 * server error
				 */
				500: ErrorResponse;
				/**
				 * node is not part of a swarm
				 */
				503: ErrorResponse;
			};
		};
	};
	"/services/{id}/logs": {
		get: {
			req: ServiceLogsData;
			res: {
				/**
				 * logs returned as a stream in response body
				 */
				200: (Blob | File);
				/**
				 * no such service
				 */
				404: ErrorResponse;
				/**
				 * server error
				 */
				500: ErrorResponse;
				/**
				 * node is not part of a swarm
				 */
				503: ErrorResponse;
			};
		};
	};
	"/tasks": {
		get: {
			req: TaskListData;
			res: {
				/**
				 * no error
				 */
				200: Array<Task>;
				/**
				 * server error
				 */
				500: ErrorResponse;
				/**
				 * node is not part of a swarm
				 */
				503: ErrorResponse;
			};
		};
	};
	"/tasks/{id}": {
		get: {
			req: TaskInspectData;
			res: {
				/**
				 * no error
				 */
				200: Task;
				/**
				 * no such task
				 */
				404: ErrorResponse;
				/**
				 * server error
				 */
				500: ErrorResponse;
				/**
				 * node is not part of a swarm
				 */
				503: ErrorResponse;
			};
		};
	};
	"/tasks/{id}/logs": {
		get: {
			req: TaskLogsData;
			res: {
				/**
				 * logs returned as a stream in response body
				 */
				200: (Blob | File);
				/**
				 * no such task
				 */
				404: ErrorResponse;
				/**
				 * server error
				 */
				500: ErrorResponse;
				/**
				 * node is not part of a swarm
				 */
				503: ErrorResponse;
			};
		};
	};
	"/secrets": {
		get: {
			req: SecretListData;
			res: {
				/**
				 * no error
				 */
				200: Array<Secret>;
				/**
				 * server error
				 */
				500: ErrorResponse;
				/**
				 * node is not part of a swarm
				 */
				503: ErrorResponse;
			};
		};
	};
	"/secrets/create": {
		post: {
			req: SecretCreateData;
			res: {
				/**
				 * no error
				 */
				201: IdResponse;
				/**
				 * name conflicts with an existing object
				 */
				409: ErrorResponse;
				/**
				 * server error
				 */
				500: ErrorResponse;
				/**
				 * node is not part of a swarm
				 */
				503: ErrorResponse;
			};
		};
	};
	"/secrets/{id}": {
		get: {
			req: SecretInspectData;
			res: {
				/**
				 * no error
				 */
				200: Secret;
				/**
				 * secret not found
				 */
				404: ErrorResponse;
				/**
				 * server error
				 */
				500: ErrorResponse;
				/**
				 * node is not part of a swarm
				 */
				503: ErrorResponse;
			};
		};
		delete: {
			req: SecretDeleteData;
			res: {
				/**
				 * no error
				 */
				204: void;
				/**
				 * secret not found
				 */
				404: ErrorResponse;
				/**
				 * server error
				 */
				500: ErrorResponse;
				/**
				 * node is not part of a swarm
				 */
				503: ErrorResponse;
			};
		};
	};
	"/secrets/{id}/update": {
		post: {
			req: SecretUpdateData;
			res: {
				/**
				 * no error
				 */
				200: unknown;
				/**
				 * bad parameter
				 */
				400: ErrorResponse;
				/**
				 * no such secret
				 */
				404: ErrorResponse;
				/**
				 * server error
				 */
				500: ErrorResponse;
				/**
				 * node is not part of a swarm
				 */
				503: ErrorResponse;
			};
		};
	};
	"/configs": {
		get: {
			req: ConfigListData;
			res: {
				/**
				 * no error
				 */
				200: Array<Config>;
				/**
				 * server error
				 */
				500: ErrorResponse;
				/**
				 * node is not part of a swarm
				 */
				503: ErrorResponse;
			};
		};
	};
	"/configs/create": {
		post: {
			req: ConfigCreateData;
			res: {
				/**
				 * no error
				 */
				201: IdResponse;
				/**
				 * name conflicts with an existing object
				 */
				409: ErrorResponse;
				/**
				 * server error
				 */
				500: ErrorResponse;
				/**
				 * node is not part of a swarm
				 */
				503: ErrorResponse;
			};
		};
	};
	"/configs/{id}": {
		get: {
			req: ConfigInspectData;
			res: {
				/**
				 * no error
				 */
				200: Config;
				/**
				 * config not found
				 */
				404: ErrorResponse;
				/**
				 * server error
				 */
				500: ErrorResponse;
				/**
				 * node is not part of a swarm
				 */
				503: ErrorResponse;
			};
		};
		delete: {
			req: ConfigDeleteData;
			res: {
				/**
				 * no error
				 */
				204: void;
				/**
				 * config not found
				 */
				404: ErrorResponse;
				/**
				 * server error
				 */
				500: ErrorResponse;
				/**
				 * node is not part of a swarm
				 */
				503: ErrorResponse;
			};
		};
	};
	"/configs/{id}/update": {
		post: {
			req: ConfigUpdateData;
			res: {
				/**
				 * no error
				 */
				200: unknown;
				/**
				 * bad parameter
				 */
				400: ErrorResponse;
				/**
				 * no such config
				 */
				404: ErrorResponse;
				/**
				 * server error
				 */
				500: ErrorResponse;
				/**
				 * node is not part of a swarm
				 */
				503: ErrorResponse;
			};
		};
	};
	"/distribution/{name}/json": {
		get: {
			req: DistributionInspectData;
			res: {
				/**
				 * descriptor and platform information
				 */
				200: DistributionInspect;
				/**
				 * Failed authentication or no image found
				 */
				401: ErrorResponse;
				/**
				 * Server error
				 */
				500: ErrorResponse;
			};
		};
	};
	"/session": {
		post: {
			res: {
				/**
				 * bad parameter
				 */
				400: ErrorResponse;
				/**
				 * server error
				 */
				500: ErrorResponse;
			};
		};
	};
};
export declare class ContainerService {
	private readonly client;
	constructor(client: DockerClient);
	/**
	 * List containers
	 * Returns a list of containers. For details on the format, see the
	 * [inspect endpoint](#operation/ContainerInspect).
	 *
	 * Note that it uses a different, smaller representation of a container
	 * than inspecting a single container. For example, the list of linked
	 * containers is not propagated .
	 *
	 * @param data The data for the request.
	 * @param data.all Return all containers. By default, only running containers are shown.
	 *
	 * @param data.limit Return this number of most recently created containers, including
	 * non-running ones.
	 *
	 * @param data.size Return the size of container as fields `SizeRw` and `SizeRootFs`.
	 *
	 * @param data.filters Filters to process on the container list, encoded as JSON (a
	 * `map[string][]string`). For example, `{"status": ["paused"]}` will
	 * only return paused containers.
	 *
	 * Available filters:
	 *
	 * - `ancestor`=(`<image-name>[:<tag>]`, `<image id>`, or `<image@digest>`)
	 * - `before`=(`<container id>` or `<container name>`)
	 * - `expose`=(`<port>[/<proto>]`|`<startport-endport>/[<proto>]`)
	 * - `exited=<int>` containers with exit code of `<int>`
	 * - `health`=(`starting`|`healthy`|`unhealthy`|`none`)
	 * - `id=<ID>` a container's ID
	 * - `isolation=`(`default`|`process`|`hyperv`) (Windows daemon only)
	 * - `is-task=`(`true`|`false`)
	 * - `label=key` or `label="key=value"` of a container label
	 * - `name=<name>` a container's name
	 * - `network`=(`<network id>` or `<network name>`)
	 * - `publish`=(`<port>[/<proto>]`|`<startport-endport>/[<proto>]`)
	 * - `since`=(`<container id>` or `<container name>`)
	 * - `status=`(`created`|`restarting`|`running`|`removing`|`paused`|`exited`|`dead`)
	 * - `volume`=(`<volume name>` or `<mount point destination>`)
	 *
	 * @returns ContainerSummary no error
	 */
	containerList(data?: ContainerListData): Promise<DockerResponse<ContainerListResponse>>;
	/**
	 * Create a container
	 * @param data The data for the request.
	 * @param data.body Container to create
	 * @param data.name Assign the specified name to the container. Must match
	 * `/?[a-zA-Z0-9][a-zA-Z0-9_.-]+`.
	 *
	 * @param data.platform Platform in the format `os[/arch[/variant]]` used for image lookup.
	 *
	 * When specified, the daemon checks if the requested image is present
	 * in the local image cache with the given OS and Architecture, and
	 * otherwise returns a `404` status.
	 *
	 * If the option is not set, the host's native OS and Architecture are
	 * used to look up the image in the image cache. However, if no platform
	 * is passed and the given image does exist in the local image cache,
	 * but its OS or architecture does not match, the container is created
	 * with the available image, and a warning is added to the `Warnings`
	 * field in the response, for example;
	 *
	 * WARNING: The requested image's platform (linux/arm64/v8) does not
	 * match the detected host platform (linux/amd64) and no
	 * specific platform was requested
	 *
	 * @returns ContainerCreateResponse Container created successfully
	 */
	containerCreate(data: ContainerCreateData): Promise<DockerResponse<ContainerCreateResponse2>>;
	/**
	 * Inspect a container
	 * Return low-level information about a container.
	 * @param data The data for the request.
	 * @param data.id ID or name of the container
	 * @param data.size Return the size of container as fields `SizeRw` and `SizeRootFs`
	 * @returns unknown no error
	 */
	containerInspect(data: ContainerInspectData): Promise<DockerResponse<ContainerInspectResponse>>;
	/**
	 * List processes running inside a container
	 * On Unix systems, this is done by running the `ps` command. This endpoint
	 * is not supported on Windows.
	 *
	 * @param data The data for the request.
	 * @param data.id ID or name of the container
	 * @param data.psArgs The arguments to pass to `ps`. For example, `aux`
	 * @returns unknown no error
	 */
	containerTop(data: ContainerTopData): Promise<DockerResponse<ContainerTopResponse>>;
	/**
	 * Get container logs
	 * Get `stdout` and `stderr` logs from a container.
	 *
	 * Note: This endpoint works only for containers with the `json-file` or
	 * `journald` logging driver.
	 *
	 * @param data The data for the request.
	 * @param data.id ID or name of the container
	 * @param data.follow Keep connection after returning logs.
	 * @param data.stdout Return logs from `stdout`
	 * @param data.stderr Return logs from `stderr`
	 * @param data.since Only return logs since this time, as a UNIX timestamp
	 * @param data.until Only return logs before this time, as a UNIX timestamp
	 * @param data.timestamps Add timestamps to every log line
	 * @param data.tail Only return this number of log lines from the end of the logs.
	 * Specify as an integer or `all` to output all log lines.
	 *
	 * @returns binary logs returned as a stream in response body.
	 * For the stream format, [see the documentation for the attach endpoint](#operation/ContainerAttach).
	 * Note that unlike the attach endpoint, the logs endpoint does not
	 * upgrade the connection and does not set Content-Type.
	 *
	 */
	containerLogs(data: ContainerLogsData): Promise<DockerResponse<ContainerLogsResponse>>;
	/**
	 * Get changes on a container’s filesystem
	 * Returns which files in a container's filesystem have been added, deleted,
	 * or modified. The `Kind` of modification can be one of:
	 *
	 * - `0`: Modified ("C")
	 * - `1`: Added ("A")
	 * - `2`: Deleted ("D")
	 *
	 * @param data The data for the request.
	 * @param data.id ID or name of the container
	 * @returns FilesystemChange The list of changes
	 */
	containerChanges(data: ContainerChangesData): Promise<DockerResponse<ContainerChangesResponse>>;
	/**
	 * Export a container
	 * Export the contents of a container as a tarball.
	 * @param data The data for the request.
	 * @param data.id ID or name of the container
	 * @returns unknown no error
	 */
	containerExport(data: ContainerExportData): Promise<DockerResponse<ContainerExportResponse>>;
	/**
	 * Get container stats based on resource usage
	 * This endpoint returns a live stream of a container’s resource usage
	 * statistics.
	 *
	 * The `precpu_stats` is the CPU statistic of the *previous* read, and is
	 * used to calculate the CPU usage percentage. It is not an exact copy
	 * of the `cpu_stats` field.
	 *
	 * If either `precpu_stats.online_cpus` or `cpu_stats.online_cpus` is
	 * nil then for compatibility with older daemons the length of the
	 * corresponding `cpu_usage.percpu_usage` array should be used.
	 *
	 * On a cgroup v2 host, the following fields are not set
	 * * `blkio_stats`: all fields other than `io_service_bytes_recursive`
	 * * `cpu_stats`: `cpu_usage.percpu_usage`
	 * * `memory_stats`: `max_usage` and `failcnt`
	 * Also, `memory_stats.stats` fields are incompatible with cgroup v1.
	 *
	 * To calculate the values shown by the `stats` command of the docker cli tool
	 * the following formulas can be used:
	 * * used_memory = `memory_stats.usage - memory_stats.stats.cache`
	 * * available_memory = `memory_stats.limit`
	 * * Memory usage % = `(used_memory / available_memory) * 100.0`
	 * * cpu_delta = `cpu_stats.cpu_usage.total_usage - precpu_stats.cpu_usage.total_usage`
	 * * system_cpu_delta = `cpu_stats.system_cpu_usage - precpu_stats.system_cpu_usage`
	 * * number_cpus = `lenght(cpu_stats.cpu_usage.percpu_usage)` or `cpu_stats.online_cpus`
	 * * CPU usage % = `(cpu_delta / system_cpu_delta) * number_cpus * 100.0`
	 *
	 * @param data The data for the request.
	 * @param data.id ID or name of the container
	 * @param data.stream Stream the output. If false, the stats will be output once and then
	 * it will disconnect.
	 *
	 * @param data.oneShot Only get a single stat instead of waiting for 2 cycles. Must be used
	 * with `stream=false`.
	 *
	 * @returns unknown no error
	 */
	containerStats(data: ContainerStatsData): Promise<DockerResponse<ContainerStatsResponse>>;
	/**
	 * Resize a container TTY
	 * Resize the TTY for a container.
	 * @param data The data for the request.
	 * @param data.id ID or name of the container
	 * @param data.h Height of the TTY session in characters
	 * @param data.w Width of the TTY session in characters
	 * @returns unknown no error
	 */
	containerResize(data: ContainerResizeData): Promise<DockerResponse<ContainerResizeResponse>>;
	/**
	 * Start a container
	 * @param data The data for the request.
	 * @param data.id ID or name of the container
	 * @param data.detachKeys Override the key sequence for detaching a container. Format is a
	 * single character `[a-Z]` or `ctrl-<value>` where `<value>` is one
	 * of: `a-z`, `@`, `^`, `[`, `,` or `_`.
	 *
	 * @returns void no error
	 */
	containerStart(data: ContainerStartData): Promise<DockerResponse<ContainerStartResponse>>;
	/**
	 * Stop a container
	 * @param data The data for the request.
	 * @param data.id ID or name of the container
	 * @param data.signal Signal to send to the container as an integer or string (e.g. `SIGINT`).
	 *
	 * @param data.t Number of seconds to wait before killing the container
	 * @returns void no error
	 */
	containerStop(data: ContainerStopData): Promise<DockerResponse<ContainerStopResponse>>;
	/**
	 * Restart a container
	 * @param data The data for the request.
	 * @param data.id ID or name of the container
	 * @param data.signal Signal to send to the container as an integer or string (e.g. `SIGINT`).
	 *
	 * @param data.t Number of seconds to wait before killing the container
	 * @returns void no error
	 */
	containerRestart(data: ContainerRestartData): Promise<DockerResponse<ContainerRestartResponse>>;
	/**
	 * Kill a container
	 * Send a POSIX signal to a container, defaulting to killing to the
	 * container.
	 *
	 * @param data The data for the request.
	 * @param data.id ID or name of the container
	 * @param data.signal Signal to send to the container as an integer or string (e.g. `SIGINT`).
	 *
	 * @returns void no error
	 */
	containerKill(data: ContainerKillData): Promise<DockerResponse<ContainerKillResponse>>;
	/**
	 * Update a container
	 * Change various configuration options of a container without having to
	 * recreate it.
	 *
	 * @param data The data for the request.
	 * @param data.id ID or name of the container
	 * @param data.update
	 * @returns unknown The container has been updated.
	 */
	containerUpdate(data: ContainerUpdateData): Promise<DockerResponse<ContainerUpdateResponse>>;
	/**
	 * Rename a container
	 * @param data The data for the request.
	 * @param data.id ID or name of the container
	 * @param data.name New name for the container
	 * @returns void no error
	 */
	containerRename(data: ContainerRenameData): Promise<DockerResponse<ContainerRenameResponse>>;
	/**
	 * Pause a container
	 * Use the freezer cgroup to suspend all processes in a container.
	 *
	 * Traditionally, when suspending a process the `SIGSTOP` signal is used,
	 * which is observable by the process being suspended. With the freezer
	 * cgroup the process is unaware, and unable to capture, that it is being
	 * suspended, and subsequently resumed.
	 *
	 * @param data The data for the request.
	 * @param data.id ID or name of the container
	 * @returns void no error
	 */
	containerPause(data: ContainerPauseData): Promise<DockerResponse<ContainerPauseResponse>>;
	/**
	 * Unpause a container
	 * Resume a container which has been paused.
	 * @param data The data for the request.
	 * @param data.id ID or name of the container
	 * @returns void no error
	 */
	containerUnpause(data: ContainerUnpauseData): Promise<DockerResponse<ContainerUnpauseResponse>>;
	/**
	 * Attach to a container
	 * Attach to a container to read its output or send it input. You can attach
	 * to the same container multiple times and you can reattach to containers
	 * that have been detached.
	 *
	 * Either the `stream` or `logs` parameter must be `true` for this endpoint
	 * to do anything.
	 *
	 * See the [documentation for the `docker attach` command](https://docs.docker.com/engine/reference/commandline/attach/)
	 * for more details.
	 *
	 * ### Hijacking
	 *
	 * This endpoint hijacks the HTTP connection to transport `stdin`, `stdout`,
	 * and `stderr` on the same socket.
	 *
	 * This is the response from the daemon for an attach request:
	 *
	 * ```
	 * HTTP/1.1 200 OK
	 * Content-Type: application/vnd.docker.raw-stream
	 *
	 * [STREAM]
	 * ```
	 *
	 * After the headers and two new lines, the TCP connection can now be used
	 * for raw, bidirectional communication between the client and server.
	 *
	 * To hint potential proxies about connection hijacking, the Docker client
	 * can also optionally send connection upgrade headers.
	 *
	 * For example, the client sends this request to upgrade the connection:
	 *
	 * ```
	 * POST /containers/16253994b7c4/attach?stream=1&stdout=1 HTTP/1.1
	 * Upgrade: tcp
	 * Connection: Upgrade
	 * ```
	 *
	 * The Docker daemon will respond with a `101 UPGRADED` response, and will
	 * similarly follow with the raw stream:
	 *
	 * ```
	 * HTTP/1.1 101 UPGRADED
	 * Content-Type: application/vnd.docker.raw-stream
	 * Connection: Upgrade
	 * Upgrade: tcp
	 *
	 * [STREAM]
	 * ```
	 *
	 * ### Stream format
	 *
	 * When the TTY setting is disabled in [`POST /containers/create`](#operation/ContainerCreate),
	 * the HTTP Content-Type header is set to application/vnd.docker.multiplexed-stream
	 * and the stream over the hijacked connected is multiplexed to separate out
	 * `stdout` and `stderr`. The stream consists of a series of frames, each
	 * containing a header and a payload.
	 *
	 * The header contains the information which the stream writes (`stdout` or
	 * `stderr`). It also contains the size of the associated frame encoded in
	 * the last four bytes (`uint32`).
	 *
	 * It is encoded on the first eight bytes like this:
	 *
	 * ```go
	 * header := [8]byte{STREAM_TYPE, 0, 0, 0, SIZE1, SIZE2, SIZE3, SIZE4}
	 * ```
	 *
	 * `STREAM_TYPE` can be:
	 *
	 * - 0: `stdin` (is written on `stdout`)
	 * - 1: `stdout`
	 * - 2: `stderr`
	 *
	 * `SIZE1, SIZE2, SIZE3, SIZE4` are the four bytes of the `uint32` size
	 * encoded as big endian.
	 *
	 * Following the header is the payload, which is the specified number of
	 * bytes of `STREAM_TYPE`.
	 *
	 * The simplest way to implement this protocol is the following:
	 *
	 * 1. Read 8 bytes.
	 * 2. Choose `stdout` or `stderr` depending on the first byte.
	 * 3. Extract the frame size from the last four bytes.
	 * 4. Read the extracted size and output it on the correct output.
	 * 5. Goto 1.
	 *
	 * ### Stream format when using a TTY
	 *
	 * When the TTY setting is enabled in [`POST /containers/create`](#operation/ContainerCreate),
	 * the stream is not multiplexed. The data exchanged over the hijacked
	 * connection is simply the raw data from the process PTY and client's
	 * `stdin`.
	 *
	 * @param data The data for the request.
	 * @param data.id ID or name of the container
	 * @param data.detachKeys Override the key sequence for detaching a container.Format is a single
	 * character `[a-Z]` or `ctrl-<value>` where `<value>` is one of: `a-z`,
	 * `@`, `^`, `[`, `,` or `_`.
	 *
	 * @param data.logs Replay previous logs from the container.
	 *
	 * This is useful for attaching to a container that has started and you
	 * want to output everything since the container started.
	 *
	 * If `stream` is also enabled, once all the previous output has been
	 * returned, it will seamlessly transition into streaming current
	 * output.
	 *
	 * @param data.stream Stream attached streams from the time the request was made onwards.
	 *
	 * @param data.stdin Attach to `stdin`
	 * @param data.stdout Attach to `stdout`
	 * @param data.stderr Attach to `stderr`
	 * @returns unknown no error, no upgrade header found
	 */
	containerAttach(data: ContainerAttachData): Promise<DockerResponse<ContainerAttachResponse>>;
	/**
	 * Attach to a container via a websocket
	 * @param data The data for the request.
	 * @param data.id ID or name of the container
	 * @param data.detachKeys Override the key sequence for detaching a container.Format is a single
	 * character `[a-Z]` or `ctrl-<value>` where `<value>` is one of: `a-z`,
	 * `@`, `^`, `[`, `,`, or `_`.
	 *
	 * @param data.logs Return logs
	 * @param data.stream Return stream
	 * @param data.stdin Attach to `stdin`
	 * @param data.stdout Attach to `stdout`
	 * @param data.stderr Attach to `stderr`
	 * @returns unknown no error, no upgrade header found
	 */
	containerAttachWebsocket(data: ContainerAttachWebsocketData): Promise<DockerResponse<ContainerAttachWebsocketResponse>>;
	/**
	 * Wait for a container
	 * Block until a container stops, then returns the exit code.
	 * @param data The data for the request.
	 * @param data.id ID or name of the container
	 * @param data.condition Wait until a container state reaches the given condition.
	 *
	 * Defaults to `not-running` if omitted or empty.
	 *
	 * @returns ContainerWaitResponse The container has exit.
	 */
	containerWait(data: ContainerWaitData): Promise<DockerResponse<ContainerWaitResponse2>>;
	/**
	 * Remove a container
	 * @param data The data for the request.
	 * @param data.id ID or name of the container
	 * @param data.v Remove anonymous volumes associated with the container.
	 * @param data.force If the container is running, kill it before removing it.
	 * @param data.link Remove the specified link associated with the container.
	 * @returns void no error
	 */
	containerDelete(data: ContainerDeleteData): Promise<DockerResponse<ContainerDeleteResponse>>;
	/**
	 * Get information about files in a container
	 * A response header `X-Docker-Container-Path-Stat` is returned, containing
	 * a base64 - encoded JSON object with some filesystem header information
	 * about the path.
	 *
	 * @param data The data for the request.
	 * @param data.id ID or name of the container
	 * @param data.path Resource in the container’s filesystem to archive.
	 * @returns string no error
	 */
	containerArchiveInfo(data: ContainerArchiveInfoData): Promise<DockerResponse<ContainerArchiveInfoResponse>>;
	/**
	 * Get an archive of a filesystem resource in a container
	 * Get a tar archive of a resource in the filesystem of container id.
	 * @param data The data for the request.
	 * @param data.id ID or name of the container
	 * @param data.path Resource in the container’s filesystem to archive.
	 * @returns unknown no error
	 */
	containerArchive(data: ContainerArchiveData): Promise<DockerResponse<ContainerArchiveResponse>>;
	/**
	 * Extract an archive of files or folders to a directory in a container
	 * Upload a tar archive to be extracted to a path in the filesystem of container id.
	 * `path` parameter is asserted to be a directory. If it exists as a file, 400 error
	 * will be returned with message "not a directory".
	 *
	 * @param data The data for the request.
	 * @param data.id ID or name of the container
	 * @param data.path Path to a directory in the container to extract the archive’s contents into.
	 * @param data.inputStream The input stream must be a tar archive compressed with one of the
	 * following algorithms: `identity` (no compression), `gzip`, `bzip2`,
	 * or `xz`.
	 *
	 * @param data.noOverwriteDirNonDir If `1`, `true`, or `True` then it will be an error if unpacking the
	 * given content would cause an existing directory to be replaced with
	 * a non-directory and vice versa.
	 *
	 * @param data.copyUidgid If `1`, `true`, then it will copy UID/GID maps to the dest file or
	 * dir
	 *
	 * @returns unknown The content was extracted successfully
	 */
	putContainerArchive(data: PutContainerArchiveData): Promise<DockerResponse<PutContainerArchiveResponse>>;
	/**
	 * Delete stopped containers
	 * @param data The data for the request.
	 * @param data.filters Filters to process on the prune list, encoded as JSON (a `map[string][]string`).
	 *
	 * Available filters:
	 * - `until=<timestamp>` Prune containers created before this timestamp. The `<timestamp>` can be Unix timestamps, date formatted timestamps, or Go duration strings (e.g. `10m`, `1h30m`) computed relative to the daemon machine’s time.
	 * - `label` (`label=<key>`, `label=<key>=<value>`, `label!=<key>`, or `label!=<key>=<value>`) Prune containers with (or without, in case `label!=...` is used) the specified labels.
	 *
	 * @returns unknown No error
	 */
	containerPrune(data?: ContainerPruneData): Promise<DockerResponse<ContainerPruneResponse>>;
}
export declare class ImageService {
	private readonly client;
	constructor(client: DockerClient);
	/**
	 * List Images
	 * Returns a list of images on the server. Note that it uses a different, smaller representation of an image than inspecting a single image.
	 * @param data The data for the request.
	 * @param data.all Show all images. Only images from a final layer (no children) are shown by default.
	 * @param data.filters A JSON encoded value of the filters (a `map[string][]string`) to
	 * process on the images list.
	 *
	 * Available filters:
	 *
	 * - `before`=(`<image-name>[:<tag>]`,  `<image id>` or `<image@digest>`)
	 * - `dangling=true`
	 * - `label=key` or `label="key=value"` of an image label
	 * - `reference`=(`<image-name>[:<tag>]`)
	 * - `since`=(`<image-name>[:<tag>]`,  `<image id>` or `<image@digest>`)
	 * - `until=<timestamp>`
	 *
	 * @param data.sharedSize Compute and show shared size as a `SharedSize` field on each image.
	 * @param data.digests Show digest information as a `RepoDigests` field on each image.
	 * @returns ImageSummary Summary image data for the images matching the query
	 */
	imageList(data?: ImageListData): Promise<DockerResponse<ImageListResponse>>;
	/**
	 * Build an image
	 * Build an image from a tar archive with a `Dockerfile` in it.
	 *
	 * The `Dockerfile` specifies how the image is built from the tar archive. It is typically in the archive's root, but can be at a different path or have a different name by specifying the `dockerfile` parameter. [See the `Dockerfile` reference for more information](https://docs.docker.com/engine/reference/builder/).
	 *
	 * The Docker daemon performs a preliminary validation of the `Dockerfile` before starting the build, and returns an error if the syntax is incorrect. After that, each instruction is run one-by-one until the ID of the new image is output.
	 *
	 * The build is canceled if the client drops the connection by quitting or being killed.
	 *
	 * @param data The data for the request.
	 * @param data.inputStream A tar archive compressed with one of the following algorithms: identity (no compression), gzip, bzip2, xz.
	 * @param data.dockerfile Path within the build context to the `Dockerfile`. This is ignored if `remote` is specified and points to an external `Dockerfile`.
	 * @param data.t A name and optional tag to apply to the image in the `name:tag` format. If you omit the tag the default `latest` value is assumed. You can provide several `t` parameters.
	 * @param data.extrahosts Extra hosts to add to /etc/hosts
	 * @param data.remote A Git repository URI or HTTP/HTTPS context URI. If the URI points to a single text file, the file’s contents are placed into a file called `Dockerfile` and the image is built from that file. If the URI points to a tarball, the file is downloaded by the daemon and the contents therein used as the context for the build. If the URI points to a tarball and the `dockerfile` parameter is also specified, there must be a file with the corresponding path inside the tarball.
	 * @param data.q Suppress verbose build output.
	 * @param data.nocache Do not use the cache when building the image.
	 * @param data.cachefrom JSON array of images used for build cache resolution.
	 * @param data.pull Attempt to pull the image even if an older image exists locally.
	 * @param data.rm Remove intermediate containers after a successful build.
	 * @param data.forcerm Always remove intermediate containers, even upon failure.
	 * @param data.memory Set memory limit for build.
	 * @param data.memswap Total memory (memory + swap). Set as `-1` to disable swap.
	 * @param data.cpushares CPU shares (relative weight).
	 * @param data.cpusetcpus CPUs in which to allow execution (e.g., `0-3`, `0,1`).
	 * @param data.cpuperiod The length of a CPU period in microseconds.
	 * @param data.cpuquota Microseconds of CPU time that the container can get in a CPU period.
	 * @param data.buildargs JSON map of string pairs for build-time variables. Users pass these values at build-time. Docker uses the buildargs as the environment context for commands run via the `Dockerfile` RUN instruction, or for variable expansion in other `Dockerfile` instructions. This is not meant for passing secret values.
	 *
	 * For example, the build arg `FOO=bar` would become `{"FOO":"bar"}` in JSON. This would result in the query parameter `buildargs={"FOO":"bar"}`. Note that `{"FOO":"bar"}` should be URI component encoded.
	 *
	 * [Read more about the buildargs instruction.](https://docs.docker.com/engine/reference/builder/#arg)
	 *
	 * @param data.shmsize Size of `/dev/shm` in bytes. The size must be greater than 0. If omitted the system uses 64MB.
	 * @param data.squash Squash the resulting images layers into a single layer. *(Experimental release only.)*
	 * @param data.labels Arbitrary key/value labels to set on the image, as a JSON map of string pairs.
	 * @param data.networkmode Sets the networking mode for the run commands during build. Supported
	 * standard values are: `bridge`, `host`, `none`, and `container:<name|id>`.
	 * Any other value is taken as a custom network's name or ID to which this
	 * container should connect to.
	 *
	 * @param data.contentType
	 * @param data.xRegistryConfig This is a base64-encoded JSON object with auth configurations for multiple registries that a build may refer to.
	 *
	 * The key is a registry URL, and the value is an auth configuration object, [as described in the authentication section](#section/Authentication). For example:
	 *
	 * ```
	 * {
	 * "docker.example.com": {
	 * "username": "janedoe",
	 * "password": "hunter2"
	 * },
	 * "https://index.docker.io/v1/": {
	 * "username": "mobydock",
	 * "password": "conta1n3rize14"
	 * }
	 * }
	 * ```
	 *
	 * Only the registry domain name (and port if not the default 443) are required. However, for legacy reasons, the Docker Hub registry must be specified with both a `https://` prefix and a `/v1/` suffix even though Docker will prefer to use the v2 registry API.
	 *
	 * @param data.platform Platform in the format os[/arch[/variant]]
	 * @param data.target Target build stage
	 * @param data.outputs BuildKit output configuration
	 * @param data.version Version of the builder backend to use.
	 *
	 * - `1` is the first generation classic (deprecated) builder in the Docker daemon (default)
	 * - `2` is [BuildKit](https://github.com/moby/buildkit)
	 *
	 * @returns unknown no error
	 */
	imageBuild(data?: ImageBuildData): Promise<DockerResponse<ImageBuildResponse>>;
	/**
	 * Delete builder cache
	 * @param data The data for the request.
	 * @param data.keepStorage Amount of disk space in bytes to keep for cache
	 * @param data.all Remove all types of build cache
	 * @param data.filters A JSON encoded value of the filters (a `map[string][]string`) to
	 * process on the list of build cache objects.
	 *
	 * Available filters:
	 *
	 * - `until=<timestamp>` remove cache older than `<timestamp>`. The `<timestamp>` can be Unix timestamps, date formatted timestamps, or Go duration strings (e.g. `10m`, `1h30m`) computed relative to the daemon's local time.
	 * - `id=<id>`
	 * - `parent=<id>`
	 * - `type=<string>`
	 * - `description=<string>`
	 * - `inuse`
	 * - `shared`
	 * - `private`
	 *
	 * @returns unknown No error
	 */
	buildPrune(data?: BuildPruneData): Promise<DockerResponse<BuildPruneResponse>>;
	/**
	 * Create an image
	 * Pull or import an image.
	 * @param data The data for the request.
	 * @param data.fromImage Name of the image to pull. The name may include a tag or digest. This parameter may only be used when pulling an image. The pull is cancelled if the HTTP connection is closed.
	 * @param data.fromSrc Source to import. The value may be a URL from which the image can be retrieved or `-` to read the image from the request body. This parameter may only be used when importing an image.
	 * @param data.repo Repository name given to an image when it is imported. The repo may include a tag. This parameter may only be used when importing an image.
	 * @param data.tag Tag or digest. If empty when pulling an image, this causes all tags for the given image to be pulled.
	 * @param data.message Set commit message for imported image.
	 * @param data.inputImage Image content if the value `-` has been specified in fromSrc query parameter
	 * @param data.xRegistryAuth A base64url-encoded auth configuration.
	 *
	 * Refer to the [authentication section](#section/Authentication) for
	 * details.
	 *
	 * @param data.changes Apply `Dockerfile` instructions to the image that is created,
	 * for example: `changes=ENV DEBUG=true`.
	 * Note that `ENV DEBUG=true` should be URI component encoded.
	 *
	 * Supported `Dockerfile` instructions:
	 * `CMD`|`ENTRYPOINT`|`ENV`|`EXPOSE`|`ONBUILD`|`USER`|`VOLUME`|`WORKDIR`
	 *
	 * @param data.platform Platform in the format os[/arch[/variant]].
	 *
	 * When used in combination with the `fromImage` option, the daemon checks
	 * if the given image is present in the local image cache with the given
	 * OS and Architecture, and otherwise attempts to pull the image. If the
	 * option is not set, the host's native OS and Architecture are used.
	 * If the given image does not exist in the local image cache, the daemon
	 * attempts to pull the image with the host's native OS and Architecture.
	 * If the given image does exists in the local image cache, but its OS or
	 * architecture does not match, a warning is produced.
	 *
	 * When used with the `fromSrc` option to import an image from an archive,
	 * this option sets the platform information for the imported image. If
	 * the option is not set, the host's native OS and Architecture are used
	 * for the imported image.
	 *
	 * @returns unknown no error
	 */
	imageCreate(data?: ImageCreateData): Promise<DockerResponse<ImageCreateResponse>>;
	/**
	 * Inspect an image
	 * Return low-level information about an image.
	 * @param data The data for the request.
	 * @param data.name Image name or id
	 * @returns ImageInspect No error
	 */
	imageInspect(data: ImageInspectData): Promise<DockerResponse<ImageInspectResponse>>;
	/**
	 * Get the history of an image
	 * Return parent layers of an image.
	 * @param data The data for the request.
	 * @param data.name Image name or ID
	 * @returns unknown List of image layers
	 */
	imageHistory(data: ImageHistoryData): Promise<DockerResponse<ImageHistoryResponse>>;
	/**
	 * Push an image
	 * Push an image to a registry.
	 *
	 * If you wish to push an image on to a private registry, that image must
	 * already have a tag which references the registry. For example,
	 * `registry.example.com/myimage:latest`.
	 *
	 * The push is cancelled if the HTTP connection is closed.
	 *
	 * @param data The data for the request.
	 * @param data.name Image name or ID.
	 * @param data.xRegistryAuth A base64url-encoded auth configuration.
	 *
	 * Refer to the [authentication section](#section/Authentication) for
	 * details.
	 *
	 * @param data.tag The tag to associate with the image on the registry.
	 * @returns unknown No error
	 */
	imagePush(data: ImagePushData): Promise<DockerResponse<ImagePushResponse>>;
	/**
	 * Tag an image
	 * Tag an image so that it becomes part of a repository.
	 * @param data The data for the request.
	 * @param data.name Image name or ID to tag.
	 * @param data.repo The repository to tag in. For example, `someuser/someimage`.
	 * @param data.tag The name of the new tag.
	 * @returns unknown No error
	 */
	imageTag(data: ImageTagData): Promise<DockerResponse<ImageTagResponse>>;
	/**
	 * Remove an image
	 * Remove an image, along with any untagged parent images that were
	 * referenced by that image.
	 *
	 * Images can't be removed if they have descendant images, are being
	 * used by a running container or are being used by a build.
	 *
	 * @param data The data for the request.
	 * @param data.name Image name or ID
	 * @param data.force Remove the image even if it is being used by stopped containers or has other tags
	 * @param data.noprune Do not delete untagged parent images
	 * @returns ImageDeleteResponseItem The image was deleted successfully
	 */
	imageDelete(data: ImageDeleteData): Promise<DockerResponse<ImageDeleteResponse>>;
	/**
	 * Search images
	 * Search for an image on Docker Hub.
	 * @param data The data for the request.
	 * @param data.term Term to search
	 * @param data.limit Maximum number of results to return
	 * @param data.filters A JSON encoded value of the filters (a `map[string][]string`) to process on the images list. Available filters:
	 *
	 * - `is-official=(true|false)`
	 * - `stars=<number>` Matches images that has at least 'number' stars.
	 *
	 * @returns unknown No error
	 */
	imageSearch(data: ImageSearchData): Promise<DockerResponse<ImageSearchResponse>>;
	/**
	 * Delete unused images
	 * @param data The data for the request.
	 * @param data.filters Filters to process on the prune list, encoded as JSON (a `map[string][]string`). Available filters:
	 *
	 * - `dangling=<boolean>` When set to `true` (or `1`), prune only
	 * unused *and* untagged images. When set to `false`
	 * (or `0`), all unused images are pruned.
	 * - `until=<string>` Prune images created before this timestamp. The `<timestamp>` can be Unix timestamps, date formatted timestamps, or Go duration strings (e.g. `10m`, `1h30m`) computed relative to the daemon machine’s time.
	 * - `label` (`label=<key>`, `label=<key>=<value>`, `label!=<key>`, or `label!=<key>=<value>`) Prune images with (or without, in case `label!=...` is used) the specified labels.
	 *
	 * @returns unknown No error
	 */
	imagePrune(data?: ImagePruneData): Promise<DockerResponse<ImagePruneResponse>>;
	/**
	 * Create a new image from a container
	 * @param data The data for the request.
	 * @param data.containerConfig The container configuration
	 * @param data.container The ID or name of the container to commit
	 * @param data.repo Repository name for the created image
	 * @param data.tag Tag name for the create image
	 * @param data.comment Commit message
	 * @param data.author Author of the image (e.g., `John Hannibal Smith <hannibal@a-team.com>`)
	 * @param data.pause Whether to pause the container before committing
	 * @param data.changes `Dockerfile` instructions to apply while committing
	 * @returns IdResponse no error
	 */
	imageCommit(data?: ImageCommitData): Promise<DockerResponse<ImageCommitResponse>>;
	/**
	 * Export an image
	 * Get a tarball containing all images and metadata for a repository.
	 *
	 * If `name` is a specific name and tag (e.g. `ubuntu:latest`), then only that image (and its parents) are returned. If `name` is an image ID, similarly only that image (and its parents) are returned, but with the exclusion of the `repositories` file in the tarball, as there were no image names referenced.
	 *
	 * ### Image tarball format
	 *
	 * An image tarball contains one directory per image layer (named using its long ID), each containing these files:
	 *
	 * - `VERSION`: currently `1.0` - the file format version
	 * - `json`: detailed layer information, similar to `docker inspect layer_id`
	 * - `layer.tar`: A tarfile containing the filesystem changes in this layer
	 *
	 * The `layer.tar` file contains `aufs` style `.wh..wh.aufs` files and directories for storing attribute changes and deletions.
	 *
	 * If the tarball defines a repository, the tarball should also include a `repositories` file at the root that contains a list of repository and tag names mapped to layer IDs.
	 *
	 * ```json
	 * {
	 * "hello-world": {
	 * "latest": "565a9d68a73f6706862bfe8409a7f659776d4d60a8d096eb4a3cbce6999cc2a1"
	 * }
	 * }
	 * ```
	 *
	 * @param data The data for the request.
	 * @param data.name Image name or ID
	 * @returns binary no error
	 */
	imageGet(data: ImageGetData): Promise<DockerResponse<ImageGetResponse>>;
	/**
	 * Export several images
	 * Get a tarball containing all images and metadata for several image
	 * repositories.
	 *
	 * For each value of the `names` parameter: if it is a specific name and
	 * tag (e.g. `ubuntu:latest`), then only that image (and its parents) are
	 * returned; if it is an image ID, similarly only that image (and its parents)
	 * are returned and there would be no names referenced in the 'repositories'
	 * file for this image ID.
	 *
	 * For details on the format, see the [export image endpoint](#operation/ImageGet).
	 *
	 * @param data The data for the request.
	 * @param data.names Image names to filter by
	 * @returns binary no error
	 */
	imageGetAll(data?: ImageGetAllData): Promise<DockerResponse<ImageGetAllResponse>>;
	/**
	 * Import images
	 * Load a set of images and tags into a repository.
	 *
	 * For details on the format, see the [export image endpoint](#operation/ImageGet).
	 *
	 * @param data The data for the request.
	 * @param data.imagesTarball Tar archive containing images
	 * @param data.quiet Suppress progress details during load.
	 * @returns unknown no error
	 */
	imageLoad(data?: ImageLoadData): Promise<DockerResponse<ImageLoadResponse>>;
}
export declare class SystemService {
	private readonly client;
	constructor(client: DockerClient);
	/**
	 * Check auth configuration
	 * Validate credentials for a registry and, if available, get an identity
	 * token for accessing the registry without password.
	 *
	 * @param data The data for the request.
	 * @param data.authConfig Authentication to check
	 * @returns unknown An identity token was generated successfully.
	 * @returns void No error
	 */
	systemAuth(data?: SystemAuthData): Promise<DockerResponse<SystemAuthResponse>>;
	/**
	 * Get system information
	 * @returns SystemInfo No error
	 */
	systemInfo(): Promise<DockerResponse<SystemInfoResponse>>;
	/**
	 * Get version
	 * Returns the version of Docker that is running and various information about the system that Docker is running on.
	 * @returns SystemVersion no error
	 */
	systemVersion(): Promise<DockerResponse<SystemVersionResponse>>;
	/**
	 * Ping
	 * This is a dummy endpoint you can use to test if the server is accessible.
	 * @returns string no error
	 */
	systemPing(): Promise<DockerResponse<SystemPingResponse>>;
	/**
	 * Ping
	 * This is a dummy endpoint you can use to test if the server is accessible.
	 * @returns string no error
	 */
	systemPingHead(): Promise<DockerResponse<SystemPingHeadResponse>>;
	/**
	 * Monitor events
	 * Stream real-time events from the server.
	 *
	 * Various objects within Docker report events when something happens to them.
	 *
	 * Containers report these events: `attach`, `commit`, `copy`, `create`, `destroy`, `detach`, `die`, `exec_create`, `exec_detach`, `exec_start`, `exec_die`, `export`, `health_status`, `kill`, `oom`, `pause`, `rename`, `resize`, `restart`, `start`, `stop`, `top`, `unpause`, `update`, and `prune`
	 *
	 * Images report these events: `delete`, `import`, `load`, `pull`, `push`, `save`, `tag`, `untag`, and `prune`
	 *
	 * Volumes report these events: `create`, `mount`, `unmount`, `destroy`, and `prune`
	 *
	 * Networks report these events: `create`, `connect`, `disconnect`, `destroy`, `update`, `remove`, and `prune`
	 *
	 * The Docker daemon reports these events: `reload`
	 *
	 * Services report these events: `create`, `update`, and `remove`
	 *
	 * Nodes report these events: `create`, `update`, and `remove`
	 *
	 * Secrets report these events: `create`, `update`, and `remove`
	 *
	 * Configs report these events: `create`, `update`, and `remove`
	 *
	 * The Builder reports `prune` events
	 *
	 * @param data The data for the request.
	 * @param data.since Show events created since this timestamp then stream new events.
	 * @param data.until Show events created until this timestamp then stop streaming.
	 * @param data.filters A JSON encoded value of filters (a `map[string][]string`) to process on the event list. Available filters:
	 *
	 * - `config=<string>` config name or ID
	 * - `container=<string>` container name or ID
	 * - `daemon=<string>` daemon name or ID
	 * - `event=<string>` event type
	 * - `image=<string>` image name or ID
	 * - `label=<string>` image or container label
	 * - `network=<string>` network name or ID
	 * - `node=<string>` node ID
	 * - `plugin`=<string> plugin name or ID
	 * - `scope`=<string> local or swarm
	 * - `secret=<string>` secret name or ID
	 * - `service=<string>` service name or ID
	 * - `type=<string>` object to filter by, one of `container`, `image`, `volume`, `network`, `daemon`, `plugin`, `node`, `service`, `secret` or `config`
	 * - `volume=<string>` volume name
	 *
	 * @returns EventMessage no error
	 */
	systemEvents(data?: SystemEventsData): Promise<DockerResponse<SystemEventsResponse>>;
	/**
	 * Get data usage information
	 * @param data The data for the request.
	 * @param data.type Object types, for which to compute and return data.
	 *
	 * @returns unknown no error
	 */
	systemDataUsage(data?: SystemDataUsageData): Promise<DockerResponse<SystemDataUsageResponse>>;
}
export declare class ExecService {
	private readonly client;
	constructor(client: DockerClient);
	/**
	 * Create an exec instance
	 * Run a command inside a running container.
	 * @param data The data for the request.
	 * @param data.execConfig Exec configuration
	 * @param data.id ID or name of container
	 * @returns IdResponse no error
	 */
	containerExec(data: ContainerExecData): Promise<DockerResponse<ContainerExecResponse>>;
	/**
	 * Start an exec instance
	 * Starts a previously set up exec instance. If detach is true, this endpoint
	 * returns immediately after starting the command. Otherwise, it sets up an
	 * interactive session with the command.
	 *
	 * @param data The data for the request.
	 * @param data.id Exec instance ID
	 * @param data.execStartConfig
	 * @returns unknown No error
	 */
	execStart(data: ExecStartData): Promise<DockerResponse<ExecStartResponse>>;
	/**
	 * Resize an exec instance
	 * Resize the TTY session used by an exec instance. This endpoint only works
	 * if `tty` was specified as part of creating and starting the exec instance.
	 *
	 * @param data The data for the request.
	 * @param data.id Exec instance ID
	 * @param data.h Height of the TTY session in characters
	 * @param data.w Width of the TTY session in characters
	 * @returns unknown No error
	 */
	execResize(data: ExecResizeData): Promise<DockerResponse<ExecResizeResponse>>;
	/**
	 * Inspect an exec instance
	 * Return low-level information about an exec instance.
	 * @param data The data for the request.
	 * @param data.id Exec instance ID
	 * @returns unknown No error
	 */
	execInspect(data: ExecInspectData): Promise<DockerResponse<ExecInspectResponse>>;
}
export declare class VolumeService {
	private readonly client;
	constructor(client: DockerClient);
	/**
	 * List volumes
	 * @param data The data for the request.
	 * @param data.filters JSON encoded value of the filters (a `map[string][]string`) to
	 * process on the volumes list. Available filters:
	 *
	 * - `dangling=<boolean>` When set to `true` (or `1`), returns all
	 * volumes that are not in use by a container. When set to `false`
	 * (or `0`), only volumes that are in use by one or more
	 * containers are returned.
	 * - `driver=<volume-driver-name>` Matches volumes based on their driver.
	 * - `label=<key>` or `label=<key>:<value>` Matches volumes based on
	 * the presence of a `label` alone or a `label` and a value.
	 * - `name=<volume-name>` Matches all or part of a volume name.
	 *
	 * @returns VolumeListResponse Summary volume data that matches the query
	 */
	volumeList(data?: VolumeListData): Promise<DockerResponse<VolumeListResponse2>>;
	/**
	 * Create a volume
	 * @param data The data for the request.
	 * @param data.volumeConfig Volume configuration
	 * @returns Volume The volume was created successfully
	 */
	volumeCreate(data: VolumeCreateData): Promise<DockerResponse<VolumeCreateResponse>>;
	/**
	 * Inspect a volume
	 * @param data The data for the request.
	 * @param data.name Volume name or ID
	 * @returns Volume No error
	 */
	volumeInspect(data: VolumeInspectData): Promise<DockerResponse<VolumeInspectResponse>>;
	/**
	 * "Update a volume. Valid only for Swarm cluster volumes"
	 *
	 * @param data The data for the request.
	 * @param data.name The name or ID of the volume
	 * @param data.version The version number of the volume being updated. This is required to
	 * avoid conflicting writes. Found in the volume's `ClusterVolume`
	 * field.
	 *
	 * @param data.body The spec of the volume to update. Currently, only Availability may
	 * change. All other fields must remain unchanged.
	 *
	 * @returns unknown no error
	 */
	volumeUpdate(data: VolumeUpdateData): Promise<DockerResponse<VolumeUpdateResponse>>;
	/**
	 * Remove a volume
	 * Instruct the driver to remove the volume.
	 * @param data The data for the request.
	 * @param data.name Volume name or ID
	 * @param data.force Force the removal of the volume
	 * @returns void The volume was removed
	 */
	volumeDelete(data: VolumeDeleteData): Promise<DockerResponse<VolumeDeleteResponse>>;
	/**
	 * Delete unused volumes
	 * @param data The data for the request.
	 * @param data.filters Filters to process on the prune list, encoded as JSON (a `map[string][]string`).
	 *
	 * Available filters:
	 * - `label` (`label=<key>`, `label=<key>=<value>`, `label!=<key>`, or `label!=<key>=<value>`) Prune volumes with (or without, in case `label!=...` is used) the specified labels.
	 * - `all` (`all=true`) - Consider all (local) volumes for pruning and not just anonymous volumes.
	 *
	 * @returns unknown No error
	 */
	volumePrune(data?: VolumePruneData): Promise<DockerResponse<VolumePruneResponse>>;
}
export declare class NetworkService {
	private readonly client;
	constructor(client: DockerClient);
	/**
	 * List networks
	 * Returns a list of networks. For details on the format, see the
	 * [network inspect endpoint](#operation/NetworkInspect).
	 *
	 * Note that it uses a different, smaller representation of a network than
	 * inspecting a single network. For example, the list of containers attached
	 * to the network is not propagated in API versions 1.28 and up.
	 *
	 * @param data The data for the request.
	 * @param data.filters JSON encoded value of the filters (a `map[string][]string`) to process
	 * on the networks list.
	 *
	 * Available filters:
	 *
	 * - `dangling=<boolean>` When set to `true` (or `1`), returns all
	 * networks that are not in use by a container. When set to `false`
	 * (or `0`), only networks that are in use by one or more
	 * containers are returned.
	 * - `driver=<driver-name>` Matches a network's driver.
	 * - `id=<network-id>` Matches all or part of a network ID.
	 * - `label=<key>` or `label=<key>=<value>` of a network label.
	 * - `name=<network-name>` Matches all or part of a network name.
	 * - `scope=["swarm"|"global"|"local"]` Filters networks by scope (`swarm`, `global`, or `local`).
	 * - `type=["custom"|"builtin"]` Filters networks by type. The `custom` keyword returns all user-defined networks.
	 *
	 * @returns Network No error
	 */
	networkList(data?: NetworkListData): Promise<DockerResponse<NetworkListResponse>>;
	/**
	 * Inspect a network
	 * @param data The data for the request.
	 * @param data.id Network ID or name
	 * @param data.verbose Detailed inspect output for troubleshooting
	 * @param data.scope Filter the network by scope (swarm, global, or local)
	 * @returns Network No error
	 */
	networkInspect(data: NetworkInspectData): Promise<DockerResponse<NetworkInspectResponse>>;
	/**
	 * Remove a network
	 * @param data The data for the request.
	 * @param data.id Network ID or name
	 * @returns void No error
	 */
	networkDelete(data: NetworkDeleteData): Promise<DockerResponse<NetworkDeleteResponse>>;
	/**
	 * Create a network
	 * @param data The data for the request.
	 * @param data.networkConfig Network configuration
	 * @returns unknown No error
	 */
	networkCreate(data: NetworkCreateData): Promise<DockerResponse<NetworkCreateResponse>>;
	/**
	 * Connect a container to a network
	 * The network must be either a local-scoped network or a swarm-scoped network with the `attachable` option set. A network cannot be re-attached to a running container
	 * @param data The data for the request.
	 * @param data.id Network ID or name
	 * @param data.container
	 * @returns unknown No error
	 */
	networkConnect(data: NetworkConnectData): Promise<DockerResponse<NetworkConnectResponse>>;
	/**
	 * Disconnect a container from a network
	 * @param data The data for the request.
	 * @param data.id Network ID or name
	 * @param data.container
	 * @returns unknown No error
	 */
	networkDisconnect(data: NetworkDisconnectData): Promise<DockerResponse<NetworkDisconnectResponse>>;
	/**
	 * Delete unused networks
	 * @param data The data for the request.
	 * @param data.filters Filters to process on the prune list, encoded as JSON (a `map[string][]string`).
	 *
	 * Available filters:
	 * - `until=<timestamp>` Prune networks created before this timestamp. The `<timestamp>` can be Unix timestamps, date formatted timestamps, or Go duration strings (e.g. `10m`, `1h30m`) computed relative to the daemon machine’s time.
	 * - `label` (`label=<key>`, `label=<key>=<value>`, `label!=<key>`, or `label!=<key>=<value>`) Prune networks with (or without, in case `label!=...` is used) the specified labels.
	 *
	 * @returns unknown No error
	 */
	networkPrune(data?: NetworkPruneData): Promise<DockerResponse<NetworkPruneResponse>>;
}
export declare class PluginService {
	private readonly client;
	constructor(client: DockerClient);
	/**
	 * List plugins
	 * Returns information about installed plugins.
	 * @param data The data for the request.
	 * @param data.filters A JSON encoded value of the filters (a `map[string][]string`) to
	 * process on the plugin list.
	 *
	 * Available filters:
	 *
	 * - `capability=<capability name>`
	 * - `enable=<true>|<false>`
	 *
	 * @returns Plugin No error
	 */
	pluginList(data?: PluginListData): Promise<DockerResponse<PluginListResponse>>;
	/**
	 * Get plugin privileges
	 * @param data The data for the request.
	 * @param data.remote The name of the plugin. The `:latest` tag is optional, and is the
	 * default if omitted.
	 *
	 * @returns PluginPrivilege no error
	 */
	getPluginPrivileges(data: GetPluginPrivilegesData): Promise<DockerResponse<GetPluginPrivilegesResponse>>;
	/**
	 * Install a plugin
	 * Pulls and installs a plugin. After the plugin is installed, it can be
	 * enabled using the [`POST /plugins/{name}/enable` endpoint](#operation/PostPluginsEnable).
	 *
	 * @param data The data for the request.
	 * @param data.remote Remote reference for plugin to install.
	 *
	 * The `:latest` tag is optional, and is used as the default if omitted.
	 *
	 * @param data.name Local name for the pulled plugin.
	 *
	 * The `:latest` tag is optional, and is used as the default if omitted.
	 *
	 * @param data.xRegistryAuth A base64url-encoded auth configuration to use when pulling a plugin
	 * from a registry.
	 *
	 * Refer to the [authentication section](#section/Authentication) for
	 * details.
	 *
	 * @param data.body
	 * @returns void no error
	 */
	pluginPull(data: PluginPullData): Promise<DockerResponse<PluginPullResponse>>;
	/**
	 * Inspect a plugin
	 * @param data The data for the request.
	 * @param data.name The name of the plugin. The `:latest` tag is optional, and is the
	 * default if omitted.
	 *
	 * @returns Plugin no error
	 */
	pluginInspect(data: PluginInspectData): Promise<DockerResponse<PluginInspectResponse>>;
	/**
	 * Remove a plugin
	 * @param data The data for the request.
	 * @param data.name The name of the plugin. The `:latest` tag is optional, and is the
	 * default if omitted.
	 *
	 * @param data.force Disable the plugin before removing. This may result in issues if the
	 * plugin is in use by a container.
	 *
	 * @returns Plugin no error
	 */
	pluginDelete(data: PluginDeleteData): Promise<DockerResponse<PluginDeleteResponse>>;
	/**
	 * Enable a plugin
	 * @param data The data for the request.
	 * @param data.name The name of the plugin. The `:latest` tag is optional, and is the
	 * default if omitted.
	 *
	 * @param data.timeout Set the HTTP client timeout (in seconds)
	 * @returns unknown no error
	 */
	pluginEnable(data: PluginEnableData): Promise<DockerResponse<PluginEnableResponse>>;
	/**
	 * Disable a plugin
	 * @param data The data for the request.
	 * @param data.name The name of the plugin. The `:latest` tag is optional, and is the
	 * default if omitted.
	 *
	 * @param data.force Force disable a plugin even if still in use.
	 *
	 * @returns unknown no error
	 */
	pluginDisable(data: PluginDisableData): Promise<DockerResponse<PluginDisableResponse>>;
	/**
	 * Upgrade a plugin
	 * @param data The data for the request.
	 * @param data.name The name of the plugin. The `:latest` tag is optional, and is the
	 * default if omitted.
	 *
	 * @param data.remote Remote reference to upgrade to.
	 *
	 * The `:latest` tag is optional, and is used as the default if omitted.
	 *
	 * @param data.xRegistryAuth A base64url-encoded auth configuration to use when pulling a plugin
	 * from a registry.
	 *
	 * Refer to the [authentication section](#section/Authentication) for
	 * details.
	 *
	 * @param data.body
	 * @returns void no error
	 */
	pluginUpgrade(data: PluginUpgradeData): Promise<DockerResponse<PluginUpgradeResponse>>;
	/**
	 * Create a plugin
	 * @param data The data for the request.
	 * @param data.name The name of the plugin. The `:latest` tag is optional, and is the
	 * default if omitted.
	 *
	 * @param data.tarContext Path to tar containing plugin rootfs and manifest
	 * @returns void no error
	 */
	pluginCreate(data: PluginCreateData): Promise<DockerResponse<PluginCreateResponse>>;
	/**
	 * Push a plugin
	 * Push a plugin to the registry.
	 *
	 * @param data The data for the request.
	 * @param data.name The name of the plugin. The `:latest` tag is optional, and is the
	 * default if omitted.
	 *
	 * @returns unknown no error
	 */
	pluginPush(data: PluginPushData): Promise<DockerResponse<PluginPushResponse>>;
	/**
	 * Configure a plugin
	 * @param data The data for the request.
	 * @param data.name The name of the plugin. The `:latest` tag is optional, and is the
	 * default if omitted.
	 *
	 * @param data.body
	 * @returns void No error
	 */
	pluginSet(data: PluginSetData): Promise<DockerResponse<PluginSetResponse>>;
}
export declare class NodeService {
	private readonly client;
	constructor(client: DockerClient);
	/**
	 * List nodes
	 * @param data The data for the request.
	 * @param data.filters Filters to process on the nodes list, encoded as JSON (a `map[string][]string`).
	 *
	 * Available filters:
	 * - `id=<node id>`
	 * - `label=<engine label>`
	 * - `membership=`(`accepted`|`pending`)`
	 * - `name=<node name>`
	 * - `node.label=<node label>`
	 * - `role=`(`manager`|`worker`)`
	 *
	 * @returns Node no error
	 */
	nodeList(data?: NodeListData): Promise<DockerResponse<NodeListResponse>>;
	/**
	 * Inspect a node
	 * @param data The data for the request.
	 * @param data.id The ID or name of the node
	 * @returns Node no error
	 */
	nodeInspect(data: NodeInspectData): Promise<DockerResponse<NodeInspectResponse>>;
	/**
	 * Delete a node
	 * @param data The data for the request.
	 * @param data.id The ID or name of the node
	 * @param data.force Force remove a node from the swarm
	 * @returns unknown no error
	 */
	nodeDelete(data: NodeDeleteData): Promise<DockerResponse<NodeDeleteResponse>>;
	/**
	 * Update a node
	 * @param data The data for the request.
	 * @param data.id The ID of the node
	 * @param data.version The version number of the node object being updated. This is required
	 * to avoid conflicting writes.
	 *
	 * @param data.body
	 * @returns unknown no error
	 */
	nodeUpdate(data: NodeUpdateData): Promise<DockerResponse<NodeUpdateResponse>>;
}
export declare class SwarmService {
	private readonly client;
	constructor(client: DockerClient);
	/**
	 * Inspect swarm
	 * @returns Swarm no error
	 */
	swarmInspect(): Promise<DockerResponse<SwarmInspectResponse>>;
	/**
	 * Initialize a new swarm
	 * @param data The data for the request.
	 * @param data.body
	 * @returns string no error
	 */
	swarmInit(data: SwarmInitData): Promise<DockerResponse<SwarmInitResponse>>;
	/**
	 * Join an existing swarm
	 * @param data The data for the request.
	 * @param data.body
	 * @returns unknown no error
	 */
	swarmJoin(data: SwarmJoinData): Promise<DockerResponse<SwarmJoinResponse>>;
	/**
	 * Leave a swarm
	 * @param data The data for the request.
	 * @param data.force Force leave swarm, even if this is the last manager or that it will
	 * break the cluster.
	 *
	 * @returns unknown no error
	 */
	swarmLeave(data?: SwarmLeaveData): Promise<DockerResponse<SwarmLeaveResponse>>;
	/**
	 * Update a swarm
	 * @param data The data for the request.
	 * @param data.body
	 * @param data.version The version number of the swarm object being updated. This is
	 * required to avoid conflicting writes.
	 *
	 * @param data.rotateWorkerToken Rotate the worker join token.
	 * @param data.rotateManagerToken Rotate the manager join token.
	 * @param data.rotateManagerUnlockKey Rotate the manager unlock key.
	 * @returns unknown no error
	 */
	swarmUpdate(data: SwarmUpdateData): Promise<DockerResponse<SwarmUpdateResponse>>;
	/**
	 * Get the unlock key
	 * @returns unknown no error
	 */
	swarmUnlockkey(): Promise<DockerResponse<SwarmUnlockkeyResponse>>;
	/**
	 * Unlock a locked manager
	 * @param data The data for the request.
	 * @param data.body
	 * @returns unknown no error
	 */
	swarmUnlock(data: SwarmUnlockData): Promise<DockerResponse<SwarmUnlockResponse>>;
}
export declare class ServiceService {
	private readonly client;
	constructor(client: DockerClient);
	/**
	 * List services
	 * @param data The data for the request.
	 * @param data.filters A JSON encoded value of the filters (a `map[string][]string`) to
	 * process on the services list.
	 *
	 * Available filters:
	 *
	 * - `id=<service id>`
	 * - `label=<service label>`
	 * - `mode=["replicated"|"global"]`
	 * - `name=<service name>`
	 *
	 * @param data.status Include service status, with count of running and desired tasks.
	 *
	 * @returns Service no error
	 */
	serviceList(data?: ServiceListData): Promise<DockerResponse<ServiceListResponse>>;
	/**
	 * Create a service
	 * @param data The data for the request.
	 * @param data.body
	 * @param data.xRegistryAuth A base64url-encoded auth configuration for pulling from private
	 * registries.
	 *
	 * Refer to the [authentication section](#section/Authentication) for
	 * details.
	 *
	 * @returns ServiceCreateResponse no error
	 */
	serviceCreate(data: ServiceCreateData): Promise<DockerResponse<ServiceCreateResponse2>>;
	/**
	 * Inspect a service
	 * @param data The data for the request.
	 * @param data.id ID or name of service.
	 * @param data.insertDefaults Fill empty fields with default values.
	 * @returns Service no error
	 */
	serviceInspect(data: ServiceInspectData): Promise<DockerResponse<ServiceInspectResponse>>;
	/**
	 * Delete a service
	 * @param data The data for the request.
	 * @param data.id ID or name of service.
	 * @returns unknown no error
	 */
	serviceDelete(data: ServiceDeleteData): Promise<DockerResponse<ServiceDeleteResponse>>;
	/**
	 * Update a service
	 * @param data The data for the request.
	 * @param data.id ID or name of service.
	 * @param data.body
	 * @param data.version The version number of the service object being updated. This is
	 * required to avoid conflicting writes.
	 * This version number should be the value as currently set on the
	 * service *before* the update. You can find the current version by
	 * calling `GET /services/{id}`
	 *
	 * @param data.registryAuthFrom If the `X-Registry-Auth` header is not specified, this parameter
	 * indicates where to find registry authorization credentials.
	 *
	 * @param data.rollback Set to this parameter to `previous` to cause a server-side rollback
	 * to the previous service spec. The supplied spec will be ignored in
	 * this case.
	 *
	 * @param data.xRegistryAuth A base64url-encoded auth configuration for pulling from private
	 * registries.
	 *
	 * Refer to the [authentication section](#section/Authentication) for
	 * details.
	 *
	 * @returns ServiceUpdateResponse no error
	 */
	serviceUpdate(data: ServiceUpdateData): Promise<DockerResponse<ServiceUpdateResponse2>>;
	/**
	 * Get service logs
	 * Get `stdout` and `stderr` logs from a service. See also
	 * [`/containers/{id}/logs`](#operation/ContainerLogs).
	 *
	 * **Note**: This endpoint works only for services with the `local`,
	 * `json-file` or `journald` logging drivers.
	 *
	 * @param data The data for the request.
	 * @param data.id ID or name of the service
	 * @param data.details Show service context and extra details provided to logs.
	 * @param data.follow Keep connection after returning logs.
	 * @param data.stdout Return logs from `stdout`
	 * @param data.stderr Return logs from `stderr`
	 * @param data.since Only return logs since this time, as a UNIX timestamp
	 * @param data.timestamps Add timestamps to every log line
	 * @param data.tail Only return this number of log lines from the end of the logs.
	 * Specify as an integer or `all` to output all log lines.
	 *
	 * @returns binary logs returned as a stream in response body
	 */
	serviceLogs(data: ServiceLogsData): Promise<DockerResponse<ServiceLogsResponse>>;
}
export declare class TaskService {
	private readonly client;
	constructor(client: DockerClient);
	/**
	 * List tasks
	 * @param data The data for the request.
	 * @param data.filters A JSON encoded value of the filters (a `map[string][]string`) to
	 * process on the tasks list.
	 *
	 * Available filters:
	 *
	 * - `desired-state=(running | shutdown | accepted)`
	 * - `id=<task id>`
	 * - `label=key` or `label="key=value"`
	 * - `name=<task name>`
	 * - `node=<node id or name>`
	 * - `service=<service name>`
	 *
	 * @returns Task no error
	 */
	taskList(data?: TaskListData): Promise<DockerResponse<TaskListResponse>>;
	/**
	 * Inspect a task
	 * @param data The data for the request.
	 * @param data.id ID of the task
	 * @returns Task no error
	 */
	taskInspect(data: TaskInspectData): Promise<DockerResponse<TaskInspectResponse>>;
	/**
	 * Get task logs
	 * Get `stdout` and `stderr` logs from a task.
	 * See also [`/containers/{id}/logs`](#operation/ContainerLogs).
	 *
	 * **Note**: This endpoint works only for services with the `local`,
	 * `json-file` or `journald` logging drivers.
	 *
	 * @param data The data for the request.
	 * @param data.id ID of the task
	 * @param data.details Show task context and extra details provided to logs.
	 * @param data.follow Keep connection after returning logs.
	 * @param data.stdout Return logs from `stdout`
	 * @param data.stderr Return logs from `stderr`
	 * @param data.since Only return logs since this time, as a UNIX timestamp
	 * @param data.timestamps Add timestamps to every log line
	 * @param data.tail Only return this number of log lines from the end of the logs.
	 * Specify as an integer or `all` to output all log lines.
	 *
	 * @returns binary logs returned as a stream in response body
	 */
	taskLogs(data: TaskLogsData): Promise<DockerResponse<TaskLogsResponse>>;
}
export declare class SecretService {
	private readonly client;
	constructor(client: DockerClient);
	/**
	 * List secrets
	 * @param data The data for the request.
	 * @param data.filters A JSON encoded value of the filters (a `map[string][]string`) to
	 * process on the secrets list.
	 *
	 * Available filters:
	 *
	 * - `id=<secret id>`
	 * - `label=<key> or label=<key>=value`
	 * - `name=<secret name>`
	 * - `names=<secret name>`
	 *
	 * @returns Secret no error
	 */
	secretList(data?: SecretListData): Promise<DockerResponse<SecretListResponse>>;
	/**
	 * Create a secret
	 * @param data The data for the request.
	 * @param data.body
	 * @returns IdResponse no error
	 */
	secretCreate(data?: SecretCreateData): Promise<DockerResponse<SecretCreateResponse>>;
	/**
	 * Inspect a secret
	 * @param data The data for the request.
	 * @param data.id ID of the secret
	 * @returns Secret no error
	 */
	secretInspect(data: SecretInspectData): Promise<DockerResponse<SecretInspectResponse>>;
	/**
	 * Delete a secret
	 * @param data The data for the request.
	 * @param data.id ID of the secret
	 * @returns void no error
	 */
	secretDelete(data: SecretDeleteData): Promise<DockerResponse<SecretDeleteResponse>>;
	/**
	 * Update a Secret
	 * @param data The data for the request.
	 * @param data.id The ID or name of the secret
	 * @param data.version The version number of the secret object being updated. This is
	 * required to avoid conflicting writes.
	 *
	 * @param data.body The spec of the secret to update. Currently, only the Labels field
	 * can be updated. All other fields must remain unchanged from the
	 * [SecretInspect endpoint](#operation/SecretInspect) response values.
	 *
	 * @returns unknown no error
	 */
	secretUpdate(data: SecretUpdateData): Promise<DockerResponse<SecretUpdateResponse>>;
}
export declare class ConfigService {
	private readonly client;
	constructor(client: DockerClient);
	/**
	 * List configs
	 * @param data The data for the request.
	 * @param data.filters A JSON encoded value of the filters (a `map[string][]string`) to
	 * process on the configs list.
	 *
	 * Available filters:
	 *
	 * - `id=<config id>`
	 * - `label=<key> or label=<key>=value`
	 * - `name=<config name>`
	 * - `names=<config name>`
	 *
	 * @returns Config no error
	 */
	configList(data?: ConfigListData): Promise<DockerResponse<ConfigListResponse>>;
	/**
	 * Create a config
	 * @param data The data for the request.
	 * @param data.body
	 * @returns IdResponse no error
	 */
	configCreate(data?: ConfigCreateData): Promise<DockerResponse<ConfigCreateResponse>>;
	/**
	 * Inspect a config
	 * @param data The data for the request.
	 * @param data.id ID of the config
	 * @returns Config no error
	 */
	configInspect(data: ConfigInspectData): Promise<DockerResponse<ConfigInspectResponse>>;
	/**
	 * Delete a config
	 * @param data The data for the request.
	 * @param data.id ID of the config
	 * @returns void no error
	 */
	configDelete(data: ConfigDeleteData): Promise<DockerResponse<ConfigDeleteResponse>>;
	/**
	 * Update a Config
	 * @param data The data for the request.
	 * @param data.id The ID or name of the config
	 * @param data.version The version number of the config object being updated. This is
	 * required to avoid conflicting writes.
	 *
	 * @param data.body The spec of the config to update. Currently, only the Labels field
	 * can be updated. All other fields must remain unchanged from the
	 * [ConfigInspect endpoint](#operation/ConfigInspect) response values.
	 *
	 * @returns unknown no error
	 */
	configUpdate(data: ConfigUpdateData): Promise<DockerResponse<ConfigUpdateResponse>>;
}
export declare class DistributionService {
	private readonly client;
	constructor(client: DockerClient);
	/**
	 * Get image information from the registry
	 * Return image digest and platform information by contacting the registry.
	 *
	 * @param data The data for the request.
	 * @param data.name Image name or id
	 * @returns DistributionInspect descriptor and platform information
	 */
	distributionInspect(data: DistributionInspectData): Promise<DockerResponse<DistributionInspectResponse>>;
}
export declare class SessionService {
	private readonly client;
	constructor(client: DockerClient);
	/**
	 * Initialize interactive session
	 * Start a new interactive session with a server. Session allows server to
	 * call back to the client for advanced capabilities.
	 *
	 * ### Hijacking
	 *
	 * This endpoint hijacks the HTTP connection to HTTP2 transport that allows
	 * the client to expose gPRC services on that connection.
	 *
	 * For example, the client sends this request to upgrade the connection:
	 *
	 * ```
	 * POST /session HTTP/1.1
	 * Upgrade: h2c
	 * Connection: Upgrade
	 * ```
	 *
	 * The Docker daemon responds with a `101 UPGRADED` response follow with
	 * the raw stream:
	 *
	 * ```
	 * HTTP/1.1 101 UPGRADED
	 * Connection: Upgrade
	 * Upgrade: h2c
	 * ```
	 *
	 */
	session(): Promise<DockerResponse<void>>;
}
export declare class Docker {
	containers: ContainerService;
	images: ImageService;
	services: ServiceService;
	system: SystemService;
	exec: ExecService;
	volume: VolumeService;
	network: NetworkService;
	plugin: PluginService;
	node: NodeService;
	swarm: SwarmService;
	task: TaskService;
	secret: SecretService;
	config: ConfigService;
	constructor(connectSetting: ConnectOptions);
}

export {
	Docker as default,
	Node$1 as Node,
	Plugin$1 as Plugin,
};

export {};
